@@ -1,22 +1,26 @@
 OC.L10N.register(
     "comments",
     {
-    "<strong>Comments</strong> for files" : "<strong>Commentaires</strong> pour les fichiers",
-    "%1$s commented" : "%1$s a commenté",
-    "%1$s commented on %2$s" : "%1$s a commenté %2$s",
-    "Comments" : "Commentaires",
     "Type in a new comment..." : "Écrire un nouveau commentaire...",
     "Delete comment" : "Supprimer le commentaire",
     "Post" : "Poster",
     "Cancel" : "Annuler",
     "Edit comment" : "Modifier le commentaire",
     "[Deleted user]" : "[Utilisateur supprimé]",
+    "Comments" : "Commentaires",
     "No other comments available" : "Aucun autre commentaire",
     "More comments..." : "Plus de commentaires...",
     "Save" : "Enregistrer",
     "Allowed characters {count} of {max}" : "{count} sur {max} caractères autorisés",
+    "Error occurred while retrieving comment with id {id}" : "Une erreur est survenue lors de la récupération du commentaire avec l'id {id}",
+    "Error occurred while updating comment with id {id}" : "Une erreur est survenue lors de la mise à jour du commentaire avec l'id {id}",
+    "Error occurred while posting comment" : "Une erreur est survenue lors de l'envoi du commentaire",
     "{count} unread comments" : "{count} commentaires non lus",
     "Comment" : "Commenter",
-    "<strong>Comments</strong> for files" : "<strong>Commentaires</strong> pour les fichiers"
+    "<strong>Comments</strong> for files <em>(always listed in stream)</em>" : "<strong>Commentaires</strong> pour les fichiers <em>(toujours listés dans le flux)</em>",
+    "You commented" : "Vous avez commenté",
+    "%1$s commented" : "%1$s a commenté",
+    "You commented on %2$s" : "Vous avez commenté %2$s",
+    "%1$s commented on %2$s" : "%1$s a commenté %2$s"
 },
 "nplurals=2; plural=(n > 1);");
