@@ -1,9 +1,10 @@
 <?php
 /**
- * @author Björn Schießle <schiessle@owncloud.com>
+ * @author Björn Schießle <bjoern@schiessle.org>
  * @author Clark Tomlinson <fallen013@gmail.com>
+ * @author Thomas Müller <thomas.mueller@tmit.eu>
  *
- * @copyright Copyright (c) 2016, ownCloud, Inc.
+ * @copyright Copyright (c) 2017, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -23,7 +24,7 @@
 
 namespace OCA\Encryption\AppInfo;
 
-(new Application())->registerRoutes($this, array('routes' => array(
+(new Application())->registerRoutes($this, ['routes' => [
 
 	[
 		'name' => 'Recovery#adminRecovery',
@@ -57,4 +58,4 @@ namespace OCA\Encryption\AppInfo;
 	]
 
 
-)));
+]]);
