@@ -2,6 +2,8 @@ OC.L10N.register(
     "encryption",
     {
     "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "Neispravan privatni ključ za Aplikaciju za šifrovanje. Molimo da osvežite vašu lozinku privatnog ključa u ličnim podešavanjima kako bi dobili pristup šifrovanim fajlovima.",
+    "The share will expire on %s." : "Deljeni sadržaj će isteći: %s",
+    "Cheers!" : "U zdravlje!",
     "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Aplikacija za šifrovanje je omogućena ali Vaši ključevi nisu inicijalizovani, molimo Vas da se izlogujete i ulogujete ponovo.",
     "Disabled" : "Onemogućeno"
 },
