@@ -20,11 +20,13 @@ OC.L10N.register(
     "Could not update the private key password." : "ไม่สามารถอัพเดทรหัสการเข้ารหัสส่วนตัว",
     "The old password was not correct, please try again." : "รหัสผ่านเดิมไม่ถูกต้องโปรดลองอีกครั้ง",
     "The current log-in password was not correct, please try again." : "รหัสผ่านเข้าสู่ระบบในปัจจุบันไม่ถูกต้องโปรดลองอีกครั้ง",
-    "Private key password successfully updated." : "รหัสการเข้ารหัสส่วนตัวถูกอัพเดทเรียบร้อยแล้ว",
+    "Private key password successfully updated." : "อัพเดทรหัส Private key เรียบร้อยแล้ว",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "คุณจำเป็นต้องย้ายรหัสการเข้ารหัสลับของคุณจากการเข้ารหัสเก่า (ownCloud ที่มีเวอร์ชันต่ำกว่าหรือเท่ากับ 8.0) ไปเวอร์ชันใหม่ โปรดเรียกใช้ 'occ encryption:migrate' หรือติดต่อผู้ดูแลระบบ",
     "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "รหัสส่วนตัวไม่ถูกต้องสำหรับการเข้ารหัสแอพฯ กรุณาอัพเดทรหัสการเข้ารหัสผ่านส่วนตัวของคุณในการตั้งค่าส่วนบุคคลและในการกู้คืนการเข้าถึงไฟล์ที่มีการเข้ารหัสของคุณ",
-    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "การเข้ารหัสแอพฯ ถูกเปิดใช้งานแต่รหัสของคุณยังไม่ได้เริ่มต้นใช้ โปรดออกและเข้าสู่ระบบอีกครั้ง",
+    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "การเข้ารหัสลับแอพฯ กำลังใช้งานอยู่ในขณะนี้ แต่คีย์ของคุณยังใช้งานไม่ได้ ต้องออกจากระบบและเข้าสู่ระบบอีกครั้ง",
     "Encryption App is enabled and ready" : "เข้ารหัสแอพถูกเปิดใช้งานและพร้อมทำงาน",
+    "Bad Signature" : "ลายเซ็นไม่ดี",
+    "Missing Signature" : "ลายเซ็นขาดหายไป",
     "one-time password for server-side-encryption" : "รหัสผ่านเพียงครั้งเดียว สำหรับเข้ารหัสฝั่งเซิร์ฟเวอร์",
     "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "ไม่สามารถถอดรหัสไฟล์นี้ มันอาจเป็นไฟล์ที่ใช้งานร่วมกัน กรุณาถามเจ้าของไฟล์เพื่อยกเลิกการใช้งานร่วมกัน ",
     "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "ไม่สามารถอ่านไฟล์นี้ มันอาจเป็นไฟล์ที่ใช้งานร่วมกัน กรุณาสอบถามเจ้าของไฟล์เพื่อแชร์ไฟล์กับคุณ",
@@ -32,6 +34,14 @@ OC.L10N.register(
     "The share will expire on %s." : "การแชร์จะหมดอายุในวันที่ %s",
     "Cheers!" : "ไชโย!",
     "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"ownCloud basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "นี่คุณ <br><br> ผู้ดูแลระบบเปิดใช้งานการเข้ารหัสฝั่งเซิร์ฟเวอร์ ไฟล์ของคุณจะถูกเข้ารหัสโดยใช้รหัสผ่าน <strong>%s</strong> <br><br>กรุณาเข้าสู่ระบบเว็บอินเตอร์เฟซไปที่ส่วน \"โมดูลการเข้ารหัส ownCloud พื้นฐาน\" ของการตั้งค่าส่วนบุคคลของคุณและอัพเดทการเข้ารหัสรหัสผ่านของคุณโดย ป้อนรหัสผ่านนี้ในช่อง \"รหัสผ่านเก่าที่เข้าสู่ระบบ\" และเข้าสู่ระบบด้วยรหัสผ่านปัจจุบันของคุณ<br><br>",
+    "Default encryption module" : "โมดูลการเข้ารหัสเริ่มต้น",
+    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "การเข้ารหัสแอพฯ ถูกเปิดใช้งานแต่รหัสของคุณยังไม่ได้เริ่มต้นใช้ โปรดออกและเข้าสู่ระบบอีกครั้ง",
+    "Encryption type: Master Key" : "ประเภทการเข้ารหัส: คีย์หลัก",
+    "Encryption type: User Specific Key" : "ประเภทการเข้ารหัส: คีย์เฉพาะของผู้ใช้",
+    "Please select an encryption option" : "โปรดเลือกตัวเลือกการเข้ารหัส",
+    "Master Key" : "คีย์หลัก",
+    "User-specific key" : "คีย์เฉพาะของผู้ใช้",
+    "Permanently select this mode" : "เลือกโหมดนี้อย่างถาวร",
     "Encrypt the home storage" : "การเข้ารหัสพื้นที่จัดเก็บหน้าโฮม",
     "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "การเปิดใช้งานตัวเลือกนี้จะเข้ารหัสไฟล์ทั้งหมดที่เก็บไว้ในพื้นที่จัดเก็บข้อมูลหลัก มิฉะนั้นจะเข้ารหัสเฉพาะไฟล์ที่เป็นพื้นที่จัดเก็บข้อมูลภายนอก",
     "Enable recovery key" : "เปิดใช้งานการกู้คืนรหัส",
