@@ -5,8 +5,8 @@ script('federatedfilesharing', 'settings-admin');
 ?>
 
 <div id="fileSharingSettings" class="section">
-	<h2><?php p($l->t('Federated Cloud Sharing'));?></h2>
-	<a target="_blank" rel="noreferrer" class="icon-info svg"
+	<h2 class="app-name has-documentation"><?php p($l->t('Federated Cloud Sharing'));?></h2>
+	<a target="_blank" rel="noreferrer" class="icon-info"
 		title="<?php p($l->t('Open documentation'));?>"
 		href="<?php p(link_to_docs('admin-sharing-federated')); ?>"></a>
 
