@@ -7,9 +7,10 @@ OC.L10N.register(
     "Could not add server" : "Impossible d'ajouter le serveur",
     "Federation" : "Fédération",
     "ownCloud Federation allows you to connect with other trusted ownClouds to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "La Fédération ownCloud permet la connexion à d'autres instances ownCloud de confiance pour partager les annuaires d'utilisateurs. Cela peut par exemple être utilisé pour compléter automatiquement les noms des utilisateurs externes lors d'un partage vers une autre instance.",
-    "Add server automatically once a federated share was created successfully" : "Ajouter un serveur automatiquement une fois que le partage a été créer avec succès .",
+    "Add server automatically once a federated share was created successfully" : "Ajouter un serveur automatiquement une fois que le partage a été créé avec succès",
     "Trusted ownCloud Servers" : "Serveur ownCloud de confiance ",
     "+ Add ownCloud server" : "Ajouter un serveur Owncloud",
-    "ownCloud Server" : "Serveur OwnCloud"
+    "ownCloud Server" : "Serveur OwnCloud",
+    "Add" : "Ajouter"
 },
 "nplurals=2; plural=(n > 1);");
