@@ -1,34 +1,18 @@
 OC.L10N.register(
     "files",
     {
-    "Storage not available" : "Emmagatzemament no disponible",
     "Storage invalid" : "Emmagatzemament no vàlid",
     "Unknown error" : "Error desconegut",
-    "Unable to set upload directory." : "No es pot establir la carpeta de pujada.",
-    "Invalid Token" : "Testimoni no vàlid",
-    "No file was uploaded. Unknown error" : "No s'ha carregat cap fitxer. Error desconegut",
-    "There is no error, the file uploaded with success" : "No hi ha errors, el fitxer s'ha carregat correctament",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "L’arxiu que voleu carregar supera el màxim definit en la directiva upload_max_filesize del php.ini:",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El fitxer carregat supera la directiva MAX_FILE_SIZE especificada al formulari HTML",
-    "The uploaded file was only partially uploaded" : "El fitxer només s'ha carregat parcialment",
-    "No file was uploaded" : "No s'ha carregat cap fitxer",
-    "Missing a temporary folder" : "Falta un fitxer temporal",
-    "Failed to write to disk" : "Ha fallat en escriure al disc",
-    "Not enough storage available" : "No hi ha prou espai disponible",
-    "The target folder has been moved or deleted." : "La carpeta de destí s'ha mogut o eliminat.",
-    "Upload failed. Could not find uploaded file" : "La pujada ha fallat. El fitxer pujat no s'ha trobat.",
-    "Upload failed. Could not get file info." : "La pujada ha fallat. No s'ha pogut obtenir informació del fitxer.",
-    "Invalid directory." : "Directori no vàlid.",
-    "Files" : "Fitxers",
     "All files" : "Tots els fitxers",
-    "Favorites" : "Preferits",
-    "Home" : "Casa",
+    "Saved" : "Desat",
+    "Home" : "Inici",
     "Close" : "Tanca",
+    "Favorites" : "Preferits",
     "Upload cancelled." : "La pujada s'ha cancel·lat.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "No es pot pujar {filename} perquè és una carpeta o té 0 bytes",
-    "Total file size {size1} exceeds upload limit {size2}" : "Mida total del fitxer {size1} excedeix el límit de pujada {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hi ha prou espai lliure, està carregant {size1} però només pot {size2}",
-    "Could not get result from server." : "No hi ha resposta del servidor.",
+    "Uploading..." : "Pujant...",
+    "..." : "...",
     "File upload is in progress. Leaving the page now will cancel the upload." : "Hi ha una pujada en curs. Si abandoneu la pàgina la pujada es cancel·larà.",
     "Actions" : "Accions",
     "Download" : "Baixa",
@@ -36,11 +20,12 @@ OC.L10N.register(
     "Delete" : "Esborra",
     "Disconnect storage" : "Desonnecta l'emmagatzematge",
     "Unshare" : "Deixa de compartir",
+    "Files" : "Fitxers",
     "Details" : "Detalls",
     "Select" : "Selecciona",
     "Pending" : "Pendent",
     "Unable to determine date" : "No s'ha pogut determinar la data",
-    "No entries in this folder match '{filter}'" : "No hi ha resultats que coincideixin amb '{filter}'",
+    "Invalid path" : "El camí no és vàlid",
     "Name" : "Nom",
     "Size" : "Mida",
     "Modified" : "Modificat",
@@ -84,8 +69,6 @@ OC.L10N.register(
     "Save" : "Desa",
     "Settings" : "Arranjament",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Useu aquesta adreça per <a href=\"%s\" target=\"_blank\">accedir als fitxers via WebDAV</a>",
-    "Cancel upload" : "Cancel·la la pujada",
     "No files in here" : "No hi ha arxius",
     "Upload some content or sync with your devices!" : "Pugi continguts o sincronitzi els seus dispositius.",
     "No entries found in this folder" : "No hi ha entrades en aquesta carpeta",
@@ -94,10 +77,6 @@ OC.L10N.register(
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Els fitxers que esteu intentant pujar excedeixen la mida màxima de pujada del servidor",
     "No favorites" : "No hi ha favorits",
     "Files and folders you mark as favorite will show up here" : "Aquí apareixeran els arxius i carpetes que vostè marqui com favorits",
-    "Text file" : "Fitxer de text",
-    "You changed %1$s" : "Has canviat %1$s",
-    "You created %1$s" : "Has creat %1$s",
-    "You deleted %1$s" : "Has esborrat %1$s",
-    "You restored %1$s" : "Has restaurat %1$s"
+    "Text file" : "Fitxer de text"
 },
 "nplurals=2; plural=(n != 1);");
