@@ -2,9 +2,9 @@ OC.L10N.register(
     "files",
     {
     "Unknown error" : "Error desconocido",
-    "Files" : "Archivos",
     "Download" : "Descargar",
     "Rename" : "Renombrar",
+    "Files" : "Archivos",
     "Details" : "detalles",
     "New folder" : "Nuevo directorio",
     "Upload" : "Subir",
@@ -17,10 +17,6 @@ OC.L10N.register(
     "%2$s changed %1$s" : "%2$s cambió %1$s",
     "You deleted %1$s" : "Ha borrado %1$s",
     "%2$s deleted %1$s" : "%2$s borró %1$s",
-    "Settings" : "Configuración",
-    "Cancel upload" : "cancelar subida",
-    "You changed %1$s" : "Cambió %1$s",
-    "You created %1$s" : "Ha creado %1$s",
-    "You deleted %1$s" : "Ha borrado %1$s"
+    "Settings" : "Configuración"
 },
 "nplurals=2; plural=(n != 1);");
