@@ -1,36 +1,22 @@
 OC.L10N.register(
     "files",
     {
-    "Storage not available" : "Tallennustila ei ole käytettävissä",
+    "Storage is temporarily not available" : "Tallennustila ei juuri nyt ole käytettävissä",
     "Storage invalid" : "Virheellinen tallennustila",
     "Unknown error" : "Tuntematon virhe",
-    "Unable to set upload directory." : "Lähetyskansion asettaminen epäonnistui.",
-    "Invalid Token" : "Virheellinen token",
-    "No file was uploaded. Unknown error" : "Tiedostoa ei lähetetty. Tuntematon virhe",
-    "There is no error, the file uploaded with success" : "Ei virheitä, tiedosto lähetettiin onnistuneesti",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Lähetetyn tiedoston koko ylittää php.ini-tiedoston upload_max_filesize-säännön:",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Lähetettävän tiedoston enimmäiskoko ylittää HTML-lomakkeessa määritellyn MAX_FILE_SIZE-säännön",
-    "The uploaded file was only partially uploaded" : "Tiedoston lähetys onnistui vain osittain",
-    "No file was uploaded" : "Yhtäkään tiedostoa ei lähetetty",
-    "Missing a temporary folder" : "Tilapäiskansio puuttuu",
-    "Failed to write to disk" : "Levylle kirjoitus epäonnistui",
-    "Not enough storage available" : "Tallennustilaa ei ole riittävästi käytettävissä",
-    "The target folder has been moved or deleted." : "Kohdekansio on siirretty tai poistettu.",
-    "Upload failed. Could not find uploaded file" : "Lähetys epäonnistui. Lähettävää tiedostoa ei löydetty.",
-    "Upload failed. Could not get file info." : "Lähetys epäonnistui. Lähettävää tiedostoa ei löydetty.",
-    "Invalid directory." : "Virheellinen kansio.",
-    "Files" : "Tiedostot",
     "All files" : "Kaikki tiedostot",
+    "Saved" : "Tallennettu",
+    "There was an error saving" : "Virhe tallentaessa",
     "File could not be found" : "TIedostoa ei löytynyt",
     "Home" : "Koti",
     "Close" : "Sulje",
     "Favorites" : "Suosikit",
+    "Could not create folder \"{dir}\"" : "Kansiota \"{dir}\" ei voitu luoda",
     "Upload cancelled." : "Lähetys peruttu.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kohdetta {filename} ei voi lähettää, koska se on joko kansio tai sen koko on 0 tavua",
-    "Total file size {size1} exceeds upload limit {size2}" : "Yhteiskoko {size1} ylittää lähetysrajan {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ei riittävästi vapaata tilaa. Lähetyksesi koko on {size1}, mutta vain {size2} on jäljellä",
-    "Error uploading file \"{fileName}\": {message}" : "Virhe lähettäessä tiedostoa \"{fileName}\": {message}",
-    "Could not get result from server." : "Tuloksien saaminen palvelimelta ei onnistunut.",
+    "Target folder \"{dir}\" does not exist any more" : "Kohdekansio \"{dir}\" ei ole enää olemassa",
+    "Not enough free space" : "Ei riittävästi vapaata tilaa",
     "Uploading..." : "Lähetetään...",
     "..." : "...",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize}/{totalSize} ({bitrate})",
@@ -41,10 +27,13 @@ OC.L10N.register(
     "Delete" : "Poista",
     "Disconnect storage" : "Katkaise yhteys tallennustilaan",
     "Unshare" : "Peru jakaminen",
+    "Could not load info for file \"{file}\"" : "Tietojen lataaminen tiedoston \"{file}\" osalta epäonnistui",
+    "Files" : "Tiedostot",
     "Details" : "Tiedot",
     "Select" : "Valitse",
     "Pending" : "Odottaa",
     "Unable to determine date" : "Päivämäärän määrittäminen epäonnistui",
+    "Invalid path" : "Virheellinen polku",
     "This operation is forbidden" : "Tämä toiminto on kielletty",
     "This directory is unavailable, please check the logs or contact the administrator" : "Hakemisto ei ole käytettävissä. Tarkista lokit tai ole yhteydessä ylläpitoon.",
     "Could not move \"{file}\", target exists" : "Tiedoston \"{file}\" siirtäminen ei onnistunut, kohde on olemassa",
@@ -55,16 +44,15 @@ OC.L10N.register(
     "Could not rename \"{fileName}\"" : "Tiedoston \"{fileName}\" nimeäminen uudelleen ei onnistunut",
     "Could not create file \"{file}\"" : "Tiedostoa \"{file}\" ei voitu luoda",
     "Could not create file \"{file}\" because it already exists" : "Tiedostoa \"{file}\" ei voitu luoda, koska se on jo olemassa",
-    "Could not create folder \"{dir}\"" : "Kansiota \"{dir}\" ei voitu luoda",
     "Could not create folder \"{dir}\" because it already exists" : "Kansiota \"{dir}\" ei voitu luoda, koska se on jo olemassa",
     "Error deleting file \"{fileName}\"." : "Virhe poistaessa tiedostoa \"{fileName}\".",
-    "No entries in this folder match '{filter}'" : "Mikään tässä kansiossa ei vastaa suodatusta '{filter}'",
     "Name" : "Nimi",
     "Size" : "Koko",
     "Modified" : "Muokattu",
     "_%n folder_::_%n folders_" : ["%n kansio","%n kansiota"],
     "_%n file_::_%n files_" : ["%n tiedosto","%n tiedostoa"],
     "{dirs} and {files}" : "{dirs} ja {files}",
+    "_including %n hidden_::_including %n hidden_" : ["mukaan lukien %n piilotettu","mukaan lukien %n piilotettua"],
     "You don’t have permission to upload or create files here" : "Käyttöoikeutesi eivät riitä tiedostojen lähettämiseen tai kansioiden luomiseen tähän sijaintiin",
     "_Uploading %n file_::_Uploading %n files_" : ["Lähetetään %n tiedosto","Lähetetään %n tiedostoa"],
     "New" : "Uusi",
@@ -79,7 +67,6 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n tavu","%n tavua"],
     "Favorited" : "Lisätty suosikkeihin",
     "Favorite" : "Suosikki",
-    "Local link" : "Paikallinen linkki",
     "Folder" : "Kansio",
     "New folder" : "Uusi kansio",
     "{newname} already exists" : "{newname} on jo olemassa",
