@@ -1,36 +1,22 @@
 OC.L10N.register(
     "files",
     {
-    "Storage not available" : "Support de stockage non disponible",
+    "Storage is temporarily not available" : "Espace de stockage temporairement indisponible",
     "Storage invalid" : "Support de stockage non valable",
     "Unknown error" : "Erreur Inconnue ",
-    "Unable to set upload directory." : "Impossible de définir le dossier de destination.",
-    "Invalid Token" : "Jeton non valide",
-    "No file was uploaded. Unknown error" : "Aucun fichier n'a été envoyé. Erreur inconnue",
-    "There is no error, the file uploaded with success" : "Aucune erreur, le fichier a été envoyé avec succès.",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Le fichier envoyé dépasse l'instruction upload_max_filesize située dans le fichier php.ini :",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Le fichier envoyé dépasse la valeur MAX_FILE_SIZE qui était spécifiée dans le formulaire HTML.",
-    "The uploaded file was only partially uploaded" : "Le fichier n'a été que partiellement envoyé.",
-    "No file was uploaded" : "Pas de fichier envoyé.",
-    "Missing a temporary folder" : "Absence de dossier temporaire",
-    "Failed to write to disk" : "Erreur d'écriture sur le disque",
-    "Not enough storage available" : "Trop peu d'espace de stockage disponible",
-    "The target folder has been moved or deleted." : "Le dossier cible a été déplacé ou supprimé.",
-    "Upload failed. Could not find uploaded file" : "L'envoi a échoué. Impossible de trouver le fichier envoyé.",
-    "Upload failed. Could not get file info." : "L'envoi a échoué. Impossible d'obtenir les informations du fichier.",
-    "Invalid directory." : "Dossier non valide.",
-    "Files" : "Fichiers",
     "All files" : "Tous les fichiers",
+    "Saved" : "Sauvegardé",
+    "There was an error saving" : "Il y a eu une erreur durant la sauvegarde",
     "File could not be found" : "Ce fichier n'a pu être trouvé.",
     "Home" : "Mes fichiers",
     "Close" : "Fermer",
     "Favorites" : "Favoris",
+    "Could not create folder \"{dir}\"" : "Impossible de créer le dossier \"{dir}\"",
     "Upload cancelled." : "Envoi annulé.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossible d'envoyer {filename} car il s'agit d'un répertoire ou d'un fichier de taille nulle",
-    "Total file size {size1} exceeds upload limit {size2}" : "La taille totale du fichier {size1} excède la taille maximale d'envoi {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Espace libre insuffisant : vous tentez d'envoyer {size1} mais seulement {size2} sont disponibles",
-    "Error uploading file \"{fileName}\": {message}" : "Erreur lors de l'envoi du fichier \"{fileName}\" : {message}",
-    "Could not get result from server." : "Ne peut recevoir les résultats du serveur.",
+    "Target folder \"{dir}\" does not exist any more" : "Le dossier de destination « {dir} » n'existe plus",
+    "Not enough free space" : "Pas assez d'espace libre",
     "Uploading..." : "Téléversement en cours…",
     "..." : "...",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} sur {totalSize} ({bitrate})",
@@ -41,10 +27,13 @@ OC.L10N.register(
     "Delete" : "Supprimer",
     "Disconnect storage" : "Déconnecter ce support de stockage",
     "Unshare" : "Ne plus partager",
+    "Could not load info for file \"{file}\"" : "Impossible de charger les informations pour le fichier \"{file}\"",
+    "Files" : "Fichiers",
     "Details" : "Détails",
     "Select" : "Sélectionner",
     "Pending" : "En attente",
     "Unable to determine date" : "Impossible de déterminer la date",
+    "Invalid path" : "Chemin non valide",
     "This operation is forbidden" : "Cette opération est interdite",
     "This directory is unavailable, please check the logs or contact the administrator" : "Ce répertoire n'est pas disponible. Consultez les logs ou contactez votre administrateur",
     "Could not move \"{file}\", target exists" : "Impossible de déplacer \"{file}\", la cible existe",
@@ -55,16 +44,15 @@ OC.L10N.register(
     "Could not rename \"{fileName}\"" : "Impossible de renommer \"{fileName}\"",
     "Could not create file \"{file}\"" : "Impossible de créer le fichier \"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "Impossible de créer le fichier \"{file}\" car il existe déjà",
-    "Could not create folder \"{dir}\"" : "Impossible de créer le dossier \"{dir}\"",
     "Could not create folder \"{dir}\" because it already exists" : "Impossible de créer le dossier \"{dir}\" car il existe déjà",
     "Error deleting file \"{fileName}\"." : "Erreur à la suppression du fichier \"{fileName}\".",
-    "No entries in this folder match '{filter}'" : "Aucune entrée de ce dossier ne correspond à '{filter}'",
     "Name" : "Nom",
     "Size" : "Taille",
     "Modified" : "Modifié",
     "_%n folder_::_%n folders_" : ["%n dossier","%n dossiers"],
     "_%n file_::_%n files_" : ["%n fichier","%n fichiers"],
     "{dirs} and {files}" : "{dirs} et {files}",
+    "_including %n hidden_::_including %n hidden_" : ["inclure %n caché","inclure %n cachés"],
     "You don’t have permission to upload or create files here" : "Vous n'avez pas la permission d'ajouter des fichiers ici",
     "_Uploading %n file_::_Uploading %n files_" : ["Téléversement de %n fichier","Téléversement de %n fichiers"],
     "New" : "Nouveau",
@@ -79,7 +67,7 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n octet","%n octets"],
     "Favorited" : "Marqué comme favori",
     "Favorite" : "Favoris",
-    "Local link" : "Dossier local",
+    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Lien privé : seules les personnes ayant accès à ce fichier/dossier peuvent l'utiliser. Utilisez le en tant que lien permanent pour vous-même ou pour désigner des fichiers dans les partages aux autres utilisateurs.",
     "Folder" : "Dossier",
     "New folder" : "Nouveau dossier",
     "{newname} already exists" : "{newname} existe déjà",
