@@ -1,34 +1,19 @@
 OC.L10N.register(
     "files",
     {
-    "Storage not available" : "A tároló elérhetetlen.",
     "Storage invalid" : "A tároló érvénytelen",
     "Unknown error" : "Ismeretlen hiba",
-    "Unable to set upload directory." : "Nem található a mappa, ahova feltölteni szeretne.",
-    "Invalid Token" : "Hibás token",
-    "No file was uploaded. Unknown error" : "Nem történt feltöltés. Ismeretlen hiba",
-    "There is no error, the file uploaded with success" : "A fájlt sikerült feltölteni",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "A feltöltött fájl mérete meghaladja a php.ini állományban megadott upload_max_filesize paraméter értékét.",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "A feltöltött fájl mérete meghaladja a MAX_FILE_SIZE paramétert, ami a HTML  formban került megadásra.",
-    "The uploaded file was only partially uploaded" : "Az eredeti fájlt csak részben sikerült feltölteni.",
-    "No file was uploaded" : "Nem töltődött fel állomány",
-    "Missing a temporary folder" : "Hiányzik egy ideiglenes mappa",
-    "Failed to write to disk" : "Nem sikerült a lemezre történő írás",
-    "Not enough storage available" : "Nincs elég szabad hely.",
-    "The target folder has been moved or deleted." : "A célmappa törlődött, vagy áthelyezésre került.",
-    "Upload failed. Could not find uploaded file" : "A feltöltés nem sikerült. Nem található a feltöltendő állomány.",
-    "Upload failed. Could not get file info." : "A feltöltés nem sikerült. Az állományt leíró információk nem érhetők el.",
-    "Invalid directory." : "Érvénytelen mappa.",
-    "Files" : "Fájlkezelő",
     "All files" : "Az összes állomány",
-    "Favorites" : "Kedvencek",
+    "Saved" : "Elmentve!",
     "Home" : "Otthoni",
     "Close" : "Bezárás",
+    "Favorites" : "Kedvencek",
+    "Could not create folder \"{dir}\"" : "{dir} könyvtár nem létrehozható",
     "Upload cancelled." : "A feltöltést megszakítottuk.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "A(z) {filename} állomány nem tölthető fel, mert ez vagy egy mappa, vagy pedig 0 bájtból áll.",
-    "Total file size {size1} exceeds upload limit {size2}" : "A teljes fájlméret: {size1} meghaladja a feltöltési limitet: {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nincs elég szabad hely. A feltöltés mérete {size1}, de csak ennyi hely van: {size2}.",
-    "Could not get result from server." : "A kiszolgálótól nem kapható meg a művelet eredménye.",
+    "Uploading..." : "Feltöltés...",
+    "..." : "...",
     "File upload is in progress. Leaving the page now will cancel the upload." : "Fájlfeltöltés van folyamatban. Az oldal elhagyása megszakítja a feltöltést.",
     "Actions" : "Műveletek",
     "Download" : "Letöltés",
@@ -36,10 +21,12 @@ OC.L10N.register(
     "Delete" : "Törlés",
     "Disconnect storage" : "Tároló leválasztása",
     "Unshare" : "A megosztás visszavonása",
+    "Files" : "Fájlkezelő",
     "Details" : "Részletek",
     "Select" : "Kiválaszt",
     "Pending" : "Folyamatban",
     "Unable to determine date" : "Nem lehet meghatározni a dátumot",
+    "Invalid path" : "Érvénytelen útvonal",
     "This operation is forbidden" : "Tiltott művelet",
     "This directory is unavailable, please check the logs or contact the administrator" : "Ez a könyvtár nem elérhető, kérem nézze meg a naplófájlokat vagy keresse az adminisztrátort",
     "Could not move \"{file}\", target exists" : "{file} fájl nem áthelyezhető, mert a cél már létezik",
@@ -50,10 +37,8 @@ OC.L10N.register(
     "Could not rename \"{fileName}\"" : "{fileName} fájl nem átnevezhető",
     "Could not create file \"{file}\"" : "{file} fájl nem létrehozható",
     "Could not create file \"{file}\" because it already exists" : "{file} fájl nem létrehozható, mert már létezik",
-    "Could not create folder \"{dir}\"" : "{dir} könyvtár nem létrehozható",
     "Could not create folder \"{dir}\" because it already exists" : "{dir} könyvtár nem létrehozható, mert már létezik",
     "Error deleting file \"{fileName}\"." : "Hiba történt {fileName} fájl törlése közben.",
-    "No entries in this folder match '{filter}'" : "Nincsenek egyező bejegyzések ebben a könyvtárban '{filter}'",
     "Name" : "Név",
     "Size" : "Méret",
     "Modified" : "Módosítva",
@@ -104,9 +89,9 @@ OC.L10N.register(
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM-mel akár 5 percbe is telhet, míg ez a beállítás érvénybe lép.",
     "Missing permissions to edit from here." : "Innen nem lehet szerkeszteni hiányzó jogosultság miatt.",
     "Settings" : "Beállítások",
+    "Show hidden files" : "Rejtett fájlok megjelenítése",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Ezt a címet használja, ha <a href=\"%s\" target=\"_blank\">WebDAV-on keresztül szeretné elérni a fájljait</a>",
-    "Cancel upload" : "A feltöltés megszakítása",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Használja ezt a címet <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">a Fájlok eléréséhez WebDAV-on keresztül</a>.",
     "No files in here" : "Itt nincsenek fájlok",
     "Upload some content or sync with your devices!" : "Tölts fel néhány tartalmat, vagy szinkronizálj az eszközöddel!",
     "No entries found in this folder" : "Nincsenek bejegyzések ebben a könyvtárban",
@@ -116,13 +101,6 @@ OC.L10N.register(
     "No favorites" : "Nincsenek kedvencek",
     "Files and folders you mark as favorite will show up here" : "A kedvencnek jelölt fájlokat és mappákat itt találod meg",
     "Text file" : "Szövegfájl",
-    "New text file.txt" : "Új szöveges fájl.txt",
-    "Changed by %2$s" : "Megváltoztatta: %2$s",
-    "Deleted by %2$s" : "Törölte: %2$s",
-    "Restored by %2$s" : "Visszaállította: %2$s",
-    "You changed %1$s" : "Megváltoztattam: %1$s",
-    "You created %1$s" : "Létrehoztam: %1$s",
-    "You deleted %1$s" : "Töröltem: %1$s",
-    "You restored %1$s" : "Visszatöltötted %1$s"
+    "New text file.txt" : "Új szöveges fájl.txt"
 },
 "nplurals=2; plural=(n != 1);");
