@@ -1,35 +1,25 @@
 OC.L10N.register(
     "files",
     {
-    "Storage not available" : "Penyimpanan tidak tersedia",
+    "Storage is temporarily not available" : "Penyimpanan sementara ini tidak tersedia",
     "Storage invalid" : "Penyimpanan tidak sah",
     "Unknown error" : "Kesalahan tidak diketahui",
-    "Unable to set upload directory." : "Tidak dapat mengatur folder unggah",
-    "Invalid Token" : "Token tidak sah",
-    "No file was uploaded. Unknown error" : "Tidak ada berkas yang diunggah. Kesalahan tidak dikenal.",
-    "There is no error, the file uploaded with success" : "Tidak ada kesalahan, berkas sukses diunggah",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Berkas yang diunggah melampaui direktif upload_max_filesize pada php.ini",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Berkas yang diunggah melampaui direktif MAX_FILE_SIZE yang ditentukan dalam formulir HTML.",
-    "The uploaded file was only partially uploaded" : "Berkas hanya diunggah sebagian",
-    "No file was uploaded" : "Tidak ada berkas yang diunggah",
-    "Missing a temporary folder" : "Folder sementara tidak ada",
-    "Failed to write to disk" : "Gagal menulis ke disk",
-    "Not enough storage available" : "Ruang penyimpanan tidak mencukupi",
-    "The target folder has been moved or deleted." : "Folder tujuan telah dipindahkan atau dihapus.",
-    "Upload failed. Could not find uploaded file" : "Unggah gagal. Tidak menemukan berkas yang akan diunggah",
-    "Upload failed. Could not get file info." : "Unggah gagal. Tidak mendapatkan informasi berkas.",
-    "Invalid directory." : "Direktori tidak valid.",
-    "Files" : "Berkas",
     "All files" : "Semua berkas",
+    "Saved" : "Disimpan",
+    "There was an error saving" : "Ada kesalahan saat menyimpan",
+    "File could not be found" : "Berkas tidak dapat ditemukan",
     "Home" : "Rumah",
     "Close" : "Tutup",
     "Favorites" : "Favorit",
+    "Could not create folder \"{dir}\"" : "Tidak dapat membuat folder \"{dir}\"",
     "Upload cancelled." : "Pengunggahan dibatalkan.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Tidak dapat mengunggah {filename} karena ini sebuah direktori atau memiliki ukuran 0 byte",
-    "Total file size {size1} exceeds upload limit {size2}" : "Jumlah ukuran berkas {size1} melampaui batas unggah {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ruang bebas tidak mencukupi, Anda mengunggah {size1} tetapi hanya {size2} yang tersisa",
-    "Could not get result from server." : "Tidak mendapatkan hasil dari server.",
+    "Target folder \"{dir}\" does not exist any more" : "Folder tujuan \"{dir}\" tidak lagi ada",
+    "Not enough free space" : "Ruang bebas tidak cukup",
     "Uploading..." : "Mengunggah...",
+    "..." : "...",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} dari {totalSize} ({bitrate})",
     "File upload is in progress. Leaving the page now will cancel the upload." : "Berkas sedang diunggah. Meninggalkan halaman ini akan membatalkan proses.",
     "Actions" : "Tindakan",
     "Download" : "Unduh",
@@ -37,19 +27,32 @@ OC.L10N.register(
     "Delete" : "Hapus",
     "Disconnect storage" : "Memutuskan penyimpaan",
     "Unshare" : "Batalkan berbagi",
+    "Could not load info for file \"{file}\"" : "Tidak dapat memuat info untuk berkas \"{file}\"",
+    "Files" : "Berkas",
     "Details" : "Rincian",
     "Select" : "Pilih",
     "Pending" : "Tertunda",
     "Unable to determine date" : "Tidak dapat menentukan tanggal",
+    "Invalid path" : "Jalur lokasi salah.",
     "This operation is forbidden" : "Operasi ini dilarang",
     "This directory is unavailable, please check the logs or contact the administrator" : "Direktori ini tidak tersedia, silakan periksa log atau hubungi kontak",
-    "No entries in this folder match '{filter}'" : "Tidak ada entri di folder ini yang cocok dengan '{filter}'",
+    "Could not move \"{file}\", target exists" : "Tidak dapat memindahkan \"{file}\", berkas tujuan sudah ada",
+    "Could not move \"{file}\"" : "Tidak dapat memindahkan \"{file}\"",
+    "{newName} already exists" : "{newName} sudah ada",
+    "Could not rename \"{fileName}\", it does not exist any more" : "Tidak dapat mengubah nama \"{fileName}\", karena berkas tidak lagi ada",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nama \"{targetName}\" sudah digunakan pada folder \"{dir}\". Silakan pilih nama yang berbeda.",
+    "Could not rename \"{fileName}\"" : "Tidak dapat mengubah nama \"{fileName}\"",
+    "Could not create file \"{file}\"" : "Tidak dapat membuat berkas \"{file}\"",
+    "Could not create file \"{file}\" because it already exists" : "Tidak dapat membuat berkas \"{file}\" karena sudah ada",
+    "Could not create folder \"{dir}\" because it already exists" : "Tidak dapat membuat folder \"{dir}\" karena sudah ada",
+    "Error deleting file \"{fileName}\"." : "Kesalahan saat menghapus berkas \"{fileName}\".",
     "Name" : "Nama",
     "Size" : "Ukuran",
     "Modified" : "Dimodifikasi",
     "_%n folder_::_%n folders_" : ["%n folder"],
     "_%n file_::_%n files_" : ["%n berkas"],
     "{dirs} and {files}" : "{dirs} dan {files}",
+    "_including %n hidden_::_including %n hidden_" : ["termasuk %n tersembunyi"],
     "You don’t have permission to upload or create files here" : "Anda tidak memiliki akses untuk mengunggah atau membuat berkas disini",
     "_Uploading %n file_::_Uploading %n files_" : ["Mengunggah %n berkas"],
     "New" : "Baru",
@@ -91,8 +94,12 @@ OC.L10N.register(
     "Maximum upload size" : "Ukuran pengunggahan maksimum",
     "max. possible: " : "Kemungkinan maks.:",
     "Save" : "Simpan",
+    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Dengan PHP-FPM mungkin butuh 5 menit agar perubahan dapat diterapkan.",
+    "Missing permissions to edit from here." : "Tidak memiliki izin untuk menyunting dari sini.",
     "Settings" : "Pengaturan",
+    "Show hidden files" : "Tampilkan berkas tersembunyi",
     "WebDAV" : "WebDAV",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Gunakan alamat ini untuk <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">mengakses Berkas Anda via WebDAV</a>",
     "No files in here" : "Tidak ada berkas disini",
     "Upload some content or sync with your devices!" : "Unggah beberapa konten dan sinkronisasikan dengan perangkat Anda!",
     "No entries found in this folder" : "Tidak ada entri yang ditemukan dalam folder ini",
