@@ -1,35 +1,23 @@
 OC.L10N.register(
     "files",
     {
-    "Storage not available" : "Geymsla ekki tiltæk",
-    "Storage invalid" : "Ógild geymsla",
+    "Storage is temporarily not available" : "Gagnageymsla ekki tiltæk í augnablikinu",
+    "Storage invalid" : "Ógild gagnageymsla",
     "Unknown error" : "Óþekkt villa",
-    "Unable to set upload directory." : "Gat ekki sett innhleðslumöppu.",
-    "Invalid Token" : "Ógilt teikn",
-    "No file was uploaded. Unknown error" : "Engin skrá var send inn. Óþekkt villa.",
-    "There is no error, the file uploaded with success" : "Engin villa, innsending heppnaðist",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Innsend skrá er stærri en upload_max stillingin í php.ini:",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Innsenda skráin er stærri en MAX_FILE_SIZE sem skilgreint er í HTML sniðinu.",
-    "The uploaded file was only partially uploaded" : "Einungis hluti af innsendri skrá skilaði sér",
-    "No file was uploaded" : "Engin skrá skilaði sér",
-    "Missing a temporary folder" : "Vantar bráðabirgðamöppu",
-    "Failed to write to disk" : "Tókst ekki að skrifa á disk",
-    "Not enough storage available" : "Ekki er nægilegt geymslupláss tiltækt",
-    "The target folder has been moved or deleted." : "Markmappan hefur verið færð eða henni eytt.",
-    "Upload failed. Could not find uploaded file" : "Innsending mistókst. Fann ekki innsendu skrána",
-    "Upload failed. Could not get file info." : "Innsending mistókst. Gat ekki nálgast skráarupplýsingar.",
-    "Invalid directory." : "Ógild mappa.",
-    "Files" : "Skrár",
     "All files" : "Allar skrár",
+    "Saved" : "Vistað",
+    "There was an error saving" : "Villa kom upp við vistun",
+    "File could not be found" : "Þessi skrá fannst ekki",
     "Home" : "Heim",
     "Close" : "Loka",
     "Favorites" : "Eftirlæti",
+    "Could not create folder \"{dir}\"" : "Gat ekki búið til möppuna \"{dir}\"",
     "Upload cancelled." : "Hætt við innsendingu.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Tókst ekki að hlaða inn {filename} þar sem þetta er mappa eða er 0 bæti",
-    "Total file size {size1} exceeds upload limit {size2}" : "Heildarskráastærð {size1} er meiri en leyfilegt innsendingahámark {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ekki nægilegt laust pláss, þú ert að senda inn {size1} en einungis {size2} eru eftir",
-    "Error uploading file \"{fileName}\": {message}" : "Villa við að senda inn skrána \"{fileName}\": {message}",
-    "Could not get result from server." : "Fékk ekki niðurstöður frá þjóni.",
+    "Target folder \"{dir}\" does not exist any more" : "Markmappan \"{dir}\" er ekki lengur til",
+    "Target folder does not exist any more" : "Markmappan er ekki lengur til",
+    "Not enough free space" : "Ekki nægilegt pláss",
     "Uploading..." : "Sendi inn ...",
     "..." : "...",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} af {totalSize} ({bitrate})",
@@ -38,12 +26,15 @@ OC.L10N.register(
     "Download" : "Niðurhal",
     "Rename" : "Endurnefna",
     "Delete" : "Eyða",
-    "Disconnect storage" : "Aftengja geymslu",
+    "Disconnect storage" : "Aftengja gagnageymslu",
     "Unshare" : "Hætta deilingu",
+    "Could not load info for file \"{file}\"" : "Gat ekki hlaðið inn upplýsingum fyrir skrána \"{file}\"",
+    "Files" : "Skrár",
     "Details" : "Nánar",
     "Select" : "Velja",
     "Pending" : "Í bið",
     "Unable to determine date" : "Tókst ekki að ákvarða dagsetningu",
+    "Invalid path" : "Ógild slóð",
     "This operation is forbidden" : "Þessi aðgerð er bönnuð",
     "This directory is unavailable, please check the logs or contact the administrator" : "Þessi mappa er ekki tiltæk, athugaðu annálana eða hafðu samband við kerfissjóra",
     "Could not move \"{file}\", target exists" : "Gat ekki fært \"{file}\", markskrá er til",
@@ -54,21 +45,22 @@ OC.L10N.register(
     "Could not rename \"{fileName}\"" : "Gat ekki endurnefnt \"{fileName}\"",
     "Could not create file \"{file}\"" : "Gat ekki búið til skrána \"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "Gat ekki búið til skrána \"{file}\" vegna þess að hún er þegar til",
-    "Could not create folder \"{dir}\"" : "Gat ekki búið til möppuna \"{dir}\"",
     "Could not create folder \"{dir}\" because it already exists" : "Gat ekki búið til möppuna \"{dir}\" vegna þess að hún er þegar til",
     "Error deleting file \"{fileName}\"." : "Villa við að eyða skránni \"{fileName}\".",
-    "No entries in this folder match '{filter}'" : "Engar færslur í þessari möppu samsvara '{filter}'",
+    "No entries in this folder match {filter}" : "Engar færslur í þessari möppu samsvara {filter}",
     "Name" : "Heiti",
     "Size" : "Stærð",
     "Modified" : "Breytt",
     "_%n folder_::_%n folders_" : ["%n mappa","%n möppur"],
     "_%n file_::_%n files_" : ["%n skrá","%n skrár"],
     "{dirs} and {files}" : "{dirs} og {files}",
+    "_including %n hidden_::_including %n hidden_" : ["þar á meðal %n falin","þar á meðal %n faldar"],
     "You don’t have permission to upload or create files here" : "Þú hefur ekki heimild til að hlaða inn eða búa til skjöl hér",
     "_Uploading %n file_::_Uploading %n files_" : ["Sendi inn %n skrá","Sendi inn %n skrár"],
     "New" : "Nýtt",
     "\"{name}\" is an invalid file name." : "\"{name}\" er ógilt skráarheiti.",
     "File name cannot be empty." : "Heiti skráar má ekki vera tómt",
+    "\"{name}\" has a forbidden file type/extension." : "\"{name}\" er með óleyfilega skráategund/skráarendingu.",
     "Storage of {owner} is full, files can not be updated or synced anymore!" : "Geymslupláss {owner} er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
     "Your storage is full, files can not be updated or synced anymore!" : "Geymsluplássið þitt er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
     "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Geymslupláss {owner} er næstum fullt ({usedSpacePercent}%)",
@@ -78,7 +70,7 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n bæti","%n bæti"],
     "Favorited" : "Sett í eftirlæti",
     "Favorite" : "Eftirlæti",
-    "Local link" : "Staðvær tengill",
+    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Einkatengilll: Aðeins fólk sem hefur aðgang að skránni/möppunni getur notað hann. Notaðu hann sem varanlegan tengil fyrir sjálfan þig eða til að beina öðrum á skrár innan sameigna.",
     "Folder" : "Mappa",
     "New folder" : "Ný mappa",
     "{newname} already exists" : "{newname} er þegar til",
