@@ -1,36 +1,22 @@
 OC.L10N.register(
     "files",
     {
-    "Storage not available" : "Archiviazione non disponibile",
+    "Storage is temporarily not available" : "L'archiviazione non è temporaneamente disponibile",
     "Storage invalid" : "Archiviazione non valida",
     "Unknown error" : "Errore sconosciuto",
-    "Unable to set upload directory." : "Impossibile impostare una cartella di caricamento.",
-    "Invalid Token" : "Token non valido",
-    "No file was uploaded. Unknown error" : "Nessun file è stato caricato. Errore sconosciuto",
-    "There is no error, the file uploaded with success" : "Non ci sono errori, il file è stato caricato correttamente",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Il file caricato supera la direttiva upload_max_filesize in php.ini:",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Il file caricato supera la direttiva MAX_FILE_SIZE specificata nel modulo HTML",
-    "The uploaded file was only partially uploaded" : "Il file è stato caricato solo parzialmente",
-    "No file was uploaded" : "Nessun file è stato caricato",
-    "Missing a temporary folder" : "Manca una cartella temporanea",
-    "Failed to write to disk" : "Scrittura su disco non riuscita",
-    "Not enough storage available" : "Spazio di archiviazione insufficiente",
-    "The target folder has been moved or deleted." : "La cartella di destinazione è stata spostata o eliminata.",
-    "Upload failed. Could not find uploaded file" : "Caricamento non riuscito. Impossibile trovare il file caricato.",
-    "Upload failed. Could not get file info." : "Caricamento non riuscito. Impossibile ottenere informazioni sul file.",
-    "Invalid directory." : "Cartella non valida.",
-    "Files" : "File",
     "All files" : "Tutti i file",
+    "Saved" : "Salvato",
+    "There was an error saving" : "Si è verificato un errore durante il salvataggio",
     "File could not be found" : "Il file non può essere trovato",
     "Home" : "Home",
     "Close" : "Chiudi",
     "Favorites" : "Preferiti",
+    "Could not create folder \"{dir}\"" : "Impossibile creare la cartella \"{dir}\"",
     "Upload cancelled." : "Caricamento annullato.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossibile caricare {filename} poiché è una cartella oppure ha una dimensione di 0 byte.",
-    "Total file size {size1} exceeds upload limit {size2}" : "La dimensione totale del file {size1} supera il limite di caricamento {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Spazio insufficiente, stai caricando {size1}, ma è rimasto solo {size2}",
-    "Error uploading file \"{fileName}\": {message}" : "Errore durante il caricamento del file \"{fileName}\": {message}",
-    "Could not get result from server." : "Impossibile ottenere il risultato dal server.",
+    "Target folder \"{dir}\" does not exist any more" : "La cartella di destinazione \"{dir}\" non esiste più",
+    "Not enough free space" : "Spazio libero insufficiente",
     "Uploading..." : "Caricamento in corso...",
     "..." : "...",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} di {totalSize} ({bitrate})",
@@ -41,10 +27,13 @@ OC.L10N.register(
     "Delete" : "Elimina",
     "Disconnect storage" : "Disconnetti archiviazione",
     "Unshare" : "Rimuovi condivisione",
+    "Could not load info for file \"{file}\"" : "Impossibile caricare le informazioni per il file \"{file}\"",
+    "Files" : "File",
     "Details" : "Dettagli",
     "Select" : "Seleziona",
     "Pending" : "In corso",
     "Unable to determine date" : "Impossibile determinare la data",
+    "Invalid path" : "Percorso non valido",
     "This operation is forbidden" : "Questa operazione è vietata",
     "This directory is unavailable, please check the logs or contact the administrator" : "Questa cartella non è disponibile, controlla i log o contatta l'amministratore",
     "Could not move \"{file}\", target exists" : "Impossibile spostare \"{file}\", la destinazione esiste già",
@@ -55,16 +44,15 @@ OC.L10N.register(
     "Could not rename \"{fileName}\"" : "Impossibile rinominare \"{fileName}\"",
     "Could not create file \"{file}\"" : "Impossibile creare il file \"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "Impossibile creare il file \"{file}\" poiché esiste già",
-    "Could not create folder \"{dir}\"" : "Impossibile creare la cartella \"{dir}\"",
     "Could not create folder \"{dir}\" because it already exists" : "Impossibile creare la cartella \"{dir}\" poiché esiste già",
     "Error deleting file \"{fileName}\"." : "Errore durante l'eliminazione del file \"{fileName}\".",
-    "No entries in this folder match '{filter}'" : "Nessuna voce in questa cartella corrisponde a '{filter}'",
     "Name" : "Nome",
     "Size" : "Dimensione",
     "Modified" : "Modificato",
     "_%n folder_::_%n folders_" : ["%n cartella","%n cartelle"],
     "_%n file_::_%n files_" : ["%n file","%n file"],
     "{dirs} and {files}" : "{dirs} e {files}",
+    "_including %n hidden_::_including %n hidden_" : ["Incluso %n nascosto","Inclusi %n nascosti"],
     "You don’t have permission to upload or create files here" : "Qui non hai i permessi di caricare o creare file",
     "_Uploading %n file_::_Uploading %n files_" : ["Caricamento di %n file in corso","Caricamento di %n file in corso"],
     "New" : "Nuovo",
@@ -79,7 +67,7 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
     "Favorited" : "Preferiti",
     "Favorite" : "Preferito",
-    "Local link" : "Collegamento locale",
+    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Collegamento Privato: Solo le persone che hanno accesso a questo file/cartella possono utilizzarlo.\nUtilizzalo come un collegamento permanente per te. Oppure, dentro una condivisione, per puntare a quei file.",
     "Folder" : "Cartella",
     "New folder" : "Nuova cartella",
     "{newname} already exists" : "{newname} esiste già",
