@@ -1,38 +1,27 @@
 OC.L10N.register(
     "files",
     {
-    "Storage not available" : "Сториџот не е достапен",
     "Storage invalid" : "Сториџот не е валиден",
     "Unknown error" : "Непозната грешка",
-    "Unable to set upload directory." : "Не може да се постави папката за префрлање на податоци.",
-    "Invalid Token" : "Грешен токен",
-    "No file was uploaded. Unknown error" : "Ниту еден фајл не се вчита. Непозната грешка",
-    "There is no error, the file uploaded with success" : "Датотеката беше успешно подигната.",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Подигнатата датотека ја надминува upload_max_filesize директивата во php.ini:",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Големината на датотеката ја надминува MAX_FILE_SIZE директивата која беше специфицирана во HTML формата",
-    "The uploaded file was only partially uploaded" : "Датотеката беше само делумно подигната.",
-    "No file was uploaded" : "Не беше подигната датотека.",
-    "Missing a temporary folder" : "Недостасува привремена папка",
-    "Failed to write to disk" : "Неуспеав да запишам на диск",
-    "Not enough storage available" : "Нема доволно слободен сториџ",
-    "Upload failed. Could not find uploaded file" : "Префрлањето е неуспешно. Не можам да го најдам префрлената датотека.",
-    "Invalid directory." : "Погрешна папка.",
-    "Files" : "Датотеки",
     "All files" : "Сите датотеки",
-    "Favorites" : "Омилени",
+    "Saved" : "Снимено",
     "Home" : "Дома",
     "Close" : "Затвори",
+    "Favorites" : "Омилени",
     "Upload cancelled." : "Преземањето е прекинато.",
-    "Could not get result from server." : "Не можам да добијам резултат од серверот.",
+    "Uploading..." : "Подигнувам...",
+    "..." : "...",
     "File upload is in progress. Leaving the page now will cancel the upload." : "Подигање на датотека е во тек. Напуштење на страницата ќе го прекине.",
     "Actions" : "Акции",
     "Download" : "Преземи",
     "Rename" : "Преименувај",
     "Delete" : "Избриши",
     "Unshare" : "Не споделувај",
+    "Files" : "Датотеки",
     "Details" : "Детали:",
     "Select" : "Избери",
     "Pending" : "Чека",
+    "Invalid path" : "Грешна патека",
     "This operation is forbidden" : "Операцијата не е дозволена",
     "Name" : "Име",
     "Size" : "Големина",
@@ -67,7 +56,6 @@ OC.L10N.register(
     "Missing permissions to edit from here." : "Недостасуваат пермисии за да уредувате од тука",
     "Settings" : "Подесувања",
     "WebDAV" : "WebDAV",
-    "Cancel upload" : "Откажи прикачување",
     "No files in here" : "Тука нема датотеки",
     "No entries found in this folder" : "Нема ништо во оваа папка",
     "Select all" : "Избери се",
@@ -75,12 +63,6 @@ OC.L10N.register(
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Датотеките кои се обидувате да ги подигнете ја надминуваат максималната големина за подигнување датотеки на овој сервер.",
     "Files and folders you mark as favorite will show up here" : "Датотеките и папките кои ќе ги означите како чести, ќе се појават тука",
     "Text file" : "Текстуална датотека",
-    "New text file.txt" : "Нова текстуална датотека file.txt",
-    "Changed by %2$s" : "Променето од %2$s",
-    "Deleted by %2$s" : "Избришано од %2$s",
-    "Restored by %2$s" : "Повратено од %2$s",
-    "You changed %1$s" : "Вие изменивте %1$s",
-    "You created %1$s" : "Вие креиравте %1$s",
-    "You deleted %1$s" : "Вие избришавте %1$s"
+    "New text file.txt" : "Нова текстуална датотека file.txt"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
