@@ -1,36 +1,22 @@
 OC.L10N.register(
     "files",
     {
-    "Storage not available" : "Opslag niet beschikbaar",
+    "Storage is temporarily not available" : "Opslag is tijdelijk niet beschikbaar",
     "Storage invalid" : "Opslag ongeldig",
     "Unknown error" : "Onbekende fout",
-    "Unable to set upload directory." : "Kan uploadmap niet instellen.",
-    "Invalid Token" : "Ongeldig Token",
-    "No file was uploaded. Unknown error" : "Er was geen bestand geladen.  Onbekende fout",
-    "There is no error, the file uploaded with success" : "Het bestand is succesvol geüpload.",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Het geüploade bestand overscheidt de upload_max_filesize optie in php.ini:",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Het bestand overschrijdt de MAX_FILE_SIZE instelling dat is opgegeven in het HTML formulier",
-    "The uploaded file was only partially uploaded" : "Het bestand is slechts gedeeltelijk geüpload",
-    "No file was uploaded" : "Er is geen bestand geüpload",
-    "Missing a temporary folder" : "Er ontbreekt een tijdelijke map",
-    "Failed to write to disk" : "Schrijven naar schijf mislukt",
-    "Not enough storage available" : "Niet genoeg opslagruimte beschikbaar",
-    "The target folder has been moved or deleted." : "De doelmap is verplaatst of verwijderd.",
-    "Upload failed. Could not find uploaded file" : "Upload mislukt. Kon geüploade bestand niet vinden",
-    "Upload failed. Could not get file info." : "Upload mislukt. Kon geen bestandsinfo krijgen.",
-    "Invalid directory." : "Ongeldige directory.",
-    "Files" : "Bestanden",
     "All files" : "Alle bestanden",
+    "Saved" : "Bewaard",
+    "There was an error saving" : "Er trad een fout op bij opslaan",
     "File could not be found" : "Bestand kon niet worden gevonden",
     "Home" : "Thuis",
     "Close" : "Sluiten",
     "Favorites" : "Favorieten",
+    "Could not create folder \"{dir}\"" : "Kon map \"{dir}\" niet aanmaken",
     "Upload cancelled." : "Uploaden geannuleerd.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan {filename} niet uploaden omdat het een map is of 0 bytes groot is",
-    "Total file size {size1} exceeds upload limit {size2}" : "Totale bestandsgrootte {size1} groter dan uploadlimiet {size2}",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Niet genoeg vrije ruimte. U upload {size1}, maar is is slechts {size2} beschikbaar",
-    "Error uploading file \"{fileName}\": {message}" : "Fout tijdens het uploaden van bestand \"{fileName}\": {message}",
-    "Could not get result from server." : "Kon het resultaat van de server niet terugkrijgen.",
+    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Niet genoeg vrije ruimte. U uploadt {size1}, maar is is slechts {size2} beschikbaar",
+    "Target folder \"{dir}\" does not exist any more" : "Doelmap \"{dir}\" bestaat niet mee",
+    "Not enough free space" : "Niet genoeg vrije ruimte beschikbaar",
     "Uploading..." : "Uploading...",
     "..." : "...",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} van {totalSize} ({bitrate})",
@@ -41,10 +27,13 @@ OC.L10N.register(
     "Delete" : "Verwijderen",
     "Disconnect storage" : "Verbinding met opslag verbreken",
     "Unshare" : "Stop met delen",
+    "Could not load info for file \"{file}\"" : "Kon info voor bestand \"{file}\" niet laden",
+    "Files" : "Bestanden",
     "Details" : "Details",
     "Select" : "Selecteer",
     "Pending" : "In behandeling",
     "Unable to determine date" : "Kon datum niet vaststellen",
+    "Invalid path" : "Ongeldig pad",
     "This operation is forbidden" : "Deze taak is verboden",
     "This directory is unavailable, please check the logs or contact the administrator" : "Deze map is niet beschikbaar. Verifieer de logs of neem contact op met de beheerder",
     "Could not move \"{file}\", target exists" : "Kon \"{file}\" niet verplaatsen, doel bestaat al",
@@ -55,15 +44,14 @@ OC.L10N.register(
     "Could not rename \"{fileName}\"" : "Kon \"{fileName}\" niet hernoemen",
     "Could not create file \"{file}\"" : "Kon \"{file}\" niet aanmaken",
     "Could not create file \"{file}\" because it already exists" : "Kon \"{file}\" niet aanmaken, omdat het al bestaat",
-    "Could not create folder \"{dir}\"" : "Kon map \"{dir}\" niet aanmaken",
     "Could not create folder \"{dir}\" because it already exists" : "Kon map \"{dir}\" niet aanmaken, omdat die al bestaat",
     "Error deleting file \"{fileName}\"." : "Fout bij verwijderen bestand \"{fileName}\".",
-    "No entries in this folder match '{filter}'" : "Niets in deze map komt overeen met '{filter}'",
     "Name" : "Naam",
     "Size" : "Grootte",
     "Modified" : "Aangepast",
     "_%n file_::_%n files_" : ["%n bestand","%n bestanden"],
     "{dirs} and {files}" : "{dirs} en {files}",
+    "_including %n hidden_::_including %n hidden_" : ["Inclusief %n verborgen","Inclusief %n verborgen"],
     "You don’t have permission to upload or create files here" : "U hebt geen toestemming om hier te uploaden of bestanden te maken",
     "_Uploading %n file_::_Uploading %n files_" : ["%n bestand aan het uploaden","%n bestanden aan het uploaden"],
     "New" : "Nieuw",
@@ -78,7 +66,7 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
     "Favorited" : "Favoriet",
     "Favorite" : "Favoriet",
-    "Local link" : "Lokale link",
+    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Privélink: alleen personen die toegang hebben tot het bestand of de map kunnen deze gebruiken. Gebruik het als een permanente link voor uzelf of om anderen te verwijzen naar bestanden binnen shares.",
     "Folder" : "Map",
     "New folder" : "Nieuwe map",
     "{newname} already exists" : "{newname} bestaat al",
