@@ -1,34 +1,17 @@
 OC.L10N.register(
     "files",
     {
-    "Storage not available" : "Spațiu de stocare indisponibil",
     "Storage invalid" : "Spațiu de stocare invalid",
     "Unknown error" : "Eroare necunoscută",
-    "Unable to set upload directory." : "Imposibil de a seta directorul pentru încărcare.",
-    "Invalid Token" : "Jeton Invalid",
-    "No file was uploaded. Unknown error" : "Niciun fișier nu a fost încărcat. Eroare necunoscută",
-    "There is no error, the file uploaded with success" : "Nu a apărut nici o eroare, fișierul a fost încărcat cu succes",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Fișierul încărcat depășește directiva upload_max_filesize din php.ini:",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Fișierul încărcat depășește directiva MAX_FILE_SIZE specificată în formularul HTML",
-    "The uploaded file was only partially uploaded" : "Fișierul a fost încărcat doar parțial",
-    "No file was uploaded" : "Nu a fost încărcat niciun fișier",
-    "Missing a temporary folder" : "Lipsește un dosar temporar",
-    "Failed to write to disk" : "Eroare la scrierea pe disc",
-    "Not enough storage available" : "Nu este disponibil suficient spațiu pe disc",
-    "The target folder has been moved or deleted." : "Dosarul țintă a fost mutat sau șters.",
-    "Upload failed. Could not find uploaded file" : "Încărcare eșuată. Nu se poate găsi fișierul încărcat",
-    "Upload failed. Could not get file info." : "Încărcare eșuată. Nu se pot obține informații despre fișier.",
-    "Invalid directory." : "Dosar invalid.",
-    "Files" : "Fișiere",
     "All files" : "Toate fișierele.",
+    "Saved" : "Salvat",
     "Home" : "Acasă",
     "Close" : "Închide",
     "Favorites" : "Favorite",
+    "Could not create folder \"{dir}\"" : "Nu s-a putut crea directorul \"{dir}\"",
     "Upload cancelled." : "Încărcare anulată.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nu se poate încărca {filename} deoarece este un director sau are mărimea de 0 octeți",
-    "Total file size {size1} exceeds upload limit {size2}" : "Mărimea fișierului este {size1} ce depășește limita de încărcare de {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Spațiu liber insuficient, încărcați {size1} însă doar {size2} disponibil rămas",
-    "Could not get result from server." : "Nu se poate obține rezultatul de la server.",
     "Uploading..." : "Încărcare",
     "..." : "...",
     "File upload is in progress. Leaving the page now will cancel the upload." : "Fișierul este în curs de încărcare. Părăsirea paginii va întrerupe încărcarea.",
@@ -38,10 +21,12 @@ OC.L10N.register(
     "Delete" : "Șterge",
     "Disconnect storage" : "Deconectează stocarea",
     "Unshare" : "Nu mai partaja",
+    "Files" : "Fișiere",
     "Details" : "Detalii",
     "Select" : "Alege",
     "Pending" : "În așteptare",
     "Unable to determine date" : "Nu s-a putut determina data",
+    "Invalid path" : "Cale invalidă",
     "This operation is forbidden" : "Operațiunea este interzisă",
     "This directory is unavailable, please check the logs or contact the administrator" : "Acest director nu este disponibil, te rugăm verifică logurile sau contactează un administrator",
     "Could not move \"{file}\", target exists" : "Nu s-a putut muta fișierul \"{file}\", există deja un altul cu același nume în directorul destinație",
@@ -52,10 +37,8 @@ OC.L10N.register(
     "Could not rename \"{fileName}\"" : "Nu s-a putut redenumi \"{fileName}\"",
     "Could not create file \"{file}\"" : "Nu s-a putut crea fișierul \"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "Nu s-a putut crea fișierul \"{file}\" deoarece există deja unul cu același nume",
-    "Could not create folder \"{dir}\"" : "Nu s-a putut crea directorul \"{dir}\"",
     "Could not create folder \"{dir}\" because it already exists" : "Nu s-a putut crea directorul \"{dir}\" deoarece există deja unul cu același nume",
     "Error deleting file \"{fileName}\"." : "Eroare la ștergerea fișierului \"{fileName}\".",
-    "No entries in this folder match '{filter}'" : "Niciun element din acest director nu se potrivește cu '{filter}'",
     "Name" : "Nume",
     "Size" : "Mărime",
     "Modified" : "Modificat",
@@ -73,7 +56,6 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n octet","%n octeți","%n octeți"],
     "Favorited" : "Adăugate la favorite",
     "Favorite" : "Favorit",
-    "Local link" : "Legătură locală",
     "Folder" : "Dosar",
     "New folder" : "Un nou dosar",
     "{newname} already exists" : "{newname} există deja",
