@@ -1,34 +1,20 @@
 OC.L10N.register(
     "files",
     {
-    "Storage not available" : "Úložisko nie je dostupné",
     "Storage invalid" : "Úložisko nie je platné",
     "Unknown error" : "Neznáma chyba",
-    "Unable to set upload directory." : "Nemožno nastaviť priečinok pre nahrané súbory.",
-    "Invalid Token" : "Neplatný token",
-    "No file was uploaded. Unknown error" : "Žiaden súbor nebol nahraný. Neznáma chyba",
-    "There is no error, the file uploaded with success" : "Nenastala žiadna chyba, súbor bol úspešne nahraný",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Nahraný súbor prekročil limit nastavený v upload_max_filesize v súbore php.ini:",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Ukladaný súbor prekračuje nastavenie MAX_FILE_SIZE z volieb HTML formulára.",
-    "The uploaded file was only partially uploaded" : "Ukladaný súbor sa nahral len čiastočne",
-    "No file was uploaded" : "Žiadny súbor nebol uložený",
-    "Missing a temporary folder" : "Chýba dočasný priečinok",
-    "Failed to write to disk" : "Zápis na disk sa nepodaril",
-    "Not enough storage available" : "Nedostatok dostupného úložného priestoru",
-    "The target folder has been moved or deleted." : "Cieľový priečinok bol premiestnený alebo odstránený.",
-    "Upload failed. Could not find uploaded file" : "Nahrávanie zlyhalo. Nepodarilo sa nájsť nahrávaný súbor",
-    "Upload failed. Could not get file info." : "Nahrávanie zlyhalo. Nepodarilo sa získať informácie o súbore.",
-    "Invalid directory." : "Neplatný priečinok.",
-    "Files" : "Súbory",
     "All files" : "Všetky súbory",
-    "Favorites" : "Obľúbené",
+    "Saved" : "Uložené",
+    "File could not be found" : "Súbor nenájdený",
     "Home" : "Domov",
     "Close" : "Zavrieť",
+    "Favorites" : "Obľúbené",
+    "Could not create folder \"{dir}\"" : "Nemožno vytvoriť adresár \"{dir}\"",
     "Upload cancelled." : "Odosielanie je zrušené.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nemožno nahrať súbor {filename}, pretože je to priečinok, alebo má 0 bitov",
-    "Total file size {size1} exceeds upload limit {size2}" : "Celková veľkosť súboru {size1} prekračuje upload limit {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nie je dostatok voľného miesta, chcete nahrať {size1} ale k dispozíciji je len {size2}",
-    "Could not get result from server." : "Nepodarilo sa dostať výsledky zo servera.",
+    "Uploading..." : "Nahrávam...",
+    "..." : "...",
     "File upload is in progress. Leaving the page now will cancel the upload." : "Opustenie stránky zruší práve prebiehajúce odosielanie súboru.",
     "Actions" : "Akcie",
     "Download" : "Sťahovanie",
@@ -36,13 +22,20 @@ OC.L10N.register(
     "Delete" : "Zmazať",
     "Disconnect storage" : "Odpojiť úložisko",
     "Unshare" : "Zrušiť zdieľanie",
+    "Files" : "Súbory",
     "Details" : "Podrobnosti",
     "Select" : "Vybrať",
     "Pending" : "Čaká",
     "Unable to determine date" : "Nemožno určiť dátum",
+    "Invalid path" : "Neplatná cesta",
     "This operation is forbidden" : "Táto operácia je zakázaná",
     "This directory is unavailable, please check the logs or contact the administrator" : "Priečinok je nedostupný, skontrolujte prosím logy, alebo kontaktujte správcu",
-    "No entries in this folder match '{filter}'" : "V tomto priečinku nič nezodpovedá '{filter}'",
+    "Could not move \"{file}\", target exists" : "Nie je možné presunúť „{file}“, cieľ už existuje",
+    "Could not move \"{file}\"" : "Nie je možné presunúť „{file}“",
+    "{newName} already exists" : "{newName} už existuje",
+    "Could not rename \"{fileName}\"" : "Nemožno premenovať súbor \"{fileName}\"",
+    "Could not create file \"{file}\"" : "Nemožno vytvoriť súbor \"{file}\"",
+    "Could not create file \"{file}\" because it already exists" : "Nemožno vytvoriť súbor \"{file}\", lebo už existuje",
     "Name" : "Názov",
     "Size" : "Veľkosť",
     "Modified" : "Upravené",
@@ -82,15 +75,17 @@ OC.L10N.register(
     "%2$s deleted %1$s" : "%2$s zmazal %1$s",
     "You restored %1$s" : "Bol obnovený %1$s",
     "%2$s restored %1$s" : "%2$s obnovil %1$s",
+    "Changed by %2$s" : "Zmenené používateľom %2$s",
+    "Deleted by %2$s" : "Vymazané používateľom %2$s",
+    "Restored by %2$s" : "Obnovené používateľom %2$s",
     "Upload (max. %s)" : "Nahrať (max. %s)",
     "File handling" : "Nastavenie správania sa k súborom",
     "Maximum upload size" : "Maximálna veľkosť odosielaného súboru",
     "max. possible: " : "najväčšie možné:",
     "Save" : "Uložiť",
     "Settings" : "Nastavenia",
+    "Show hidden files" : "Zobraziť skryté súbory",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Použite túto linku <a href=\"%s\" target=\"_blank\">pre prístup k vašim súborom cez WebDAV</a>",
-    "Cancel upload" : "Zrušiť nahrávanie",
     "No files in here" : "Nie sú tu žiadne súbory",
     "Upload some content or sync with your devices!" : "Nahrajte nejaký obsah alebo synchronizujte zo svojimi zariadeniami!",
     "No entries found in this folder" : "V tomto priečinku nebolo nič nájdené",
@@ -100,10 +95,6 @@ OC.L10N.register(
     "No favorites" : "Žiadne obľúbené",
     "Files and folders you mark as favorite will show up here" : "Súbory a priečinky označené ako obľúbené budú zobrazené tu",
     "Text file" : "Textový súbor",
-    "New text file.txt" : "Nový text file.txt",
-    "You changed %1$s" : "Zmenili ste %1$s",
-    "You created %1$s" : "Vytvorili ste %1$s",
-    "You deleted %1$s" : "Bol zmazaný %1$s",
-    "You restored %1$s" : "Bol obnovený %1$s"
+    "New text file.txt" : "Nový text file.txt"
 },
 "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
