@@ -1,35 +1,22 @@
 OC.L10N.register(
     "files",
     {
-    "Storage not available" : "Na voljo ni dovolj prostora",
+    "Storage is temporarily not available" : "Shramba trenutno ni na voljo",
     "Storage invalid" : "Določen prostor ni veljaven",
     "Unknown error" : "Neznana napaka",
-    "Unable to set upload directory." : "Mapo, v katero boste prenašali dokumente, ni mogoče določiti",
-    "Invalid Token" : "Neveljaven žeton",
-    "No file was uploaded. Unknown error" : "Ni poslane datoteke. Neznana napaka.",
-    "There is no error, the file uploaded with success" : "Datoteka je uspešno naložena.",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Poslana datoteka presega dovoljeno velikost, ki je določena z možnostjo upload_max_filesize v datoteki php.ini:",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Poslana datoteka presega velikost, ki jo določa parameter največje dovoljene velikosti v obrazcu HTML.",
-    "The uploaded file was only partially uploaded" : "Poslan je le del datoteke.",
-    "No file was uploaded" : "Ni poslane datoteke",
-    "Missing a temporary folder" : "Manjka začasna mapa",
-    "Failed to write to disk" : "Pisanje na disk je spodletelo",
-    "Not enough storage available" : "Na voljo ni dovolj prostora",
-    "The target folder has been moved or deleted." : "Ciljna mapa je premaknjena ali izbrisana.",
-    "Upload failed. Could not find uploaded file" : "Pošiljanje je spodletelo. Ni mogoče najti poslane datoteke.",
-    "Upload failed. Could not get file info." : "Pošiljanje je spodletelo. Ni mogoče pridobiti podrobnosti datoteke.",
-    "Invalid directory." : "Neveljavna mapa.",
-    "Files" : "Datoteke",
     "All files" : "Vse datoteke",
+    "Saved" : "Shranjeno",
+    "There was an error saving" : "Med shranjevanjem je prišlo do napake",
+    "File could not be found" : "Datoteke ni mogoče najti",
     "Home" : "Domači naslov",
     "Close" : "Zapri",
     "Favorites" : "Priljubljene",
+    "Could not create folder \"{dir}\"" : "Ni mogoče ustvariti mape \"{dir}\"",
     "Upload cancelled." : "Pošiljanje je preklicano.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ni mogoče poslati datoteke {filename}, saj je to ali mapa ali pa je velikost datoteke 0 bajtov.",
-    "Total file size {size1} exceeds upload limit {size2}" : "Skupna velikost {size1} presega omejitev velikosti {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Na voljo ni dovolj prostora. Velikost poslane datoteke je {size1}, na voljo pa je je {size2}.",
-    "Error uploading file \"{fileName}\": {message}" : "Napaka pošiljanja datoteke \"{fileName}\": {message}",
-    "Could not get result from server." : "Ni mogoče pridobiti podatkov s strežnika.",
+    "Target folder \"{dir}\" does not exist any more" : "Ciljna mapa \"{dir}\" ne obstaja več",
+    "Not enough free space" : "Na voljo ni dovolj prostora",
     "Uploading..." : "Poteka pošiljanje ...",
     "..." : "...",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} od {totalSize} ({bitrate})",
@@ -40,30 +27,32 @@ OC.L10N.register(
     "Delete" : "Izbriši",
     "Disconnect storage" : "Odklopi shrambo",
     "Unshare" : "Prekini souporabo",
+    "Could not load info for file \"{file}\"" : "Ni mogoče naložiti podrobnosti za datoteko »{file}«",
+    "Files" : "Datoteke",
     "Details" : "Podrobnosti",
     "Select" : "Izberi",
     "Pending" : "V čakanju ...",
     "Unable to determine date" : "Ni mogoče določiti datuma",
+    "Invalid path" : "Neveljavna pot",
     "This operation is forbidden" : "To dejanje ni dovoljeno!",
     "This directory is unavailable, please check the logs or contact the administrator" : "Mapa ni na voljo. Preverite dnevnik in stopite v stik s skrbnikom sistema.",
     "Could not move \"{file}\", target exists" : "Datoteke \"{file}\" ni mogoče premakniti, ker cilj že obstaja",
     "Could not move \"{file}\"" : "Ni mogoče premakniti \"{file}\"",
     "{newName} already exists" : "{newName} že obstaja",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Ni mogoče preimenovati \"{fileName}\", ker datoteka ne obstaja več",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ime \"{targetName}\" je že v uporabi v mapi \"{dir}\". Izberite drugo ime ali drugo mapo.",
+    "Could not rename \"{fileName}\", it does not exist any more" : "Datoteke »{fileName}« ni mogoče preimenovati, ker ne obstaja več",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ime »{targetName}« je že v uporabi v mapi »{dir}«. Izberite drugo ime ali drugo mapo.",
     "Could not rename \"{fileName}\"" : "Ni mogoče preimenovati \"{fileName}\"",
     "Could not create file \"{file}\"" : "Ni mogoče ustvariti datoteke \"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "Ni mogoče ustvariti datoteke \"{file}\", ker že obstaja",
-    "Could not create folder \"{dir}\"" : "Ni mogoče ustvariti mape \"{dir}\"",
     "Could not create folder \"{dir}\" because it already exists" : "Ni mogoče ustvariti mape \"{dir}\", ker že obstaja",
     "Error deleting file \"{fileName}\"." : "Napaka brisanja datoteke \"{fileName}\".",
-    "No entries in this folder match '{filter}'" : "Ni zadetkov, ki bi bili skladni z nizom '{filter}'",
     "Name" : "Ime",
     "Size" : "Velikost",
     "Modified" : "Spremenjeno",
     "_%n folder_::_%n folders_" : ["%n mapa","%n mapi","%n mape","%n map"],
     "_%n file_::_%n files_" : ["%n datoteka","%n datoteki","%n datoteke","%n datotek"],
     "{dirs} and {files}" : "{dirs} in {files}",
+    "_including %n hidden_::_including %n hidden_" : ["z vključno %n skritim","z vključno %n skritima","z vključno %n skritimi","z vključno %n skritimi"],
     "You don’t have permission to upload or create files here" : "Ni ustreznih dovoljenj za pošiljanje ali ustvarjanje datotek na tem mestu.",
     "_Uploading %n file_::_Uploading %n files_" : ["Posodabljanje %n datoteke","Posodabljanje %n datotek","Posodabljanje %n datotek","Posodabljanje %n datotek"],
     "New" : "Novo",
@@ -78,17 +67,16 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n bajt","%n bajta","%n bajti","%n bajtov"],
     "Favorited" : "Označeno kot priljubljeno",
     "Favorite" : "Priljubljene",
-    "Local link" : "Krajevna povezava",
     "Folder" : "Mapa",
     "New folder" : "Nova mapa",
     "{newname} already exists" : "{newname} že obstaja",
     "Upload" : "Pošlji",
     "An error occurred while trying to update the tags" : "Prišlo je do napake med posodabljanjem oznak",
-    "A new file or folder has been <strong>created</strong>" : "Nova datoteka ali mapa je <strong>ustvarjena</strong>",
-    "A file or folder has been <strong>changed</strong>" : "Datoteka ali mapa je <strong>spremenjena</strong>.",
-    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Omeji obvestila o ustvarjanju in spreminjanju <strong>najpogosteje uporabljenih </strong> datotek <em>(omogoči pretok)</em>",
-    "A file or folder has been <strong>deleted</strong>" : "Datoteka ali mapa je <strong>izbrisana</strong>.",
-    "A file or folder has been <strong>restored</strong>" : "Datoteka ali mapa je <strong>obnovljena</strong>.",
+    "A new file or folder has been <strong>created</strong>" : "<strong>Ustvarjena</strong> je nova datoteka ali mapa.",
+    "A file or folder has been <strong>changed</strong>" : "<strong>Spremenjena</strong> je datoteka ali mapa",
+    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Omeji obvestila o ustvarjanju in spreminjanju <strong>najpogosteje uporabljenih </strong> datotek <em>(omogoči pretok)</em>.",
+    "A file or folder has been <strong>deleted</strong>" : "<strong>Izbrisana</strong> je datoteka ali mapa",
+    "A file or folder has been <strong>restored</strong>" : "<strong>Obnovljena</strong> je datoteka ali mapa",
     "You created %1$s" : "Ustvarili ste %1$s",
     "%2$s created %1$s" : "%2$s je ustvaril %1$s",
     "%1$s was created in a public folder" : "Datoteka %1$s je ustvarjena v javni mapi.",
