@@ -1,38 +1,21 @@
 OC.L10N.register(
     "files",
     {
-    "Storage not available" : "Depolama mevcut değil",
     "Storage invalid" : "Depolama geçersiz",
     "Unknown error" : "Bilinmeyen hata",
-    "Unable to set upload directory." : "Yükleme dizini ayarlanamadı.",
-    "Invalid Token" : "Geçersiz Belirteç",
-    "No file was uploaded. Unknown error" : "Dosya yüklenmedi. Bilinmeyen hata",
-    "There is no error, the file uploaded with success" : "Dosya başarıyla yüklendi, hata oluşmadı",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "php.ini dosyasında upload_max_filesize ile belirtilen dosya yükleme sınırı aşıldı:",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yüklenecek dosyanın boyutu HTML formunda belirtilen MAX_FILE_SIZE limitini aşıyor",
-    "The uploaded file was only partially uploaded" : "Dosya karşıya kısmen yüklenebildi",
-    "No file was uploaded" : "Hiç dosya gönderilmedi",
-    "Missing a temporary folder" : "Geçici bir dizin eksik",
-    "Failed to write to disk" : "Diske yazılamadı",
-    "Not enough storage available" : "Yeterli disk alanı yok",
-    "The target folder has been moved or deleted." : "Hedef klasör taşındı veya silindi.",
-    "Upload failed. Could not find uploaded file" : "Yükleme başarısız. Yüklenen dosya bulunamadı",
-    "Upload failed. Could not get file info." : "Yükleme başarısız. Dosya bilgisi alınamadı.",
-    "Invalid directory." : "Geçersiz dizin.",
-    "Files" : "Dosyalar",
     "All files" : "Tüm dosyalar",
+    "Saved" : "Kaydedildi",
     "File could not be found" : "Dosya bulunamadı",
     "Home" : "Ev",
     "Close" : "Kapat",
     "Favorites" : "Sık kullanılanlar",
+    "Could not create folder \"{dir}\"" : "\"{dir}\" klasörü oluşturulamadı",
     "Upload cancelled." : "Yükleme iptal edildi.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename} bir dizin veya 0 bayt olduğundan yüklenemedi",
-    "Total file size {size1} exceeds upload limit {size2}" : "Toplam dosya boyutu {size1}, {size2} gönderme sınırını aşıyor",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Yeterince boş alan yok. Gönderdiğiniz boyut {size1} ancak {size2} alan mevcut",
-    "Error uploading file \"{fileName}\": {message}" : "\"{fileName}\" dosyası yüklenirken hata: {message}",
-    "Could not get result from server." : "Sunucudan sonuç alınamadı.",
     "Uploading..." : "Yükleniyor...",
     "..." : "...",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
     "File upload is in progress. Leaving the page now will cancel the upload." : "Dosya yükleme işlemi sürüyor. Şu anda sayfadan ayrılmak yükleme işlemini iptal edecek.",
     "Actions" : "Eylemler",
     "Download" : "İndir",
@@ -40,10 +23,12 @@ OC.L10N.register(
     "Delete" : "Sil",
     "Disconnect storage" : "Depolama bağlantısını kes",
     "Unshare" : "Paylaşmayı Kaldır",
+    "Files" : "Dosyalar",
     "Details" : "Ayrıntılar",
     "Select" : "Seç",
     "Pending" : "Bekliyor",
     "Unable to determine date" : "Tarih tespit edilemedi",
+    "Invalid path" : "Geçersiz yol",
     "This operation is forbidden" : "Bu işlem yasak",
     "This directory is unavailable, please check the logs or contact the administrator" : "Bu dizine yazılamıyor, lütfen günlüğü kontrol edin veya yönetici ile iletişime geçin",
     "Could not move \"{file}\", target exists" : "\"{file}\" taşınamadı, hedef mevcut",
@@ -54,10 +39,8 @@ OC.L10N.register(
     "Could not rename \"{fileName}\"" : "\"{fileName}\" adlandırılamadı",
     "Could not create file \"{file}\"" : "\"{file}\" dosyası oluşturulamadı",
     "Could not create file \"{file}\" because it already exists" : "\"{file}\" dosyası zaten mevcut olduğundan oluşturulamadı",
-    "Could not create folder \"{dir}\"" : "\"{dir}\" klasörü oluşturulamadı",
     "Could not create folder \"{dir}\" because it already exists" : "\"{dir}\" klasörü zaten mevcut olduğundan oluşturulamadı",
     "Error deleting file \"{fileName}\"." : "\"{fileName}\" dosyası silinirken hata.",
-    "No entries in this folder match '{filter}'" : "Bu klasörde hiçbir girdi '{filter}' ile eşleşmiyor",
     "Name" : "İsim",
     "Size" : "Boyut",
     "Modified" : "Değiştirilme",
@@ -78,7 +61,6 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n bayt","%n bayt"],
     "Favorited" : "Sık kullanılanlara eklendi",
     "Favorite" : "Sık kullanılan",
-    "Local link" : "Yerel bağlantı",
     "Folder" : "Klasör",
     "New folder" : "Yeni klasör",
     "{newname} already exists" : "{newname} zaten mevcut",
