@@ -1,36 +1,22 @@
 OC.L10N.register(
     "files",
     {
-    "Storage not available" : "存储空间不可用",
+    "Storage is temporarily not available" : "存储临时性不可用",
     "Storage invalid" : "存储空间无效",
     "Unknown error" : "未知错误",
-    "Unable to set upload directory." : "无法设置上传文件夹。",
-    "Invalid Token" : "无效密匙",
-    "No file was uploaded. Unknown error" : "没有文件被上传。未知错误",
-    "There is no error, the file uploaded with success" : "文件上传成功，没有错误发生",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "上传文件大小已超过php.ini中upload_max_filesize所规定的值",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上传的文件长度超出了 HTML 表单中 MAX_FILE_SIZE 的限制",
-    "The uploaded file was only partially uploaded" : "已上传文件只上传了部分（不完整）",
-    "No file was uploaded" : "没有文件被上传",
-    "Missing a temporary folder" : "缺少临时目录",
-    "Failed to write to disk" : "写入磁盘失败",
-    "Not enough storage available" : "没有足够的存储空间",
-    "The target folder has been moved or deleted." : "目标文件夹已经被移动或删除。",
-    "Upload failed. Could not find uploaded file" : "上传失败。未发现上传的文件",
-    "Upload failed. Could not get file info." : "上传失败。无法获取文件信息。",
-    "Invalid directory." : "无效文件夹。",
-    "Files" : "文件",
     "All files" : "全部文件",
+    "Saved" : "已保存",
+    "There was an error saving" : "保存错误",
     "File could not be found" : "文件未找到",
     "Home" : "家庭",
     "Close" : "关闭",
     "Favorites" : "收藏",
+    "Could not create folder \"{dir}\"" : "不能创建文件夹 \"{dir}\"",
     "Upload cancelled." : "上传已取消",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "不能上传文件 {filename} ，由于它是一个目录或者为0字节",
-    "Total file size {size1} exceeds upload limit {size2}" : "总文件大小 {size1} 超过上传限制 {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "没有足够的可用空间，您正在上传 {size1} 的文件但是只有 {size2} 可用。",
-    "Error uploading file \"{fileName}\": {message}" : "上传文件错误 \"{fileName}\": {message}",
-    "Could not get result from server." : "不能从服务器得到结果",
+    "Target folder \"{dir}\" does not exist any more" : "目标目录“{dir}”不存在",
+    "Not enough free space" : "空闲空间不足",
     "Uploading..." : "上传中...",
     "..." : "...",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
@@ -41,10 +27,13 @@ OC.L10N.register(
     "Delete" : "删除",
     "Disconnect storage" : "断开储存连接",
     "Unshare" : "取消共享",
+    "Could not load info for file \"{file}\"" : "无法加载文件 \"{file}\" 的信息",
+    "Files" : "文件",
     "Details" : "详细信息",
     "Select" : "选择",
     "Pending" : "等待",
     "Unable to determine date" : "无法确定日期",
+    "Invalid path" : "无效路径",
     "This operation is forbidden" : "操作被禁止",
     "This directory is unavailable, please check the logs or contact the administrator" : "此目录不可用，请检查日志或联系管理员",
     "Could not move \"{file}\", target exists" : "不能移动 \"{file}\"，目标已存在。",
@@ -55,21 +44,21 @@ OC.L10N.register(
     "Could not rename \"{fileName}\"" : "不能重命名 \"{fileName}\"",
     "Could not create file \"{file}\"" : "不能创建文件 \"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "不能创建文件 \"{file}\" ，因为它已经存在",
-    "Could not create folder \"{dir}\"" : "不能创建文件夹 \"{dir}\"",
     "Could not create folder \"{dir}\" because it already exists" : "不能创建文件夹 \"{dir}\" ，因为它已经存在",
     "Error deleting file \"{fileName}\"." : "删除文件 \"{fileName}\" 时出错。",
-    "No entries in this folder match '{filter}'" : "此文件夹中无项目匹配“{filter}”",
     "Name" : "名称",
     "Size" : "大小",
     "Modified" : "修改日期",
     "_%n folder_::_%n folders_" : ["%n 文件夹"],
     "_%n file_::_%n files_" : ["%n个文件"],
     "{dirs} and {files}" : "{dirs} 和 {files}",
-    "You don’t have permission to upload or create files here" : "您没有权限来上传湖州哦和创建文件",
+    "_including %n hidden_::_including %n hidden_" : ["包含 %n 隐藏项"],
+    "You don’t have permission to upload or create files here" : "您在这没有上传和创建文件的权限",
     "_Uploading %n file_::_Uploading %n files_" : ["上传 %n 个文件"],
     "New" : "新建",
     "\"{name}\" is an invalid file name." : "“{name}”是一个无效的文件名。",
     "File name cannot be empty." : "文件名不能为空。",
+    "\"{name}\" has a forbidden file type/extension." : "\"{name}\" 的文件类型/扩展名被禁止。",
     "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} 的存储空间已满，文件将无法更新或同步！",
     "Your storage is full, files can not be updated or synced anymore!" : "您的存储空间已满，文件将无法更新或同步！",
     "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} 的存储空间即将用完 ({usedSpacePercent}%)",
@@ -79,7 +68,7 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n 字节"],
     "Favorited" : "已收藏",
     "Favorite" : "收藏",
-    "Local link" : "本地链接",
+    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "私人链接：只有有权访问该文件/文件夹的人才可以使用它。将其作为给您自己或者其他人分享文件的永久链接。",
     "Folder" : "文件夹",
     "New folder" : "增加文件夹",
     "{newname} already exists" : "{newname} 已经存在",
