@@ -3,25 +3,25 @@ OC.L10N.register(
     {
     "Personal" : "شخصي",
     "System" : "النظام",
-    "Never" : "أبدا",
     "Saved" : "حفظ",
-    "None" : "لا شيء",
-    "App key" : "مفتاح التطبيق",
-    "App secret" : "التطبيق السري",
     "Username" : "إسم المستخدم",
     "Password" : "كلمة السر",
+    "Save" : "حفظ",
+    "App key" : "مفتاح التطبيق",
+    "App secret" : "التطبيق السري",
     "Bucket" : "الحزمة",
     "Hostname" : "إسم الإستضافة",
     "Port" : "المنفذ",
     "Region" : "المنطقة",
     "WebDAV" : "WebDAV",
     "URL" : "عنوان الموقع",
-    "Host" : "المضيف",
     "Local" : "محلي",
     "Location" : "المكان",
     "ownCloud" : "ownCloud",
+    "Host" : "المضيف",
     "Share" : "شارك",
     "Name" : "اسم",
+    "Never" : "أبدا",
     "Folder name" : "اسم المجلد",
     "Configuration" : "إعداد",
     "Delete" : "إلغاء"
