@@ -4,25 +4,24 @@ OC.L10N.register(
     "Step 1 failed. Exception: %s" : "1-ci addım səhv oldu. İstisna: %s",
     "Step 2 failed. Exception: %s" : "2-ci addım. İstisna: %s",
     "External storage" : "Kənar informasıya daşıyıcısı",
-    "Storage with id \"%i\" not found" : "\"%i\"-li depo tapılmadı",
-    "Invalid mount point" : "Yalnış mount nöqtəsi",
-    "Invalid storage backend \"%s\"" : "Yalnış depo arxasonu \"%s\"",
     "Personal" : "Şəxsi",
     "System" : "Sistem",
     "Grant access" : "Yetkinin verilməsi",
-    "Access granted" : "Yetki verildi",
     "Generate keys" : "Açarları generasiya et",
     "Error generating key pair" : "Açar cütlüyünün generasiyası səhvi",
     "All users. Type to select user or group." : "Sistem istifadəçiləri. Daxil edin ki, istifadəçi və ya qrupu seçəsiniz.",
     "(group)" : "(qrup)",
     "Saved" : "Saxlanıldı",
-    "None" : "Heç bir",
+    "Username" : "İstifadəçi adı",
+    "Password" : "Şifrə",
+    "Save" : "Saxla",
+    "Storage with id \"%i\" not found" : "\"%i\"-li depo tapılmadı",
+    "Invalid mount point" : "Yalnış mount nöqtəsi",
+    "Invalid storage backend \"%s\"" : "Yalnış depo arxasonu \"%s\"",
     "App key" : "Proqram açarı",
     "App secret" : "Proqram sirri",
     "Client ID" : "Müştəri İD-s",
     "Client secret" : "Müxtəri sirri",
-    "Username" : "İstifadəçi adı",
-    "Password" : "Şifrə",
     "Public key" : "İctimai açar",
     "Amazon S3" : "Amazon S3",
     "Bucket" : "Vedrə",
@@ -36,20 +35,17 @@ OC.L10N.register(
     "Remote subfolder" : "Uzaq altqovluğu",
     "Secure https://" : "Təhlükəsiz https://",
     "Dropbox" : "Dropbox",
-    "Host" : "Şəbəkədə ünvan",
-    "Secure ftps://" : "Təhlükəsiz ftps://",
     "Local" : "Yerli",
     "Location" : "Yerləşdiyiniz ünvan",
+    "Host" : "Şəbəkədə ünvan",
     "Share" : "Yayımla",
     "SMB / CIFS using OC login" : "OC login istifadə edir SMB / CIFS",
     "Username as share" : "Paylaşım üçün istifadəçi adı",
     "OpenStack Object Storage" : "OpenStack Obyekt Deposu",
     "<b>Note:</b> " : "<b>Qeyd:</b> ",
     "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Qeyd:</b> PHP-də cURL dəstəyi aktiv deyil və ya yüklənməyib. %s -in birləşdirilməsi mümkün deyil. Xahiş edilir onun yüklənilməsi barəsində inzibatşınıza məlumat verəsiniz.",
-    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Qeyd:</b> PHP-də FTP dəstəyi aktiv deyil və ya yüklənməyib. %s -in birləşdirilməsi mümkün deyil. Xahiş edilir onun yüklənilməsi barəsində inzibatşınıza məlumat verəsiniz.",
     "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Qeyd:</b> \"%s\" yüklənməyib. %s -in birləşdirilməsi mümkün deyil. Xahiş edilir onun yüklənilməsi barəsində inzibatşınıza məlumat verəsiniz.",
     "No external storage configured" : "Kənar depo konfiq edilməyib",
-    "You can add external storages in the personal settings" : "Siz şəxsi quraşdırmalarınızda kənar depo əlavə edə bilərsiniz",
     "Name" : "Ad",
     "Storage type" : "Depo tipi",
     "Scope" : "Həcm",
@@ -57,10 +53,9 @@ OC.L10N.register(
     "Folder name" : "Qovluq adı",
     "Configuration" : "Konfiqurasiya",
     "Available for" : "Üçün mövcuddur",
+    "Add storage" : "Deponu əlavə et",
     "Advanced settings" : "İrəliləmiş quraşdırmalar",
     "Delete" : "Sil",
-    "Add storage" : "Deponu əlavə et",
-    "Enable User External Storage" : "İstifadəçi kənar deponu aktivləşdir",
     "Allow users to mount the following external storage" : "Göstərilən kənar deponun bərkidilməsi üçün istifadəçilərə izin ver"
 },
 "nplurals=2; plural=(n != 1);");
