@@ -1,13 +1,15 @@
 OC.L10N.register(
     "files_external",
     {
-    "Location" : "Ort",
-    "Port" : "Port",
-    "Host" : "Host",
+    "Personal" : "Persönlich",
     "Username" : "Benutzername",
     "Password" : "Passwort",
+    "Save" : "Speichern",
+    "Port" : "Port",
+    "Location" : "Ort",
+    "Host" : "Host",
     "Share" : "Freigeben",
-    "Personal" : "Persönlich",
+    "Name" : "Name",
     "Folder name" : "Ordner Name",
     "Delete" : "Löschen"
 },
