@@ -2,19 +2,10 @@ OC.L10N.register(
     "files_external",
     {
     "External storage" : "Malena memorilo",
-    "Invalid storage backend \"%s\"" : "Ne validas memormotoro \"%s”",
-    "Not permitted to use backend \"%s\"" : "Ne permesatas uzi motoron “%s”",
-    "Insufficient data: %s" : "Nesufiĉaj datumoj: %s",
-    "%s" : "%s",
     "Personal" : "Persona",
     "System" : "Sistemo",
     "Grant access" : "Doni alirpermeson",
-    "Access granted" : "Alirpermeso donita",
     "Generate keys" : "Generi ŝlosilojn",
-    "Enable encryption" : "Kapabligi ĉifradon",
-    "Enable previews" : "Kapabligi antaŭvidojn",
-    "Enable sharing" : "Kapabligi kunhavigadon",
-    "Never" : "Neniam",
     "All users. Type to select user or group." : "Ĉiuj uzantoj. Tajpu por elekti uzanton aŭ grupon.",
     "(group)" : "(grupo)",
     "Admin defined" : "Difinita de administranto",
@@ -22,15 +13,17 @@ OC.L10N.register(
     "Username" : "Uzantonomo",
     "Password" : "Pasvorto",
     "Save" : "Konservi",
+    "Invalid storage backend \"%s\"" : "Ne validas memormotoro \"%s”",
+    "Not permitted to use backend \"%s\"" : "Ne permesatas uzi motoron “%s”",
+    "Insufficient data: %s" : "Nesufiĉaj datumoj: %s",
+    "%s" : "%s",
     "Access key" : "Alira ŝlosilo",
     "Secret key" : "Sekreta ŝlosilo",
-    "None" : "Nenio",
     "App key" : "Aplikaĵa ŝlosilo",
     "App secret" : "Aplikaĵosekreto",
     "Client ID" : "Klientidentigilo",
     "Client secret" : "Klientosekreto",
     "API key" : "API-ŝlosilo",
-    "Username and password" : "Uzantonomo kaj pasvorto",
     "Public key" : "Publika ŝlosilo",
     "Amazon S3" : "Amazon S3",
     "Hostname" : "Gastigonomo",
@@ -42,13 +35,11 @@ OC.L10N.register(
     "Remote subfolder" : "Fora subdosierujo",
     "Secure https://" : "Sekura https://",
     "Dropbox" : "Dropbox",
-    "FTP" : "FTP",
-    "Host" : "Gastigo",
-    "Secure ftps://" : "Sekura ftps://",
     "Local" : "Loka",
     "Location" : "Loko",
     "ownCloud" : "ownCloud",
     "SFTP" : "SFTP",
+    "Host" : "Gastigo",
     "Root" : "Radiko",
     "SFTP with secret key login" : "SFTP kun sekretoŝlosila ensaluto",
     "Share" : "Kunhavigi",
@@ -59,6 +50,10 @@ OC.L10N.register(
     "Name" : "Nomo",
     "Storage type" : "Memortipo",
     "Scope" : "Amplekso",
+    "Enable encryption" : "Kapabligi ĉifradon",
+    "Enable previews" : "Kapabligi antaŭvidojn",
+    "Enable sharing" : "Kapabligi kunhavigadon",
+    "Never" : "Neniam",
     "External Storage" : "Malena memorilo",
     "Folder name" : "Dosierujnomo",
     "Authentication" : "Aŭtentigo",
