@@ -1,28 +1,27 @@
 OC.L10N.register(
     "files_external",
     {
-    "Please provide a valid Dropbox app key and secret." : "Por favor, proporcioná un secreto y una contraseña válida para la aplicación Dropbox.",
     "External storage" : "Almacenamiento externo",
-    "Location" : "Ubicación",
-    "Port" : "Puerto",
-    "Region" : "Provincia",
-    "Host" : "Servidor",
+    "Personal" : "Personal",
+    "Grant access" : "Permitir acceso",
+    "Saved" : "Guardado",
     "Username" : "Nombre de usuario",
     "Password" : "Contraseña",
-    "Share" : "Compartir",
+    "Save" : "Guardar",
+    "API key" : "clave API",
+    "Port" : "Puerto",
+    "Region" : "Provincia",
+    "WebDAV" : "WebDAV",
     "URL" : "URL",
-    "Access granted" : "Acceso permitido",
-    "Error configuring Dropbox storage" : "Error al configurar el almacenamiento de Dropbox",
-    "Grant access" : "Permitir acceso",
-    "Error configuring Google Drive storage" : "Error al configurar el almacenamiento de Google Drive",
-    "Personal" : "Personal",
-    "Saved" : "Guardado",
+    "Location" : "Ubicación",
+    "ownCloud" : "ownCloud",
+    "Host" : "Servidor",
+    "Share" : "Compartir",
     "Name" : "Nombre",
     "External Storage" : "Almacenamiento externo",
     "Folder name" : "Nombre de la carpeta",
     "Configuration" : "Configuración",
     "Add storage" : "Añadir almacenamiento",
-    "Delete" : "Borrar",
-    "Enable User External Storage" : "Habilitar almacenamiento de usuario externo"
+    "Delete" : "Borrar"
 },
 "nplurals=2; plural=(n != 1);");
