@@ -7,14 +7,12 @@ OC.L10N.register(
     "Personal" : "Pertsonala",
     "System" : "Sistema",
     "Grant access" : "Baimendu sarrera",
-    "Access granted" : "Sarrera baimendua",
     "All users. Type to select user or group." : "Erabiltzaile guztiak. Idatzi erabiltzaile edo taldea hautatzeko.",
     "(group)" : "(taldea)",
     "Saved" : "Gordeta",
     "Username" : "Erabiltzaile izena",
     "Password" : "Pasahitza",
     "Save" : "Gorde",
-    "None" : "Ezer",
     "App key" : "Aplikazio gakoa",
     "App secret" : "App sekretua",
     "Client ID" : "Bezero ID",
@@ -32,11 +30,10 @@ OC.L10N.register(
     "Remote subfolder" : "Urruneko azpikarpeta",
     "Secure https://" : "https:// segurua",
     "Dropbox" : "Dropbox",
-    "Host" : "Ostalaria",
-    "Secure ftps://" : "ftps:// segurua",
     "Local" : "Bertakoa",
     "Location" : "Kokapena",
     "ownCloud" : "ownCloud",
+    "Host" : "Ostalaria",
     "Root" : "Erroa",
     "Share" : "Partekatu",
     "SMB / CIFS using OC login" : "SMB / CIFS saioa hasteko OC erabiliz",
@@ -44,7 +41,6 @@ OC.L10N.register(
     "OpenStack Object Storage" : "OpenStack Objektu Biltegiratzea",
     "<b>Note:</b> " : "<b>Oharra:</b>",
     "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Oharra:</b> :PHPko cURL euskarria ez dago instalatuta edo gaitua. Ezinezko da %s muntatzea. Mesedez eskatu sistema administratzaleari instala dezan. ",
-    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Oharra:</b> :PHPko FTP euskarria ez dago instalatuta edo gaitua. Ezinezko da %s muntatzea. Mesedez eskatu sistema administratzaleari instala dezan. ",
     "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Oharra:</b>\"%s\" euskarria ez dago instalatuta Ezinezko da %s muntatzea. Mesedez eskatu sistema administratzaleari instala dezan. ",
     "No external storage configured" : "Ez da kanpo biltegiratzerik konfiguratu",
     "Name" : "Izena",
@@ -55,8 +51,6 @@ OC.L10N.register(
     "Available for" : "Hauentzat eskuragarri",
     "Add storage" : "Gehitu biltegiratzea",
     "Delete" : "Ezabatu",
-    "Allow users to mount the following external storage" : "Baimendu erabiltzaileak hurrengo kanpo biltegiratzeak muntatzen",
-    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Oharra:</b> :PHPko FTP euskarria ez dago instalatuta edo gaitua. Ezinezko da %s muntatzea. Mesedez eskatu sistema administratzaleari instala dezan. ",
-    "SMB / CIFS using OC login" : "SMB / CIFS saioa hasteko OC erabiliz"
+    "Allow users to mount the following external storage" : "Baimendu erabiltzaileak hurrengo kanpo biltegiratzeak muntatzen"
 },
 "nplurals=2; plural=(n != 1);");
