@@ -7,6 +7,37 @@ OC.L10N.register(
     "Step 1 failed. Exception: %s" : "L’étape 1 a échoué. Erreur : %s",
     "Step 2 failed. Exception: %s" : "L’étape 2 a échoué. Erreur : %s",
     "External storage" : "Stockage externe",
+    "Dropbox App Configuration" : "Configuration de l'application Dropbox",
+    "Google Drive App Configuration" : "Configuration de l'application Google Drive",
+    "Personal" : "Personnel",
+    "System" : "Système",
+    "Grant access" : "Autoriser l'accès",
+    "Error configuring OAuth1" : "Erreur lors de la configuration de OAuth1",
+    "Error configuring OAuth2" : "Erreur lors de la configuration de OAuth2",
+    "Generate keys" : "Générer des clés",
+    "Error generating key pair" : "Erreur lors de la génération des clés",
+    "All users. Type to select user or group." : "Tous les utilisateurs. Cliquez ici pour restreindre.",
+    "(group)" : "(groupe)",
+    "Compatibility with Mac NFD encoding (slow)" : "Compatibilité avec l'encodage Mac NFD (lent)",
+    "Admin defined" : "Défini par l'administrateur",
+    "Saved" : "Sauvegardé",
+    "Disabling external storage will unmount all storages for all users, are you sure ?" : "Désactiver le stockage externe va démonter tous les stockages de tous les utilisateurs, êtes-vous sûr ?",
+    "Disable external storage" : "Désactiver le stockage externe",
+    "Empty response from the server" : "Réponse vide du serveur",
+    "Couldn't access. Please logout and login to activate this mount point" : "Impossible d'accéder. Veuillez vous déconnecter et vous reconnecter pour activer ce point de montage.",
+    "Couldn't get the information from the ownCloud server: {code} {type}" : "Impossible d'obtenir l'information depuis le serveur ownCloud : {code} {type}",
+    "Couldn't get the list of external mount points: {type}" : "Impossible de récupérer la liste des points de montage externes : {type}",
+    "There was an error with message: " : "Il y a eu une erreur avec le message :",
+    "External mount error" : "Erreur de point de montage externe",
+    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Impossible d'obtenir la liste des points de montage des disques réseaux Windows : Réponse vide du serveur",
+    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Certains points de montage externes configurés ne sont pas connectés. Veuillez cliquer sur la(les) ligne(s) rouge(s) pour plus d'informations",
+    "Please enter the credentials for the {mount} mount" : "Veuillez entrer les identifiants pour le montage {mount}",
+    "Username" : "Nom d'utilisateur",
+    "Password" : "Mot de passe",
+    "Credentials saved" : "Identifiants sauvegardés",
+    "Credentials saving failed" : "La sauvegarde des identifiants a échoué",
+    "Credentials required" : "Des informations d'identification sont requises",
+    "Save" : "Enregistrer",
     "Storage with id \"%i\" not found" : "Stockage avec l'id \"%i\" non trouvé",
     "Invalid backend or authentication mechanism class" : "Service ou méthode d'authentification non valable",
     "Invalid mount point" : "Point de montage non valide",
@@ -19,44 +50,8 @@ OC.L10N.register(
     "Insufficient data: %s" : "Données insuffisantes : %s",
     "%s" : "%s",
     "Storage with id \"%i\" is not user editable" : "Le support de stockage d'id \"%i\" n'est pas modifiable par les utilisateurs",
-    "Personal" : "Personnel",
-    "System" : "Système",
-    "Grant access" : "Autoriser l'accès",
-    "Access granted" : "Accès autorisé",
-    "Error configuring OAuth1" : "Erreur lors de la configuration de OAuth1",
-    "Error configuring OAuth2" : "Erreur lors de la configuration de OAuth2",
-    "Generate keys" : "Générer des clés",
-    "Error generating key pair" : "Erreur lors de la génération des clés",
-    "Enable encryption" : "Activer le chiffrement",
-    "Enable previews" : "Activer les prévisualisations",
-    "Enable sharing" : "Permettre le partage",
-    "Check for changes" : "Rechercher les modifications",
-    "Never" : "Jamais",
-    "Once every direct access" : "Une fois à chaque accès direct",
-    "All users. Type to select user or group." : "Tous les utilisateurs. Cliquez ici pour restreindre.",
-    "(group)" : "(groupe)",
-    "Admin defined" : "Défini par l'administrateur",
-    "Saved" : "Sauvegardé",
-    "Empty response from the server" : "Réponse vide du serveur",
-    "Couldn't access. Please logout and login to activate this mount point" : "Impossible d'accéder. Veuillez vous déconnecter et vous reconnecter pour activer ce point de montage.",
-    "Couldn't get the information from the ownCloud server: {code} {type}" : "Impossible d'obtenir l'information depuis le serveur ownCloud : {code} {type}",
-    "Couldn't get the list of external mount points: {type}" : "Impossible de récupérer la liste des points de montage externes : {type}",
-    "There was an error with message: " : "Il y a eu une erreur avec le message :",
-    "External mount error" : "Erreur de point de montage externe",
-    "external-storage" : "external-storage",
-    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Impossible d'obtenir la liste des points de montage des disques réseaux Windows : Réponse vide du serveur",
-    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Certains points de montage externes configurés ne sont pas connectés. Veuillez cliquer sur la(les) ligne(s) rouge(s) pour plus d'informations",
-    "Please enter the credentials for the {mount} mount" : "Veuillez entrer les identifiants pour le montage {mount}",
-    "Username" : "Nom d'utilisateur",
-    "Password" : "Mot de passe",
-    "Credentials saved" : "Identifiants sauvegardés",
-    "Credentials saving failed" : "La sauvegarde des identifiants a échoué",
-    "Credentials required" : "Des informations d'identification sont requises",
-    "Save" : "Enregistrer",
     "Access key" : "Clé d'accès",
     "Secret key" : "Clé secrète",
-    "Builtin" : "Intégré",
-    "None" : "Aucun",
     "OAuth1" : "OAuth1",
     "App key" : "App key",
     "App secret" : "App secret",
@@ -68,8 +63,6 @@ OC.L10N.register(
     "Identity endpoint URL" : "Identity endpoint URL",
     "Rackspace" : "Rackspace",
     "API key" : "Clé API",
-    "Username and password" : "Nom d'utilisateur et mot de passe",
-    "Log-in credentials, save in session" : "Identifiants de connexion, sauvegardés pour la session",
     "RSA public key" : "Clé publique RSA",
     "Public key" : "Clef publique",
     "Amazon S3" : "Amazon S3",
@@ -84,14 +77,12 @@ OC.L10N.register(
     "Remote subfolder" : "Sous-dossier distant",
     "Secure https://" : "Sécurisation https://",
     "Dropbox" : "Dropbox",
-    "FTP" : "FTP",
-    "Host" : "Hôte",
-    "Secure ftps://" : "Sécurisation ftps://",
     "Google Drive" : "Google Drive",
     "Local" : "Local",
     "Location" : "Emplacement",
     "ownCloud" : "ownCloud",
     "SFTP" : "SFTP",
+    "Host" : "Hôte",
     "Root" : "Racine",
     "SFTP with secret key login" : "SFTP avec identification par clé",
     "SMB / CIFS" : "SMB / CIFS",
@@ -104,14 +95,21 @@ OC.L10N.register(
     "Request timeout (seconds)" : "Délai d'expiration des requêtes (en secondes)",
     "<b>Note:</b> " : "<b>Attention :</b>",
     "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Attention :</b> La prise en charge de cURL par PHP n'est pas activée ou installée. Le montage de %s n'est pas possible. Contactez votre administrateur système pour l'installer.",
-    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Attention : </b> La prise en charge du FTP par PHP n'est pas activée ou installée. Le montage de %s n'est pas possible. Contactez votre administrateur système pour l'installer.",
     "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Attention : </b> \"%s\" n'est pas installé. Le montage de %s n'est pas possible. Contactez votre administrateur système pour l'installer.",
     "No external storage configured" : "Aucun stockage externe configuré",
-    "You can add external storages in the personal settings" : "Vous pouvez ajouter des stockages externes via vos paramètres personnels",
+    "You can add external storages in the storage settings" : "Vous pouvez ajouter des stockages externes dans les paramètres de stockage",
     "Name" : "Nom",
     "Storage type" : "Type de stockage",
     "Scope" : "Portée",
+    "Enable encryption" : "Activer le chiffrement",
+    "Enable previews" : "Activer les prévisualisations",
+    "Enable sharing" : "Permettre le partage",
+    "Check for changes" : "Rechercher les modifications",
+    "Never" : "Jamais",
+    "Once every direct access" : "Une fois à chaque accès direct",
     "External Storage" : "Stockage externe",
+    "Enable external storage" : "Activer le stockage externe",
+    "External storage has been disabled by the administrator" : "Le stockage externe a été désactivé par l'adminstrateur",
     "Folder name" : "Nom du dossier",
     "Authentication" : "Authentification",
     "Configuration" : "Configuration",
@@ -120,8 +118,6 @@ OC.L10N.register(
     "Advanced settings" : "Paramètres avancés",
     "Delete" : "Supprimer",
     "Allow users to mount external storage" : "Autoriser les utilisateurs à monter des espaces de stockage externes",
-    "Allow users to mount the following external storage" : "Autoriser les utilisateurs à monter les stockages externes suivants",
-    "SMB / CIFS" : "SMB / CIFS",
-    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Certains points de montage externes configurés ne sont pas connectés. Veuillez cliquer sur la(les) ligne(s) rouge(s) pour plus d'informations"
+    "Allow users to mount the following external storage" : "Autoriser les utilisateurs à monter les stockages externes suivants"
 },
 "nplurals=2; plural=(n > 1);");
