@@ -2,16 +2,20 @@ OC.L10N.register(
     "files_external",
     {
     "Personal" : "Անձնական",
-    "Never" : "Երբեք",
+    "Saved" : "Պահված",
     "Username" : "Օգտանուն",
     "Password" : "Գաղտնաբառ",
     "Save" : "Պահպանել",
+    "Port" : "Պորտ",
+    "WebDAV" : "WebDAV",
     "URL" : "URL",
     "Dropbox" : "Dropbox",
+    "Location" : "Տեղակայություն",
+    "Host" : "Հոստ",
     "Share" : "Կիսվել",
     "Name" : "Անուն",
+    "Never" : "Երբեք",
     "Folder name" : "Պանակի անուն",
-    "Delete" : "Ջնջել",
-    "Saved" : "Պահված"
+    "Delete" : "Ջնջել"
 },
 "nplurals=2; plural=(n != 1);");
