@@ -7,6 +7,37 @@ OC.L10N.register(
     "Step 1 failed. Exception: %s" : "ステップ 1 の実行に失敗しました。例外: %s",
     "Step 2 failed. Exception: %s" : "ステップ 2 の実行に失敗しました。例外: %s",
     "External storage" : "外部ストレージ",
+    "Dropbox App Configuration" : "Dropbox アプリ設定",
+    "Google Drive App Configuration" : "Google アプリ設定",
+    "Personal" : "個人",
+    "System" : "システム",
+    "Grant access" : "アクセスを許可",
+    "Error configuring OAuth1" : "OAuth1設定エラー",
+    "Error configuring OAuth2" : "OAuth2 設定エラー",
+    "Generate keys" : "キーを生成",
+    "Error generating key pair" : "キーペアの生成エラー",
+    "All users. Type to select user or group." : "すべてのユーザー。ユーザー、グループを追加",
+    "(group)" : "(グループ)",
+    "Compatibility with Mac NFD encoding (slow)" : "Mac NFD エンコード互換 (遅い)",
+    "Admin defined" : "管理者設定済",
+    "Saved" : "保存されました",
+    "Disabling external storage will unmount all storages for all users, are you sure ?" : "外部ストレージを無効化すると、すべてのユーザーに影響を与えます。続行しますか？",
+    "Disable external storage" : "外部ストレージを無効化",
+    "Empty response from the server" : "サーバーから空の応答がありました",
+    "Couldn't access. Please logout and login to activate this mount point" : "アクセスできません｡このマウントポイントを有効にするには、一度ログアウトしてからログインしてください。",
+    "Couldn't get the information from the ownCloud server: {code} {type}" : "ownCloudサーバーから情報を取得できません: {code} {type}",
+    "Couldn't get the list of external mount points: {type}" : "外部マウントポイントのリストを取得できません: {type}",
+    "There was an error with message: " : "メッセージ付きのエラーが発生しました：",
+    "External mount error" : "外部マウントエラー",
+    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Windowsネットワークドライブのマウントポイントリストを取得できません:サーバーから空の応答がありました",
+    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "いくつかの設定済み外部マウントポイントに接続できませんでした。詳細情報は赤い行をクリックしてください",
+    "Please enter the credentials for the {mount} mount" : " {mount} をマウントするための必要な資格情報を入力してください",
+    "Username" : "ユーザー名",
+    "Password" : "パスワード",
+    "Credentials saved" : "資格情報を保存しました",
+    "Credentials saving failed" : "資格情報の保存に失敗しました",
+    "Credentials required" : "資格情報が必要です",
+    "Save" : "保存",
     "Storage with id \"%i\" not found" : "ストレージID \"%i\" が見つかりません",
     "Invalid backend or authentication mechanism class" : "バックエンドまたは認証システムクラスが無効",
     "Invalid mount point" : "無効なマウントポイント",
@@ -19,44 +50,8 @@ OC.L10N.register(
     "Insufficient data: %s" : "データが不足しています: %s",
     "%s" : "%s",
     "Storage with id \"%i\" is not user editable" : "ストレージID \"%i\" はユーザーが編集できません",
-    "Personal" : "個人",
-    "System" : "システム",
-    "Grant access" : "アクセスを許可",
-    "Access granted" : "アクセスは許可されました",
-    "Error configuring OAuth1" : "OAuth1 設定エラー",
-    "Error configuring OAuth2" : "OAuth2 設定エラー",
-    "Generate keys" : "キーを生成",
-    "Error generating key pair" : "キーペアの生成エラー",
-    "Enable encryption" : "暗号化を有効に",
-    "Enable previews" : "プレビューを有効に",
-    "Enable sharing" : "共有の有効化",
-    "Check for changes" : "変更点を確認",
-    "Never" : "更新無",
-    "Once every direct access" : "直指定時のみ",
-    "All users. Type to select user or group." : "すべてのユーザー。ユーザー、グループを追加",
-    "(group)" : "(グループ)",
-    "Admin defined" : "管理者設定済",
-    "Saved" : "保存されました",
-    "Empty response from the server" : "サーバーから空の応答がありました",
-    "Couldn't access. Please logout and login to activate this mount point" : "アクセス出来ませんでした｡このマウントポイントを有効にするには一度ログアウトしてからログインしてください。",
-    "Couldn't get the information from the ownCloud server: {code} {type}" : "ownCloud サーバーから情報を取得出来ませんでした。: {code} {type}",
-    "Couldn't get the list of external mount points: {type}" : "外部マウントポイントのリストを取得出来ませんでした。: {type}",
-    "There was an error with message: " : "メッセージ付きのエラーが発生しました：",
-    "External mount error" : "外部マウントエラー",
-    "external-storage" : "外部ストレージ",
-    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Windows ネットワークドライブのマウントポイントリストを取得出来ませんでした:サーバーから空の応答がありました",
-    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "いくつかの設定済み外部マウントポイントに接続できませんでした。詳細情報は赤い行をクリックしてください",
-    "Please enter the credentials for the {mount} mount" : " {mount} のマウントのために必要な資格情報を入力してください",
-    "Username" : "ユーザー名",
-    "Password" : "パスワード",
-    "Credentials saved" : "資格情報を保存しました",
-    "Credentials saving failed" : "資格情報の保存に失敗しました",
-    "Credentials required" : "資格情報が必要です",
-    "Save" : "保存",
     "Access key" : "アクセスキー",
     "Secret key" : "シークレットキー",
-    "Builtin" : "ビルトイン",
-    "None" : "なし",
     "OAuth1" : "OAuth1",
     "App key" : "アプリキー",
     "App secret" : "アプリシークレット",
@@ -68,8 +63,6 @@ OC.L10N.register(
     "Identity endpoint URL" : "認証エンドポイントURL",
     "Rackspace" : "Rackspace",
     "API key" : "APIキー",
-    "Username and password" : "ユーザー名とパスワード",
-    "Log-in credentials, save in session" : "ログイン認証情報は、セッションに保存されます。",
     "RSA public key" : "RSA公開鍵",
     "Public key" : "公開鍵",
     "Amazon S3" : "Amazon S3",
@@ -84,14 +77,12 @@ OC.L10N.register(
     "Remote subfolder" : "リモートサブフォルダー",
     "Secure https://" : "セキュア https://",
     "Dropbox" : "Dropbox",
-    "FTP" : "FTP",
-    "Host" : "ホスト",
-    "Secure ftps://" : "Secure ftps://",
     "Google Drive" : "Google Drive",
     "Local" : "ローカル",
     "Location" : "場所",
     "ownCloud" : "ownCloud",
     "SFTP" : "SFTP",
+    "Host" : "ホスト",
     "Root" : "ルート",
     "SFTP with secret key login" : "秘密鍵でSFTPログイン",
     "SMB / CIFS" : "SMB / CIFS",
@@ -104,14 +95,21 @@ OC.L10N.register(
     "Request timeout (seconds)" : "リクエストがタイムアウトするまでの秒数",
     "<b>Note:</b> " : "<b>注意:</b> ",
     "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>注意:</b> PHPにcURLのエクステンションが入っていないか、有効ではありません。%s をマウントすることができません。このシステムの管理者にインストールをお願いしてください。",
-    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>注意:</b> PHPにFTPのエクステンションが入っていないか、有効ではありません。%s をマウントすることができません。このシステムの管理者にインストールをお願いしてください。",
     "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>注意:</b> \"%s\" がインストールされていません。%sをマウントできません。このシステムの管理者にインストールをお願いしてください。",
     "No external storage configured" : "外部ストレージは設定されていません",
-    "You can add external storages in the personal settings" : "個人設定で外部ストレージを設定することができます。",
+    "You can add external storages in the storage settings" : "ストレージ設定で外部ストレージを設定することができます。",
     "Name" : "名前",
     "Storage type" : "ストレージ種別",
     "Scope" : "スコープ",
+    "Enable encryption" : "暗号化を有効に",
+    "Enable previews" : "プレビューを有効に",
+    "Enable sharing" : "共有の有効化",
+    "Check for changes" : "変更点を確認",
+    "Never" : "更新無",
+    "Once every direct access" : "直指定時のみ",
     "External Storage" : "外部ストレージ",
+    "Enable external storage" : "外部ストレージを有効化",
+    "External storage has been disabled by the administrator" : "外部ストレージが管理者によって無効化されました",
     "Folder name" : "フォルダー名",
     "Authentication" : "認証",
     "Configuration" : "設定",
@@ -120,8 +118,6 @@ OC.L10N.register(
     "Advanced settings" : "詳細設定",
     "Delete" : "削除",
     "Allow users to mount external storage" : "ユーザーに外部ストレージの接続を許可する",
-    "Allow users to mount the following external storage" : "ユーザーに以下の外部ストレージのマウントを許可する",
-    "SMB / CIFS" : "SMB / CIFS",
-    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "いくつかの設定済み外部マウントポイントに接続できませんでした。詳細情報は赤い行をクリックしてください"
+    "Allow users to mount the following external storage" : "ユーザーに以下の外部ストレージのマウントを許可する"
 },
 "nplurals=1; plural=0;");
