@@ -3,23 +3,22 @@ OC.L10N.register(
     {
     "Personal" : "Лично",
     "Grant access" : "Дозволи пристап",
-    "Access granted" : "Пристапот е дозволен",
     "Saved" : "Снимено",
     "Username" : "Корисничко име",
     "Password" : "Лозинка",
     "Save" : "Сними",
-    "None" : "Ништо",
     "API key" : "API key",
     "Port" : "Порта",
     "Region" : "Регион",
     "WebDAV" : "WebDAV",
     "URL" : "Адреса",
-    "Host" : "Домаќин",
     "Local" : "Локален",
     "Location" : "Локација",
     "ownCloud" : "ownCloud",
+    "Host" : "Домаќин",
     "Share" : "Сподели",
     "Name" : "Име",
+    "Enable encryption" : "Овозможи енкрипција",
     "External Storage" : "Надворешно складиште",
     "Folder name" : "Име на папка",
     "Configuration" : "Конфигурација",
