@@ -7,6 +7,37 @@ OC.L10N.register(
     "Step 1 failed. Exception: %s" : "Stap 1 is mislukt. Uitzondering: %s",
     "Step 2 failed. Exception: %s" : "Stap 2 is mislukt. Uitzondering: %s",
     "External storage" : "Externe opslag",
+    "Dropbox App Configuration" : "Dropbox app configuratie",
+    "Google Drive App Configuration" : "Google Drive app configuratie",
+    "Personal" : "Persoonlijk",
+    "System" : "Systeem",
+    "Grant access" : "Sta toegang toe",
+    "Error configuring OAuth1" : "Fout bij configureren OAuth1",
+    "Error configuring OAuth2" : "Fout bij configureren OAuth2",
+    "Generate keys" : "Genereer sleutels",
+    "Error generating key pair" : "Fout bij genereren sleutelpaar",
+    "All users. Type to select user or group." : "Alle gebruikers. Tikken om een gebruiker of groep te selecteren.",
+    "(group)" : "(groep)",
+    "Compatibility with Mac NFD encoding (slow)" : "Compatibiliteit met Mac NFD encoding (traag)",
+    "Admin defined" : "Beheerder gedefinieerd",
+    "Saved" : "Bewaard",
+    "Disabling external storage will unmount all storages for all users, are you sure ?" : "Externe opslag uitzetten zorgt ervoor dat de opslag voor alle gebruikers wordt afgekoppeld. Weet u zeker dat u door wilt gaan?",
+    "Disable external storage" : "Externe opslag uitzetten",
+    "Empty response from the server" : "Lege reactie van de server",
+    "Couldn't access. Please logout and login to activate this mount point" : "Geen toegang. Log uit en opnieuw in om dit koppelpunt te activeren",
+    "Couldn't get the information from the ownCloud server: {code} {type}" : "Kon geen informatie van de ownCloud server krijgen: {code} {type}",
+    "Couldn't get the list of external mount points: {type}" : "Kon geen overzicht met externe koppelpunten krijgen: {type}",
+    "There was an error with message: " : "Er was een fout met de volgende melding:",
+    "External mount error" : "Extern koppelpunt fout",
+    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Kon geen overzicht met Windows netwerk koppelpunten krijgen: lege reactie van de server",
+    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Sommige van de geconfigureerde koppelpunten zijn niet verbonden. Klik op de rode rij(en) voor meer informatie",
+    "Please enter the credentials for the {mount} mount" : "Geef de inloggegeven sop voor de {mount} mount",
+    "Username" : "Gebruikersnaam",
+    "Password" : "Wachtwoord",
+    "Credentials saved" : "Inloggegevens opgeslagen",
+    "Credentials saving failed" : "Opslaan inloggegevens mislukt",
+    "Credentials required" : "Inloggegevens vereist",
+    "Save" : "Bewaren",
     "Storage with id \"%i\" not found" : "Opslag met id \"%i\" niet gevonden",
     "Invalid backend or authentication mechanism class" : "Ongeldige backend of authenticatie mechanisme klasse",
     "Invalid mount point" : "Ongeldig aankoppelpunt",
@@ -19,44 +50,8 @@ OC.L10N.register(
     "Insufficient data: %s" : "Onvoldoende gegevens: %s",
     "%s" : "%s",
     "Storage with id \"%i\" is not user editable" : "Opslag met id \"%i\" is niet te bewerken door gebruiker",
-    "Personal" : "Persoonlijk",
-    "System" : "Systeem",
-    "Grant access" : "Sta toegang toe",
-    "Access granted" : "Toegang toegestaan",
-    "Error configuring OAuth1" : "Fout bij configureren OAuth1",
-    "Error configuring OAuth2" : "Fout bij configureren OAuth2",
-    "Generate keys" : "Genereer sleutels",
-    "Error generating key pair" : "Fout bij genereren sleutelpaar",
-    "Enable encryption" : "Versleuteling inschakelen",
-    "Enable previews" : "Activeren voorbeelden",
-    "Enable sharing" : "Activeren delen",
-    "Check for changes" : "Controleren op wijzigingen",
-    "Never" : "Nooit",
-    "Once every direct access" : "Een keer bij elke directe toegang",
-    "All users. Type to select user or group." : "Alle gebruikers. Tikken om een gebruiker of groep te selecteren.",
-    "(group)" : "(groep)",
-    "Admin defined" : "Beheerder gedefinieerd",
-    "Saved" : "Bewaard",
-    "Empty response from the server" : "Lege reactie van de server",
-    "Couldn't access. Please logout and login to activate this mount point" : "Geen toegang. Log uit en opnieuw in om dit koppelpunt te activeren",
-    "Couldn't get the information from the ownCloud server: {code} {type}" : "Kon geen informatie van de ownCloud server krijgen: {code} {type}",
-    "Couldn't get the list of external mount points: {type}" : "Kon geen overzicht met externe koppelpunten krijgen: {type}",
-    "There was an error with message: " : "Er was een fout met de volgende melding:",
-    "External mount error" : "Extern koppelpunt fout",
-    "external-storage" : "externe opslag",
-    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Kon geen overzicht met Windows netwerk koppelpunten krijgen: lege reactie van de server",
-    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Sommige van de geconfigureerde koppelpunten zijn niet verbonden. Klok op de rode rij(en) voor meer informatie",
-    "Please enter the credentials for the {mount} mount" : "Geef de inloggegeven sop voor de {mount} mount",
-    "Username" : "Gebruikersnaam",
-    "Password" : "Wachtwoord",
-    "Credentials saved" : "Inloggegevens opgeslagen",
-    "Credentials saving failed" : "Opslaan inloggegevens mislukt",
-    "Credentials required" : "Inloggegevens vereist",
-    "Save" : "Bewaren",
     "Access key" : "Access Key",
     "Secret key" : "Geheime sleutel",
-    "Builtin" : "Ingebouwd",
-    "None" : "Geen",
     "OAuth1" : "OAuth1",
     "App key" : "App key",
     "App secret" : "App secret",
@@ -68,8 +63,6 @@ OC.L10N.register(
     "Identity endpoint URL" : "Identiteiten endpoint URL",
     "Rackspace" : "Rackspace",
     "API key" : "API sleutel",
-    "Username and password" : "Gebruikersnaam en wachtwoord",
-    "Log-in credentials, save in session" : "Inloggegevens, opslaan in sessie",
     "RSA public key" : "RSA publieke sleutel",
     "Public key" : "Publieke sleutel",
     "Amazon S3" : "Amazon S3",
@@ -84,14 +77,12 @@ OC.L10N.register(
     "Remote subfolder" : "Externe submap",
     "Secure https://" : "Secure https://",
     "Dropbox" : "Dropbox",
-    "FTP" : "FTP",
-    "Host" : "Host",
-    "Secure ftps://" : "Secure ftps://",
     "Google Drive" : "Google Drive",
     "Local" : "Lokaal",
     "Location" : "Locatie",
     "ownCloud" : "ownCloud",
     "SFTP" : "SFTP",
+    "Host" : "Host",
     "Root" : "Root",
     "SFTP with secret key login" : "SFTP met geheime sleutel inlog",
     "SMB / CIFS" : "SMB / CIFS",
@@ -104,14 +95,21 @@ OC.L10N.register(
     "Request timeout (seconds)" : "Aanvraag time-out (seconds)",
     "<b>Note:</b> " : "<b>Let op:</b> ",
     "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Let op:</b> Curl ondersteuning in PHP is niet geactiveerd of geïnstalleerd. Mounten van %s is niet mogelijk. Vraag uw systeembeheerder dit te installeren.",
-    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Let op:</b> FTP ondersteuning in PHP is niet geactiveerd of geïnstalleerd. Mounten van %s is niet mogelijk. Vraag uw beheerder dit te installeren.",
     "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Let op:</b> \"%s\" is niet geïnstalleerd. Mounten van %s is niet mogelijk. Vraag uw beheerder om dit te installeren.",
     "No external storage configured" : "Geen externe opslag geconfigureerd",
-    "You can add external storages in the personal settings" : "U kunt externe opslag toevogene in persoonlijke instellingen",
+    "You can add external storages in the storage settings" : "U kunt externe opslag toevoegen in opslaginstellingen",
     "Name" : "Naam",
     "Storage type" : "Opslagtype",
     "Scope" : "Scope",
+    "Enable encryption" : "Versleuteling inschakelen",
+    "Enable previews" : "Activeren voorbeelden",
+    "Enable sharing" : "Activeren delen",
+    "Check for changes" : "Controleren op wijzigingen",
+    "Never" : "Nooit",
+    "Once every direct access" : "Een keer bij elke directe toegang",
     "External Storage" : "Externe opslag",
+    "Enable external storage" : "Externe opslag aanzetten",
+    "External storage has been disabled by the administrator" : "Externe opslag is uitgezet door de beheerder",
     "Folder name" : "Mapnaam",
     "Authentication" : "Authenticatie",
     "Configuration" : "Configuratie",
@@ -120,8 +118,6 @@ OC.L10N.register(
     "Advanced settings" : "Geavanceerde instellingen",
     "Delete" : "Verwijder",
     "Allow users to mount external storage" : "Sta gebruikers toe om een externe opslag aan te koppelen",
-    "Allow users to mount the following external storage" : "Sta gebruikers toe de volgende externe opslag aan te koppelen",
-    "SMB / CIFS" : "SMB / CIFS",
-    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Sommige van de geconfigureerde koppelpunten zijn niet verbonden. Klik op de rode rij(en) voor meer informatie"
+    "Allow users to mount the following external storage" : "Sta gebruikers toe de volgende externe opslag aan te koppelen"
 },
 "nplurals=2; plural=(n != 1);");
