@@ -21,14 +21,10 @@
 
 namespace OCA\Files_External\Command;
 
-use Symfony\Component\Console\Command\Command;
-use Symfony\Component\Console\Helper\Table;
-use Symfony\Component\Console\Helper\TableHelper;
 use Symfony\Component\Console\Input\ArrayInput;
 use Symfony\Component\Console\Input\InputArgument;
 use Symfony\Component\Console\Input\InputInterface;
 use Symfony\Component\Console\Input\InputOption;
-use Symfony\Component\Console\Input\Input;
 use Symfony\Component\Console\Output\OutputInterface;
 
 class Export extends ListCommand {
