@@ -29,7 +29,7 @@
  *
  */
 
-use \OCA\Files_External\AppInfo\Application;
+use OCA\Files_External\AppInfo\Application;
 
 /**
  * Class to configure mount.json globally and for users
