@@ -2,6 +2,7 @@ OC.L10N.register(
     "files_sharing",
     {
     "Cancel" : "Abbrechen",
+    "Share" : "Teilen",
     "A file or folder has been <strong>shared</strong>" : "Eine Datei oder ein Ordner wurde <strong>geteilt</strong>",
     "You shared %1$s with %2$s" : "du teilst %1$s mit %2$s",
     "You shared %1$s with group %2$s" : "Du teilst %1$s mit der Gruppe %2$s",
@@ -9,6 +10,8 @@ OC.L10N.register(
     "%2$s shared %1$s with you" : "%2$s hat %1$s mit dir geteilt",
     "Shares" : "teilt",
     "Password" : "Passwort",
+    "Name" : "Name",
+    "Expiration date" : "Ablaufdatum",
     "Download" : "Herunterladen"
 },
 "nplurals=2; plural=(n != 1);");
