@@ -9,7 +9,7 @@ OC.L10N.register(
     "Shared with you" : "Kunhavata kun vi",
     "Shared with others" : "Kunhavata kun aliaj",
     "Shared by link" : "Kunhavata per ligilo",
-    "Federated sharing" : "Federa kunhavado",
+    "Uploading..." : "Alŝutante...",
     "Nothing shared with you yet" : "Nenio kunhavatas kun vi ankoraŭ",
     "Files and folders others share with you will show up here" : "Dosieroj kaj dosierujoj, kiujn aliuloj kunhavigas, aperos ĉi tie",
     "Nothing shared yet" : "Nenio kunhavatas ankoraŭ",
@@ -24,6 +24,7 @@ OC.L10N.register(
     "You can upload into this folder" : "Vi povas alŝuti en ĉi tiun dosierujon",
     "No ownCloud installation (7 or higher) found at {remote}" : "Ne troviĝis instalo de ownCloud (7 aŭ pli alta) ĉe {remote}",
     "Invalid ownCloud url" : "Nevalidas URL de ownCloud",
+    "Share" : "Kunhavigi",
     "Shared by" : "Kunhavigita de",
     "Sharing" : "Kunhavigo",
     "A file or folder has been <strong>shared</strong>" : "Dosiero aŭ dosierujo <strong>kunhaviĝis</strong>",
@@ -63,17 +64,13 @@ OC.L10N.register(
     "%2$s removed public link" : "%2$s forigis publikan ligilon",
     "Shared by %2$s" : "Kunhavigata de %2$s",
     "Shares" : "Kunhavoj",
-    "You received \"/%2$s\" as a remote share from %1$s" : "Vi ricevis “/%2$s” kiel fora kunhavigo de %1$s",
-    "Accept" : "Akcepti",
-    "Decline" : "Malakcepti",
-    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Kunhavigi kun mi per mia identigilo de #ownCloud-federnuba identigilo; vidu %s",
-    "Share with me through my #ownCloud Federated Cloud ID" : "Kunhavigi kun mi per mia #ownCloud-federnuba identigilo",
     "This share is password-protected" : "Ĉi tiu kunhavigo estas protektata per pasvorto",
     "The password is wrong. Try again." : "La pasvorto malĝustas. Provu denove.",
     "Password" : "Pasvorto",
     "No entries found in this folder" : "Neniu enigo troviĝis en ĉi tiu dosierujo",
     "Name" : "Nomo",
     "Share time" : "Kunhavotempo",
+    "Expiration date" : "Limdato",
     "Sorry, this link doesn’t seem to work anymore." : "Pardonu, ĉi tiu ligilo ŝajne ne plu funkcias.",
     "Reasons might be:" : "Kialoj povas esti:",
     "the item was removed" : "la ero foriĝis",
@@ -83,24 +80,6 @@ OC.L10N.register(
     "Add to your ownCloud" : "Aldoni al via ownCloud",
     "Download" : "Elŝuti",
     "Download %s" : "Elŝuti %s",
-    "Direct link" : "Direkta ligilo",
-    "Federated Cloud Sharing" : "Federnuba kunhavado",
-    "Open documentation" : "Malfermi la dokumentaron",
-    "Federated Cloud" : "Federa nubo",
-    "Your Federated Cloud ID:" : "Via federnuba identigilo:",
-    "Share it:" : "Kunhavigi ĝin:",
-    "Add to your website" : "Aldoni al via TTT-ejo",
-    "Share with me via ownCloud" : "Kunhavigi kun mi per ownCloud",
-    "HTML Code:" : "HTML-kodo:",
-    "Public shared file %1$s was downloaded" : "La publika kunhavata dosiero %1$s elŝutiĝis",
-    "Public shared folder %1$s was downloaded" : "La publika kunhavata dosierujo %1$s elŝutiĝis",
-    "Removed share for %2$s" : "Foriĝis kunhavo kun %2$s",
-    "Removed share of group %2$s" : "Foriĝis kunhavo kun grupo %2$s",
-    "Shared by %2$s" : "Kunhavigata de %2$s",
-    "Shared via link by %2$s" : "Kunhavata ligile de %2$s",
-    "Shared with group %3$s by %2$s" : "Kunhavata kun grupo %3$s de %2$s",
-    "You removed the public link for %1$s" : "Vi forigis la publikan ligilon por %1$s",
-    "You removed the share of %2$s for %1$s" : "Vi malkunhavigis %1$s kun %2$s",
-    "You removed the share of group %2$s for %1$s" : "Vi malkunhavigis %1$s kun grupo %2$s"
+    "Direct link" : "Direkta ligilo"
 },
 "nplurals=2; plural=(n != 1);");
