@@ -9,6 +9,7 @@ OC.L10N.register(
     "Shared with you" : "Sinuga jagatud",
     "Shared with others" : "Teistega jagatud",
     "Shared by link" : "Jagatud lingiga",
+    "Uploading..." : "Üleslaadimine...",
     "Nothing shared with you yet" : "Sinuga pole veel midagi jagatud",
     "Files and folders others share with you will show up here" : "Siin näidatakse faile ja kaustasid, mida teised on sulle jaganud",
     "Nothing shared yet" : "Midagi pole veel jagatud",
@@ -23,22 +24,38 @@ OC.L10N.register(
     "You can upload into this folder" : "Sa saad sellesse kausta faile üles laadida",
     "No ownCloud installation (7 or higher) found at {remote}" : "Saidilt {remote} ei leitud ownCloudi (7 või uuem) ",
     "Invalid ownCloud url" : "Vigane ownCloud url",
+    "Share" : "Jaga",
+    "No expiration date set" : "Aegumise kuupäeva pole määratud",
     "Shared by" : "Jagas",
     "Sharing" : "Jagamine",
+    "Share API is disabled" : "Jagamise API on välja lülitatud",
+    "Please specify a valid user" : "Palun määra korrektne kasutaja",
+    "Please specify a valid group" : "Palun määra korrektne grupp",
+    "Public link sharing is disabled by the administrator" : "Avalik linkide jagamine on administraatori poolt keelatud",
+    "Public upload disabled by the administrator" : "Avalik üleslaadimine on administraatori poolt keelatud",
+    "Public upload is only possible for publicly shared folders" : "Avalik üleslaadimine on võimalik ainult avalikkusele jagatud kaustades",
+    "Unknown share type" : "Tundmatu jagamise liik",
+    "Not a directory" : "Pole kaust",
+    "Could not lock path" : "Asukoha lukustamine ebaõnnestus",
     "A file or folder has been <strong>shared</strong>" : "Fail või kataloog on <strong>jagatud</strong>",
     "You shared %1$s with %2$s" : "Jagasid %1$s  %2$s kasutajaga",
     "You shared %1$s with group %2$s" : "Jagasid %1$s %2$s grupiga",
-    "%2$s shared %1$s with you" : "%2$s jagas sinuga %1$s",
     "You shared %1$s via link" : "Jagasid %1$s lingiga",
+    "%2$s shared %1$s with you" : "%2$s jagas sinuga %1$s",
+    "Downloaded via public link" : "Alla laetud avalikult lingilt",
+    "Shared with %2$s" : "Jagatud kasutajaga %2$s",
+    "Shared with group %2$s" : "Jagatud grupiga %2$s",
+    "Shared via public link" : "Jagatud avaliku lingiga",
+    "Removed public link" : "Avalik link on eemaldatud",
+    "Public link expired" : "Avalik link aegus",
     "Shares" : "Jagamised",
-    "Accept" : "Nõustu",
-    "Decline" : "Lükka tagasi",
     "This share is password-protected" : "See jagamine on parooliga kaitstud",
     "The password is wrong. Try again." : "Parool on vale. Proovi uuesti.",
     "Password" : "Parool",
     "No entries found in this folder" : "Selles kaustas ei leitud kirjeid",
     "Name" : "Nimi",
     "Share time" : "Jagamise aeg",
+    "Expiration date" : "Aegumise kuupäev",
     "Sorry, this link doesn’t seem to work anymore." : "Vabandust, see link ei tundu enam toimivat.",
     "Reasons might be:" : "Põhjused võivad olla:",
     "the item was removed" : "üksus on eemaldatud",
@@ -48,13 +65,6 @@ OC.L10N.register(
     "Add to your ownCloud" : "Lisa oma ownCloudi",
     "Download" : "Lae alla",
     "Download %s" : "Laadi alla %s",
-    "Direct link" : "Otsene link",
-    "Open documentation" : "Ava dokumentatsioon",
-    "Allow users on this server to send shares to other servers" : "Luba selle serveri kasutajatel saata faile teistesse serveritesse",
-    "Allow users on this server to receive shares from other servers" : "Luba selle serveri kasutajatel võtta vastu jagamisi teistest serveritest",
-    "Share it:" : "Jaga seda:",
-    "Add to your website" : "Lisa oma veebisaidile",
-    "Share with me via ownCloud" : "Jaga minuga läbi ownCloudiga",
-    "HTML Code:" : "HTML kood:"
+    "Direct link" : "Otsene link"
 },
 "nplurals=2; plural=(n != 1);");
