@@ -10,6 +10,7 @@ OC.L10N.register(
     "Shared with you" : "Compartido con vostede",
     "Shared with others" : "Compartido con outros",
     "Shared by link" : "Compartido por ligazón",
+    "Uploading..." : "Enviando...",
     "Nothing shared with you yet" : "Aínda non hai nada compartido con vostede.",
     "Files and folders others share with you will show up here" : "Os ficheiros e cartafoles que outros compartan con vostede amosaranse aquí",
     "Nothing shared yet" : "Aínda non hay nada compartido",
@@ -24,6 +25,7 @@ OC.L10N.register(
     "You can upload into this folder" : "Pode envialo a este cartafol",
     "No ownCloud installation (7 or higher) found at {remote}" : "Non se atopa unha instalación de ownCloud (7 ou superior) en {remote}",
     "Invalid ownCloud url" : "URL incorrecto do ownCloud",
+    "Share" : "Compartir",
     "Shared by" : "Compartido por",
     "Sharing" : "Compartindo",
     "A file or folder has been <strong>shared</strong>" : "<strong>Compartiuse</strong> un ficheiro ou cartafol",
@@ -41,15 +43,13 @@ OC.L10N.register(
     "You shared %1$s via link" : "Vostede compartiu %1$s mediante ligazón",
     "%2$s shared %1$s with you" : "%2$s compartiu %1$s con vostede",
     "Shares" : "Comparticións",
-    "Accept" : "Aceptar",
-    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Comparte comigo a través do meu ID da nube federada do #ownCloud , vexa %s",
-    "Share with me through my #ownCloud Federated Cloud ID" : "Comparte comigo a través do meu ID da nube federada do #ownCloud",
     "This share is password-protected" : "Esta compartición está protexida con contrasinal",
     "The password is wrong. Try again." : "O contrasinal é incorrecto. Ténteo de novo.",
     "Password" : "Contrasinal",
     "No entries found in this folder" : "Non se atoparon entradas neste cartafol",
     "Name" : "Nome",
     "Share time" : "Compartir o tempo",
+    "Expiration date" : "Data de caducidade",
     "Sorry, this link doesn’t seem to work anymore." : "Semella que esta ligazón non funciona.",
     "Reasons might be:" : "As razóns poderían ser:",
     "the item was removed" : "o elemento foi retirado",
@@ -59,17 +59,6 @@ OC.L10N.register(
     "Add to your ownCloud" : "Engadir ao seu ownCloud",
     "Download" : "Descargar",
     "Download %s" : "Descargar %s",
-    "Direct link" : "Ligazón directa",
-    "Federated Cloud Sharing" : "Nube federada compartida",
-    "Open documentation" : "Abrir a documentación",
-    "Allow users on this server to send shares to other servers" : "Permitir aos usuarios deste servidor enviar comparticións a outros servidores",
-    "Allow users on this server to receive shares from other servers" : "Permitir aos usuarios deste servidor recibir comparticións de outros servidores",
-    "Federated Cloud" : "Nube federada",
-    "Your Federated Cloud ID:" : "ID da súa nube federada:",
-    "Share it:" : "Compártao:",
-    "Share with me via ownCloud" : "Comparte comigo a través do ownCloud",
-    "HTML Code:" : "Código HTML:",
-    "Public shared file %1$s was downloaded" : "Foi descargado o ficheiro público %1$s",
-    "Public shared folder %1$s was downloaded" : "Foi descargado o cartafol público %1$s"
+    "Direct link" : "Ligazón directa"
 },
 "nplurals=2; plural=(n != 1);");
