@@ -11,7 +11,10 @@ OC.L10N.register(
     "Shared with you" : "Condivisi con te",
     "Shared with others" : "Condivisi con altri",
     "Shared by link" : "Condivisi tramite collegamento",
-    "Federated sharing" : "Condivisione federata",
+    "Anonymous upload" : "Caricamento Anonimo",
+    "Click to select files or use drag & drop to upload" : "Clicca per selezione il file da caricare oppure trascinalo qui",
+    "Uploaded files" : "File caricati",
+    "Uploading..." : "Caricamento in corso...",
     "Nothing shared with you yet" : "Non è stato condiviso ancora niente con te",
     "Files and folders others share with you will show up here" : "I file e le cartelle che altri condividono con te saranno mostrati qui",
     "Nothing shared yet" : "Ancora nessuna condivisione",
@@ -26,8 +29,30 @@ OC.L10N.register(
     "You can upload into this folder" : "Puoi caricare in questa cartella",
     "No ownCloud installation (7 or higher) found at {remote}" : "Nessuna installazione di ownCloud (7 o superiore) trovata su {remote}",
     "Invalid ownCloud url" : "URL di ownCloud non valido",
+    "Share" : "Condividi",
+    "No expiration date set" : "Nessuna data di scadenza impostata",
     "Shared by" : "Condiviso da",
     "Sharing" : "Condivisione",
+    "Share API is disabled" : "API di condivisione disabilitate",
+    "Wrong share ID, share doesn't exist" : "ID di condivisione errato, la condivisione non esiste",
+    "Could not delete share" : "impossibile eliminare la condivisione",
+    "Please specify a file or folder path" : "Specifica un percorso di un file o di una cartella",
+    "Wrong path, file/folder doesn't exist" : "Percorso errato, file/cartella inesistente",
+    "Cannot remove all permissions" : "Impossibile rimuovere tutti i permessi",
+    "Please specify a valid user" : "Specifica un utente valido",
+    "Group sharing is disabled by the administrator" : "La condivisione di gruppo è disabilitata dall'amministratore",
+    "Please specify a valid group" : "Specifica un gruppo valido",
+    "Public link sharing is disabled by the administrator" : "La condivisione pubblica di collegamenti è disabilitata dall'amministratore",
+    "Public upload disabled by the administrator" : "Caricamento pubblico disabilitato dall'amministratore",
+    "Public upload is only possible for publicly shared folders" : "Il caricamento pubblico è possibile solo per cartelle condivise pubblicamente",
+    "Invalid date, date format must be YYYY-MM-DD" : "Data non valida, il formato della data deve essere YYYY-MM-DD",
+    "Sharing %s failed because the back end does not allow shares from type %s" : "Condivisione di %s non riuscita poiché il motore non consente condivisioni del tipo %s",
+    "Unknown share type" : "Tipo di condivisione sconosciuto",
+    "Not a directory" : "Non è una cartella",
+    "Could not lock path" : "Impossibile bloccare il percorso",
+    "Can't change permissions for public share links" : "Impossibile cambiare i permessi per i collegamenti di condivisione pubblici",
+    "Wrong or no update parameter given" : "Parametro fornito non valido o non di aggiornamento",
+    "Cannot increase permissions" : "Impossibile aumentare i permessi",
     "A file or folder has been <strong>shared</strong>" : "Un file o una cartella è stato <strong>condiviso</strong>",
     "A file or folder was shared from <strong>another server</strong>" : "Un file o una cartella è stato condiviso da <strong>un altro server</strong>",
     "A public shared file or folder was <strong>downloaded</strong>" : "Un file condiviso pubblicamente o una cartella è stato <strong>scaricato</strong>",
@@ -71,49 +96,23 @@ OC.L10N.register(
     "Public link of %2$s expired" : "il collegamento pubblico di %2$s è scaduto",
     "Shared by %2$s" : "Condivisa da %2$s",
     "Shares" : "Condivisioni",
-    "You received \"/%2$s\" as a remote share from %1$s" : "Hai ricevuto \"/%2$s\" come condivisione remota da %1$s",
-    "Accept" : "Accetta",
-    "Decline" : "Rifiuta",
-    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Condividi con me attraverso il mio ID di cloud federata #ownCloud, vedi %s",
-    "Share with me through my #ownCloud Federated Cloud ID" : "Condividi con me attraverso il mio ID di cloud federata #ownCloud",
     "This share is password-protected" : "Questa condivisione è protetta da password",
     "The password is wrong. Try again." : "La password è errata. Prova ancora.",
     "Password" : "Password",
     "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
     "Name" : "Nome",
     "Share time" : "Tempo di condivisione",
+    "Expiration date" : "Data di scadenza",
     "Sorry, this link doesn’t seem to work anymore." : "Spiacenti, questo collegamento sembra non essere più attivo.",
     "Reasons might be:" : "I motivi potrebbero essere:",
     "the item was removed" : "l'elemento è stato rimosso",
     "the link expired" : "il collegamento è scaduto",
     "sharing is disabled" : "la condivisione è disabilitata",
     "For more info, please ask the person who sent this link." : "Per ulteriori informazioni, chiedi alla persona che ti ha inviato il collegamento.",
+    "%s is publicly shared" : "%s è condiviso pubblicamente",
     "Add to your ownCloud" : "Aggiungi al tuo ownCloud",
     "Download" : "Scarica",
     "Download %s" : "Scarica %s",
-    "Direct link" : "Collegamento diretto",
-    "Federated Cloud Sharing" : "Condivisione cloud federata",
-    "Open documentation" : "Apri la documentazione",
-    "Allow users on this server to send shares to other servers" : "Consenti agli utenti su questo server di inviare condivisioni ad altri server",
-    "Allow users on this server to receive shares from other servers" : "Consenti agli utenti su questo server di ricevere condivisioni da altri server",
-    "Federated Cloud" : "Cloud federata",
-    "Your Federated Cloud ID:" : "Il tuo ID di cloud federata:",
-    "Share it:" : "Condividilo:",
-    "Add to your website" : "Aggiungilo al tuo sito web",
-    "Share with me via ownCloud" : "Condividi con me tramite ownCloud",
-    "HTML Code:" : "Codice HTML:",
-    "Public link of %2$s expired" : "il collegamento pubblico di %2$s è scaduto",
-    "Public shared file %1$s was downloaded" : "Il file condiviso pubblicamente %1$s è stato scaricato",
-    "Public shared folder %1$s was downloaded" : "La cartella condivisa pubblicamente %1$s è stata scaricata",
-    "Removed share for %2$s" : "Condivisione rimossa per %2$s",
-    "Removed share of group %2$s" : "Condivisione rimossa del gruppo %2$s",
-    "Shared by %2$s" : "Condivisa da %2$s",
-    "Shared via link by %2$s" : "Condivisa tramite collegamento da %2$s",
-    "Shared with group %3$s by %2$s" : "Condivisa con il gruppo %3$s da %2$s",
-    "The public link of %2$s for %1$s expired" : "il collegamento pubblico di %2$s per %1$s è scaduto",
-    "You removed the public link for %1$s" : "Hai rimosso il collegamento pubblico per %1$s",
-    "You removed the share of %2$s for %1$s" : "Hai rimosso la condivisione di %2$s per %1$s",
-    "You removed the share of group %2$s for %1$s" : "Hai rimosso la condivisione del gruppo %2$s per %1$s",
-    "Your public link for %1$s expired" : "il tuo collegamento pubblico per %1$s è scaduto"
+    "Direct link" : "Collegamento diretto"
 },
 "nplurals=2; plural=(n != 1);");
