@@ -11,6 +11,10 @@ OC.L10N.register(
     "Shared with you" : "Të ndara me ju",
     "Shared with others" : "Të ndara me të tjerët",
     "Shared by link" : "Të ndara me lidhje",
+    "Anonymous upload" : "Ngarkim anonim",
+    "Click to select files or use drag & drop to upload" : "Klikoni që të përzgjidhni kartela ose përdorni teknikën merr & vër që të ngarkoni",
+    "Uploaded files" : "Kartela të ngarkuara",
+    "Uploading..." : "Po ngarkohet...",
     "Nothing shared with you yet" : "Ende pa ndarë gjë me ju",
     "Files and folders others share with you will show up here" : "Këtu do të shfaqen kartelat dhe dosjet që të jerët ndajnë me ju",
     "Nothing shared yet" : "Ende pa ndarë gjë",
@@ -25,6 +29,8 @@ OC.L10N.register(
     "You can upload into this folder" : "Mund të ngarkoni te kjo dosje",
     "No ownCloud installation (7 or higher) found at {remote}" : "Te {remote} s’u gjet instalim ownCloud (7 ose më sipër)",
     "Invalid ownCloud url" : "URL ownCloud e pavlefshme",
+    "Share" : "Ndaje",
+    "No expiration date set" : "S’ka të caktuar datë skadimi",
     "Shared by" : "Ndarë nga",
     "Sharing" : "Ndarje",
     "Share API is disabled" : "API i ndarjeve është çaktivizuar",
@@ -32,6 +38,7 @@ OC.L10N.register(
     "Could not delete share" : "Ndarja s’u fshi dot",
     "Please specify a file or folder path" : "Ju lutemi, tregoni një shteg kartele ose dosjeje",
     "Wrong path, file/folder doesn't exist" : "Shteg i gabuar, kratela/dosja s’ekziston",
+    "Cannot remove all permissions" : "S’mund të hiqen krejt lejet",
     "Please specify a valid user" : "Ju lutemi, tregoni një përdorues të vlefshëm",
     "Group sharing is disabled by the administrator" : "Ndarja në grup është çaktivizuar nga përgjegjësi",
     "Please specify a valid group" : "Ju lutemi, tregoni një grup të vlefshëm",
@@ -95,12 +102,14 @@ OC.L10N.register(
     "No entries found in this folder" : "S’u gjetën zëra në këtë dosje",
     "Name" : "Emër",
     "Share time" : "Kohë ndarjeje",
+    "Expiration date" : "Datë skadimi",
     "Sorry, this link doesn’t seem to work anymore." : "Na ndjeni, kjo lidhje duket se nuk funksionon më.",
     "Reasons might be:" : "Arsyet mund të jenë:",
     "the item was removed" : "objekti është hequr",
     "the link expired" : "lidhja ka skaduar",
     "sharing is disabled" : "ndarjet janë çaktivizuar",
     "For more info, please ask the person who sent this link." : "Për më shumë të dhëna, ju lutemi, pyetni personin që ju dërgoi këtë lidhje.",
+    "%s is publicly shared" : "%s ndahet publikisht me të tjerët",
     "Add to your ownCloud" : "Shtojeni te ownCloud-i juaj",
     "Download" : "Shkarko",
     "Download %s" : "Shkarko %s",
