@@ -10,6 +10,7 @@ OC.L10N.register(
     "Shared with you" : "Дељено са вама",
     "Shared with others" : "Дељено са осталима",
     "Shared by link" : "Дељено путем везе",
+    "Uploading..." : "Отпремам…",
     "Nothing shared with you yet" : "Још увек се ништа са вама не дели",
     "Files and folders others share with you will show up here" : "Фајлови и фасцикле које други деле са вама појавиће се овде",
     "Nothing shared yet" : "Још се ништа не дели",
@@ -24,6 +25,7 @@ OC.L10N.register(
     "You can upload into this folder" : "Можете да отпремате у ову фасциклу",
     "No ownCloud installation (7 or higher) found at {remote}" : "Нема оунКлауд инсталације верзије 7 или више на {remote}",
     "Invalid ownCloud url" : "Неисправан оунКлауд УРЛ",
+    "Share" : "Дељење",
     "Shared by" : "Дели",
     "Sharing" : "Дељење",
     "A file or folder has been <strong>shared</strong>" : "Фајл или фасцикла је <strong>дељен</strong>",
@@ -40,13 +42,13 @@ OC.L10N.register(
     "You shared %1$s via link" : "Поделили сте %1$s путем везе",
     "%2$s shared %1$s with you" : "%2$s подели %1$s са вама",
     "Shares" : "Дељења",
-    "Accept" : "Прихвати",
     "This share is password-protected" : "Дељење је заштићено лозинком",
     "The password is wrong. Try again." : "Лозинка је погрешна. Покушајте поново.",
     "Password" : "Лозинка",
     "No entries found in this folder" : "Нема ничега у овој фасцикли",
     "Name" : "Назив",
     "Share time" : "Време дељења",
+    "Expiration date" : "Датум истека",
     "Sorry, this link doesn’t seem to work anymore." : "Нажалост, изгледа да веза више не ради.",
     "Reasons might be:" : "Разлози могу бити:",
     "the item was removed" : "ставка је уклоњена",
@@ -56,15 +58,6 @@ OC.L10N.register(
     "Add to your ownCloud" : "Додај у свој облак",
     "Download" : "Преузми",
     "Download %s" : "Преузми %s",
-    "Direct link" : "Директна веза",
-    "Federated Cloud Sharing" : "Здружено дељење у облаку",
-    "Open documentation" : "Отвори документацију",
-    "Allow users on this server to send shares to other servers" : "Дозвољава корисницима овог сервера да шаљу дељења на друге сервере",
-    "Allow users on this server to receive shares from other servers" : "Дозвољава корисницима овог сервера да примају дељења са других сервера",
-    "Federated Cloud" : "Здружени облак",
-    "Decline" : "Одбиј",
-    "Federated sharing" : "Здружено дељење",
-    "Public shared file %1$s was downloaded" : "Јавно дељени фајл %1$s је преузет",
-    "Public shared folder %1$s was downloaded" : "Јавно дељена фасцикла %1$s је преузета"
+    "Direct link" : "Директна веза"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
