@@ -1,7 +1,4 @@
-<?php /** @var $l OC_L10N */ ?>
-<div id="controls">
-	<div id="file_action_panel"></div>
-</div>
+<?php /** @var $l \OCP\IL10N */ ?>
 <div id='notification'></div>
 
 <div id="emptycontent" class="hidden"></div>
@@ -25,6 +22,9 @@
 			<th id="headerDate" class="hidden column-mtime">
 				<a id="modified" class="columntitle" data-sort="mtime"><span><?php p($l->t( 'Share time' )); ?></span><span class="sort-indicator"></span></a>
 			</th>
+			<th class="hidden column-expiration">
+				<a class="columntitle"><span><?php p($l->t( 'Expiration date' )); ?></span></a>
+			</th>
 		</tr>
 	</thead>
 	<tbody id="fileList">
