@@ -5,15 +5,17 @@ OC.L10N.register(
     "Couldn't restore %s" : "Konnte %s nicht wiederherstellen",
     "Deleted files" : "Gelöschte Dateien",
     "Restore" : "Wiederherstellen",
+    "Delete" : "Löschen",
     "Delete permanently" : "Endgültig löschen",
     "Error" : "Fehler",
+    "This operation is forbidden" : "Diese Operation ist nicht erlaubt",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Dieses Verzeichnis ist nicht verfügbar, bitte überprüfen Sie die Logdateien oder kontaktieren Sie den Administrator",
     "restored" : "Wiederhergestellt",
     "No deleted files" : "Keine gelöschten Dateien",
     "You will be able to recover deleted files from here" : "Sie können hier gelöschte Dateien wiederherstellen",
     "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
     "Select all" : "Alle auswählen",
     "Name" : "Name",
-    "Deleted" : "Gelöscht",
-    "Delete" : "Löschen"
+    "Deleted" : "Gelöscht"
 },
 "nplurals=2; plural=(n != 1);");
