@@ -208,7 +208,7 @@ class Trashbin {
 		$view = new View('/');
 		self::copy_recursive($source, $target, $view);
 
-		self::retainVersions($targetFilename, $owner, $ownerPath, $timestamp, true);
+		self::retainVersions($targetFilename, $owner, $ownerPath, $timestamp, null, true);
 
 		if ($view->file_exists($target)) {
 			self::insertTrashEntry($owner, $targetFilename, $targetLocation, $timestamp);
@@ -304,7 +304,7 @@ class Trashbin {
 			\OCP\Util::emitHook('\OCA\Files_Trashbin\Trashbin', 'post_moveToTrash', ['filePath' => Filesystem::normalizePath($file_path),
 				'trashPath' => Filesystem::normalizePath($filename . '.d' . $timestamp)]);
 
-			self::retainVersions($filename, $owner, $ownerPath, $timestamp);
+			self::retainVersions($filename, $owner, $ownerPath, $timestamp, $sourceStorage);
 
 			// if owner !== user we need to also add a copy to the owners trash
 			if ($user !== $owner) {
@@ -331,9 +331,19 @@ class Trashbin {
 	 * @param integer $timestamp when the file was deleted
 	 * @param bool $forceCopy true to only make a copy of the versions into the trashbin
 	 */
-	private static function retainVersions($filename, $owner, $ownerPath, $timestamp, $forceCopy = false) {
+	private static function retainVersions($filename, $owner, $ownerPath, $timestamp, $sourceStorage = null, $forceCopy = false) {
 		if (\OCP\App::isEnabled('files_versions') && !empty($ownerPath)) {
 
+			$copyKeysResult = false;
+
+			/**
+			 * In case if encryption is enabled then we need to retain the keys which were
+			 * deleted due to move operation to trashbin.
+			 */
+			if ($sourceStorage !== null) {
+				$copyKeysResult = $sourceStorage->retainKeys($filename, $owner, $ownerPath, $timestamp, $sourceStorage);
+			}
+
 			$user = User::getUser();
 			$rootView = new View('/');
 
@@ -355,6 +365,10 @@ class Trashbin {
 					}
 				}
 			}
+
+			if ($copyKeysResult === true) {
+				$sourceStorage->deleteAllFileKeys($filename);
+			}
 		}
 	}
 
