@@ -4,8 +4,9 @@ OC.L10N.register(
     "Could not revert: %s" : "Nelze vrátit: %s",
     "Versions" : "Verze",
     "Failed to revert {file} to revision {timestamp}." : "Selhalo vrácení souboru {file} na verzi {timestamp}.",
-    "More versions..." : "Více verzí...",
+    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtů"],
+    "Restore" : "Obnovit",
     "No other versions available" : "Žádné další verze nejsou dostupné",
-    "Restore" : "Obnovit"
+    "More versions..." : "Více verzí..."
 },
 "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
