@@ -13,4 +13,4 @@ OC.L10N.register(
     "Access files via WebDAV" : "Uzyskaj dostęp do plików poprzez WebDAV",
     "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"http://owncloud.org\">website</a>." : "Więcej informacji znajduje się w <a target=\"_blank\" href=\"%s\">dokumentacji</a> i na naszej <a target=\"_blank\" href=\"http://owncloud.org\">stronie</a>."
 },
-"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
+"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>=14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
