@@ -1,11 +1,11 @@
 OC.L10N.register(
     "systemtags",
     {
-    "%s (not-assignable)" : "%s (pole määratav)",
-    "%s (invisible)" : "%s (nähtamatu)",
     "Tags" : "Sildid",
     "Tagged files" : "Sildistatud failid",
     "Select tags to filter by" : "Vali sildid, mille järgi filtreerida",
+    "%s (restricted)" : "%s (piiratud)",
+    "%s (invisible)" : "%s (nähtamatu)",
     "No files in here" : "Siin ei ole faile",
     "No entries found in this folder" : "Selles kaustast ei leitud kirjeid",
     "Name" : "Nimi",
