@@ -11,8 +11,8 @@ OC.L10N.register(
     "Sharing email (plain text fallback)" : "Partilhar mensagem (texto sem formatação)",
     "Lost password mail" : "Perdi a palavra passe do correio",
     "New user email (HTML)" : "Novo e-mail de utilizador (HTML)",
-    "New user email (plain text fallback)" : "Novo email de utilizador (texto simples)",
-    "Activity notification mail" : "Email de notificação de actividade",
+    "New user email (plain text fallback)" : "Novo e-mail do utilizador (texto simples)",
+    "Activity notification mail" : "E-mail de notificação da atividade",
     "Mail Templates" : "Modelos de Correio",
     "Theme" : "Tema",
     "Template" : "Modelo",
