@@ -10,21 +10,18 @@
  *
  */
 
+/* global oc_updateState */
+
 /**
  * this gets only loaded if an update is available and then shows a temporary notification
  */
 $(document).ready(function(){
-	var head = $('html > head'),
-		version = oc_updateState.updateVersion,
+	var version = oc_updateState.updateVersion,
 		docLink = oc_updateState.updateLink,
 		text = t('core', '{version} is available. Get more information on how to update.', {version: version}),
-		element = $('<a>').attr('href', docLink).text(text);
+		element = $('<a>').attr('href', docLink).attr('target','_blank').text(text);
 
-	OC.Notification.showTemporary(
-		element,
-		{
-			isHTML: true
-		}
-	);
+	OC.Notification.showHtml(element, {
+			type: 'error'
+	});
 });
-
