@@ -20,12 +20,8 @@
  */
 namespace OC\Core\Command\Maintenance;
 
-use InvalidArgumentException;
-use OC\Setup;
-use OCP\IConfig;
 use Symfony\Component\Console\Command\Command;
 use Symfony\Component\Console\Input\InputInterface;
-use Symfony\Component\Console\Input\InputOption;
 use Symfony\Component\Console\Output\OutputInterface;
 
 class UpdateHtaccess extends Command {
@@ -33,7 +29,7 @@ class UpdateHtaccess extends Command {
 	protected function configure() {
 		$this
 			->setName('maintenance:update:htaccess')
-			->setDescription('Updates the .htaccess file');
+			->setDescription('Updates the .htaccess file.');
 	}
 
 	protected function execute(InputInterface $input, OutputInterface $output) {
