@@ -10,12 +10,6 @@
 		_create: function() {
 			var self = this;
 
-			this.originalCss = {
-				display: this.element[0].style.display,
-				width: this.element[0].style.width,
-				height: this.element[0].style.height
-			};
-
 			this.originalTitle = this.element.attr('title');
 			this.options.title = this.options.title || this.originalTitle;
 
@@ -29,11 +23,6 @@
 			this.$dialog.append(this.element.detach());
 			this.element.removeAttr('title').addClass('oc-dialog-content').appendTo(this.$dialog);
 
-			this.$dialog.css({
-				display: 'inline-block',
-				position: 'fixed'
-			});
-
 			$(document).on('keydown keyup', function(event) {
 				if (
 					event.target !== self.$dialog.get(0) &&
@@ -73,21 +62,7 @@
 					return false;
 				}
 			});
-			$(window).resize(function() {
-				self.parent = self.$dialog.parent().length > 0 ? self.$dialog.parent() : $('body');
-				var pos = self.parent.position();
-				self.$dialog.css({
-					left: pos.left + ($(window).innerWidth() - self.$dialog.outerWidth())/2,
-					top: pos.top + ($(window).innerHeight() - self.$dialog.outerHeight())/2,
-					width: Math.min(self.options.width, $(window).innerWidth() - 20 ),
-					height: Math.min(self.options.height, $(window).innerHeight() - 20)
-				});
-				// set sizes of content
-				self._setSizes();
-			});
-
 			this._setOptions(this.options);
-			$(window).trigger('resize');
 			this._createOverlay();
 		},
 		_init: function() {
@@ -106,7 +81,6 @@
 							+ '</h3>');
 						this.$title = $title.prependTo(this.$dialog);
 					}
-					this._setSizes();
 					break;
 				case 'buttons':
 					if(this.$buttonrow) {
@@ -141,7 +115,6 @@
 							self.$buttonrow.find('button').removeClass('primary');
 							$(this).addClass('primary');
 						});
-					this._setSizes();
 					break;
 				case 'closeButton':
 					if(value) {
@@ -154,12 +127,6 @@
 						this.$dialog.find('.oc-dialog-close').remove();
 					}
 					break;
-				case 'width':
-					this.$dialog.css('width', value);
-					break;
-				case 'height':
-					this.$dialog.css('height', value);
-					break;
 				case 'close':
 					this.closeCB = value;
 					break;
@@ -171,27 +138,6 @@
 			//this._super(options);
 			$.Widget.prototype._setOptions.apply(this, arguments);
 		},
-		_setSizes: function() {
-			// var content_height = this.$dialog.height();
-			// if(this.$title) {
-			// 	content_height -= this.$title.outerHeight(true);
-			// }
-			// if(this.$buttonrow) {
-			// 	content_height -= this.$buttonrow.outerHeight(true);
-			// }
-			// this.parent = this.$dialog.parent().length > 0 ? this.$dialog.parent() : $('body');
-			// content_height = Math.min(content_height, this.parent.height()-20);
-			// if (content_height> 0) {
-			// 	this.element.css({
-			// 		height: content_height + 'px',
-			// 		width: this.$dialog.innerWidth()-20 + 'px'
-			// 	});
-			// } else {
-			// 	this.element.css({
-			// 		width : this.$dialog.innerWidth() - 20 + 'px'
-			// 	});
-			// }
-		},
 		_createOverlay: function() {
 			if(!this.options.modal) {
 				return;
@@ -243,8 +189,7 @@
 			if(this.originalTitle) {
 				this.element.attr('title', this.originalTitle);
 			}
-			this.element.removeClass('oc-dialog-content')
-					.css(this.originalCss).detach().insertBefore(this.$dialog);
+			this.element.removeClass('oc-dialog-content').detach().insertBefore(this.$dialog);
 			this.$dialog.remove();
 		}
 	});
