@@ -171,7 +171,6 @@ var OCdialogs = {
 
 			$('body').append(self.$filePicker);
 
-
 			self.$filePicker.ready(function() {
 				self.$filelist = self.$filePicker.find('.filelist');
 				self.$dirTree = self.$filePicker.find('.dirtree');
@@ -219,6 +218,13 @@ var OCdialogs = {
 					self.$filePicker = null;
 				}
 			});
+
+			// We can access primary class only from oc-dialog.
+			// Hence this is one of the approach to get the choose button.
+			var getOcDialog = self.$filePicker.closest('.oc-dialog');
+			var buttonEnableDisable = getOcDialog.find('.primary');
+			buttonEnableDisable.prop("disabled", "true");
+
 			if (!OC.Util.hasSVGSupport()) {
 				OC.Util.replaceSVG(self.$filePicker.parent());
 			}
@@ -236,7 +242,7 @@ var OCdialogs = {
 	 * Displays raw dialog
 	 * You better use a wrapper instead ...
 	*/
-	message:function(content, title, dialogType, buttons, callback, modal) {
+	message:function(content, title, dialogType, buttons, callback, modal, cssClass) {
 		return $.when(this._getMessageTemplate()).then(function($tmpl) {
 			var dialogName = 'oc-dialog-' + OCdialogs.dialogsCounter + '-content';
 			var dialogId = '#' + dialogName;
@@ -246,46 +252,52 @@ var OCdialogs = {
 				message: content,
 				type: dialogType
 			});
+
 			if (modal === undefined) {
 				modal = false;
 			}
+
 			$('body').append($dlg);
 			var buttonlist = [];
-			switch (buttons) {
-			case OCdialogs.YES_NO_BUTTONS:
-				buttonlist = [{
-					text: t('core', 'No'),
-					click: function(){
-						if (callback !== undefined) {
-							callback(false);
+			if (_.isArray(buttons)) {
+				buttonlist = buttons;
+			} else {
+				switch (buttons) {
+				case OCdialogs.YES_NO_BUTTONS:
+					buttonlist = [{
+						text: t('core', 'No'),
+						click: function(){
+							if (callback !== undefined) {
+								callback(false);
+							}
+							$(dialogId).ocdialog('close');
 						}
-						$(dialogId).ocdialog('close');
-					}
-				},
-				{
-					text: t('core', 'Yes'),
-					click: function(){
-						if (callback !== undefined) {
-							callback(true);
-						}
-						$(dialogId).ocdialog('close');
 					},
-					defaultButton: true
-				}];
-				break;
-			case OCdialogs.OK_BUTTON:
-				var functionToCall = function() {
-					$(dialogId).ocdialog('close');
-					if(callback !== undefined) {
-						callback();
-					}
-				};
-				buttonlist[0] = {
-					text: t('core', 'Ok'),
-					click: functionToCall,
-					defaultButton: true
-				};
-				break;
+					{
+						text: t('core', 'Yes'),
+						click: function(){
+							if (callback !== undefined) {
+								callback(true);
+							}
+							$(dialogId).ocdialog('close');
+						},
+						defaultButton: true
+					}];
+					break;
+				case OCdialogs.OK_BUTTON:
+					var functionToCall = function() {
+						$(dialogId).ocdialog('close');
+						if(callback !== undefined) {
+							callback();
+						}
+					};
+					buttonlist[0] = {
+						text: t('core', 'Ok'),
+						click: functionToCall,
+						defaultButton: true
+					};
+					break;
+				}
 			}
 
 			$(dialogId).ocdialog({
@@ -293,6 +305,11 @@ var OCdialogs = {
 				modal: modal,
 				buttons: buttonlist
 			});
+
+			if (cssClass != undefined) {
+				$(dialogId).addClass(cssClass);
+			}
+
 			OCdialogs.dialogsCounter++;
 		})
 		.fail(function(status, error) {
@@ -312,9 +329,11 @@ var OCdialogs = {
 	 * @param {object} original file with name, size and mtime
 	 * @param {object} replacement file with name, size and mtime
 	 * @param {object} controller with onCancel, onSkip, onReplace and onRename methods
+	 * @return {Promise} jquery promise that resolves after the dialog template was loaded
 	*/
 	fileexists:function(data, original, replacement, controller) {
 		var self = this;
+		var dialogDeferred = new $.Deferred();
 
 		var getCroppedPreview = function(file) {
 			var deferred = new $.Deferred();
@@ -342,11 +361,12 @@ var OCdialogs = {
 
 		var crop = function(img) {
 			var canvas = document.createElement('canvas'),
-				width = img.width,
-				height = img.height,
-				x, y, size;
+					targetSize = 96,
+					width = img.width,
+					height = img.height,
+					x, y, size;
 
-			// calculate the width and height, constraining the proportions
+			// Calculate the width and height, constraining the proportions
 			if (width > height) {
 				y = 0;
 				x = (width - height) / 2;
@@ -356,14 +376,90 @@ var OCdialogs = {
 			}
 			size = Math.min(width, height);
 
-			// resize the canvas and draw the image data into it
-			canvas.width = 64;
-			canvas.height = 64;
+			// Set canvas size to the cropped area
+			canvas.width = size;
+			canvas.height = size;
 			var ctx = canvas.getContext("2d");
-			ctx.drawImage(img, x, y, size, size, 0, 0, 64, 64);
+			ctx.drawImage(img, x, y, size, size, 0, 0, size, size);
+
+			// Resize the canvas to match the destination (right size uses 96px)
+			resampleHermite(canvas, size, size, targetSize, targetSize);
+
 			return canvas.toDataURL("image/png", 0.7);
 		};
 
+		/**
+		 * Fast image resize/resample using Hermite filter with JavaScript.
+		 *
+		 * @author: ViliusL
+		 *
+		 * @param {*} canvas
+		 * @param {number} W
+		 * @param {number} H
+		 * @param {number} W2
+		 * @param {number} H2
+		 */
+		var resampleHermite = function (canvas, W, H, W2, H2) {
+			W2 = Math.round(W2);
+			H2 = Math.round(H2);
+			var img = canvas.getContext("2d").getImageData(0, 0, W, H);
+			var img2 = canvas.getContext("2d").getImageData(0, 0, W2, H2);
+			var data = img.data;
+			var data2 = img2.data;
+			var ratio_w = W / W2;
+			var ratio_h = H / H2;
+			var ratio_w_half = Math.ceil(ratio_w / 2);
+			var ratio_h_half = Math.ceil(ratio_h / 2);
+
+			for (var j = 0; j < H2; j++) {
+				for (var i = 0; i < W2; i++) {
+					var x2 = (i + j * W2) * 4;
+					var weight = 0;
+					var weights = 0;
+					var weights_alpha = 0;
+					var gx_r = 0;
+					var gx_g = 0;
+					var gx_b = 0;
+					var gx_a = 0;
+					var center_y = (j + 0.5) * ratio_h;
+					for (var yy = Math.floor(j * ratio_h); yy < (j + 1) * ratio_h; yy++) {
+						var dy = Math.abs(center_y - (yy + 0.5)) / ratio_h_half;
+						var center_x = (i + 0.5) * ratio_w;
+						var w0 = dy * dy; //pre-calc part of w
+						for (var xx = Math.floor(i * ratio_w); xx < (i + 1) * ratio_w; xx++) {
+							var dx = Math.abs(center_x - (xx + 0.5)) / ratio_w_half;
+							var w = Math.sqrt(w0 + dx * dx);
+							if (w >= -1 && w <= 1) {
+								//hermite filter
+								weight = 2 * w * w * w - 3 * w * w + 1;
+								if (weight > 0) {
+									dx = 4 * (xx + yy * W);
+									//alpha
+									gx_a += weight * data[dx + 3];
+									weights_alpha += weight;
+									//colors
+									if (data[dx + 3] < 255)
+										weight = weight * data[dx + 3] / 250;
+									gx_r += weight * data[dx];
+									gx_g += weight * data[dx + 1];
+									gx_b += weight * data[dx + 2];
+									weights += weight;
+								}
+							}
+						}
+					}
+					data2[x2] = gx_r / weights;
+					data2[x2 + 1] = gx_g / weights;
+					data2[x2 + 2] = gx_b / weights;
+					data2[x2 + 3] = gx_a / weights_alpha;
+				}
+			}
+			canvas.getContext("2d").clearRect(0, 0, Math.max(W, W2), Math.max(H, H2));
+			canvas.width = W2;
+			canvas.height = H2;
+			canvas.getContext("2d").putImageData(img2, 0, 0);
+		};
+
 		var addConflict = function($conflicts, original, replacement) {
 
 			var $conflict = $conflicts.find('.template').clone().removeClass('template').addClass('conflict');
@@ -388,19 +484,23 @@ var OCdialogs = {
 				c:		original.etag,
 				forceIcon:	0
 			};
-			var previewpath = OC.generateUrl('/core/preview.png?') + $.param(urlSpec);
+			var previewpath = Files.generatePreviewUrl(urlSpec);
 			// Escaping single quotes
-			previewpath = previewpath.replace(/'/g, "%27")
+			previewpath = previewpath.replace(/'/g, "%27");
 			$originalDiv.find('.icon').css({"background-image":   "url('" + previewpath + "')"});
 			getCroppedPreview(replacement).then(
 				function(path){
 					$replacementDiv.find('.icon').css('background-image','url(' + path + ')');
 				}, function(){
-					Files.getMimeIcon(replacement.type,function(path){
-						$replacementDiv.find('.icon').css('background-image','url(' + path + ')');
-					});
+					path = OC.MimeType.getIconUrl(replacement.type);
+					$replacementDiv.find('.icon').css('background-image','url(' + path + ')');
 				}
 			);
+			// connect checkboxes with labels
+			var checkboxId = $conflicts.find('.conflict').length;
+			$originalDiv.find('input:checkbox').attr('id', 'checkbox_original_'+checkboxId);
+			$replacementDiv.find('input:checkbox').attr('id', 'checkbox_replacement_'+checkboxId);
+
 			$conflicts.append($conflict);
 
 			//set more recent mtime bold
@@ -459,7 +559,7 @@ var OCdialogs = {
 
 			//recalculate dimensions
 			$(window).trigger('resize');
-
+			dialogDeferred.resolve();
 		} else {
 			//create dialog
 			this._fileexistsshown = true;
@@ -478,8 +578,10 @@ var OCdialogs = {
 				});
 				$('body').append($dlg);
 
-				var $conflicts = $dlg.find('.conflicts');
-				addConflict($conflicts, original, replacement);
+				if (original && replacement) {
+					var $conflicts = $dlg.find('.conflicts');
+					addConflict($conflicts, original, replacement);
+				}
 
 				var buttonlist = [{
 						text: t('core', 'Cancel'),
@@ -516,6 +618,14 @@ var OCdialogs = {
 
 				$(dialogId).css('height','auto');
 
+				var $primaryButton = $dlg.closest('.oc-dialog').find('button.continue');
+				$primaryButton.prop('disabled', true);
+
+				function updatePrimaryButton() {
+					var checkedCount = $dlg.find('.conflicts .checkbox:checked').length;
+					$primaryButton.prop('disabled', checkedCount === 0);
+				}
+
 				//add checkbox toggling actions
 				$(dialogId).find('.allnewfiles').on('click', function() {
 					var $checkboxes = $(dialogId).find('.conflict .replacement input[type="checkbox"]');
@@ -531,7 +641,7 @@ var OCdialogs = {
 				});
 				$(dialogId).find('.conflicts').on('click', '.replacement input[type="checkbox"],.original:not(.readonly) input[type="checkbox"]', function() {
 					var $checkbox = $(this);
-					$checkbox.prop('checked', !checkbox.prop('checked'));
+					$checkbox.prop('checked', !$checkbox.prop('checked'));
 				});
 
 				//update counters
@@ -547,6 +657,7 @@ var OCdialogs = {
 						$(dialogId).find('.allnewfiles').prop('checked', false);
 						$(dialogId).find('.allnewfiles + .count').text('');
 					}
+					updatePrimaryButton();
 				});
 				$(dialogId).on('click', '.original,.allexistingfiles', function(){
 					var count = $(dialogId).find('.conflict .original input[type="checkbox"]:checked').length;
@@ -561,13 +672,18 @@ var OCdialogs = {
 						$(dialogId).find('.allexistingfiles').prop('checked', false);
 						$(dialogId).find('.allexistingfiles + .count').text('');
 					}
+					updatePrimaryButton();
 				});
+
+				dialogDeferred.resolve();
 			})
 			.fail(function() {
+				dialogDeferred.reject();
 				alert(t('core', 'Error loading file exists template'));
 			});
 		}
 		//}
+		return dialogDeferred.promise();
 	},
 	_getFilePickerTemplate: function() {
 		var defer = $.Deferred();
@@ -639,9 +755,10 @@ var OCdialogs = {
 		var dirs = [];
 		var others = [];
 		var self = this;
-		this.$filelist.empty().addClass('loading');
+		this.$filelist.empty().addClass('icon-loading');
 		this.$filePicker.data('path', dir);
 		$.when(this._getFileList(dir, this.$filePicker.data('mimetype'))).then(function(response) {
+
 			$.each(response.data.files, function(index, file) {
 				if (file.type === 'dir') {
 					dirs.push(file);
@@ -654,13 +771,14 @@ var OCdialogs = {
 			var sorted = dirs.concat(others);
 
 			$.each(sorted, function(idx, entry) {
+				entry.icon = OC.MimeType.getIconUrl(entry.mimetype);
 				var $li = self.$listTmpl.octemplate({
 					type: entry.type,
 					dir: dir,
 					filename: entry.name,
 					date: OC.Util.relativeModifiedDate(entry.mtime)
 				});
-				if (entry.isPreviewAvailable) {
+				if (entry.type === 'file') {
 					var urlSpec = {
 						file: dir + '/' + entry.name
 					};
@@ -673,7 +791,7 @@ var OCdialogs = {
 				self.$filelist.append($li);
 			});
 
-			self.$filelist.removeClass('loading');
+			self.$filelist.removeClass('icon-loading');
 			if (!OC.Util.hasSVGSupport()) {
 				OC.Util.replaceSVG(self.$filePicker.find('.dirtree'));
 			}
@@ -712,18 +830,33 @@ var OCdialogs = {
 		var self = event.data;
 		var dir = $(event.target).data('dir');
 		self._fillFilePicker(dir);
+		var getOcDialog = this.closest('.oc-dialog');
+		var buttonEnableDisable = $('.primary', getOcDialog);
+		if (this.$filePicker.data('mimetype') === "http/unix-directory") {
+			buttonEnableDisable.prop("disabled", false);
+		} else {
+			buttonEnableDisable.prop("disabled", true);
+		}
 	},
 	/**
 	 * handle clicks made in the filepicker
 	*/
 	_handlePickerClick:function(event, $element) {
+		var getOcDialog = this.$filePicker.closest('.oc-dialog');
+		var buttonEnableDisable = getOcDialog.find('.primary');
 		if ($element.data('type') === 'file') {
 			if (this.$filePicker.data('multiselect') !== true || !event.ctrlKey) {
 				this.$filelist.find('.filepicker_element_selected').removeClass('filepicker_element_selected');
 			}
 			$element.toggleClass('filepicker_element_selected');
+			buttonEnableDisable.prop("disabled", false);
 		} else if ( $element.data('type') === 'dir' ) {
 			this._fillFilePicker(this.$filePicker.data('path') + '/' + $element.data('entryname'));
+			if (this.$filePicker.data('mimetype') === "httpd/unix-directory") {
+				buttonEnableDisable.prop("disabled", false);
+			} else {
+				buttonEnableDisable.prop("disabled", true);
+			}
 		}
 	}
 };
