@@ -1,25 +1,47 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Неуспешно изпращане на имейл до следните потребители: %s.",
-    "Turned on maintenance mode" : "Режим за поддръжка е включен",
-    "Turned off maintenance mode" : "Режим за поддръжка е изключен",
-    "Updated database" : "Базата данни е обоновена",
-    "Checked database schema update" : "Обновяването на схемата на базата данни е проверено",
-    "Checked database schema update for apps" : "Обновяването на схемата на базата данни за приложения е проверено",
-    "Updated \"%s\" to %s" : "Обновен \"%s\" до %s",
-    "Repair warning: " : "Предупреждение при поправка:",
-    "Repair error: " : "Грешка при поправка:",
+    "Please select a file." : "Моля изберете файл.",
+    "File is too big" : "Файла е прекалено голям",
     "Invalid file provided" : "Предоставен е невалиден файл",
     "No image or file provided" : "Не бяха доставени картинка или файл",
     "Unknown filetype" : "Непознат файлов тип",
     "Invalid image" : "Невалидно изображение",
+    "An error occurred. Please contact your admin." : "Настъпи грешка. Свържи се с администратора си.",
     "No temporary profile picture available, try again" : "Не е налична временна профилна снимка, опитайте отново",
     "No crop data provided" : "Липсват данни за изрязването",
+    "No valid crop data provided" : "Невалидни данни за изрязването",
+    "Crop is not square" : "Орязването не в квадратна форма",
     "Couldn't reset password because the token is invalid" : "Промяната на паролата е невъзможно, защото връзката за удостоверение не е валидна",
-    "Couldn't send reset email. Please make sure your username is correct." : "Неуспешно изпращане на имейл за възстановяване на паролата. Моля, уверете се, че потребителското име е правилно.",
+    "Couldn't reset password because the token is expired" : "Неуспешно възстановяване на паролата, защото ключа е изтекъл",
     "%s password reset" : "Паролата на %s е променена.",
     "Couldn't send reset email. Please contact your administrator." : "Изпращането на електронна поща е неуспешно. Моля, свържете се с вашия администратор.",
+    "Couldn't send mail to following users: %s " : "Неуспешно изпращане на имейл до следните потребители: %s.",
+    "Preparing update" : "Подговорка за обновяване",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "Предупреждение при поправка:",
+    "Repair error: " : "Грешка при поправка:",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Моля, обновявете от командия ред, защото автоматичното обновяване е деактивирано в config.php.",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: Проверка на таблица %s",
+    "Turned on maintenance mode" : "Режим за поддръжка е включен",
+    "Turned off maintenance mode" : "Режим за поддръжка е изключен",
+    "Maintenance mode is kept active" : "Режим на подръжка е активен",
+    "Updating database schema" : "Обновяване на схемата на базата данни",
+    "Updated database" : "Базата данни е обоновена",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Проверява се дали схемата на базата данни може да бъде обновена (това може да отнеме дълго време в зависимост от размера на базата данни)",
+    "Checked database schema update" : "Обновяването на схемата на базата данни е проверено",
+    "Checking updates of apps" : "Търсят се обновления за приложенията",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Проверява се дали схемата на базата данни %s може да бъде обновена (това може да отнеме дълго време в зависимост от размера на базата данни)",
+    "Checked database schema update for apps" : "Обновяването на схемата на базата данни за приложения е проверено",
+    "Updated \"%s\" to %s" : "Обновен \"%s\" до %s",
+    "Set log level to debug" : "Задавне на ниво за дебъг доклада",
+    "Reset log level" : "Възстановяване на нивото на доклада",
+    "Starting code integrity check" : "Започва се проверка за интегритета на кода",
+    "Finished code integrity check" : "Завърши проверката за интегритета на кода",
+    "%s (3rdparty)" : "%s (приложение на 3то лице)",
+    "%s (incompatible)" : "%s (несъвместимост)",
+    "Following apps have been disabled: %s" : "Следните приложения са изкючени: %s",
+    "Already up to date" : "Най-нова версия",
     "Sunday" : "Неделя",
     "Monday" : "Понеделник",
     "Tuesday" : "Вторник",
@@ -34,6 +56,13 @@ OC.L10N.register(
     "Thu." : "Чет.",
     "Fri." : "Пет.",
     "Sat." : "Съб.",
+    "Su" : "Нед",
+    "Mo" : "Пон",
+    "Tu" : "Вт",
+    "We" : "Ср",
+    "Th" : "Чтв",
+    "Fr" : "Пет",
+    "Sa" : "Сб",
     "January" : "Януари",
     "February" : "Февруари",
     "March" : "Март",
@@ -58,7 +87,9 @@ OC.L10N.register(
     "Oct." : "Окт.",
     "Nov." : "Ное.",
     "Dec." : "Дек.",
+    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Възникна проблем с проверката за цялостта на кода. Повече информация…</a>",
     "Settings" : "Настройки",
+    "Problem loading page, reloading in 5 seconds" : "Проблем при зареждане на страницата, презареждане след 5 секунди",
     "Saving..." : "Запазване...",
     "Dismiss" : "Затвори",
     "seconds ago" : "преди секунди",
@@ -90,30 +121,50 @@ OC.L10N.register(
     "Good password" : "Добра парола",
     "Strong password" : "Сигурна парола",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Вашият web сървър все още не е удачно настроен да позволява синхронизация на файлове, защото WebDAV интерфейсът изглежда не работи.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Вашият уеб сървър не е настроен правилно да се справя с   \"{url}\". Допълнителна информация може да бъде намерена в нашата<a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">документация</a>.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Сървърът няма работеща интернет връзка. Това означава, че някои функции като прикачването на външни дискови устройства, уведомления за обновяване или инсталиране на външни приложения няма да работят. Достъпът на файлове отвън или изпращане на имейли за уведомление вероятно също няма да работят. Препоръчваме да включиш интернет връзката за този сървър ако искаш да използваш всички тези функции.",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Не е настроен кеш на паметта. За подобряване на производителността, моля, настройте memcache ако е на разположение. Допълнителна инфромация може да бъде открита в нашата <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">документация</a>.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom не е достъпен за четене от PHP, което е крайно нежелателно от съображения за сигурност. Допълнителна информация може да бъде открита в нашата <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">документация</a>.",
+    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "В момента използвате PHP {version}. Силно препоръчваме да обновите версията си на PHP, за да се възползвате от <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">подобрения на производителността и сигурността предоставени от PHP Груп</a>, веднага щом дистрибуцията Ви го поддържа.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Reverse proxy headers конфигурацията е неправилна или достъпвате ownCloud от доверенo прокси. Ако не достъпвате ownCloud от доверено прокси, това е проблем по сигурността и може да позволи на нападаетел да се престори, че техният IP адрес е достъпен за ownCloud. Допълнителна информация може да бъде намерена в нашата <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">документация</a>.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached е настроен като дистрибутиран кеш, но грешният \"memcache\" PHP модул е инсталиран. \\OC\\Memcache\\Memcached подържа единствено \"memcached\" и не \"memcache\". Разгледайте <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki относно двата модула</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Някои файлове не преминаха успешно тестът за цялостност. Допълнителна информация как да се разреши този проблем може да бъде намерена в нашата <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">документация</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Списък от валидни файлове…</a> / <a href=\"{rescanEndpoint}\">Повторно сканиране…</a>)",
     "Error occurred while checking server setup" : "Настъпи грешка при проверката на настройките на сървъра.",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Твоята директория за данни и файлове вероятно са достъпни от интернет. .htaccess файла не функционира. Силно препоръчваме да настроиш уебсъръра по такъв начин, че директорията за данни да не бъде достъпна или да я преместиш извън директорията корен на сървъра.",
+    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "\"{header}\" HTTP header не е конфигуриран да бъде \"{expected}\". Това е потенциален проблем по сигурността и защитата на личното пространство и препоръчваме да промените тази настройка.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "\"Strict-Transport-Security\" HTTP header не е конфигуриран на поне \"{seconds}\" секунди. За по-добра сигурност препоръчваме да включите HSTS, както е описано в нашите<a href=\"{docUrl}\" rel=\"noreferrer\">съвети по сигурност</a>.",
+    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Достъпвате този сайт през HTTP. Силно препоръчваме да настроите сървъра си да изисква HTTPS, както е описано в нашите <a href=\"{docUrl}\">съвети по сигурност</a>.",
     "Shared" : "Споделено",
     "Shared with {recipients}" : "Споделено с {recipients}.",
     "Error" : "Грешка",
     "Error while sharing" : "Грешка при споделяне",
     "Error while unsharing" : "Грешка при премахване на споделянето",
-    "Error setting expiration date" : "Грешка при настройване на датата за изтичане",
     "The public link will expire no later than {days} days after it is created" : "Общодостъпната връзка ще изтече не по-късно от {days} дни след създаването ѝ.",
     "Set expiration date" : "Задаване на дата на изтичане",
     "Expiration" : "Изтичане",
     "Expiration date" : "Дата на изтичане",
+    "Link" : "Връзка",
+    "Edit" : "Редакция",
+    "Remove" : "Премахване",
+    "Copied!" : "Копирано!",
+    "Not supported!" : "Не се поддържа!",
+    "Press ⌘-C to copy." : "Натиснете ⌘-C, за да копирате.",
+    "Press Ctrl-C to copy." : "Натиснете Ctrl-C, за да копирате.",
     "Choose a password for the public link" : "Изберете парола за общодостъпната връзка",
+    "Password" : "Парола",
+    "Name" : "Име",
+    "Allow editing" : "Позволяване на редактиране",
+    "Save" : "Запазване",
+    "Share to Twitter. Opens in a new window." : "Споделете в Twitter. Отваря се в нов прозорец.",
+    "Share to Facebook. Opens in a new window." : "Споделете във Facebook. Отваря се в нов прозорец.",
+    "Share to Diaspora. Opens in a new window." : "Споделете в Diaspora. Отваря се в нов прозорец.",
+    "Share to Google+. Opens in a new window." : "Споделете в Google+. Отваря се в нов прозорец.",
+    "Share via email. Opens your mail client." : "Споделете чрез имейл. Отваря се във Вашето имейл приложение.",
+    "Error while sending notification" : "Грешка при изпращане на известие",
     "Sending ..." : "Изпращане ...",
     "Email sent" : "Електронната поща е изпратена",
-    "Resharing is not allowed" : "Повторно споделяне не е разрешено.",
-    "Share link" : "Връзка за споделяне",
-    "Link" : "Връзка",
-    "Password protect" : "Защитено с парола",
-    "Password" : "Парола",
-    "Allow editing" : "Позволяване на редактиране",
     "Email link to person" : "Имейл връзка към човек",
-    "Send" : "Изпращане",
+    "Send link via email" : "Изпратете връзка чрез имейл",
     "Shared with you and the group {group} by {owner}" : "Споделено от {owner} с Вас и групата {group} .",
     "Shared with you by {owner}" : "Споделено с Вас от {owner}.",
     "group" : "група",
@@ -126,10 +177,30 @@ OC.L10N.register(
     "change" : "промяна",
     "delete" : "изтриване",
     "access control" : "контрол на достъпа",
+    "Could not unshare" : "Неуспешно споделяне",
+    "Share details could not be loaded for this item." : "Информация за споделянето не може да бъде заредена за този файл.",
+    "No users or groups found for {search}" : "Не са отркити потребители или групи за {search}",
+    "No users found for {search}" : "Не са открити потребители за {search}",
+    "An error occurred. Please try again" : "Възникна грешка. Моля, опитайте отново",
+    "{sharee} (group)" : "{sharee} (група)",
+    "{sharee} (at {server})" : "{sharee} (на {server})",
+    "{sharee} (remote)" : "{sharee} (отдалечен)",
     "Share" : "Споделяне",
+    "Resharing is not allowed" : "Повторно споделяне не е разрешено.",
+    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Споделете с хора на други ownClouds използвайки синтаксиса username@example.com/ownCloud",
+    "Share with users…" : "Споделяне с потребители...",
+    "Share with users, groups or remote users…" : "Споделяне с потребители, групи или отдалечени потребители...",
+    "Share with users or groups…" : "Споделяне с потребители или групи...",
+    "Share with users or remote users…" : "Споделяне с потребители или отдалечени потребители...",
+    "Error removing share" : "Грешка при премахване на споделянето",
     "Warning" : "Предупреждение",
+    "Non-existing tag #{tag}" : "Не съществуващ таг #{tag}",
+    "restricted" : "ограничен",
+    "invisible" : "невидим",
+    "({scope})" : "({scope})",
     "Delete" : "Изтриване",
     "Rename" : "Преименуване",
+    "Collaborative tags" : "Тагове за сътрудничество",
     "The object type is not specified." : "Видът на обекта не е избран.",
     "Enter new" : "Въвеждане на нов",
     "Add" : "Добавяне",
@@ -141,24 +212,24 @@ OC.L10N.register(
     "sunny" : "слънчево",
     "Hello {name}, the weather is {weather}" : "Здравей {name}, времето е {weather}",
     "Hello {name}" : "Здравейте, {name}",
+    "new" : "нов",
     "_download %n file_::_download %n files_" : ["изтегли %n файл","изтегли %n файла"],
-    "Updating {productName} to version {version}, this may take a while." : "Обновяване на {productName} към версия {version}. Това може да отнеме време.",
+    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Тече обновяването, напускането на тази страница може да прекъсне процеса в някои среди.",
+    "Updating to {version}" : "Обновяване до {version}",
+    "An error occurred." : "Възникна грешка.",
     "Please reload the page." : "Моля, презаредете страницата.",
-    "The update was unsuccessful. " : "Обновяването бе неуспешно.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Обновяванет е неуспешно. За повече информация <a href=\"{url}\">проверете форумите ни</a>, разглеждащи този проблем.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Обновяването е неуспешно. Моля, докладвайте проблема на <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud общността</a>.",
+    "The update was successful. There were warnings." : "Обновяването е успешно. Имаше предупреждения.",
     "The update was successful. Redirecting you to ownCloud now." : "Обновяването е успешно. Сега Ви пренасочваме към ownCloud.",
     "Searching other places" : "Търсене в други места",
+    "No search results in other folders" : "Няма резултати от търсенето в други папки.",
+    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} резултат в друга папка","{count} резултата в други папки"],
     "Personal" : "Лични",
     "Users" : "Потребители",
     "Apps" : "Приложения",
     "Admin" : "Админ",
     "Help" : "Помощ",
-    "Error loading tags" : "Грешка при зареждане на етикети",
-    "Tag already exists" : "Етикетите вече съществуват",
-    "Error deleting tag(s)" : "Грешка при изтриване на етикет(и).",
-    "Error tagging" : "Грешка при задаване на етикета.",
-    "Error untagging" : "Грешка при премахване на етикета.",
-    "Error favoriting" : "Грешка при отбелязване в любими.",
-    "Error unfavoriting" : "Грешка при премахване отбелязването в любими.",
     "Access forbidden" : "Достъпът е забранен",
     "File not found" : "Файлът не е открит",
     "The specified document has not been found on the server." : "Избраният документ не е намерен на сървъра.",
@@ -179,31 +250,41 @@ OC.L10N.register(
     "File: %s" : "Файл: %s",
     "Line: %s" : "Линия: %s",
     "Trace" : "Проследяване на грешките",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Вашата директория за данни и файлове Ви вероятно са достъпни от интернет, поради това, че файлът \".htaccess\" не функционира.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "За информация как правилно да настроиш сървъра си, моля прегледай <a href=\"%s\" target=\"_blank\">документацията</a>.",
     "Create an <strong>admin account</strong>" : "Създаване на <strong>администраторски профил</strong>.",
     "Username" : "Потребителско име",
     "Storage & database" : "Дисково пространство и база данни",
     "Data folder" : "Директория за данни",
     "Configure the database" : "Конфигуриране на базата данни",
     "Only %s is available." : "Само %s е достъпен.",
+    "Install and activate additional PHP modules to choose other database types." : "Инсталирайте и активирнайте допълнителни PHP модули, за да използвате други типове бази данни.",
+    "For more details check out the documentation." : "За повече информация разгледайте документацията.",
     "Database user" : "Потребител за базата данни",
     "Database password" : "Парола за базата данни",
     "Database name" : "Име на базата данни",
     "Database tablespace" : "Tablespace на базата данни",
     "Database host" : "Хост за базата данни",
+    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "Моля, въведете номера на порта заедно с името на сървъра(пр. localhost: 5432).",
+    "Performance warning" : "Предупреждение за производителността",
     "SQLite will be used as database." : "Ще бъде използвана SQLite за база данни.",
     "For larger installations we recommend to choose a different database backend." : "За по- големи инсталации Ви препоръчваме да изберете друг сървър за бази данни.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Особено, когато използвате клиент за работен плот за синхронизация, използването на SQLite e непрепоръчително.",
     "Finish setup" : "Завършване на настройките",
     "Finishing …" : "Завършване...",
+    "Need help?" : "Имате нужда от помощ?",
+    "See the documentation" : "Разгледайте документацията",
     "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Здрасти,<br><br>само да те уведомя, че %s сподели <strong>%s</strong> с теб.\n<br><a href=\"%s\">Разгледай го!</a><br><br>.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Това приложение изисква JavaScript, за да функционира правилно. Моля, {linkstart}включи JavaScript{linkend} и презареди страницата.",
     "Log out" : "Отписване",
     "Search" : "Търсене",
     "Server side authentication failed!" : "Удостоверяването от страна на сървъра е неуспешно!",
     "Please contact your administrator." : "Моля, свържете се с администратора.",
+    "An internal error occurred." : "Възникна вътрешна грешка.",
+    "Please try again or contact your administrator." : "Моля, опитайте отново или се свържете с администратора си.",
+    "Username or email" : "Потребителско име или имейл",
     "Log in" : "Вписване",
+    "Wrong password. Reset it?" : "Грешна парола. Възстановете я?",
+    "Wrong password." : "Грешна парола.",
+    "Stay logged in" : "Останете вписане",
     "Alternative Logins" : "Алтернативни методи на вписване",
     "Use the following link to reset your password: {link}" : "Използвайте следната връзка, за да възстановите паролата си: {link}",
     "New password" : "Нова парола",
@@ -213,17 +294,27 @@ OC.L10N.register(
     "This means only administrators can use the instance." : "Това означава, че само администраторът може да го използва.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Свържи се със системния си администратор ако това съобщение се задържи твърде дълго или се е появило неочаквано.",
     "Thank you for your patience." : "Благодарим за търпението.",
+    "Two-step verification" : "Двустъпково потвърждение",
+    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Засилена сигурност е активирана за профила Ви. Моля, удостоверете и с друг метод.",
+    "Cancel login" : "Отказване на вписването",
+    "Please authenticate using the selected factor." : "Моля, удостоверете, използвайки избрания метод.",
+    "An error occurred while verifying the token" : "Настъпи грешка при проверката на токена",
     "You are accessing the server from an untrusted domain." : "Свръзваш се със сървъра от неодобрен домейн.",
+    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Моля, свържете се с администратора. Ако Вие сте администраторът на тази инстанция, нагласете \"trusted_domains\" в config/config.php. Примерна конфигурация е показана в config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "В зависимост от конфигурацията ти, като администратор може натискайки бутонът по-долу да отбележиш домейнът като сигурен.",
     "Add \"%s\" as trusted domain" : "Добави \"%s\" като сигурен домейн",
+    "App update required" : "Обновяване на приложението е задължително",
+    "%s will be updated to version %s" : "%s ще бъде обновено до версия %s",
+    "These apps will be updated:" : "Следните приложения ще бъдат обновени:",
     "The theme %s has been disabled." : "Темата %s бе изключена.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Моля, увери се, че си направил копия на базата данни, папките с настройки и данни, преди да продължиш.",
     "Start update" : "Започване на обновяването",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "За да избегнеш таймаутове при по-големи инсталации, можеш да изпълниш следните команди в инсталанционната директория:",
+    "Detailed logs" : "Подробни доклади",
+    "Update needed" : "Нужно е обновяване",
+    "Please use the command line updater because you have a big instance." : "Тъй като имате голяма инстанция, моля, изпозлвайте командния ред за обновяване.",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "За помощ, разгледайте <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">документацията</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "В момента този %s се обновява, а това може да отнеме време.",
-    "This page will refresh itself when the %s instance is available again." : "Тази страница ще се опресни автоматично, когато %s е отново на линия.",
-    "Error loading file picker template: {error}" : "Грешка при зареждането на шаблон за избор на файл: {error}",
-    "Password can not be changed. Please contact your administrator." : "Паролата не може да бъде промена. Моля, свържете се с администратора.",
-    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Сървърът няма работеща интернет връзка. Това означава, че някои функции като прикачването на външни дискови устройства, уведомления за обновяване или инсталиране на външни приложения няма да работят. Достъпът на файлове отвън или изпращане на имейли за уведомление вероятно също няма да работят. Препоръчваме да включиш интернет връзката за този сървър ако искаш да използваш всички тези функции."
+    "This page will refresh itself when the %s instance is available again." : "Тази страница ще се опресни автоматично, когато %s е отново на линия."
 },
 "nplurals=2; plural=(n != 1);");
