@@ -1,13 +1,13 @@
 OC.L10N.register(
     "core",
     {
+    "No image or file provided" : "কোন ইমেজ বা ফাইল প্রদান করা হয়নি",
+    "Unknown filetype" : "অজানা প্রকৃতির ফাইল",
+    "Invalid image" : "অবৈধ চিত্র",
     "Couldn't send mail to following users: %s " : "নিম্নোক্ত ব্যবহারকারীকে মেইল পাঠানো গেলনা: %s",
     "Turned on maintenance mode" : "রক্ষণাবেক্ষণ মোড চালু হয়েছে",
     "Turned off maintenance mode" : "রক্ষণাবেক্ষণ মোড বন্ধ হয়েছে",
     "Updated database" : "ডাটাবেজ নবায়ন করা হয়েছে",
-    "No image or file provided" : "কোন ইমেজ বা ফাইল প্রদান করা হয়নি",
-    "Unknown filetype" : "অজানা প্রকৃতির ফাইল",
-    "Invalid image" : "অবৈধ চিত্র",
     "Sunday" : "রবিবার",
     "Monday" : "সোমবার",
     "Tuesday" : "মঙ্গলবার",
@@ -65,17 +65,16 @@ OC.L10N.register(
     "Error" : "সমস্যা",
     "Error while sharing" : "ভাগাভাগি করতে সমস্যা দেখা দিয়েছে  ",
     "Error while unsharing" : "ভাগাভাগি বাতিল করতে সমস্যা দেখা দিয়েছে",
-    "Error setting expiration date" : "মেয়াদোত্তীর্ণ হওয়ার তারিখ নির্ধারণ করতে সমস্যা দেখা দিয়েছে",
     "Set expiration date" : "মেয়াদোত্তীর্ণ হওয়ার তারিখ নির্ধারণ করুন",
     "Expiration date" : "মেয়াদোত্তীর্ণ হওয়ার তারিখ",
+    "Edit" : "সম্পাদনা",
+    "Remove" : "অপসারণ",
+    "Password" : "কূটশব্দ",
+    "Name" : "নাম",
+    "Save" : "সংরক্ষণ",
     "Sending ..." : "পাঠানো হচ্ছে......",
     "Email sent" : "ই-মেইল পাঠানো হয়েছে",
-    "Resharing is not allowed" : "পূনঃরায় ভাগাভাগি অনুমোদিত নয়",
-    "Share link" : "লিংক ভাগাভাগি করেন",
-    "Password protect" : "কূটশব্দ সুরক্ষিত",
-    "Password" : "কূটশব্দ",
     "Email link to person" : "ব্যক্তির সাথে ই-মেইল যুক্ত কর",
-    "Send" : "পাঠাও",
     "Shared with you and the group {group} by {owner}" : "{owner} আপনার এবং {group} গোষ্ঠীর সাথে ভাগাভাগি করেছেন",
     "Shared with you by {owner}" : "{owner} আপনার সাথে ভাগাভাগি করেছেন",
     "group" : "দল",
@@ -86,6 +85,7 @@ OC.L10N.register(
     "delete" : "মুছে ফেল",
     "access control" : "অধিগম্যতা নিয়ন্ত্রণ",
     "Share" : "ভাগাভাগি কর",
+    "Resharing is not allowed" : "পূনঃরায় ভাগাভাগি অনুমোদিত নয়",
     "Warning" : "সতর্কবাণী",
     "Delete" : "মুছে",
     "Rename" : "পূনঃনামকরণ",
@@ -99,10 +99,6 @@ OC.L10N.register(
     "Apps" : "অ্যাপ",
     "Admin" : "প্রশাসন",
     "Help" : "সহায়িকা",
-    "Error deleting tag(s)" : "ট্যাগ(সমূহ) অপসারণে সমস্যা",
-    "Error tagging" : "ট্যাগ করতে সমস্যা",
-    "Error untagging" : "ট্যাগ বাতিল করতে সমস্যা",
-    "Error favoriting" : "প্রিয় তালিকাভুক্তিতে সমস্যা",
     "Access forbidden" : "অধিগমনের অনুমতি নেই",
     "File not found" : "ফাইল খুঁজে পাওয়া গেল না",
     "Cheers!" : "শুভেচ্ছা!",
