@@ -5,11 +5,15 @@ OC.L10N.register(
     "Saving..." : "সংরক্ষণ করা হচ্ছে ...",
     "Cancel" : "বাতিল করা",
     "Error" : "ভুল",
+    "Edit" : "এডিট",
+    "Remove" : "সরান",
+    "Name" : "নাম",
+    "Save" : "সেভ",
     "Share" : "শেয়ার",
     "Warning" : "সতর্কীকরণ",
     "Delete" : "মুছে ফেলা",
+    "Rename" : "পুনঃনামকরণ",
     "Add" : "যোগ করা",
-    "Username" : "ইউজারনেম",
     "Search" : "অনুসন্ধান"
 },
 "nplurals=2; plural=(n != 1);");
