@@ -51,20 +51,18 @@ OC.L10N.register(
     "Error" : "Gwall",
     "Error while sharing" : "Gwall wrth rannu",
     "Error while unsharing" : "Gwall wrth ddad-rannu",
-    "Error while changing permissions" : "Gwall wrth newid caniatâd",
-    "Error setting expiration date" : "Gwall wrth osod dyddiad dod i ben",
     "Set expiration date" : "Gosod dyddiad dod i ben",
     "Expiration date" : "Dyddiad dod i ben",
+    "Edit" : "Golygu",
+    "Remove" : "Gwaredu",
+    "Password" : "Cyfrinair",
+    "Name" : "Enw",
+    "Save" : "Cadw",
     "Sending ..." : "Yn anfon ...",
     "Email sent" : "Anfonwyd yr e-bost",
-    "Resharing is not allowed" : "Does dim hawl ail-rannu",
-    "Password protect" : "Diogelu cyfrinair",
-    "Password" : "Cyfrinair",
     "Email link to person" : "E-bostio dolen at berson",
-    "Send" : "Anfon",
     "Shared with you and the group {group} by {owner}" : "Rhannwyd â chi a'r grŵp {group} gan {owner}",
     "Shared with you by {owner}" : "Rhannwyd â chi gan {owner}",
-    "Shared in {item} with {user}" : "Rhannwyd yn {item} â {user}",
     "group" : "grŵp",
     "Unshare" : "Dad-rannu",
     "can edit" : "yn gallu golygu",
@@ -72,21 +70,20 @@ OC.L10N.register(
     "delete" : "dileu",
     "access control" : "rheolaeth mynediad",
     "Share" : "Rhannu",
+    "Resharing is not allowed" : "Does dim hawl ail-rannu",
     "Warning" : "Rhybudd",
-    "The object type is not specified." : "Nid yw'r math o wrthrych wedi cael ei nodi.",
     "Delete" : "Dileu",
+    "Rename" : "Ailenwi",
+    "The object type is not specified." : "Nid yw'r math o wrthrych wedi cael ei nodi.",
     "Add" : "Ychwanegu",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Methodd y diweddariad. Adroddwch y mater hwn i <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">gymuned ownCloud</a>.",
     "The update was successful. Redirecting you to ownCloud now." : "Roedd y diweddariad yn llwyddiannus. Cewch eich ailgyfeirio i ownCloud nawr.",
-    "Use the following link to reset your password: {link}" : "Defnyddiwch y ddolen hon i ailosod eich cyfrinair: {link}",
-    "New password" : "Cyfrinair newydd",
-    "Reset password" : "Ailosod cyfrinair",
     "Personal" : "Personol",
     "Users" : "Defnyddwyr",
     "Apps" : "Pecynnau",
     "Admin" : "Gweinyddu",
     "Help" : "Cymorth",
     "Access forbidden" : "Mynediad wedi'i wahardd",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Mwy na thebyg fod modd cyrraedd eich cyfeiriadur data a ffeilau o'r rhyngrwyd oherwydd nid yw'r ffeil .htaccess yn gweithio. ",
     "Create an <strong>admin account</strong>" : "Crewch <strong>gyfrif gweinyddol</strong>",
     "Username" : "Enw defnyddiwr",
     "Data folder" : "Plygell data",
@@ -100,7 +97,9 @@ OC.L10N.register(
     "Log out" : "Allgofnodi",
     "Search" : "Chwilio",
     "Log in" : "Mewngofnodi",
-    "remember" : "cofio",
-    "Alternative Logins" : "Mewngofnodiadau Amgen"
+    "Alternative Logins" : "Mewngofnodiadau Amgen",
+    "Use the following link to reset your password: {link}" : "Defnyddiwch y ddolen hon i ailosod eich cyfrinair: {link}",
+    "New password" : "Cyfrinair newydd",
+    "Reset password" : "Ailosod cyfrinair"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
