@@ -1,29 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Die E-Mail konnte nicht an folgende Benutzer gesendet werden: %s",
-    "Preparing update" : "Update vorbereiten",
-    "Turned on maintenance mode" : "Wartungsmodus eingeschaltet",
-    "Turned off maintenance mode" : "Wartungsmodus ausgeschaltet",
-    "Maintenance mode is kept active" : "Wartungsmodus bleibt aktiviert",
-    "Updating database schema" : "Datenbank-Schema wird upgedatet",
-    "Updated database" : "Datenbank aktualisiert",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Prüfen, ob das Datenbankschema aktualisiert werden kann (dies kann je nach Datenbankgröße sehr lange dauern)",
-    "Checked database schema update" : "Datenbankschema-Aktualisierung überprüft",
-    "Checking updates of apps" : "Es wird nach Updates für die Apps gesucht",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Prüfen, ob das Datenbankschema für %s aktualisiert werden kann (dies kann je nach Datenbankgröße sehr lange dauern)",
-    "Checked database schema update for apps" : "Datenbankschema-Aktualisierung für Apps überprüft",
-    "Updated \"%s\" to %s" : "„%s“ zu %s aktualisiert",
-    "Repair warning: " : "Reparaturwarnung:",
-    "Repair error: " : "Reparaturfehler:",
-    "Set log level to debug" : "Log-Level auf \"debug\" gesetzt",
-    "Reset log level" : "Ursprüngliches Log-Level wiederhergestellt",
-    "Starting code integrity check" : "Code-Integrität wird überprüft",
-    "Finished code integrity check" : "Code-Integritätsprüfung abgeschlossen",
-    "%s (3rdparty)" : "%s (3rdparty)",
-    "%s (incompatible)" : "%s (nicht kompatibel)",
-    "Following apps have been disabled: %s" : "Die folgenden Apps sind deaktiviert worden: %s",
-    "Already up to date" : "Bereits aktuell",
     "Please select a file." : "Bitte wähle eine Datei aus.",
     "File is too big" : "Datei ist zu groß",
     "Invalid file provided" : "Ungültige Datei zur Verfügung gestellt",
@@ -37,10 +14,35 @@ OC.L10N.register(
     "Crop is not square" : "Zuschnitt ist nicht quadratisch",
     "Couldn't reset password because the token is invalid" : "Das Passwort konnte aufgrund eines ungültigen Tokens nicht zurückgesetzt werden",
     "Couldn't reset password because the token is expired" : "Das Passwort konnte nicht zurückgesetzt werden, da der Token abgelaufen ist",
-    "Couldn't send reset email. Please make sure your username is correct." : "E-Mail zum Zurücksetzen kann nicht versendet werden. Bitte stelle sicher, dass Dein Benutzername korrekt ist.",
-    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Es konnte keine E-Mail verschickt werden um das Passwort zurückzusetzten, da keine E-Mail im Benutzerkonto hinterlegt ist. Bitte kontaktiere den Administrator.",
+    "%s password changed successfully" : "%s Passwort erfolgreich geändert",
     "%s password reset" : "%s-Passwort zurücksetzen",
     "Couldn't send reset email. Please contact your administrator." : "Die E-Mail zum Zurücksetzen konnte nicht versendet werden. Bitte kontaktiere Deinen Administrator.",
+    "Couldn't send mail to following users: %s " : "Die E-Mail konnte nicht an folgende Benutzer gesendet werden: %s",
+    "Preparing update" : "Update vorbereiten",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "Reparaturwarnung:",
+    "Repair error: " : "Reparaturfehler:",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Da automatische Updates in der config.php deaktivert sind, nutze bitte den Updater über die Kommandozeile.",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: Überprüfe Tabelle %s",
+    "Turned on maintenance mode" : "Wartungsmodus eingeschaltet",
+    "Turned off maintenance mode" : "Wartungsmodus ausgeschaltet",
+    "Maintenance mode is kept active" : "Wartungsmodus bleibt aktiviert",
+    "Updating database schema" : "Datenbank-Schema wird upgedatet",
+    "Updated database" : "Datenbank aktualisiert",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Prüfen, ob das Datenbankschema aktualisiert werden kann (dies kann je nach Datenbankgröße sehr lange dauern)",
+    "Checked database schema update" : "Datenbankschema-Aktualisierung überprüft",
+    "Checking updates of apps" : "Es wird nach Updates für die Apps gesucht",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Prüfen, ob das Datenbankschema für %s aktualisiert werden kann (dies kann je nach Datenbankgröße sehr lange dauern)",
+    "Checked database schema update for apps" : "Datenbankschema-Aktualisierung für Apps überprüft",
+    "Updated \"%s\" to %s" : "„%s“ zu %s aktualisiert",
+    "Set log level to debug" : "Log-Level auf \"debug\" gesetzt",
+    "Reset log level" : "Ursprüngliches Log-Level wiederhergestellt",
+    "Starting code integrity check" : "Code-Integrität wird überprüft",
+    "Finished code integrity check" : "Code-Integritätsprüfung abgeschlossen",
+    "%s (3rdparty)" : "%s (3rdparty)",
+    "%s (incompatible)" : "%s (nicht kompatibel)",
+    "Following apps have been disabled: %s" : "Die folgenden Apps sind deaktiviert worden: %s",
+    "Already up to date" : "Bereits aktuell",
     "Sunday" : "Sonntag",
     "Monday" : "Montag",
     "Tuesday" : "Dienstag",
@@ -88,6 +90,7 @@ OC.L10N.register(
     "Dec." : "Dez.",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Es gab Probleme mit dem Code - Integritätsprüfung. Mehr Informationen…</a>",
     "Settings" : "Einstellungen",
+    "Problem loading page, reloading in 5 seconds" : "Problem beim Laden der Seite, Seite wird in 5 Sekunden nochmals geladen",
     "Saving..." : "Speichern…",
     "Dismiss" : "Ausblenden",
     "seconds ago" : "Gerade eben",
@@ -119,40 +122,65 @@ OC.L10N.register(
     "Good password" : "Gutes Passwort",
     "Strong password" : "Starkes Passwort",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Dein Webserver ist noch nicht hinreichend für Datei-Synchronisation konfiguriert, weil die WebDAV-Schnittstelle vermutlich defekt ist.",
-    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Dein Web-Server ist nicht richtig eingerichtet um die folgende URL richtig aufzulösen \"{url}\". Weitere Informationen findest du in unserer <a target=\"_blank\" href=\"{docLink}\">Dokumentation</a>.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Dein Web-Server ist nicht richtig eingerichtet um die folgende URL richtig aufzulösen \"{url}\". Weitere Informationen findest du in unserer <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">Dokumentation</a>.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Dieser Server hat keine funktionierende Internetverbindung. Dies bedeutet, dass einige Funktionen wie das Einhängen externen Speicherplatzes, Update-Benachrichtigungen oder die Installation von Drittanbieter-Apps nicht funktionieren werden. Der Fernzugriff auf Dateien und der Versand von E-Mail-Benachrichtigungen kann ebenfalls nicht funktionieren. Es wird empfohlen, die Internetverbindung dieses Servers zu aktivieren, wenn Du alle Funktionen nutzen möchtest.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Es wurde kein Memory Cache konfiguriert. Um die Leistung zu verbessern, konfiguriere bitte einen Cache-Speicher, sofern vorhanden. Weitere Informationen findest du in unserer <a target=\"_blank\" href=\"{docLink}\">Dokumentation</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "PHP hat keine Leserechte auf /dev/urandom wovon aus Sicherheitsgründen höchst abzuraten ist. Weitere Informationen sind in der <a target=\"_blank\" href=\"{docLink}\">Dokumentation</a> zu finden.",
-    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "Deine PHP Version ({version}) wird nicht länger <a href=\"{phpLink}\">unterstützt</a>. Wir empfehlen ein Upgrade deiner PHP Version, um die volle Performance und Sicherheit zu gewährleisten.",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Die Header-Einstellungen des Reverse Proxy sind falsch, oder du versuchst, dich mit ownCloud von einem vertrauten Proxy aus zu verbinden. Solltest du ownCloud nicht von einem vertrauten Proxy aus benutzen wollen, dann stellt die momentane Situation ein Sicherheitsproblem da und erlaubt Hackern, eine für ownCloud sichtbare IP-Adresse zu nutzen. Weitere Informationen findest du in der <a target=\"_blank\" href=\"{docLink}\">Dokumentation</a>.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached ist als distributed cache konfiguriert aber das falsche PHP-Modul \"memcache\" ist installiert. \\OC\\Memcache\\Memcached unterstützt nur \"memcached\" jedoch nicht \"memcache\". Schau in der <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki nach beiden Modulen</a>.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Einige Dateien haben die Integritätsprüfung nicht bestanden. Weiterführende Information findest Du in unserer <a target=\"_blank\" href=\"{docLink}\">Dokumentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Liste der ungültigen Dateien ...</a> / <a href=\"{rescanEndpoint}\">Erneut analysieren…</a>)",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Es wurde kein PHP Memory Cache konfiguriert. Konfiguriere zur Erhöhung der Leistungsfähigkeit, soweit verfügbar, einen Memory Cache. Weitere Informationen finden Sie in unserer <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">Dokumentation</a>.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "PHP hat keine Leserechte auf /dev/urandom wovon aus Sicherheitsgründen höchst abzuraten ist. Weitere Informationen sind in der <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">Dokumentation</a> zu finden.",
+    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Du verwendest im Moment PHP {version}. Wir empfehlen ein Upgrade deiner PHP Version, um die <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">Geschwindigkeits- und Sicherheitsupdates zu nutzen, welche von der PHP Gruppe bereitgestellt werden</a>, sobald diese deine Distribution diese unterstützt.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Die Header-Einstellungen des Reverse Proxy sind falsch, oder du versuchst, dich mit ownCloud von einem vertrauten Proxy aus zu verbinden. Solltest du ownCloud nicht von einem vertrauten Proxy aus benutzen wollen, dann stellt die momentane Situation ein Sicherheitsproblem da und erlaubt Hackern, eine für ownCloud sichtbare IP-Adresse zu nutzen. Weitere Informationen findest du in der <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">Dokumentation</a>.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached ist als distributed cache konfiguriert aber das falsche PHP-Modul \"memcache\" ist installiert. \\OC\\Memcache\\Memcached unterstützt nur \"memcached\" jedoch nicht \"memcache\". Schau in der <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki nach beiden Modulen</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Einige Dateien haben die Integritätsprüfung nicht bestanden. Weiterführende Information findest Du in unserer <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">Dokumentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Liste der ungültigen Dateien ...</a> / <a href=\"{rescanEndpoint}\">Erneut analysieren…</a>)",
     "Error occurred while checking server setup" : "Fehler beim Überprüfen der Servereinrichtung",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Dein Datenverzeichnis und Deine Dateien sind wahrscheinlich vom Internet aus erreichbar. Die .htaccess-Datei funktioniert nicht. Es wird dringend empfohlen, Deinen Webserver dahingehend zu konfigurieren, dass das Datenverzeichnis nicht mehr vom Internet aus erreichbar ist oder dass Du es aus dem Document-Root-Verzeichnis des Webservers herausverschiebst.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "Der „{header}“-HTTP-Header ist nicht so konfiguriert, dass er „{expected}“ entspricht. Dies ist ein potentielles Sicherheitsrisiko und es wird empfohlen, diese Einstellung zu ändern.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "Der \"Strict-Transport-Security\" HTTP-Header ist nicht auf mindestens \"{seconds}\" Sekunden eingestellt. Um die Sicherheit zu erhöhen, empehlen wir das Aktivieren von HSTS, wie es in den <a href=\"{docUrl}\">Sicherheitshinweisen</a> erläutert ist.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "Der \"Strict-Transport-Security\" HTTP-Header ist nicht auf mindestens \"{seconds}\" Sekunden eingestellt. Um die Sicherheit zu erhöhen, empfehlen wir das Aktivieren von HSTS, wie es in den <a href=\"{docUrl}\" rel=\"noreferrer\">Sicherheitshinweisen</a> erläutert ist.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Du greifst auf diese Site über HTTP zu. Wir raten dringend dazu, Deinen Server so zu konfigurieren, dass er stattdessen nur HTTPS akzeptiert, wie es in unseren <a href=\"{docUrl}\">Sicherheitshinweisen</a> beschrieben ist.",
     "Shared" : "Geteilt",
     "Shared with {recipients}" : "Geteilt mit {recipients}",
     "Error" : "Fehler",
     "Error while sharing" : "Fehler beim Teilen",
     "Error while unsharing" : "Fehler beim Aufheben der Freigabe",
-    "Error setting expiration date" : "Fehler beim Setzen des Ablaufdatums",
     "The public link will expire no later than {days} days after it is created" : "Der öffentliche Link wird spätestens {days} Tage nach seiner Erstellung ablaufen",
     "Set expiration date" : "Setze ein Ablaufdatum",
     "Expiration" : "Ablaufdatum",
     "Expiration date" : "Ablaufdatum",
+    "Expiration date is required" : "Ablaufdatum wird benötigt",
+    "Delete {link}" : "{link} löschen",
+    "Remove link" : "Link entfernen",
+    "{fileName} link" : "{fileName}-Link",
+    "Link" : "Link",
+    "Create public link" : "Öffentlichen Link erstellen",
+    "Edit" : "Bearbeiten",
+    "Remove" : "Entfernen",
+    "Click to copy to clipboard" : "Zum Kopieren in die Zwischenablage klicken",
+    "Social share" : "Soziales teilen",
+    "There are currently no link shares, you can create one" : "Es gibt derzeit keine geteilten Links, du kannst einen erstellen",
+    "Anyone with the link has access to the file/folder" : "Jeder mit dem Link hat Zugriff auf die Datei/Ordner",
+    "Copied!" : "Kopiert!",
+    "Not supported!" : "Nicht unterstützt!",
+    "Press ⌘-C to copy." : "Zum Kopieren ⌘-C drücken.",
+    "Press Ctrl-C to copy." : "Zum Kopieren Strg-C drücken.",
     "Choose a password for the public link" : "Wählen Sie ein Passwort für den öffentlichen Link",
+    "Password required" : "Passwort erforderlich",
+    "Filename" : "Dateiname",
+    "Password" : "Passwort",
+    "Name" : "Name",
+    "Allow editing" : "Bearbeitung erlauben",
+    "Show file listing" : "Dateiliste anzeigen",
+    "Edit link share: {name}" : "Geteilten Link bearbeiten: {name}",
+    "Save" : "Speichern",
+    "Create link share: {name}" : "Geteilten Link erstellen: {name}",
+    "Remove password" : "Passwort entfernen",
+    "Share to Twitter. Opens in a new window." : "Über Twitter teilen. Wird in einem neuen Fenster geöffnet.",
+    "Share to Facebook. Opens in a new window." : "Über Facebook teilen. Wird in einem neuen Fenster geöffnet.",
+    "Share to Diaspora. Opens in a new window." : "Über Diaspora teilen. Wird in einem neuen Fenster geöffnet.",
+    "Share to Google+. Opens in a new window." : "Über Google+ teilen. Wird in einem neuen Fenster geöffnet.",
+    "Share via email. Opens your mail client." : "Über E-Mail teilen. Wird in einem neuen Fenster geöffnet.",
+    "Error while sending notification" : "Fehler beim Senden der Benachrichtigung",
     "Sending ..." : "Senden…",
     "Email sent" : "E-Mail wurde verschickt",
-    "Resharing is not allowed" : "Weiterverteilen ist nicht erlaubt",
-    "Share link" : "Link teilen",
-    "Link" : "Link",
-    "Password protect" : "Passwortschutz",
-    "Password" : "Passwort",
-    "Allow editing" : "Bearbeitung erlauben",
     "Email link to person" : "Link per E-Mail verschicken",
-    "Send" : "Senden",
+    "Send link via email" : "Link als E-Mail verschicken",
     "Shared with you and the group {group} by {owner}" : "{owner} hat dies mit Dir und der Gruppe {group} geteilt",
     "Shared with you by {owner}" : "{owner} hat dies mit Dir geteilt",
     "group" : "Gruppe",
@@ -168,19 +196,24 @@ OC.L10N.register(
     "Could not unshare" : "Freigabe konnte nicht entfernt werden",
     "Share details could not be loaded for this item." : "Details der geteilten Freigabe konnten nicht geladen werden zu diesem Eintrag.",
     "No users or groups found for {search}" : "Kein Benutzer oder Gruppen gefunden für {search}",
-    "An error occured. Please try again" : "Es ist ein Fehler aufgetreten. Bitte versuche es noch einmal",
+    "No users found for {search}" : "Kein Benutzer gefunden für {search}",
+    "An error occurred. Please try again" : "Es ist ein Fehler aufgetreten. Bitte versuche es noch einmal",
     "{sharee} (group)" : "{sharee} (group)",
     "{sharee} (at {server})" : "{sharee} (at {server})",
     "{sharee} (remote)" : "{sharee} (remote)",
     "Share" : "Teilen",
+    "User and Groups" : "Nutzer und Gruppen",
+    "Public Links" : "Öffentliche Links",
+    "Resharing is not allowed" : "Weiterverteilen ist nicht erlaubt",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Mit Benutzern anderer ownClouds unter Verwendung der Syntax benutzername@beispiel.com/owncloud teilen",
-    "Share with users or groups …" : "Mit Benutzern oder Gruppen teilen…",
-    "Share with users, groups or remote users …" : "Mit Benutzern, Gruppen oder entfernten Benutzern teilen…",
+    "Share with users…" : "Mit Benutzern teilen…",
+    "Share with users, groups or remote users…" : "Mit Benutzern, Gruppen oder entfernten Benutzern teilen…",
+    "Share with users or groups…" : "Mit Benutzern oder Gruppen teilen…",
+    "Share with users or remote users…" : "Mit Benutzern oder entfernten Benutzern teilen…",
     "Error removing share" : "Fehler beim Entfernen der Freigabe",
     "Warning" : "Warnung",
-    "Error while sending notification" : "Fehler beim Senden der Benachrichtigung",
     "Non-existing tag #{tag}" : "Nicht vorhandener Tag #{tag}",
-    "not assignable" : "nicht übertragbar",
+    "restricted" : "Eingeschränkt",
     "invisible" : "unsichtbar",
     "({scope})" : "({scope})",
     "Delete" : "Löschen",
@@ -197,13 +230,14 @@ OC.L10N.register(
     "sunny" : "sonnig",
     "Hello {name}, the weather is {weather}" : "Hallo {name}, das Wetter ist {weather}",
     "Hello {name}" : "Hallo {name}",
+    "new" : "neu",
     "_download %n file_::_download %n files_" : ["Lade %n Datei herunter","Lade %n Dateien herunter"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Das Update läuft gerade. Das Verlassen dieser Seite könnte den Update Prozess in einigen Umgebungen unterbrechen.",
-    "Updating {productName} to version {version}, this may take a while." : "Aktualisiere {productName} auf Version {version}. Dies könnte eine Weile dauern.",
+    "Updating to {version}" : "Aktualisierung auf {version}",
     "An error occurred." : "Es ist ein Fehler aufgetreten.",
     "Please reload the page." : "Bitte lade die Seite neu.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Das Update war nicht erfolgreich. Für weitere Informationen <a href=\"{url}\"> schaue bitte in unser Forum </a> um das Problem zu lösen.",
-    "The update was unsuccessful. " : "Die Aktualisierung war nicht erfolgreich.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Das Update ist fehlgeschlagen. Bitte melde dieses Problem an die <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud Community</a>.",
     "The update was successful. There were warnings." : "Das Update war erfolgreich. Warnungen wurden ausgegeben.",
     "The update was successful. Redirecting you to ownCloud now." : "Das Update war erfolgreich. Du wirst nun zu ownCloud weitergeleitet.",
     "Searching other places" : "Andere Orte durchsuchen",
@@ -214,13 +248,6 @@ OC.L10N.register(
     "Apps" : "Apps",
     "Admin" : "Administration",
     "Help" : "Hilfe",
-    "Error loading tags" : "Fehler beim Laden der Schlagwörter",
-    "Tag already exists" : "Schlagwort ist bereits vorhanden",
-    "Error deleting tag(s)" : "Fehler beim Löschen des Schlagwortes bzw. der Schlagwörter",
-    "Error tagging" : "Fehler beim Hinzufügen der Schlagwörter",
-    "Error untagging" : "Fehler beim Entfernen der Schlagwörter",
-    "Error favoriting" : "Fehler beim Favorisieren",
-    "Error unfavoriting" : "Fehler beim Entfernen aus den Favoriten",
     "Access forbidden" : "Zugriff verboten",
     "File not found" : "Datei nicht gefunden",
     "The specified document has not been found on the server." : "Das ausgewählte Dokument wurde auf dem Server nicht gefunden.",
@@ -241,9 +268,6 @@ OC.L10N.register(
     "File: %s" : "Datei: %s",
     "Line: %s" : "Zeile: %s",
     "Trace" : "Spur",
-    "Security warning" : "Sicherheitshinweis",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Dein Datenverzeichnis und Deine Dateien sind wahrscheinlich vom Internet aus erreichbar, weil die .htaccess-Datei nicht funktioniert.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Informationen zum richtigen Konfigurieren Deines Servers kannst Du der <a href=\"%s\" target=\"_blank\">Dokumentation</a> entnehmen.",
     "Create an <strong>admin account</strong>" : "<strong>Administrator-Konto</strong> anlegen",
     "Username" : "Benutzername",
     "Storage & database" : "Speicher & Datenbank",
@@ -257,6 +281,7 @@ OC.L10N.register(
     "Database name" : "Datenbank-Name",
     "Database tablespace" : "Datenbank-Tablespace",
     "Database host" : "Datenbank-Host",
+    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "Bitte die Portnummer zusammen mit dem Hostnamen angeben (z. B. localhost: 5432).",
     "Performance warning" : "Leistungswarnung",
     "SQLite will be used as database." : "SQLite wird als Datenbank benutzt.",
     "For larger installations we recommend to choose a different database backend." : "Bei größeren Installationen wird die Wahl eines anderen Datenbank-Backends empfohlen.",
@@ -271,14 +296,16 @@ OC.L10N.register(
     "Search" : "Suche",
     "Server side authentication failed!" : "Serverseitige Authentifizierung fehlgeschlagen!",
     "Please contact your administrator." : "Bitte kontaktiere Deinen Administrator.",
-    "An internal error occured." : "Es ist ein interner Fehler aufgetreten.",
+    "An internal error occurred." : "Es ist ein interner Fehler aufgetreten.",
     "Please try again or contact your administrator." : "Bitte versuche es noch einmal oder kontaktiere Deinen Administrator.",
+    "Username or email" : "Benutzername oder E-Mail",
     "Log in" : "Anmelden",
     "Wrong password. Reset it?" : "Falsches Passwort. Soll es zurückgesetzt werden?",
     "Wrong password." : "Falsches Passwort.",
     "Stay logged in" : "Angemeldet bleiben",
     "Alternative Logins" : "Alternative Logins",
     "Use the following link to reset your password: {link}" : "Benutze den folgenden Link, um Dein Passwort zurückzusetzen: {link}",
+    "Password changed successfully" : "Passwort erfolgreich geändert",
     "New password" : "Neues Passwort",
     "New Password" : "Neues Passwort",
     "Reset password" : "Passwort zurücksetzen",
@@ -286,6 +313,11 @@ OC.L10N.register(
     "This means only administrators can use the instance." : "Dies bedeutet, dass diese Instanz nur von Administratoren genutzt werden kann.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktiere Deinen Systemadministrator, wenn diese Meldung dauerhaft oder unerwartet erscheint.",
     "Thank you for your patience." : "Vielen Dank für Deine Geduld.",
+    "Two-step verification" : "Bestätigung in zwei Schritten",
+    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Die erweiterte Sicherheit wurde für dich Konto aktiviert. Bitte authentisiere dich mit einem zweiten Faktor. ",
+    "Cancel login" : "Anmelden abbrechen",
+    "Please authenticate using the selected factor." : "Bitte authentisiere dich mit dem ausgewählten zweiten Faktor. ",
+    "An error occurred while verifying the token" : "Es ist ein Fehler bei der Verifizierung des Tokens aufgetreten",
     "You are accessing the server from an untrusted domain." : "Du greifst von einer nicht vertrauenswürdigen Domain auf den Server zu.",
     "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Bitte kontaktiere deinen Administrator. Wenn du ein Administrator dieser Instanz bist, konfigurieren die \"TRUSTED_DOMAINS\" Einstellung in config/config.php .Eine Beispielkonfiguration ist in config/config.sample.php zur Verfügung gestellt.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Wenn es Deine Konfiguration zulässt, kannst Du als Administrator gegebenenfalls den Button unten benutzen, um diese Domain als vertrauenswürdig einzustufen.",
@@ -293,17 +325,15 @@ OC.L10N.register(
     "App update required" : "Appupdate notwendig",
     "%s will be updated to version %s" : "%s wird auf Version %s aktuallisiert",
     "These apps will be updated:" : "Diese Apps werden aktuallisiert:",
-    "These incompatible apps will be disabled:" : "Diese inkompatiblen Apps werden deaktiviert:",
     "The theme %s has been disabled." : "Das Theme %s wurde deaktiviert.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Bitte stelle vor dem Fortsetzen sicher, dass die Datenbank, der Konfigurationsordner und der Datenordner gesichert wurden.",
     "Start update" : "Aktualisierung starten",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Zur Vermeidung von Zeitüberschreitungen bei größeren Installationen kannst Du stattdessen den folgenden Befehl in Deinem Installationsverzeichnis ausführen:",
+    "Detailed logs" : "Detaillierte Fehlermeldungen",
+    "Update needed" : "Update wird benötigt",
+    "Please use the command line updater because you have a big instance." : "Da du eine große Instanz von Owncloud besitzt, nutze bitte den Updater über die Kommandozeile.",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Für weitere Hilfen, schaue bitte in die <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">Dokumentation</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Diese %s-Instanz befindet sich gerade im Wartungsmodus, was eine Weile dauern kann.",
-    "This page will refresh itself when the %s instance is available again." : "Diese Seite aktualisiert sich automatisch, wenn die %s-Instanz wieder verfügbar ist.",
-    "Error loading file picker template: {error}" : "Fehler beim Laden der Dateiauswahlvorlage: {error}",
-    "Fri." : "Fr",
-    "Mon." : "Mo",
-    "Password can not be changed. Please contact your administrator." : "Passwort kann nicht geändert werden. Bitte kontaktiere Deinen Administrator.",
-    "Sat." : "Sa"
+    "This page will refresh itself when the %s instance is available again." : "Diese Seite aktualisiert sich automatisch, wenn die %s-Instanz wieder verfügbar ist."
 },
 "nplurals=2; plural=(n != 1);");
