@@ -14,17 +14,9 @@ OC.L10N.register(
     "Crop is not square" : "Zuschnitt ist nicht quadratisch",
     "Couldn't reset password because the token is invalid" : "Das Passwort konnte aufgrund eines ungültigen Tokens nicht zurückgesetzt werden",
     "Couldn't reset password because the token is expired" : "Das Passwort konnte nicht zurückgesetzt werden, da der Token abgelaufen ist",
-    "Couldn't send reset email. Please make sure your username is correct." : "E-Mail zum Zurücksetzen kann nicht versendet werden. Bitte stellen Sie sicher, dass Ihr Benutzername richtig ist.",
-    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Es konnte keine E-Mail verschickt werden um das Passwort zurückzusetzten, da keine E-Mail im Benutzerkonto hinterlegt ist. Bitte kontaktieren Sie den Administrator.",
+    "%s password changed successfully" : "%s Passwort erfolgreich geändert",
     "%s password reset" : "%s-Passwort zurücksetzen",
     "Couldn't send reset email. Please contact your administrator." : "Die E-Mail zum Zurücksetzen konnte nicht versendet werden. Bitte kontaktieren Sie Ihren Administrator.",
-    "Error loading tags" : "Fehler beim Laden der Schlagwörter",
-    "Tag already exists" : "Schlagwort ist bereits vorhanden",
-    "Error deleting tag(s)" : "Fehler beim Löschen des Schlagwortes bzw. der Schlagwörter",
-    "Error tagging" : "Fehler beim Hinzufügen der Schlagwörter",
-    "Error untagging" : "Fehler beim Entfernen der Schlagwörter",
-    "Error favoriting" : "Fehler beim Hinzufügen zu den Favoriten",
-    "Error unfavoriting" : "Fehler beim Entfernen aus den Favoriten",
     "Couldn't send mail to following users: %s " : "An folgende Benutzer konnte keine E-Mail gesendet werden: %s",
     "Preparing update" : "Update vorbereiten",
     "[%d / %d]: %s" : "[%d / %d]: %s",
@@ -148,22 +140,46 @@ OC.L10N.register(
     "Error" : "Fehler",
     "Error while sharing" : "Fehler beim Teilen",
     "Error while unsharing" : "Fehler beim Aufheben der Freigabe",
-    "Error setting expiration date" : "Fehler beim Setzen des Ablaufdatums",
     "The public link will expire no later than {days} days after it is created" : "Der öffentliche Link wird spätestens {days} Tage nach seiner Erstellung ablaufen",
     "Set expiration date" : "Ein Ablaufdatum setzen",
     "Expiration" : "Ablaufdatum",
     "Expiration date" : "Ablaufdatum",
-    "Choose a password for the public link" : "Wählen Sie ein Passwort für den öffentlichen Link",
-    "Resharing is not allowed" : "Das Weiterverteilen ist nicht erlaubt",
-    "Share link" : "Link teilen",
+    "Expiration date is required" : "Ablaufdatum wird benötigt",
+    "Delete {link}" : "{link} löschen",
+    "Remove link" : "Link entfernen",
+    "{fileName} link" : "{fileName}-Link",
     "Link" : "Link",
-    "Password protect" : "Passwortschutz",
+    "Create public link" : "Öffentlichen Link erstellen",
+    "Edit" : "Bearbeiten",
+    "Remove" : "Entfernen",
+    "Click to copy to clipboard" : "Zum Kopieren in die Zwischenablage klicken",
+    "Social share" : "Soziales teilen",
+    "There are currently no link shares, you can create one" : "Es gibt derzeit keine geteilten Links, Sie können einen erstellen",
+    "Anyone with the link has access to the file/folder" : "Jeder mit dem Link hat Zugriff auf die Datei/Ordner",
+    "Copied!" : "Kopiert!",
+    "Not supported!" : "Nicht unterstützt!",
+    "Press ⌘-C to copy." : "Zum Kopieren ⌘-C drücken.",
+    "Press Ctrl-C to copy." : "Zum Kopieren Strg-C drücken.",
+    "Choose a password for the public link" : "Wählen Sie ein Passwort für den öffentlichen Link",
+    "Password required" : "Passwort erforderlich",
+    "Filename" : "Dateiname",
     "Password" : "Passwort",
+    "Name" : "Name",
     "Allow editing" : "Bearbeitung erlauben",
-    "Email link to person" : "Link per E-Mail verschicken",
-    "Send" : "Senden",
+    "Show file listing" : "Dateiliste anzeigen",
+    "Edit link share: {name}" : "Geteilten Link bearbeiten: {name}",
+    "Save" : "Speichern",
+    "Create link share: {name}" : "Geteilten Link erstellen: {name}",
+    "Remove password" : "Passwort entfernen",
+    "Share to Twitter. Opens in a new window." : "Über Twitter teilen. Wird in einem neuen Fenster geöffnet.",
+    "Share to Facebook. Opens in a new window." : "Über Facebook teilen. Wird in einem neuen Fenster geöffnet.",
+    "Share to Diaspora. Opens in a new window." : "Über Diaspora teilen. Wird in einem neuen Fenster geöffnet.",
+    "Share to Google+. Opens in a new window." : "Über Google+ teilen. Wird in einem neuen Fenster geöffnet.",
+    "Share via email. Opens your mail client." : "Über E-Mail teilen. Wird in einem neuen Fenster geöffnet.",
+    "Error while sending notification" : "Fehler beim Senden der Benachrichtigung",
     "Sending ..." : "Senden…",
     "Email sent" : "E-Mail gesendet",
+    "Email link to person" : "Link per E-Mail verschicken",
     "Send link via email" : "Link als E-Mail verschicken",
     "Shared with you and the group {group} by {owner}" : "Von {owner} mit Ihnen und der Gruppe {group} geteilt.",
     "Shared with you by {owner}" : "Von {owner} mit Ihnen geteilt.",
@@ -186,6 +202,9 @@ OC.L10N.register(
     "{sharee} (at {server})" : "{sharee} (über {server})",
     "{sharee} (remote)" : "{sharee} (entfernt)",
     "Share" : "Teilen",
+    "User and Groups" : "Nutzer und Gruppen",
+    "Public Links" : "Öffentliche Links",
+    "Resharing is not allowed" : "Das Weiterverteilen ist nicht erlaubt",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Mit Benutzern anderer ownClouds unter Verwendung der Syntax benutzername@beispiel.com/owncloud teilen",
     "Share with users…" : "Mit Benutzern teilen…",
     "Share with users, groups or remote users…" : "Mit Benutzern, Gruppen oder entfernten Benutzern teilen…",
@@ -193,7 +212,6 @@ OC.L10N.register(
     "Share with users or remote users…" : "Mit Benutzern oder entfernten Benutzern teilen…",
     "Error removing share" : "Fehler beim Entfernen der Freigabe",
     "Warning" : "Warnung",
-    "Error while sending notification" : "Fehler beim Senden der Benachrichtigung",
     "Non-existing tag #{tag}" : "Nicht existierender Tag #{tag}",
     "restricted" : "Eingeschränkt",
     "invisible" : "unsichtbar",
@@ -250,9 +268,6 @@ OC.L10N.register(
     "File: %s" : "Datei: %s",
     "Line: %s" : "Zeile: %s",
     "Trace" : "Ablauf",
-    "Security warning" : "Sicherheitshinweis",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ihr Datenverzeichnis und Ihre Dateien sind wahrscheinlich vom Internet aus erreichbar, weil die .htaccess-Datei nicht funktioniert.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentation</a>." : "Informationen zum richtigen Konfigurieren Ihres Servers können Sie der <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">Dokumentation</a> entnehmen.",
     "Create an <strong>admin account</strong>" : "<strong>Administrator-Konto</strong> anlegen",
     "Username" : "Benutzername",
     "Storage & database" : "Speicher & Datenbank",
@@ -266,6 +281,7 @@ OC.L10N.register(
     "Database name" : "Datenbank-Name",
     "Database tablespace" : "Datenbank-Tablespace",
     "Database host" : "Datenbank-Host",
+    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "Bitte die Portnummer zusammen mit dem Hostnamen angeben (z. B. localhost: 5432).",
     "Performance warning" : "Leistungswarnung",
     "SQLite will be used as database." : "SQLite wird als Datenbank benutzt.",
     "For larger installations we recommend to choose a different database backend." : "Bei größeren Installationen wird die Wahl eines anderen Datenbank-Backends empfohlen.",
@@ -289,6 +305,7 @@ OC.L10N.register(
     "Stay logged in" : "Angemeldet bleiben",
     "Alternative Logins" : "Alternative Logins",
     "Use the following link to reset your password: {link}" : "Benutzen Sie den folgenden Link, um Ihr Passwort zurückzusetzen: {link}",
+    "Password changed successfully" : "Passwort erfolgreich geändert",
     "New password" : "Neues Passwort",
     "New Password" : "Neues Passwort",
     "Reset password" : "Passwort zurücksetzen",
@@ -297,10 +314,10 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktieren Sie Ihren Systemadministrator, wenn diese Meldung dauerhaft oder unerwartet erscheint.",
     "Thank you for your patience." : "Vielen Dank für Ihre Geduld.",
     "Two-step verification" : "Bestätigung in zwei Schritten",
-    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Die erweiterte Sicherheit wurde für Ihr Konto aktiviert. Bitte authentifizieren Sie sich mit einem zweiten Faktor. ",
+    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Die erweiterte Sicherheit wurde für Ihr Konto aktiviert. Bitte authentisieren Sie sich mit einem zweiten Faktor. ",
     "Cancel login" : "Anmelden abbrechen",
-    "Please authenticate using the selected factor." : "Bitte authentifizieren Sie sich mit dem ausgewählten zweiten Faktor. ",
-    "An error occured while verifying the token" : "Es ist ein Fehler bei der Verifizierung des Tokens aufgetreten",
+    "Please authenticate using the selected factor." : "Bitte authentisieren Sie sich mit dem ausgewählten zweiten Faktor. ",
+    "An error occurred while verifying the token" : "Es ist ein Fehler bei der Verifizierung des Tokens aufgetreten",
     "You are accessing the server from an untrusted domain." : "Sie greifen von einer nicht vertrauenswürdigen Domain auf den Server zu.",
     "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Bitte kontaktieren Sie Ihren Administrator. Wenn Sie Administrator dieser Instanz sind, konfigurieren Sie bitte die „trusted_domain“-Einstellung in config/config.php. Eine Beispielkonfiguration wird unter config/config.sample.php bereitgestellt.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Wenn es Ihre Konfiguration zulässt, können Sie als Administrator gegebenenfalls den Button unten benutzen, um diese Domain als vertrauenswürdig einzustufen.",
@@ -308,7 +325,6 @@ OC.L10N.register(
     "App update required" : "App-Update notwendig",
     "%s will be updated to version %s" : "%s wird auf Version %s aktualisiert",
     "These apps will be updated:" : "Diese Apps werden aktualisiert:",
-    "These incompatible apps will be disabled:" : "Diese inkompatiblen Apps werden deaktiviert:",
     "The theme %s has been disabled." : "Das Thema %s wurde deaktiviert.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Stellen Sie vor dem Fortsetzen bitte sicher, dass die Datenbank, der Konfigurationsordner und der Datenordner gesichert wurden.",
     "Start update" : "Aktualisierung starten",
