@@ -1,27 +1,44 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Kirja saatmine järgnevatele kasutajatele ebaõnnestus: %s ",
-    "Preparing update" : "Uuendamise ettevalmistamine",
-    "Turned on maintenance mode" : "Haldusrežiimis sisse lülitatud",
-    "Turned off maintenance mode" : "Haldusrežiimis välja lülitatud",
-    "Updated database" : "Uuendatud andmebaas",
-    "Checked database schema update" : "Andmebaasi skeemi uuendus kontrollitud",
-    "Checked database schema update for apps" : "Andmebaasi skeemi uuendus rakendustele on kontrollitud",
-    "Updated \"%s\" to %s" : "Uuendatud \"%s\" -> %s",
-    "Repair warning: " : "Paranda hoiatus:",
-    "Repair error: " : "Paranda viga:",
-    "Following incompatible apps have been disabled: %s" : "Järgnevad mitteühilduvad rakendused on välja lülitatud: %s",
-    "Following apps have been disabled: %s" : "Järgnevad rakendused on välja lülitatud: %s",
-    "Already up to date" : "On juba ajakohane",
+    "Please select a file." : "Palun vali fail.",
     "File is too big" : "Fail on liiga suur",
     "Invalid file provided" : "Vigane fail",
     "No image or file provided" : "Ühtegi pilti või faili pole pakutud",
     "Unknown filetype" : "Tundmatu failitüüp",
     "Invalid image" : "Vigane pilt",
+    "An error occurred. Please contact your admin." : "Tekkis tõrge. Palun võta ühendust administraatoriga.",
     "No temporary profile picture available, try again" : "Ühtegi ajutist profiili pilti pole saadaval, proovi uuesti",
     "No crop data provided" : "Lõikeandmeid ei leitud",
+    "No valid crop data provided" : "Korrektseid lõikeandmeid ei leitud",
     "Crop is not square" : "Lõikamine pole ruudukujuline",
+    "Couldn't reset password because the token is invalid" : "Ei saanud parooli taastada, kuna märgend on vigane",
+    "%s password changed successfully" : "%s parool on muudetud",
+    "%s password reset" : "%s parooli lähtestus",
+    "Couldn't send reset email. Please contact your administrator." : "Ei suutnud lähtestada e-maili. Palun kontakteeru süsteemihalduriga.",
+    "Couldn't send mail to following users: %s " : "Kirja saatmine järgnevatele kasutajatele ebaõnnestus: %s ",
+    "Preparing update" : "Uuendamise ettevalmistamine",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "Paranda hoiatus:",
+    "Repair error: " : "Paranda viga:",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: tabeli kontrollimine %s",
+    "Turned on maintenance mode" : "Haldusrežiimis sisse lülitatud",
+    "Turned off maintenance mode" : "Haldusrežiimis välja lülitatud",
+    "Maintenance mode is kept active" : "Hooldusrežiim on aktiivne",
+    "Updating database schema" : "Andmebaasi skeemi uuendamine",
+    "Updated database" : "Uuendatud andmebaas",
+    "Checked database schema update" : "Andmebaasi skeemi uuendus kontrollitud",
+    "Checking updates of apps" : "Rakenduse uuenduste kontrollimine",
+    "Checked database schema update for apps" : "Andmebaasi skeemi uuendus rakendustele on kontrollitud",
+    "Updated \"%s\" to %s" : "Uuendatud \"%s\" -> %s",
+    "Set log level to debug" : "Määra veatuvastuse logimise tase",
+    "Reset log level" : "Nulli logimise tase",
+    "Starting code integrity check" : "Koodi seisundi kontrollimise alustamine",
+    "Finished code integrity check" : "Koodi seisundi kontrollimine on lõpetatud",
+    "%s (3rdparty)" : "%s (3nda osapoole arendaja)",
+    "%s (incompatible)" : "%s (pole ühilduv)",
+    "Following apps have been disabled: %s" : "Järgnevad rakendused on välja lülitatud: %s",
+    "Already up to date" : "On juba ajakohane",
     "Sunday" : "Pühapäev",
     "Monday" : "Esmaspäev",
     "Tuesday" : "Teisipäev",
@@ -68,9 +85,10 @@ OC.L10N.register(
     "Nov." : "Nov.",
     "Dec." : "Dets.",
     "Settings" : "Seaded",
+    "Problem loading page, reloading in 5 seconds" : "Lehe laadimisel tekkis tõrge, 5 sekundi pärast laaditakse leht uuesti.",
     "Saving..." : "Salvestamine...",
+    "Dismiss" : "Jäta vahele",
     "seconds ago" : "sekundit tagasi",
-    "Couldn't send reset email. Please contact your administrator." : "Ei suutnud lähtestada e-maili. Palun kontakteeru süsteemihalduriga.",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Link parooli vahetuseks on saadetud Sinu e-posti aadressil.<br>Kui kiri pole saabunud mõistliku aja jooksul, siis kontrolli oma spam-/rämpskirjade katalooge<br>.Kui kirja pole ka seal, siis küsi abi süsteemihaldurilt.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Sinu failid on krüpteeritud. Kui sa pole taastamise võtit veel määranud, siis pole präast parooli taastamist mingit võimalust sinu andmeid tagasi saada. <br />Kui sa pole kindel, mida teha, siis palun väta enne jätkamist ühendust oma administaatoriga. <br />Oled sa kindel, et sa soovid jätkata?",
     "I know what I'm doing" : "Ma tean mida teen",
@@ -105,26 +123,47 @@ OC.L10N.register(
     "Error" : "Viga",
     "Error while sharing" : "Viga jagamisel",
     "Error while unsharing" : "Viga jagamise lõpetamisel",
-    "Error while changing permissions" : "Viga õiguste muutmisel",
-    "Error setting expiration date" : "Viga aegumise kuupäeva määramisel",
     "The public link will expire no later than {days} days after it is created" : "Avalik link aegub mitte hiljem kui pärast {days} päeva selle loomist",
     "Set expiration date" : "Määra aegumise kuupäev",
     "Expiration" : "Aegumine",
     "Expiration date" : "Aegumise kuupäev",
+    "Expiration date is required" : "Aegumise kuupäev on nõutud",
+    "Delete {link}" : "Kustuta {link}",
+    "Remove link" : "Eemalda link",
+    "{fileName} link" : "{fileName} link",
+    "Link" : "Link",
+    "Create public link" : "Loo avalik link",
+    "Edit" : "Muuda",
+    "Remove" : "Eemalda",
+    "Click to copy to clipboard" : "Kliki, et link lõikelauale kopeerida",
+    "Social share" : "Sotsiaalvõrgustikus jagamine",
+    "Copied!" : "Kopeeritud!",
+    "Not supported!" : "Pole toetatud!",
+    "Press ⌘-C to copy." : "Kopeerimiseks vajuta ⌘-C.",
+    "Press Ctrl-C to copy." : "Kopeerimiseks vajuta Ctrl-C.",
+    "Choose a password for the public link" : "Vali avaliku lingi jaoks parool",
+    "Password required" : "Parool on nõutud",
+    "Filename" : "Failinimi",
+    "Password" : "Parool",
+    "Name" : "Nimi",
+    "Allow editing" : "Luba muutmine",
+    "Show file listing" : "Näita failide nimekirja",
+    "Edit link share: {name}" : "Muuda jagamise link: {name}",
+    "Save" : "Salvesta",
+    "Create link share: {name}" : "Loo lingiga jagamine: {name}",
+    "Remove password" : "Eemalda parool",
+    "Share to Twitter. Opens in a new window." : "Jaga Twitteris. Avaneb uues aknas.",
+    "Share to Facebook. Opens in a new window." : "Jaga Facebookis. Avaneb uues aknas.",
+    "Share to Diaspora. Opens in a new window." : "Jaga Diasporas. Avaneb uues aknas.",
+    "Share to Google+. Opens in a new window." : "Jaga Google plusis. Avaneb uues aknas.",
+    "Share via email. Opens your mail client." : "Jaga e-postiga. Avab sinu meilikliendi",
+    "Error while sending notification" : "Tõrge teavituse saatmisel",
     "Sending ..." : "Saatmine ...",
     "Email sent" : "E-kiri on saadetud",
-    "Resharing is not allowed" : "Edasijagamine pole lubatud",
-    "Share link" : "Jaga linki",
-    "Link" : "Link",
-    "Password protect" : "Parooliga kaitstud",
-    "Password" : "Parool",
-    "Choose a password for the public link" : "Vali avaliku lingi jaoks parool",
-    "Allow editing" : "Luba muutmine",
     "Email link to person" : "Saada link isikule e-postiga",
-    "Send" : "Saada",
+    "Send link via email" : "Jaga linki e-postiga",
     "Shared with you and the group {group} by {owner}" : "Jagatud sinu ja {group} grupiga {owner} poolt",
     "Shared with you by {owner}" : "Sinuga jagas {owner}",
-    "Shared in {item} with {user}" : "Jagatud {item} kasutajaga {user}",
     "group" : "grupp",
     "notify by email" : "teavita e-postiga",
     "Unshare" : "Lõpeta jagamine",
@@ -134,14 +173,31 @@ OC.L10N.register(
     "change" : "muuda",
     "delete" : "kustuta",
     "access control" : "ligipääsukontroll",
-    "An error occured. Please try again" : "Tekkis tõrge. Palun proovi uuesti",
+    "Could not unshare" : "Jagamise lõpetamine ebaõnnestus",
+    "No users found for {search}" : "Otsinguga {search} ei leitud ühtegi kasutajat",
+    "An error occurred. Please try again" : "Tekkis tõrge. Palu proovi uuesti",
+    "{sharee} (group)" : "{sharee} (group)",
+    "{sharee} (at {server})" : "{sharee} (serveris {server})",
+    "{sharee} (remote)" : "{sharee} (mujal serveris)",
     "Share" : "Jaga",
-    "Share with users or groups …" : "Jaga kasutajate või gruppidega ...",
-    "Share with users, groups or remote users …" : "Jaga kasutajate, gruppide või eemal olevate kasutajatega ...",
+    "User and Groups" : "Kasutajad ja grupid",
+    "Public Links" : "Avalikud lingid",
+    "Resharing is not allowed" : "Edasijagamine pole lubatud",
+    "Share with users…" : "Jaga kasutajatega...",
+    "Share with users, groups or remote users…" : "Jaga kasutajate, gruppide või kaugkasutajatega...",
+    "Share with users or groups…" : "Jaga kasutajate või gruppidega...",
+    "Share with users or remote users…" : "Jaga kasutajate või kaugkasutajatega...",
+    "Error removing share" : "Jagamise eemaldamisel tekkis tõrge",
     "Warning" : "Hoiatus",
+    "Non-existing tag #{tag}" : "Silti #{tag} pole olemas",
+    "restricted" : "piiratud",
+    "invisible" : "nähtamatu",
+    "({scope})" : "({scope})",
+    "Delete" : "Kustuta",
+    "Rename" : "Nimeta ümber",
+    "Collaborative tags" : "Koostöö sildid",
     "The object type is not specified." : "Objekti tüüp pole määratletud.",
     "Enter new" : "Sisesta uus",
-    "Delete" : "Kustuta",
     "Add" : "Lisa",
     "Edit tags" : "Muuda silte",
     "Error loading dialog template: {error}" : "Viga dialoogi malli laadimisel: {error}",
@@ -151,33 +207,20 @@ OC.L10N.register(
     "sunny" : "päikeseline",
     "Hello {name}, the weather is {weather}" : "Tere {name}, ilm on {weather}",
     "Hello {name}" : "Tere, {name}",
+    "new" : "uus",
     "_download %n file_::_download %n files_" : ["laadi alla %n fail","laadi alla %n faili"],
-    "{version} is available. Get more information on how to update." : "{version} on saadaval. Vaata lisainfot uuendamise kohta.",
-    "Updating {productName} to version {version}, this may take a while." : "Uuendan {productName} versioonile {version}, see võtab veidi aega.",
+    "Updating to {version}" : "Uuendamine versioonile {version}",
+    "An error occurred." : "Tekkis tõrge.",
     "Please reload the page." : "Palun laadi see uuesti.",
-    "The update was unsuccessful. " : "Uuendamine ebaõnnestus.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Uuendus ebaõnnestus. Palun teavita probleemidest  <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud kogukonda</a>.",
+    "The update was successful. There were warnings." : "Uuendamine läks kenasti. hoiatusi polnud.",
     "The update was successful. Redirecting you to ownCloud now." : "Uuendus oli edukas. Kohe suunatakse Sind ownCloudi.",
-    "Couldn't reset password because the token is invalid" : "Ei saanud parooli taastada, kuna märgend on vigane",
-    "Couldn't send reset email. Please make sure your username is correct." : "Ei suutnud lähtestada e-maili. Palun veendu, et kasutajatunnus on õige.",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Ei suutnud lähtestada e-maili, kuna sellel kasutajal pole e-posti määratud. Palun kontakteeru süsteemihalduriga.",
-    "%s password reset" : "%s parooli lähtestus",
-    "Use the following link to reset your password: {link}" : "Kasuta järgnevat linki oma parooli taastamiseks: {link}",
-    "New password" : "Uus parool",
-    "New Password" : "Uus parool",
-    "Reset password" : "Nulli parool",
     "Searching other places" : "Otsi teistest kohtadest",
     "Personal" : "Isiklik",
     "Users" : "Kasutajad",
     "Apps" : "Rakendused",
     "Admin" : "Admin",
     "Help" : "Abiinfo",
-    "Error loading tags" : "Viga siltide laadimisel",
-    "Tag already exists" : "Silt on juba olemas",
-    "Error deleting tag(s)" : "Viga sildi (siltide) kustutamisel",
-    "Error tagging" : "Viga sildi lisamisel",
-    "Error untagging" : "Viga sildi eemaldamisel",
-    "Error favoriting" : "Viga lemmikuks lisamisel",
-    "Error unfavoriting" : "Viga lemmikutest eemaldamisel",
     "Access forbidden" : "Ligipääs on keelatud",
     "File not found" : "Faili ei leitud",
     "The specified document has not been found on the server." : "Määratud dokumenti serverist ei leitud.",
@@ -198,9 +241,6 @@ OC.L10N.register(
     "File: %s" : "Fail: %s",
     "Line: %s" : "Rida: %s",
     "Trace" : "Jälita",
-    "Security warning" : "Turvahoiatus",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su andmete kataloog ja failid on tõenäoliselt internetist vabalt saadaval kuna .htaccess fail ei toimi.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Serveri korrektseks seadistuseks palun tutvu <a href=\"%s\" target=\"_blank\">dokumentatsiooniga</a>.",
     "Create an <strong>admin account</strong>" : "Loo <strong>admini konto</strong>",
     "Username" : "Kasutajanimi",
     "Storage & database" : "Andmehoidla ja andmebaas",
@@ -219,32 +259,42 @@ OC.L10N.register(
     "Finishing …" : "Lõpetamine ...",
     "Need help?" : "Vajad abi?",
     "See the documentation" : "Vaata dokumentatsiooni",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hei,<br><br>annan teada, et %s jagas sinuga <strong>%s</strong>. <a href=\"%s\">Vaata seda!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "See rakendus vajab toimimiseks JavaScripti. Palun {linkstart}luba JavaScript{linkend} ning laadi see leht uuesti.",
     "Log out" : "Logi välja",
     "Search" : "Otsi",
     "Server side authentication failed!" : "Serveripoolne autentimine ebaõnnestus!",
     "Please contact your administrator." : "Palun kontakteeru oma süsteemihalduriga.",
-    "An internal error occured." : "Tekkis sisemine tõrge.",
+    "An internal error occurred." : "Tekkis sisemine tõrge",
     "Please try again or contact your administrator." : "Palun proovi uuesti või võta ühendust oma administraatoriga.",
+    "Username or email" : "Kasutajanimi või e-posti aadress",
     "Log in" : "Logi sisse",
-    "remember" : "pea meeles",
+    "Wrong password. Reset it?" : "Vale parool. Kas vajad parooli taastamist?",
+    "Wrong password." : "Vale parool.",
+    "Stay logged in" : "Püsi sisselogituna",
     "Alternative Logins" : "Alternatiivsed sisselogimisviisid",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hei,<br><br>annan teada, et %s jagas sinuga <strong>%s</strong>. <a href=\"%s\">Vaata seda!</a><br><br>",
+    "Use the following link to reset your password: {link}" : "Kasuta järgnevat linki oma parooli taastamiseks: {link}",
+    "Password changed successfully" : "Parool on muudetud",
+    "New password" : "Uus parool",
+    "New Password" : "Uus parool",
+    "Reset password" : "Nulli parool",
     "This ownCloud instance is currently in single user mode." : "See ownCloud on momendil seadistatud ühe kasutaja jaoks.",
     "This means only administrators can use the instance." : "See tähendab, et seda saavad kasutada ainult administraatorid.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontakteeru oma süsteemihalduriga, kui see teade püsib või on tekkinud ootamatult.",
     "Thank you for your patience." : "Täname kannatlikkuse eest.",
+    "Two-step verification" : "Kahe-etapiline kinnitamine",
+    "Cancel login" : "Tühista sisselogimine",
     "You are accessing the server from an untrusted domain." : "Sa kasutad serverit usalduseta asukohast",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Palun võta ühendust oma saidi administraatoriga. Kui sa oled ise administraator, siis seadista failis config/config.php sätet \"trusted_domain\". Näidis seadistused leiad failist config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Sõltuvalt sinu seadetest võib ka administraator kasutada allolevat nuppu, et seda domeeni usaldusväärseks märkida.",
     "Add \"%s\" as trusted domain" : "Lisa \"%s\" usaldusväärse domeenina",
     "App update required" : "Rakenduse uuendus on nõutud",
     "These apps will be updated:" : "Neid rakendusi uuendatakse:",
-    "These incompatible apps will be disabled:" : "Need mitteühilduvad rakendused lülitatakse välja:",
     "The theme %s has been disabled." : "Teema %s on keelatud.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Enne jätkamist veendu, et andmebaas, seadete ning andmete kataloog on varundatud.",
     "Start update" : "Käivita uuendus",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Suurtel saitidel aegumise vältimiseks võid sa paigalduskaustas käivitada järgmise käsu:",
+    "Detailed logs" : "Üksikasjalikud logid",
+    "Update needed" : "On vaja uuendada",
     "This page will refresh itself when the %s instance is available again." : "Se leht laetakse uuesti, kui %s instantsi on uuesti saadaval."
 },
 "nplurals=2; plural=(n != 1);");
