@@ -11,18 +11,9 @@ OC.L10N.register(
     "Crop is not square" : "بخش بریده شده مربع نیست",
     "%s password reset" : "%s رمزعبور تغییر کرد",
     "Couldn't send reset email. Please contact your administrator." : "ارسال ایمیل مجدد با مشکل مواجه شد . لطفا با مدیر سیستم تماس بگیرید .",
-    "Error loading tags" : "خطا در هنگام بارگزاری تگ ها",
-    "Tag already exists" : "تگ از قبل وجود دارد",
-    "Error deleting tag(s)" : "خطا در هنگام حذف تگ (ها)",
-    "Error tagging" : "خطا در هنگام تگ گذاری",
-    "Error untagging" : "خطا در هنگام حذف تگ",
-    "Error favoriting" : "خطا هنگام افزودن به موارد محبوب",
-    "Error unfavoriting" : "خطا هنگام حذف از موارد محبوب",
-    "Couldn't send mail to following users: %s " : "ارسال ایمیل برای کاربران روبرو با شکست مواجه شد : %s",
     "Preparing update" : "آماده‌سازی به روز‌ رسانی",
     "Repair warning: " : "اخطار تعمیر:",
     "Repair error: " : "خطای تعمیر:",
-    "Turned on maintenance mode" : "حالت \" در دست تعمیر \" فعال شد .",
     "Turned off maintenance mode" : "حالت \" در دست تعمیر \" غیرفعال شد .",
     "Maintenance mode is kept active" : "حالت تعمیرات فعال نگه‌داشته شده است",
     "Updated database" : "بروز رسانی پایگاه داده انجام شد .",
@@ -108,22 +99,23 @@ OC.L10N.register(
     "Error" : "خطا",
     "Error while sharing" : "خطا درحال به اشتراک گذاشتن",
     "Error while unsharing" : "خطا درحال لغو اشتراک",
-    "Error setting expiration date" : "خطا در تنظیم تاریخ انقضا",
     "The public link will expire no later than {days} days after it is created" : "لینک عمومی پس از {days} روز پس از ایجاد منقضی خواهد شد",
     "Set expiration date" : "تنظیم تاریخ انقضا",
     "Expiration" : "تاریخ انقضا",
     "Expiration date" : "تاریخ انقضا",
-    "Choose a password for the public link" : "انتخاب رمز برای لینک عمومی",
-    "Resharing is not allowed" : "اشتراک گذاری مجدد مجاز نمی باشد",
-    "Share link" : "اشتراک گذاشتن لینک",
     "Link" : "لینک",
-    "Password protect" : "نگهداری کردن رمز عبور",
+    "Edit" : "ویرایش",
+    "Remove" : "برداشتن",
+    "Choose a password for the public link" : "انتخاب رمز برای لینک عمومی",
+    "Filename" : "نام فایل",
     "Password" : "گذرواژه",
+    "Name" : "نام",
     "Allow editing" : "اجازه‌ی ویرایش",
-    "Email link to person" : "پیوند ایمیل برای شخص.",
-    "Send" : "ارسال",
+    "Save" : "ذخیره",
+    "Error while sending notification" : "خطا در حین ارسال نوتیفیکیشن",
     "Sending ..." : "درحال ارسال ...",
     "Email sent" : "ایمیل ارسال شد",
+    "Email link to person" : "پیوند ایمیل برای شخص.",
     "Shared with you and the group {group} by {owner}" : "به اشتراک گذاشته شده با شما و گروه {گروه} توسط {دارنده}",
     "Shared with you by {owner}" : "به اشتراک گذاشته شده با شما توسط { دارنده}",
     "group" : "گروه",
@@ -137,9 +129,9 @@ OC.L10N.register(
     "delete" : "پاک کردن",
     "access control" : "کنترل دسترسی",
     "Share" : "اشتراک‌گذاری",
+    "Resharing is not allowed" : "اشتراک گذاری مجدد مجاز نمی باشد",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "اشتراک‌گذاری با دیگر افراد بر روی ownClouds بصورت username@example.com/owncloud",
     "Warning" : "اخطار",
-    "Error while sending notification" : "خطا در حین ارسال نوتیفیکیشن",
     "Delete" : "حذف",
     "Rename" : "تغییرنام",
     "The object type is not specified." : "نوع شی تعیین نشده است.",
@@ -179,8 +171,6 @@ OC.L10N.register(
     "Message: %s" : "پیام: %s",
     "File: %s" : "فایل : %s",
     "Line: %s" : "خط: %s",
-    "Security warning" : "اخطار امنیتی",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "فایلها و فهرست های داده های شما قابل از اینترنت قابل دسترسی هستند، چونکه فایل htacces. کار نمی کند.",
     "Create an <strong>admin account</strong>" : "لطفا یک <strong> شناسه برای مدیر</strong> بسازید",
     "Username" : "نام کاربری",
     "Storage & database" : "انبارش و پایگاه داده",
