@@ -1,17 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Non é posíbel enviar correo aos usuarios seguintes: %s",
-    "Turned on maintenance mode" : "Modo de mantemento activado",
-    "Turned off maintenance mode" : "Modo de mantemento desactivado",
-    "Maintenance mode is kept active" : "Mantense activo o modo de mantemento",
-    "Updated database" : "Base de datos actualizada",
-    "Checked database schema update" : "Comprobada a actualización do esquema da base de datos",
-    "Checked database schema update for apps" : "Comprobada a actualización do esquema da base de datos para aplicacións",
-    "Updated \"%s\" to %s" : "Actualizado «%s» a %s",
-    "Repair warning: " : "Aviso de arranxo:",
-    "Repair error: " : "Arranxar o erro:",
-    "Following apps have been disabled: %s" : "As seguintes aplicacións foron desactivadas: %s",
     "File is too big" : "O ficheiro é grande de máis",
     "Invalid file provided" : "O ficheiro fornecido non é válido",
     "No image or file provided" : "Non forneceu ningunha imaxe ou ficheiro",
@@ -22,9 +11,19 @@ OC.L10N.register(
     "No valid crop data provided" : "Os datos cortados fornecidos non son válidos",
     "Crop is not square" : "O corte non é cadrado",
     "Couldn't reset password because the token is invalid" : "No, foi posíbel restabelecer o contrasinal, a marca non é correcta",
-    "Couldn't send reset email. Please make sure your username is correct." : "Non foi posíbel enviar o correo do restabelecemento. Asegúrese de que o nome de usuario é o correcto.",
     "%s password reset" : "Restabelecer o contrasinal %s",
     "Couldn't send reset email. Please contact your administrator." : "Non foi posíbel enviar o correo do restabelecemento. Póñase en contacto co administrador.",
+    "Couldn't send mail to following users: %s " : "Non é posíbel enviar correo aos usuarios seguintes: %s",
+    "Repair warning: " : "Aviso de arranxo:",
+    "Repair error: " : "Arranxar o erro:",
+    "Turned on maintenance mode" : "Modo de mantemento activado",
+    "Turned off maintenance mode" : "Modo de mantemento desactivado",
+    "Maintenance mode is kept active" : "Mantense activo o modo de mantemento",
+    "Updated database" : "Base de datos actualizada",
+    "Checked database schema update" : "Comprobada a actualización do esquema da base de datos",
+    "Checked database schema update for apps" : "Comprobada a actualización do esquema da base de datos para aplicacións",
+    "Updated \"%s\" to %s" : "Actualizado «%s» a %s",
+    "Following apps have been disabled: %s" : "As seguintes aplicacións foron desactivadas: %s",
     "Sunday" : "domingo",
     "Monday" : "luns",
     "Tuesday" : "martes",
@@ -112,22 +111,22 @@ OC.L10N.register(
     "Error" : "Erro",
     "Error while sharing" : "Produciuse un erro ao compartir",
     "Error while unsharing" : "Produciuse un erro ao deixar de compartir",
-    "Error setting expiration date" : "Produciuse un erro ao definir a data de caducidade",
     "The public link will expire no later than {days} days after it is created" : "A ligazón pública caducará, a máis tardar, {days} días após a súa creación",
     "Set expiration date" : "Definir a data de caducidade",
     "Expiration" : "Caducidade",
     "Expiration date" : "Data de caducidade",
+    "Link" : "Ligazón",
+    "Edit" : "Editar",
+    "Remove" : "Retirar",
     "Choose a password for the public link" : "Escolla un contrasinal para a ligazón pública",
+    "Filename" : "Nome de ficheiro",
+    "Password" : "Contrasinal",
+    "Name" : "Nome",
+    "Allow editing" : "Permitir a edición",
+    "Save" : "Gardar",
     "Sending ..." : "Enviando...",
     "Email sent" : "Correo enviado",
-    "Resharing is not allowed" : "Non se permite volver compartir",
-    "Share link" : "Ligazón para compartir",
-    "Link" : "Ligazón",
-    "Password protect" : "Protexido con contrasinal",
-    "Password" : "Contrasinal",
-    "Allow editing" : "Permitir a edición",
     "Email link to person" : "Enviar ligazón por correo",
-    "Send" : "Enviar",
     "Shared with you and the group {group} by {owner}" : "Compartido con vostede e co grupo {group} por {owner}",
     "Shared with you by {owner}" : "Compartido con vostede por {owner}",
     "group" : "grupo",
@@ -140,11 +139,9 @@ OC.L10N.register(
     "change" : "cambio",
     "delete" : "eliminar",
     "access control" : "control de acceso",
-    "An error occured. Please try again" : "Produciuse un erro, ténteo de novo",
     "Share" : "Compartir",
+    "Resharing is not allowed" : "Non se permite volver compartir",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Comparta con outra xente ou con outros ownClouds empregando a sintaxe «nomeusuario@exemplo.com/ouwncloud»",
-    "Share with users or groups …" : "Compartir con usuarios ou grupos ...",
-    "Share with users, groups or remote users …" : "Compartir con usuarios, grupos ou usuarios remotos ...",
     "Warning" : "Aviso",
     "Delete" : "Eliminar",
     "Rename" : "Renomear",
@@ -160,9 +157,8 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Ola {name}, o tempo é {weather}",
     "Hello {name}" : "Ola {name}",
     "_download %n file_::_download %n files_" : ["descargar %n ficheiro","descargar %n ficheiros"],
-    "Updating {productName} to version {version}, this may take a while." : "Actualizando {productName} a versión {version}, isto pode levar un anaco.",
     "Please reload the page." : "Volva cargar a páxina.",
-    "The update was unsuccessful. " : "Fracasou a actualización.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "A actualización non foi satisfactoria, informe deste problema á  <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">comunidade de ownCloud</a>.",
     "The update was successful. There were warnings." : "A actualización realizouse correctamente. Houbo algún aviso.",
     "The update was successful. Redirecting you to ownCloud now." : "A actualización realizouse correctamente. Redirixíndoo agora á ownCloud.",
     "Searching other places" : "Buscando noutros lugares",
@@ -171,13 +167,6 @@ OC.L10N.register(
     "Apps" : "Aplicacións",
     "Admin" : "Administración",
     "Help" : "Axuda",
-    "Error loading tags" : "Produciuse un erro ao cargar as etiquetas",
-    "Tag already exists" : "Xa existe a etiqueta",
-    "Error deleting tag(s)" : "Produciuse un erro ao eliminar a(s) etiqueta(s)",
-    "Error tagging" : "Produciuse un erro ao etiquetar",
-    "Error untagging" : "Produciuse un erro ao eliminar a etiqueta",
-    "Error favoriting" : "Produciuse un erro ao marcar como favorito",
-    "Error unfavoriting" : "Produciuse un erro ao desmarcar como favorito",
     "Access forbidden" : "Acceso denegado",
     "File not found" : "Ficheiro non atopado",
     "The specified document has not been found on the server." : "Non se atopou no servidor o documento indicado.",
@@ -198,9 +187,6 @@ OC.L10N.register(
     "File: %s" : "Ficheiro: %s",
     "Line: %s" : "Liña: %s",
     "Trace" : "Traza",
-    "Security warning" : "Aviso de seguridade",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "O seu directorio de datos e os ficheiros probabelmente sexan accesíbeis desde a Internet xa que o ficheiro .htaccess non está a traballar.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Para obter información sobre como como configurar axeitadamente o seu servidor, vexa a <a href=\"%s\" target=\"_blank\">documentación</a>.",
     "Create an <strong>admin account</strong>" : "Crear unha <strong>contra de administrador</strong>",
     "Username" : "Nome de usuario",
     "Storage & database" : "Almacenamento e base de datos",
@@ -228,7 +214,6 @@ OC.L10N.register(
     "Search" : "Buscar",
     "Server side authentication failed!" : "A autenticación fracasou do lado do servidor!",
     "Please contact your administrator." : "Contacte co administrador.",
-    "An internal error occured." : "Produciuse un erro interno.",
     "Please try again or contact your administrator." : "Ténteo de novo ou póñase en contacto co administrador.",
     "Log in" : "Acceder",
     "Alternative Logins" : "Accesos alternativos",
@@ -246,14 +231,11 @@ OC.L10N.register(
     "App update required" : "É necesario actualizar a aplicación",
     "%s will be updated to version %s" : "%s actualizarase á versión %s",
     "These apps will be updated:" : "Actualizaranse estas aplicacións:",
-    "These incompatible apps will be disabled:" : "Desactivaranse estas aplicacións incompatíbeis:",
     "The theme %s has been disabled." : "O tema %s foi desactivado.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Asegúrese de ter feito unha copia de seguranza da base de datos, do cartafol de configuración e do cartafol de datos, antes de proceder.",
     "Start update" : "Iniciar a actualización",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tempos de espera nas instalacións grandes, no seu lugar pode executar a seguinte orde desde o directorio de instalación:",
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia de %s atopase en modo de mantemento, isto pode levar un anaco.",
-    "This page will refresh itself when the %s instance is available again." : "Esta páxina actualizarase automaticamente cando a instancia de %s estea dispoñíbel de novo.",
-    "Error loading file picker template: {error}" : "Produciuse un erro ao cargar o modelo do selector: {error}",
-    "Password can not be changed. Please contact your administrator." : "Non é posíbel cambiar o contrasinal. Póñase en contacto co administrador."
+    "This page will refresh itself when the %s instance is available again." : "Esta páxina actualizarase automaticamente cando a instancia de %s estea dispoñíbel de novo."
 },
 "nplurals=2; plural=(n != 1);");
