@@ -1,29 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "לא ניתן היה לשלוח דואר אלקטרוני למשתמשים הבאים %s ",
-    "Preparing update" : "מכין עדכון",
-    "Turned on maintenance mode" : "הפעלת מצב אחזקה",
-    "Turned off maintenance mode" : "כיבוי מצב אחזקה",
-    "Maintenance mode is kept active" : "מצב אחזקה נשמר פעיל",
-    "Updating database schema" : "עדכון סכימת מסד נתונים",
-    "Updated database" : "עדכון מסד נתונים",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "בודק אם סכימת מסד הנתונים ניתנת לעדכון (פעולה זו יכולה להמשך זמן רב תלוי בגודל מסד הנתונים)",
-    "Checked database schema update" : "עדכון סכימת מסד נתונים נבדק",
-    "Checking updates of apps" : "בדיקת עדכוני יישומים",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "בודק אם סכימת מסד הנתונים עבור %s ניתנת לעדכון (פעולה זו יכולה להמשך זמן רב תלוי בגודל מסד הנתונים)",
-    "Checked database schema update for apps" : "עדכון סכימת מסד נתונים ליישומים נבדק",
-    "Updated \"%s\" to %s" : "מעדכן \"%s\" ל- %s",
-    "Repair warning: " : "אזהרת תיקון:",
-    "Repair error: " : "שגיאת תיקון:",
-    "Set log level to debug" : "קביעת רמת דיווח לתהליך ניפוי בשגיאות",
-    "Reset log level" : "קביעה מחדש לרמת דיווח",
-    "Starting code integrity check" : "התחלת בדיקת תקינות קוד",
-    "Finished code integrity check" : "סיום בדיקת תקינות קוד",
-    "%s (3rdparty)" : "%s (צד שלישי)",
-    "%s (incompatible)" : "%s (לא תואם)",
-    "Following apps have been disabled: %s" : "היישומים הבאים נוטרלו: %s",
-    "Already up to date" : "כבר עדכני",
     "Please select a file." : "יש לבחור קובץ.",
     "File is too big" : "הקובץ גדול מדי",
     "Invalid file provided" : "סופק קובץ לא חוקי",
@@ -37,10 +14,35 @@ OC.L10N.register(
     "Crop is not square" : "הקיטום אינו מרובע",
     "Couldn't reset password because the token is invalid" : "לא ניתן לאפס סיסמא כיוון שמחרוזת האימות אינה חוקית",
     "Couldn't reset password because the token is expired" : "לא ניתן לאפס סיסמא כיוון שמחרוזת האימות פגה תוקף",
-    "Couldn't send reset email. Please make sure your username is correct." : "לא ניתן היה לשלוח דואר אלקטרוני לאיפוס. יש לוודא ששם המשתמש נכון.",
-    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "לא ניתן היה לשלוח דואר אלקטרוני כיוון שלא מוגדר דואר אלקטרוני למשתמש זה. יש ליצור קשר עם מנהל.",
+    "%s password changed successfully" : "סיסמא %s שונתה בהצלחה",
     "%s password reset" : "%s הסיסמא אופסה",
     "Couldn't send reset email. Please contact your administrator." : "לא ניתן היה לשלוח דואר אלקטרוני לאיפוס. יש לפנות למנהל שלך.",
+    "Couldn't send mail to following users: %s " : "לא ניתן היה לשלוח דואר אלקטרוני למשתמשים הבאים %s ",
+    "Preparing update" : "מכין עדכון",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "אזהרת תיקון:",
+    "Repair error: " : "שגיאת תיקון:",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "יש להשתמש בעדכון על בסיס שורת פקודה כיוון שעדכון אוטומטי מנוטרל בקובץ config.php.",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: בודק טבלה %s",
+    "Turned on maintenance mode" : "הפעלת מצב אחזקה",
+    "Turned off maintenance mode" : "כיבוי מצב אחזקה",
+    "Maintenance mode is kept active" : "מצב אחזקה נשמר פעיל",
+    "Updating database schema" : "עדכון סכימת מסד נתונים",
+    "Updated database" : "עדכון מסד נתונים",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "בודק אם סכימת מסד הנתונים ניתנת לעדכון (פעולה זו יכולה להמשך זמן רב תלוי בגודל מסד הנתונים)",
+    "Checked database schema update" : "עדכון סכימת מסד נתונים נבדק",
+    "Checking updates of apps" : "בדיקת עדכוני יישומים",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "בודק אם סכימת מסד הנתונים עבור %s ניתנת לעדכון (פעולה זו יכולה להמשך זמן רב תלוי בגודל מסד הנתונים)",
+    "Checked database schema update for apps" : "עדכון סכימת מסד נתונים ליישומים נבדק",
+    "Updated \"%s\" to %s" : "מעדכן \"%s\" ל- %s",
+    "Set log level to debug" : "קביעת רמת דיווח לתהליך ניפוי בשגיאות",
+    "Reset log level" : "קביעה מחדש לרמת דיווח",
+    "Starting code integrity check" : "התחלת בדיקת תקינות קוד",
+    "Finished code integrity check" : "סיום בדיקת תקינות קוד",
+    "%s (3rdparty)" : "%s (צד שלישי)",
+    "%s (incompatible)" : "%s (לא תואם)",
+    "Following apps have been disabled: %s" : "היישומים הבאים נוטרלו: %s",
+    "Already up to date" : "כבר עדכני",
     "Sunday" : "יום ראשון",
     "Monday" : "יום שני",
     "Tuesday" : "יום שלישי",
@@ -88,6 +90,7 @@ OC.L10N.register(
     "Dec." : "דצמ׳",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">קיימות בעיות עם בדיקת תקינות קוד. למידע נוסף…</a>",
     "Settings" : "הגדרות",
+    "Problem loading page, reloading in 5 seconds" : "בעיה בטעינת העמוד, טעינה מחדש בעוד 5 שניות.",
     "Saving..." : "שמירה…",
     "Dismiss" : "שחרור",
     "seconds ago" : "שניות",
@@ -119,40 +122,65 @@ OC.L10N.register(
     "Good password" : "סיסמא טובה",
     "Strong password" : "סיסמא חזקה",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "שרת האינטרנט שלך אינו מוגדר כהלכה לאפשר סנכרון כיוון שממשק ה־WebDAV כנראה שבור.",
-    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "שרת האינטרנט שלך לא מוגדר כהלכה לפתור \"{url}\". מידע נוסף קיים <a target=\"_blank\" href=\"{docLink}\">במסמכים</a> שלנו.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "שרת האינטרנט שלך לא מוגדר כהלכה לפתור \"{url}\". מידע נוסף קיים <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">במסמכים</a> שלנו.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "לשרת זה אין חיבור אינטרנט פעיל. לפיכך חלק מהתכונות כגון עגינת אחסון חיצוני, הודעות על עדכונים או התקנת יישומי צד שלישי לא יעבדו. ייתכן ולא יעבדו גם כניסה לקבצים מבחוץ ושליחת הודעות דואר אלקטרוני. אנו ממליצים לאפשר חיבור אינטרנט לשרת זה אם ברצונך שיהיו לך את כל התכונות.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "לא הוגדר memory cache. על מנת לשפר את הביצועים יש להגדיר memcache אם קיים. מידע נוסף ניתן לצפות ב- <a target=\"_blank\" href=\"{docLink}\">מסמכי התיעוד</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandom אינו ניתן לקריאה על ידי PHP אשר אינו מומלץ בשל סיבות אבטחה. מידע נוסף ניתן לראות ב- <a target=\"_blank\" href=\"{docLink}\">מסמכי התיעוד</a>.",
-    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "גרסת ה- PHP שלך ({version}) אינה <a target=\"_blank\" href=\"{phpLink}\">נתמכת כבר על ידי PHP</a>. אנו ממליצים לשדרג את גרסת ה- PHP ולהנות מהיתרון של עדכוני האבטחה והביצועים שמספק ה- PHP.",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "תצורת כותרות פרוקסי ההפוכה אינה נכונה, או שהגישה ל- ownCloud מתבצעת מ- proxy אמין. אם הגישה ל- ownCloud אינה מ- proxy אמין, מדובר בבעיית אבטחה שמאפשרת לתוקף לזיין את כתובת ה- IP כגלויה ל- ownCloud. מידע נוסף ניתן למצוא ב- <a target=\"_blank\" href=\"{docLink}\">מסמכי התיעוד</a> שלנו.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached מוגדר כמטמון מופץ, אבל מותקן מודול PHP לא נכון \"memcache\". רק \\OC\\Memcache\\Memcached תומך ב- \"memcached\" אבל לא ב- \"memcache\". ניתן לצפות ב- <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki בנושא שני המודולים</a>.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "חלק מהקבצים לא עברו את בדיקת התקינות. מידע נוסף איך לפתור את הבעיה ניתן למצוא ב- to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">מסמכי התיעוד</a> שלנו. (<a href=\"{codeIntegrityDownloadEndpoint}\">רשימה של קבצים לא תקינים…</a> / <a href=\"{rescanEndpoint}\">סריקה מחדש…</a>)",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "לא הוגדר זיכרון מטמון. על מנת לשפר את הביצועים יש להגדיר memcache אם קיים. מידע נוסף ניתן לצפות ב- <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">מסמכי התיעוד</a>.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom אינו ניתן לקריאה על ידי PHP אשר אינו מומלץ בשל סיבות אבטחה. מידע נוסף ניתן לראות ב- <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">מסמכי התיעוד</a> שלנו.",
+    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "כרגע המערכת מריצה PHP {version}. מומלץ מאוד לשדרג את גרסת ה- PHP vשלך כדי לנצל את <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">עדכוני הביצועים והאבטחה המופקים על ידי קבוצת ה- PHP</a> ברגע שההפצה אליך תתמוך בזה.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "תצורת כותרות פרוקסי ההפוכה אינה נכונה, או שהגישה ל- ownCloud מתבצעת מ- proxy אמין. אם הגישה ל- ownCloud אינה מ- proxy אמין, מדובר בבעיית אבטחה שמאפשרת לתוקף לזייף את כתובת ה- IP כגלויה ל- ownCloud. מידע נוסף ניתן למצוא ב- <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">מסמכי התיעוד</a> שלנו.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached מוגדר כמטמון מופץ, אבל מותקן מודול PHP \"memcache\" מוטעה. רק \\OC\\Memcache\\Memcached תומך ב- \"memcached\" אבל לא ב- \"memcache\". ניתן לצפות ב- <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki בנושא שני המודולים</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "חלק מהקבצים לא עברו את בדיקת השלמות. מידע נוסף איך לפתור את הבעיה ניתן למצוא ב- to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">מסמכי התיעוד</a> שלנו. (<a href=\"{codeIntegrityDownloadEndpoint}\">רשימה של קבצים לא תקינים…</a> / <a href=\"{rescanEndpoint}\">סריקה מחדש…</a>)",
     "Error occurred while checking server setup" : "שגיאה אירעה בזמן בדיקת התקנת השרת",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "כנראה וניתן לגשת אל תיקיית data והקבצים שלך מהאינטרנט. קובץ .htaccess אינו עובד. אנו ממליצים בכל תוקף שתגדיר את השרת בצורה כזאת שלא ניתן יהיה לגשת לתיקיית ה- data או להעביר את תיקיית ה- dta מחוץ לנתיב המסמכים של שרת האינטרנט.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "כותרת ה- HTTP \"{header}\" אינה מוגדרת להיות שווה ל- \"{expected}\". הדבר מהווה פוטנציאל סיכון אבטחה או פגיעה בפרטיות ואנו ממליצים לתקן את הגדרה זו.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "כותרת HTTP \"Strict-Transport-Security\" אינה מוגדרת לפחות \"{seconds}\" שניות. להגברת האבטחה אנו ממליצים לאפשר HSTS כפי שמוסבר ב- <a href=\"{docUrl}\">טיפים לאבטחה</a> שלנו.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "כותרת HTTP \"Strict-Transport-Security\" אינה מוגדרת לפחות \"{seconds}\" שניות. להגברת האבטחה אנו ממליצים לאפשר HSTS כפי שמוסבר ב- <a href=\"{docUrl}\" rel=\"noreferrer\">טיפים לאבטחה</a> שלנו.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "הנך נכנס לאתר באמצעות פרוטוקול HTTP. אנו ממליצים מאוד להגדיר את השרת לעבוד עם פרוטוקול HTTPS במקום כפי שמוסבר ב- <a href=\"{docUrl}\">טיפים לאבטחה</a> שלנו.",
     "Shared" : "שותף",
     "Shared with {recipients}" : "שיתוף עם {recipients}",
     "Error" : "שגיאה",
     "Error while sharing" : "שגיאה במהלך השיתוף",
     "Error while unsharing" : "שגיאה במהלך ביטול השיתוף",
-    "Error setting expiration date" : "אירעה שגיאה בעת הגדרת תאריך התפוגה",
     "The public link will expire no later than {days} days after it is created" : "הקישור הציבורי יפוג עד {days} ימים לאחר שנוצר",
     "Set expiration date" : "הגדרת תאריך תפוגה",
     "Expiration" : "תפוגה",
     "Expiration date" : "תאריך התפוגה",
+    "Expiration date is required" : "נדרש תאריך תפוגה",
+    "Delete {link}" : "מחיקת {link}",
+    "Remove link" : "הסרת קישור",
+    "{fileName} link" : "קישור {fileName}",
+    "Link" : "קישור",
+    "Create public link" : "יצירת קישור ציבורי",
+    "Edit" : "עריכה",
+    "Remove" : "הסרה",
+    "Click to copy to clipboard" : "יש ללחוץ להעתקה ללוח הגזירים",
+    "Social share" : "שיתוף לרשת חברתית",
+    "There are currently no link shares, you can create one" : "אין כרגע שיתופי קישורים, ניתן ליצור קישור",
+    "Anyone with the link has access to the file/folder" : "כל מי שיש בידיו את הקישור יכול להיכנס לקובץ/תיקייה",
+    "Copied!" : "הועתק!",
+    "Not supported!" : "לא נתמך!",
+    "Press ⌘-C to copy." : "יש ללחוץ ⌘-C להעתקה.",
+    "Press Ctrl-C to copy." : "יש ללחוץ Ctrl-C להעתקה.",
     "Choose a password for the public link" : "בחירת סיסמא לקישור ציבורי",
+    "Password required" : "נדרשת סיסמא",
+    "Filename" : "שם קובץ",
+    "Password" : "סיסמא",
+    "Name" : "שם",
+    "Allow editing" : "אישור עריכה",
+    "Show file listing" : "הצגת רשומת קובץ",
+    "Edit link share: {name}" : "עריכת שיתוף קישור: {name}",
+    "Save" : "שמירה",
+    "Create link share: {name}" : "יצירת שיתוף קישור: {name}",
+    "Remove password" : "הסרת סיסמא",
+    "Share to Twitter. Opens in a new window." : "שיתוף בטוויטר. פתיחה בחלון חדש.",
+    "Share to Facebook. Opens in a new window." : "שיתוף בפייסבוק. פתיחה בחלון חדש.",
+    "Share to Diaspora. Opens in a new window." : "שיתוף ב- Diaspora. פתיחה בחלון חדש.",
+    "Share to Google+. Opens in a new window." : "שיתוף בגוגל פלוס. פתיחה בחלון חדש.",
+    "Share via email. Opens your mail client." : "שיתוף על בסיס דואר אלקטרוני. פותח את אפקליקציית הדואר האלקטרוני שלך.",
+    "Error while sending notification" : "שגיאה בזמן שליחת הודעה",
     "Sending ..." : "מתבצעת שליחה ...",
     "Email sent" : "הודעת הדוא״ל נשלחה",
-    "Resharing is not allowed" : "אסור לעשות שיתוף מחדש",
-    "Share link" : "קישור לשיתוף",
-    "Link" : "קישור",
-    "Password protect" : "הגנה בססמה",
-    "Password" : "סיסמא",
-    "Allow editing" : "אישור עריכה",
     "Email link to person" : "שליחת קישור בדוא״ל למשתמש",
-    "Send" : "שליחה",
+    "Send link via email" : "שליחת קישור באמצעות דואר אלקטרוני",
     "Shared with you and the group {group} by {owner}" : "שותף אתך ועם הקבוצה {group} שבבעלות {owner}",
     "Shared with you by {owner}" : "שותף אתך על ידי {owner}",
     "group" : "קבוצה",
@@ -168,19 +196,24 @@ OC.L10N.register(
     "Could not unshare" : "לא ניתן לבטל שיתוף",
     "Share details could not be loaded for this item." : "לא ניתן היה לטעון מידע שיתוף לפריט זה",
     "No users or groups found for {search}" : "לא אותרו משתמשים או קבוצות עבור {search}",
-    "An error occured. Please try again" : "אירעה שגיאה. יש לנסות בבקשה שוב",
+    "No users found for {search}" : "לא אותרו משתמשים עבור {search}",
+    "An error occurred. Please try again" : "אירעה שגיאה. יש לנסות שנית",
     "{sharee} (group)" : "{sharee} (קבוצה)",
     "{sharee} (at {server})" : "{sharee} (ב- {server})",
     "{sharee} (remote)" : "{sharee} (מרוחק)",
     "Share" : "שתף",
+    "User and Groups" : "משתמש וקבוצות",
+    "Public Links" : "קישורים ציבוריים",
+    "Resharing is not allowed" : "אסור לעשות שיתוף מחדש",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "ניתן לשתף עם אנשים אחרים המשתמשים ב- ownClouds בעזרת הפורמט הבא username@example.com/owncloud",
-    "Share with users or groups …" : "שיתוף עם משתמשים או קבוצות...",
-    "Share with users, groups or remote users …" : "שיתוף עם משתמשים, קבוצות או משתמשים חצוניים...",
+    "Share with users…" : "שיתוף עם משתמשים...",
+    "Share with users, groups or remote users…" : "שיתוף עם משתמשים, קבוצות או משתמשים מרוחקים...",
+    "Share with users or groups…" : "שיתוף עם משתמשים או קבוצות...",
+    "Share with users or remote users…" : "שיתוף עם משתמשים או משתמשים מרוחקים...",
     "Error removing share" : "שגיאה בזמן הסרת שיתוף",
     "Warning" : "אזהרה",
-    "Error while sending notification" : "שגיאה בזמן שליחת הודעה",
     "Non-existing tag #{tag}" : "תגית לא קיימת #{tag}",
-    "not assignable" : "לא ניתן להקצאה",
+    "restricted" : "מוגבל",
     "invisible" : "בלתי גלוי",
     "({scope})" : "({scope})",
     "Delete" : "מחיקה",
@@ -197,13 +230,14 @@ OC.L10N.register(
     "sunny" : "שמשי",
     "Hello {name}, the weather is {weather}" : "שלום {name}, מזג האוויר הנו {weather}",
     "Hello {name}" : "שלום {name}",
+    "new" : "חדש",
     "_download %n file_::_download %n files_" : ["הורד %n קובץ","הורדו %n קבצים"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "מתבצע עכשיו שדרוג, מעבר מדף זה עלול לפגוע בתהליך בסביבות הפעלה מסויימות.",
-    "Updating {productName} to version {version}, this may take a while." : "מעדכן {productName} לגרסה {version}, זה יקח זמן מה.",
+    "Updating to {version}" : "מעדכן ל- {version}",
     "An error occurred." : "אירעה שגיאה.",
     "Please reload the page." : "יש להעלות מחדש דף זה.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "העדכון בוצע בהצלחה. למידע נוסף <a href=\"{url}\">ניתן לבדוק בהודעת הפורום שלנו</a> המכסה נושא זו.",
-    "The update was unsuccessful. " : "העדכון בוצע בהצלחה.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "תהליך העדכון לא הושלם בהצלחה. נא דווח את הבעיה ב<a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">קהילת ownCloud</a>.",
     "The update was successful. There were warnings." : "העדכון בוצע בהצלחה. היו הזהרות.",
     "The update was successful. Redirecting you to ownCloud now." : "תהליך העדכון הסתיים בהצלחה. עכשיו מנתב אותך אל ownCloud.",
     "Searching other places" : "מחפש במקומות אחרים",
@@ -212,15 +246,8 @@ OC.L10N.register(
     "Personal" : "אישי",
     "Users" : "משתמשים",
     "Apps" : "יישומים",
-    "Admin" : "מנהל",
+    "Admin" : "ניהול",
     "Help" : "עזרה",
-    "Error loading tags" : "שגיאה בטעינת תגיות",
-    "Tag already exists" : "תגית כבר קיימת",
-    "Error deleting tag(s)" : "שגיאה במחיקת תגית(יות)",
-    "Error tagging" : "שגיאה בביצוע תגיות",
-    "Error untagging" : "שגיאה בהסרת תגיות",
-    "Error favoriting" : "שגיאה בקביעת מועדפים",
-    "Error unfavoriting" : "שגיאה בהסרת מועדפים",
     "Access forbidden" : "הגישה נחסמה",
     "File not found" : "קובץ לא נמצא",
     "The specified document has not been found on the server." : "המסמך המבוקש לא נמצא על השרת.",
@@ -241,9 +268,6 @@ OC.L10N.register(
     "File: %s" : "קובץ: %s",
     "Line: %s" : "שורה: %s",
     "Trace" : "עקבות",
-    "Security warning" : "אזהרת אבטחה",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "תיקיית וקבצי המידע שלך כנראה נגישים מהאינטרנט מכיוון שקובץ ה.htaccess לא עובד.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "למידע איך להגדיר את השרת שלך, ניתן לראות ב- <a href=\"%s\" target=\"_blank\">מסמכי התיעוד</a>.",
     "Create an <strong>admin account</strong>" : "יצירת <strong>חשבון מנהל</strong>",
     "Username" : "שם משתמש",
     "Storage & database" : "אחסון ומסד נתונים",
@@ -257,6 +281,7 @@ OC.L10N.register(
     "Database name" : "שם מסד הנתונים",
     "Database tablespace" : "מרחב הכתובות של מסד הנתונים",
     "Database host" : "שרת בסיס נתונים",
+    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "יש לפרט את מספר הפורט יחד עם שם המארח (לדוגמא, localhost: 5432).",
     "Performance warning" : "אזהרת ביצועים",
     "SQLite will be used as database." : "יעשה שימוש ב- SQLite כמסד נתונים.",
     "For larger installations we recommend to choose a different database backend." : "להתקנות נרחבות אנו ממליצים לבחור מסד נתונים אחר לצד השרת.",
@@ -271,14 +296,16 @@ OC.L10N.register(
     "Search" : "חיפוש",
     "Server side authentication failed!" : "אימות לצד שרת נכשל!",
     "Please contact your administrator." : "יש ליצור קשר עם המנהל.",
-    "An internal error occured." : "שגיאה פנימית אירעה.",
+    "An internal error occurred." : "אירעה שגיאה פנימית.",
     "Please try again or contact your administrator." : "יש לנסות שוב ליצור קשר עם המנהל שלך.",
+    "Username or email" : "שם משתמש או דואר אלקטרוני",
     "Log in" : "כניסה",
     "Wrong password. Reset it?" : "סיסמא שגוייה. האם לאפס אותה?",
     "Wrong password." : "סיסמא שגוייה.",
     "Stay logged in" : "השאר מחובר",
     "Alternative Logins" : "כניסות אלטרנטיביות",
     "Use the following link to reset your password: {link}" : "יש להשתמש בקישור הבא כדי לאפס את הססמה שלך: {link}",
+    "Password changed successfully" : "הסיסמא שונתה בהצלחה",
     "New password" : "ססמה חדשה",
     "New Password" : "סיסמא חדשה",
     "Reset password" : "איפוס ססמה",
@@ -286,6 +313,11 @@ OC.L10N.register(
     "This means only administrators can use the instance." : "לפיכך רק מנהלים יכולים להשתמש בהפעלה זו.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "יש ליצור קשר עם מנהל המערכת אם הודעה שו נמשכת או מופיעה באופן בלתי צפוי. ",
     "Thank you for your patience." : "תודה על הסבלנות.",
+    "Two-step verification" : "אימות דו-שלבי",
+    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "אבטחה מורחבת הופעלה בחשבון שלך. יש לאמת באמצעות גורם שני.",
+    "Cancel login" : "ביטול התחברות",
+    "Please authenticate using the selected factor." : "יש לאמת באמצעות גורם נבחר.",
+    "An error occurred while verifying the token" : "שגיאה אירעה בזמן אימות המחרוזת",
     "You are accessing the server from an untrusted domain." : "נכנסת לשרת משם מתחם / דומיין שאינו מהימן.",
     "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "יש ליצור קשר עם המנהל שלך. אם הנך המנהל של הפעלה זו, יש להגדיר את הגדרות ה- \"trusted_domains\" של config/config.php. דוגמת תצורה ניתן לראות ב- config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "בהתאם לתצורה שלך, כמנהל יתכן ותוכל להשתמש בכפתור מטה להפיכת שם המתחם / דומיין למהימן.",
@@ -293,14 +325,15 @@ OC.L10N.register(
     "App update required" : "נדרש עדכון יישום",
     "%s will be updated to version %s" : "%s יעודכן לגרסה %s",
     "These apps will be updated:" : "יישומים אלו יעודכנו:",
-    "These incompatible apps will be disabled:" : "יישומים לא תואמים ינוטרלו:",
     "The theme %s has been disabled." : "ערכת הנושא %s נוטרלה.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "יש לוודא שמסד הנתונים, תיקיית config ותיקיית data גובו לפני ההמשך.",
     "Start update" : "התחלת עדכון",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "למניעת פסקי זמן בהתקנות גדולות, ניתן במקום להריץ את הפקודה הבאה בתיקיית ההתקנה שלך:",
+    "Detailed logs" : "לוג פרטים",
+    "Update needed" : "עדכון נדרש",
+    "Please use the command line updater because you have a big instance." : "יש להשתמש בעדכון על בסיס שורת פקודה כיוון שמדובר בעדכון גדול.",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "לעזרה, ניתן לצפות ב<a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">מסמכי התיעוד</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "הפעלה %s זו כרגע במצב אחזקה, שתמשך זמן מה.",
-    "This page will refresh itself when the %s instance is available again." : "עמוד זה ירענן את עצמו כשהפעלת %s תהיה זמינה שוב.",
-    "Error loading file picker template: {error}" : "שגיאה בטעינת תבנית בחירת הקבצים: {error}",
-    "Password can not be changed. Please contact your administrator." : "לא ניתן לשנות את הסיסמא. יש לפנות למנהל שלך."
+    "This page will refresh itself when the %s instance is available again." : "עמוד זה ירענן את עצמו כשהפעלת %s תהיה זמינה שוב."
 },
 "nplurals=2; plural=(n != 1);");
