@@ -25,7 +25,7 @@ OC.L10N.register(
     "Cancel" : "रद्द करें ",
     "Error" : "त्रुटि",
     "Password" : "पासवर्ड",
-    "Send" : "भेजें",
+    "Save" : "सहेजें",
     "Sending ..." : "भेजा जा रहा है",
     "Email sent" : "ईमेल भेज दिया गया है ",
     "Share" : "साझा करें",
