@@ -1,25 +1,39 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Tidak dapat mengirim Email ke pengguna berikut: %s",
-    "Turned on maintenance mode" : "Hidupkan mode perawatan",
-    "Turned off maintenance mode" : "Matikan mode perawatan",
-    "Updated database" : "Basis data terbaru",
-    "Checked database schema update" : "Pembaruan skema basis data terperiksa",
-    "Checked database schema update for apps" : "Pembaruan skema basis data terperiksa untuk aplikasi",
-    "Updated \"%s\" to %s" : "Terbaru \"%s\" sampai %s",
-    "Repair warning: " : "Peringatan perbaikan:",
-    "Repair error: " : "Kesalahan perbaikan:",
-    "Following incompatible apps have been disabled: %s" : "Aplikasi tidak kompatibel berikut telah dinonaktifkan: %s",
-    "Following 3rd party apps have been disabled: %s" : "Aplikasi pihak ke-3 berikut telah dinonaktifkan: %s",
+    "File is too big" : "Berkas terlalu besar",
     "Invalid file provided" : "Berkas yang diberikan tidak sah",
     "No image or file provided" : "Tidak ada gambar atau berkas yang disediakan",
     "Unknown filetype" : "Tipe berkas tidak dikenal",
     "Invalid image" : "Gambar tidak sah",
+    "An error occurred. Please contact your admin." : "Terjadi kesalahan. Silakan hubungi admin Anda.",
     "No temporary profile picture available, try again" : "Tidak ada gambar profil sementara yang tersedia, coba lagi",
     "No crop data provided" : "Tidak ada data krop tersedia",
     "No valid crop data provided" : "Tidak ada data valid untuk dipangkas",
     "Crop is not square" : "Pangkas ini tidak persegi",
+    "Couldn't reset password because the token is invalid" : "Tidak dapat menyetel ulang sandi karena token tidak sah",
+    "Couldn't reset password because the token is expired" : "Tidak dapat menyetel ulang sandi karena token telah kadaluarsa",
+    "%s password reset" : "%s sandi disetel ulang",
+    "Couldn't send reset email. Please contact your administrator." : "Tidak dapat mengirim email setel ulang. Silakan hubungi administrator Anda.",
+    "Couldn't send mail to following users: %s " : "Tidak dapat mengirim Email ke pengguna berikut: %s",
+    "Preparing update" : "Mempersiapkan pembaruan",
+    "Repair warning: " : "Peringatan perbaikan:",
+    "Repair error: " : "Kesalahan perbaikan:",
+    "Turned on maintenance mode" : "Hidupkan mode perawatan",
+    "Turned off maintenance mode" : "Matikan mode perawatan",
+    "Maintenance mode is kept active" : "Mode Pemeliharaan masih aktif",
+    "Updating database schema" : "Memperbarui skema basis data",
+    "Updated database" : "Basis data terbaru",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Memeriksa apakah skema basis data dapat diperbarui (dapat memerlukan waktu yang lama tergantung pada ukuran basis data)",
+    "Checked database schema update" : "Pembaruan skema basis data terperiksa",
+    "Checking updates of apps" : "Memeriksa pembaruan aplikasi",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Memeriksa apakah skema untuk %s dapat diperbarui (dapat memerlukan waktu yang lama tergantung pada ukuran basis data)",
+    "Checked database schema update for apps" : "Pembaruan skema basis data terperiksa untuk aplikasi",
+    "Updated \"%s\" to %s" : "Terbaru \"%s\" sampai %s",
+    "%s (3rdparty)" : "%s (pihak ke-3)",
+    "%s (incompatible)" : "%s (tidak kompatibel)",
+    "Following apps have been disabled: %s" : "Aplikasi berikut telah dinonaktifkan: %s",
+    "Already up to date" : "Sudah yang terbaru",
     "Sunday" : "Minggu",
     "Monday" : "Senin",
     "Tuesday" : "Selasa",
@@ -27,6 +41,20 @@ OC.L10N.register(
     "Thursday" : "Kamis",
     "Friday" : "Jumat",
     "Saturday" : "Sabtu",
+    "Sun." : "Min.",
+    "Mon." : "Sen.",
+    "Tue." : "Sel.",
+    "Wed." : "Rab.",
+    "Thu." : "Kam.",
+    "Fri." : "Jum.",
+    "Sat." : "Sab.",
+    "Su" : "Min",
+    "Mo" : "Sen",
+    "Tu" : "Sel",
+    "We" : "Rab",
+    "Th" : "Kam",
+    "Fr" : "Jum",
+    "Sa" : "Sab",
     "January" : "Januari",
     "February" : "Februari",
     "March" : "Maret",
@@ -39,9 +67,22 @@ OC.L10N.register(
     "October" : "Oktober",
     "November" : "November",
     "December" : "Desember",
+    "Jan." : "Jan.",
+    "Feb." : "Feb.",
+    "Mar." : "Mar.",
+    "Apr." : "Apr.",
+    "May." : "Mei",
+    "Jun." : "Jun.",
+    "Jul." : "Jul.",
+    "Aug." : "Agu.",
+    "Sep." : "Sep.",
+    "Oct." : "Okt.",
+    "Nov." : "Nov.",
+    "Dec." : "Des.",
     "Settings" : "Pengaturan",
     "Saving..." : "Menyimpan...",
-    "Couldn't send reset email. Please contact your administrator." : "Tidak dapat mengirim email setel ulang. Silakan hubungi administrator Anda.",
+    "Dismiss" : "Buang",
+    "seconds ago" : "beberapa detik yang lalu",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Sebuah tautan untuk setel ulang sandi Anda telah dikirim ke email Anda. Jika Anda tidak menerima dalam jangka waktu yang wajar, periksa folder spam/sampah Anda.<br>Jika tidak ada, tanyakan pada administrator Anda.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Berkas-berkas Anda terenkripsi. Jika Anda tidak mengaktifkan kunci pemulihan, tidak ada cara lain untuk mendapatkan data Anda kembali setelah sandi di setel ulang.<br />Jika Anda tidak yakin dengan apa yang akan Anda dilakukan, mohon hubungi administrator Anda sebelum melanjutkan. <br />Apakah Anda yakin ingin melanjutkan?",
     "I know what I'm doing" : "Saya tahu apa yang saya lakukan",
@@ -71,57 +112,53 @@ OC.L10N.register(
     "Strong password" : "Sandi kuat",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Server web Anda belum diatur dengan benar untuk mengizinkan sinkronisasi berkas karena antarmuka WebDAV nampaknya rusak.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Server ini tidak tersambung ke internet. Ini berarti beberapa fitur seperti me-mount penyimpanan eksternal, notifikasi pembaruan atau instalasi aplikasi pihak ketiga tidak akan bekerja. Mengakses berkas secara remote dan mengirim notifikasi email juga tidak bekerja. Kami menyarankan untuk mengaktifkan koneksi internet untuk server ini jika Anda ingin memiliki fitur ini.",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Direktori data dan berkas Anda kemungkinan dapat diakses dari Internet. Berkas .htaccess tidak bekerja. Kami sangat menyarankan Anda untuk mengkonfigurasi server web agar direktori data tidak lagi dapat diakses atau pindahkan direktori data Anda di luar root dokumen server web.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Tembolok memori tidak dikonfigurasi. Untuk meningkatkan kinerja, mohon konfigurasi memcache jika tersedia. Informasi lebih lanjut dapat ditemukan di <a href=\"{docLink}\">dokumentasi</a> kami.",
     "Error occurred while checking server setup" : "Kesalahan tidak terduga saat memeriksa setelan server",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Direktori data dan berkas Anda kemungkinan dapat diakses dari Internet. Berkas .htaccess tidak bekerja. Kami sangat menyarankan Anda untuk mengkonfigurasi server web agar direktori data tidak lagi dapat diakses atau pindahkan direktori data Anda di luar root dokumen server web.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "Header HTTP \"{header}\" tidak dikonfigurasi sama dengan \"{expected}\". Hal ini berpotensi pada resiko keamanan dan privasi. Kami sarankan untuk menyesuaikan pengaturan ini.",
+    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Anda mengakses situs ini via HTTP. Kami sangat menyarankan Anda untuk mengatur server Anda menggunakan HTTPS yang dibahas di <a href=\"{docUrl}\">tips keamanan</a> kami.",
     "Shared" : "Dibagikan",
     "Shared with {recipients}" : "Dibagikan dengan {recipients}",
-    "Share" : "Bagikan",
     "Error" : "Kesalahan",
     "Error while sharing" : "Kesalahan saat membagikan",
     "Error while unsharing" : "Kesalahan saat membatalkan pembagian",
-    "Error while changing permissions" : "Kesalahan saat mengubah izin",
-    "Shared with you and the group {group} by {owner}" : "Dibagikan dengan anda dan grup {group} oleh {owner}",
-    "Shared with you by {owner}" : "Dibagikan dengan anda oleh {owner}",
-    "Share with users or groups …" : "Bagikan dengan pengguna atau grup ...",
-    "Share with users, groups or remote users …" : "Bagikan dengan pengguna, grup atau pengguna remote ...",
-    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Bagikan dengan orang lain di ownCloud menggunakan sintaks username@example.com/owncloud",
-    "Share link" : "Bagikan tautan",
     "The public link will expire no later than {days} days after it is created" : "Tautan publik akan kadaluarsa tidak lebih dari {days} hari setelah ini dibuat",
-    "Link" : "Tautan",
-    "Password protect" : "Lindungi dengan sandi",
-    "Password" : "Sandi",
-    "Choose a password for the public link" : "Tetapkan sandi untuk tautan publik",
-    "Allow editing" : "Izinkan penyuntingan",
-    "Email link to person" : "Emailkan tautan ini ke orang",
-    "Send" : "Kirim",
     "Set expiration date" : "Atur tanggal kedaluwarsa",
     "Expiration" : "Kedaluwarsa",
     "Expiration date" : "Tanggal kedaluwarsa",
-    "An error occured. Please try again" : "Terjadi masalah. Mohon coba kembali",
-    "Adding user..." : "Menambahkan pengguna...",
+    "Link" : "Tautan",
+    "Edit" : "Sunting",
+    "Remove" : "Hapus",
+    "Choose a password for the public link" : "Tetapkan sandi untuk tautan publik",
+    "Filename" : "Nama berkas",
+    "Password" : "Sandi",
+    "Name" : "Nama",
+    "Allow editing" : "Izinkan penyuntingan",
+    "Save" : "Simpan",
+    "Error while sending notification" : "Kesalahan ketika mengirim notifikasi",
+    "Sending ..." : "Mengirim ...",
+    "Email sent" : "Email terkirim",
+    "Email link to person" : "Emailkan tautan ini ke orang",
+    "Shared with you and the group {group} by {owner}" : "Dibagikan dengan anda dan grup {group} oleh {owner}",
+    "Shared with you by {owner}" : "Dibagikan dengan anda oleh {owner}",
     "group" : "grup",
     "remote" : "remote",
-    "Resharing is not allowed" : "Berbagi ulang tidak diizinkan",
-    "Shared in {item} with {user}" : "Dibagikan dalam {item} dengan {user}",
-    "Unshare" : "Batalkan berbagi",
     "notify by email" : "notifikasi via email",
+    "Unshare" : "Batalkan berbagi",
     "can share" : "dapat berbagi",
     "can edit" : "dapat sunting",
-    "access control" : "kontrol akses",
     "create" : "buat",
     "change" : "ubah",
     "delete" : "hapus",
-    "Password protected" : "Sandi dilindungi",
-    "Error unsetting expiration date" : "Kesalahan saat menghapus tanggal kedaluwarsa",
-    "Error setting expiration date" : "Kesalahan saat mengatur tanggal kedaluwarsa",
-    "Sending ..." : "Mengirim ...",
-    "Email sent" : "Email terkirim",
+    "access control" : "kontrol akses",
+    "Share details could not be loaded for this item." : "Rincian berbagi tidak dapat dimuat untuk item ini.",
+    "Share" : "Bagikan",
+    "Resharing is not allowed" : "Berbagi ulang tidak diizinkan",
+    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Bagikan dengan orang lain di ownCloud menggunakan sintaks username@example.com/owncloud",
     "Warning" : "Peringatan",
+    "Delete" : "Hapus",
+    "Rename" : "Ubah nama",
     "The object type is not specified." : "Tipe objek tidak ditentukan.",
     "Enter new" : "Masukkan baru",
-    "Delete" : "Hapus",
     "Add" : "Tambah",
     "Edit tags" : "Sunting label",
     "Error loading dialog template: {error}" : "Kesalahan saat memuat templat dialog: {error}",
@@ -132,32 +169,20 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Helo {name}, jepang {weather}",
     "Hello {name}" : "Helo {name}",
     "_download %n file_::_download %n files_" : ["unduh %n berkas"],
-    "Updating {productName} to version {version}, this may take a while." : "Memperbarui {productName} ke versi {version}, ini memerlukan waktu.",
+    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Pembaruan sedang dalam proses, meninggalkan halaman ini mungkin dapat mengganggu proses di beberapa lingkungan.",
+    "An error occurred." : "Terjadi kesalahan.",
     "Please reload the page." : "Silakan muat ulang halaman.",
-    "The update was unsuccessful. " : "Pembaruan tidak berhasil.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Pembaruan gagal. Silakan laporkan masalah ini ke <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">komunitas ownCloud</a>.",
+    "The update was successful. There were warnings." : "Pembaruan telah berhasil. Terdapat peringatan.",
     "The update was successful. Redirecting you to ownCloud now." : "Pembaruan sukses. Anda akan diarahkan ulang ke ownCloud.",
-    "Couldn't reset password because the token is invalid" : "Tidak dapat menyetel ulang sandi karena token tidak sah",
-    "Couldn't send reset email. Please make sure your username is correct." : "Tidak dapat menyetel ulang email. Mohon pastikan nama pengguna Anda benar.",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Tidak dapat menyetel ulang email karena tidak ada alamat email untuk nama pengguna ini. Silakan hubungi Administrator Anda.",
-    "%s password reset" : "%s sandi disetel ulang",
-    "Use the following link to reset your password: {link}" : "Gunakan tautan berikut untuk menyetel ulang sandi Anda: {link}",
-    "New password" : "Sandi baru",
-    "New Password" : "Sandi Baru",
-    "Reset password" : "Setel ulang sandi",
     "Searching other places" : "Mencari tempat lainnya",
-    "_{count} search result in other places_::_{count} search results in other places_" : ["{count} hasil pencarian di tempat lain"],
+    "No search results in other folders" : "Tidak ada hasil penelusuran didalam folder yang lain",
+    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} hasil pencarian di folder lain"],
     "Personal" : "Pribadi",
     "Users" : "Pengguna",
     "Apps" : "Aplikasi",
     "Admin" : "Admin",
     "Help" : "Bantuan",
-    "Error loading tags" : "Kesalahan saat saat memuat tag",
-    "Tag already exists" : "Tag sudah ada",
-    "Error deleting tag(s)" : "Kesalahan saat menghapus tag",
-    "Error tagging" : "Kesalahan saat memberikan tag",
-    "Error untagging" : "Kesalahan saat menghapus tag",
-    "Error favoriting" : "Kesalahan saat memberikan sebagai favorit",
-    "Error unfavoriting" : "Kesalahan saat menghapus sebagai favorit",
     "Access forbidden" : "Akses ditolak",
     "File not found" : "Berkas tidak ditemukan",
     "The specified document has not been found on the server." : "Dokumen yang diminta tidak tersedia pada server.",
@@ -178,15 +203,14 @@ OC.L10N.register(
     "File: %s" : "Berkas: %s",
     "Line: %s" : "Baris: %s",
     "Trace" : "Jejak",
-    "Security warning" : "Peringatan keamanan",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Kemungkinan direktori data dan berkas anda dapat diakses dari internet karena berkas .htaccess tidak berfungsi.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Untuk informasi cara mengkonfigurasi server anda dengan benar, silakan lihat <a href=\"%s\" target=\"_blank\">dokumentasi</a>.",
     "Create an <strong>admin account</strong>" : "Buat sebuah <strong>akun admin</strong>",
     "Username" : "Nama pengguna",
     "Storage & database" : "Penyimpanan & Basis data",
     "Data folder" : "Folder data",
     "Configure the database" : "Konfigurasikan basis data",
     "Only %s is available." : "Hanya %s yang tersedia",
+    "Install and activate additional PHP modules to choose other database types." : "Pasang dan aktifkan modul PHP tambahan untuk memilih tipe basis data lainnya.",
+    "For more details check out the documentation." : "Untuk lebih rinci, periksa pada dokumentasi.",
     "Database user" : "Pengguna basis data",
     "Database password" : "Sandi basis data",
     "Database name" : "Nama basis data",
@@ -200,28 +224,31 @@ OC.L10N.register(
     "Finishing …" : "Menyelesaikan ...",
     "Need help?" : "Butuh bantuan?",
     "See the documentation" : "Lihat dokumentasi",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hai,<br><br>hanya memberi tahu jika %s membagikan <strong>%s</strong> dengan Anda.<br><a href=\"%s\">Lihat!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aplikasi ini memerlukan JavaScript untuk dapat beroperasi dengan benar. Mohon {linkstart}aktifkan JavaScript{linkend} dan muat ulang halaman ini.",
     "Log out" : "Keluar",
     "Search" : "Cari",
     "Server side authentication failed!" : "Otentikasi dari sisi server gagal!",
     "Please contact your administrator." : "Silahkan hubungi administrator anda.",
-    "An internal error occured." : "Terjadi kesalahan internal.",
     "Please try again or contact your administrator." : "Mohon coba lagi atau hubungi administrator Anda.",
-    "Forgot your password? Reset it!" : "Lupa sandi Anda? Setel ulang!",
-    "remember" : "selalu masuk",
     "Log in" : "Masuk",
+    "Wrong password. Reset it?" : "Sandi salah. Atur ulang?",
+    "Stay logged in" : "Tetap masuk",
     "Alternative Logins" : "Cara Alternatif untuk Masuk",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hai,<br><br>hanya memberi tahu jika %s membagikan <strong>%s</strong> dengan Anda.<br><a href=\"%s\">Lihat!</a><br><br>",
+    "Use the following link to reset your password: {link}" : "Gunakan tautan berikut untuk menyetel ulang sandi Anda: {link}",
+    "New password" : "Sandi baru",
+    "New Password" : "Sandi Baru",
+    "Reset password" : "Setel ulang sandi",
     "This ownCloud instance is currently in single user mode." : "ownCloud ini sedang dalam mode pengguna tunggal.",
     "This means only administrators can use the instance." : "Ini berarti hanya administrator yang dapat menggunakan ownCloud.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Hubungi administrator sistem anda jika pesan ini terus muncul atau muncul tiba-tiba.",
     "Thank you for your patience." : "Terima kasih atas kesabaran anda.",
     "You are accessing the server from an untrusted domain." : "Anda mengakses server dari domain yang tidak terpercaya.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Mohon hubungi administrator Anda. Jika Anda seorang administrator dari instansi ini, konfigurasikan pengaturan \"trusted_domain\" didalam config/config.php. Contoh konfigurasi talah disediakan didalam config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Tergantung pada konfigurasi Anda, sebagai seorang administrator Anda kemungkinan dapat menggunakan tombol bawah untuk mempercayai domain ini.",
     "Add \"%s\" as trusted domain" : "tambahkan \"%s\" sebagai domain terpercaya",
-    "%s will be updated to version %s." : "%s akan diperbarui ke versi %s.",
-    "The following apps will be disabled:" : "Aplikasi berikut akan dinonaktifkan:",
+    "App update required" : "Diperlukan perbarui aplikasi",
+    "%s will be updated to version %s" : "%s akan diperbaarui ke versi %s",
+    "These apps will be updated:" : "Aplikasi berikut akan diperbarui:",
     "The theme %s has been disabled." : "Tema %s telah dinonaktfkan.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Pastikan bahwa basis data, folder konfig, dan folder data telah dicadangkan sebelum melanjutkan.",
     "Start update" : "Jalankan pembaruan",
