@@ -1,29 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Impossibile inviare email ai seguenti utenti: %s",
-    "Preparing update" : "Preparazione aggiornamento",
-    "Turned on maintenance mode" : "Modalità di manutenzione attivata",
-    "Turned off maintenance mode" : "Modalità di manutenzione disattivata",
-    "Maintenance mode is kept active" : "La modalità di manutenzione è lasciata attiva",
-    "Updating database schema" : "Aggiornamento schema database",
-    "Updated database" : "Database aggiornato",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Controllo che lo schema del database possa essere aggiornato (ciò potrebbe richiedere molto tempo in base alla dimensione del database)",
-    "Checked database schema update" : "Verificato l'aggiornamento dello schema del database",
-    "Checking updates of apps" : "Controllo degli aggiornamenti delle applicazioni",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Controllo che lo schema del database di %s possa essere aggiornato (ciò potrebbe richiedere molto tempo in base alla dimensione del database)",
-    "Checked database schema update for apps" : "Verificato l'aggiornamento dello schema del database per le applicazioni",
-    "Updated \"%s\" to %s" : "Aggiornato \"%s\" a %s",
-    "Repair warning: " : "Avviso di riparazione",
-    "Repair error: " : "Errore di riparazione:",
-    "Set log level to debug" : "Imposta il livello del log a debug",
-    "Reset log level" : "Ripristina il livello del log",
-    "Starting code integrity check" : "Avvio del controllo di integrità del codice",
-    "Finished code integrity check" : "Controllo di integrità del codice terminato",
-    "%s (3rdparty)" : "%s (Terze parti)",
-    "%s (incompatible)" : "%s (incompatibile)",
-    "Following apps have been disabled: %s" : "Le seguenti applicazioni sono state disabilitate: %s",
-    "Already up to date" : "Già aggiornato",
     "Please select a file." : "Seleziona un file.",
     "File is too big" : "Il file è troppo grande",
     "Invalid file provided" : "File non valido fornito",
@@ -37,10 +14,35 @@ OC.L10N.register(
     "Crop is not square" : "Il ritaglio non è quadrato",
     "Couldn't reset password because the token is invalid" : "Impossibile reimpostare la password poiché il token non è valido",
     "Couldn't reset password because the token is expired" : "Impossibile reimpostare la password poiché il token è scaduto",
-    "Couldn't send reset email. Please make sure your username is correct." : "Impossibile inviare l'email di reimpostazione. Assicurati che il nome utente sia corretto.",
-    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Impossibile inviare l'email di reimpostazione poiché non è presente un indirizzo email per questo nome utente. Contatta il tuo amministratore.",
+    "%s password changed successfully" : "Password di %s modificata correttamente",
     "%s password reset" : "Ripristino password di %s",
     "Couldn't send reset email. Please contact your administrator." : "Impossibile inviare l'email di reimpostazione. Contatta il tuo amministratore.",
+    "Couldn't send mail to following users: %s " : "Impossibile inviare email ai seguenti utenti: %s",
+    "Preparing update" : "Preparazione aggiornamento",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "Avviso di riparazione",
+    "Repair error: " : "Errore di riparazione:",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Utilizza lo strumento da riga di comando poiché l'aggiornamento automatico è disabilitato nel file config.php.",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: controllo della tabella %s",
+    "Turned on maintenance mode" : "Modalità di manutenzione attivata",
+    "Turned off maintenance mode" : "Modalità di manutenzione disattivata",
+    "Maintenance mode is kept active" : "La modalità di manutenzione è lasciata attiva",
+    "Updating database schema" : "Aggiornamento schema database",
+    "Updated database" : "Database aggiornato",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Controllo che lo schema del database possa essere aggiornato (ciò potrebbe richiedere molto tempo in base alla dimensione del database)",
+    "Checked database schema update" : "Verificato l'aggiornamento dello schema del database",
+    "Checking updates of apps" : "Controllo degli aggiornamenti delle applicazioni",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Controllo che lo schema del database di %s possa essere aggiornato (ciò potrebbe richiedere molto tempo in base alla dimensione del database)",
+    "Checked database schema update for apps" : "Verificato l'aggiornamento dello schema del database per le applicazioni",
+    "Updated \"%s\" to %s" : "Aggiornato \"%s\" a %s",
+    "Set log level to debug" : "Imposta il livello del log a debug",
+    "Reset log level" : "Ripristina il livello del log",
+    "Starting code integrity check" : "Avvio del controllo di integrità del codice",
+    "Finished code integrity check" : "Controllo di integrità del codice terminato",
+    "%s (3rdparty)" : "%s (Terze parti)",
+    "%s (incompatible)" : "%s (incompatibile)",
+    "Following apps have been disabled: %s" : "Le seguenti applicazioni sono state disabilitate: %s",
+    "Already up to date" : "Già aggiornato",
     "Sunday" : "Domenica",
     "Monday" : "Lunedì",
     "Tuesday" : "Martedì",
@@ -88,6 +90,7 @@ OC.L10N.register(
     "Dec." : "Dic.",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Si sono verificati errori con il controllo di integrità del codice. Ulteriori informazioni…</a>",
     "Settings" : "Impostazioni",
+    "Problem loading page, reloading in 5 seconds" : "Problema durante il caricamento della pagina, aggiornamento tra 5 secondi",
     "Saving..." : "Salvataggio in corso...",
     "Dismiss" : "Annulla",
     "seconds ago" : "secondi fa",
@@ -119,40 +122,63 @@ OC.L10N.register(
     "Good password" : "Password buona",
     "Strong password" : "Password forte",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Il tuo server web non è configurato correttamente per consentire la sincronizzazione dei file poiché l'interfaccia WebDAV sembra essere danneggiata.",
-    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Il tuo server web non è configurato correttamente per risolvere \"{url}\". Ulteriori informazioni sono disponibili nella nostra <a target=\"_blank\" href=\"{docLink}\">documentazione</a>.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Il tuo server web non è configurato correttamente per risolvere \"{url}\". Ulteriori informazioni sono disponibili nella nostra <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentazione</a>.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Questo server non ha una connessione a Internet funzionante. Ciò significa che alcune delle funzionalità come il montaggio di archivi esterni, le notifiche degli aggiornamenti o l'installazione di applicazioni di terze parti non funzioneranno. L'accesso remoto ai file e l'invio di email di notifica potrebbero non funzionare. Ti suggeriamo di abilitare la connessione a Internet del server se desideri disporre di tutte le funzionalità.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Non è stata configurata alcuna cache di memoria. Per migliorare le prestazioni, configura memcache, se disponibile. Ulteriori informazioni sono disponibili nella nostra <a target=\"_blank\" href=\"{docLink}\">documentazione</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandom non è leggibile da PHP e ciò è vivamente sconsigliato per motivi di sicurezza. Ulteriori informazioni sono disponibili nella nostra <a target=\"_blank\" href=\"{docLink}\">documentazione</a>.",
-    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "La tua versione ({version}) di PHP non è più <a target=\"_blank\" href=\"{phpLink}\">supportata da PHP</a>. Ti consigliamo di aggiornare la versione di PHP per trarre vantaggio dagli aggiornamenti in termini di prestazioni e sicurezza forniti da PHP.",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "La configurazione delle intestazioni del proxy inverso non è corretta, o stai effettuando l'accesso a ownCloud da un proxy affidabile. Se non stai effettuando l'accesso da un proxy affidabile, questo è un problema di sicurezza e può consentire a un attaccante di falsificare il suo indirizzo IP, rendendo visibile a ownCloud. Ulteriori informazioni sono disponibili nella nostra <a target=\"_blank\" href=\"{docLink}\">documentazione</a>.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached è configurato come cache distribuita, ma è installato il modulo \"memcache\" errato. \\OC\\Memcache\\Memcached supporta solo \"memcached\" e non \"memcache\". Vedi il  <a target=\"_blank\" href=\"{wikiLink}\">wiki di memcached per informazioni su entrambi i moduli</a>.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Alcuni file non hanno superato il controllo di integrità. Ulteriori informazioni su come risolvere questo problema sono disponibili nella nostra <a target=\"_blank\" href=\"{docLink}\">documentazione</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Elenco dei file non validi…</a> / <a href=\"{rescanEndpoint}\">Nuova scansione…</a>)",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Non è stata configurata alcuna cache di memoria. Per migliorare le prestazioni configura memcache, se disponibile. Ulteriori informazioni sono disponibili nella nostra <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentazione</a>.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom non è leggibile da PHP e ciò è vivamente sconsigliato per motivi di sicurezza. Ulteriori informazioni sono disponibili nella nostra <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentazione</a>.",
+    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Stai eseguendo attualmente PHP {version}. Ti esortiamo ad aggiornare la tua versione di PHP per trarre vantaggio dagli aggiornamenti in termini di <a target=\"_blank\" rel=\"noreferrer\" ref=\"{phpLink}\">prestazioni e sicurezza forniti dal PHP Group</a> non appena la tua distribuzione la supporta.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "La configurazione delle intestazioni del proxy inverso non è corretta, o stai effettuando l'accesso a ownCloud da un proxy affidabile. Se non stai effettuando l'accesso da un proxy affidabile, questo è un problema di sicurezza e può consentire a un attaccante di falsificare il suo indirizzo IP, rendendolo visibile a ownCloud. Ulteriori informazioni sono disponibili nella nostra <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentazione</a>.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached è configurato come cache distribuita, ma è installato il modulo \"memcache\" errato. \\OC\\Memcache\\Memcached supporta solo \"memcached\" e non \"memcache\". Vedi il  <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">wiki di memcached per informazioni su entrambi i moduli</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Alcuni file non hanno superato il controllo di integrità. Ulteriori informazioni su come risolvere questo problema sono disponibili nella nostra <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentazione</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Elenco dei file non validi…</a> / <a href=\"{rescanEndpoint}\">Nuova scansione…</a>)",
     "Error occurred while checking server setup" : "Si è verificato un errore durante il controllo della configurazione del server",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "La cartella dei dati e i tuoi file sono probabilmente accessibili da Internet.\nIl file .htaccess non funziona. Ti consigliamo vivamente di configurare il server web in modo che la cartella dei dati non sia più accessibile o di spostare la cartella fuori dalla radice del server web.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "L'intestazione HTTP \"{header}\" non è configurata come \"{expected}\". \nQuesto è un potenziale rischio di sicurezza o di riservatezza dei dati e noi consigliamo di modificare questa impostazione.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "L'intestazione HTTP \"Strict-Transport-Security\" non è configurata con un valore di almeno \"{seconds}\" secondi. Per migliorare la sicurezza, consigliamo di abilitare HSTS come descritto nei nostri <a href=\"{docUrl}\">consigli sulla sicurezza</a>.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "L'intestazione HTTP \"Strict-Transport-Security\" non è configurata con un valore di almeno \"{seconds}\" secondi. Per migliorare la sicurezza, consigliamo di abilitare HSTS come descritto nei nostri <a href=\"{docUrl}\" rel=\"noreferrer\">consigli sulla sicurezza</a>.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Sei connesso a questo sito tramite HTTP. Ti suggeriamo vivamente di configurare il tuo server per richiedere invece l'utilizzo del protocollo HTTPS, come descritto nei nostri <a href=\"{docUrl}\">consigli sulla sicurezza</a>.",
     "Shared" : "Condiviso",
     "Shared with {recipients}" : "Condiviso con {recipients}",
     "Error" : "Errore",
     "Error while sharing" : "Errore durante la condivisione",
     "Error while unsharing" : "Errore durante la rimozione della condivisione",
-    "Error setting expiration date" : "Errore durante l'impostazione della data di scadenza",
     "The public link will expire no later than {days} days after it is created" : "Il collegamento pubblico scadrà non più tardi di {days} giorni dopo la sua creazione",
     "Set expiration date" : "Imposta data di scadenza",
     "Expiration" : "Scadenza",
     "Expiration date" : "Data di scadenza",
+    "Expiration date is required" : "La data di scadenza è richiesta",
+    "Delete {link}" : "Elimina {link}",
+    "Remove link" : "Rimuovi collegamento",
+    "{fileName} link" : "{fileName} collegamento",
+    "Link" : "Collegamento",
+    "Create public link" : "Crea collegamento pubblico",
+    "Edit" : "Modifica",
+    "Remove" : "Rimuovi",
+    "Click to copy to clipboard" : "Fai clic per copiare negli appunti",
+    "Social share" : "Condivisione sociale",
+    "There are currently no link shares, you can create one" : "Al momento non ci sono collegamenti a condivisioni, puoi crearne uno",
+    "Copied!" : "Copiato!",
+    "Not supported!" : "Non supportato!",
+    "Press ⌘-C to copy." : "Premi ⌘-C per copiare.",
+    "Press Ctrl-C to copy." : "Premi Ctrl-C per copiare.",
     "Choose a password for the public link" : "Scegli una password per il collegamento pubblico",
+    "Password required" : "Password richiesta",
+    "Filename" : "Nome del file",
+    "Password" : "Password",
+    "Name" : "Nome",
+    "Allow editing" : "Consenti la modifica",
+    "Edit link share: {name}" : "Modifica collegamento a condivisione: {name}",
+    "Save" : "Salva",
+    "Create link share: {name}" : "Creare collegamento a condivisione: {name}",
+    "Remove password" : "Rimuovi password",
+    "Share to Twitter. Opens in a new window." : "Condividi su Twitter. Apre una nuova finestra.",
+    "Share to Facebook. Opens in a new window." : "Condividi su Facebook. Apre una nuova finestra.",
+    "Share to Diaspora. Opens in a new window." : "Condividi su Diaspora. Apre una nuova finestra.",
+    "Share to Google+. Opens in a new window." : "Condividi su Google+. Apre una nuova finestra.",
+    "Share via email. Opens your mail client." : "Condividi tramite email. Apre una nuova finestra.",
+    "Error while sending notification" : "Errore durante l'invio della notifica",
     "Sending ..." : "Invio in corso...",
     "Email sent" : "Messaggio inviato",
-    "Resharing is not allowed" : "La ri-condivisione non è consentita",
-    "Share link" : "Condividi collegamento",
-    "Link" : "Collegamento",
-    "Password protect" : "Proteggi con password",
-    "Password" : "Password",
-    "Allow editing" : "Consenti la modifica",
     "Email link to person" : "Invia collegamento via email",
-    "Send" : "Invia",
+    "Send link via email" : "Invia collegamento tramite email",
     "Shared with you and the group {group} by {owner}" : "Condiviso con te e con il gruppo {group} da {owner}",
     "Shared with you by {owner}" : "Condiviso con te da {owner}",
     "group" : "gruppo",
@@ -168,19 +194,24 @@ OC.L10N.register(
     "Could not unshare" : "Impossibile rimuovere la condivisione",
     "Share details could not be loaded for this item." : "I dettagli della condivisione non possono essere caricati per questo elemento.",
     "No users or groups found for {search}" : "Nessun utente o gruppo trovato per {search}",
-    "An error occured. Please try again" : "Si è verificato un errore. Prova ancora",
+    "No users found for {search}" : "Nessun utente trovato per {search}",
+    "An error occurred. Please try again" : "Si è verificato un errore. Prova ancora",
     "{sharee} (group)" : "{sharee} (group)",
     "{sharee} (at {server})" : "{sharee} (su {server})",
     "{sharee} (remote)" : "{sharee} (remote)",
     "Share" : "Condividi",
+    "User and Groups" : "Utenti e gruppi",
+    "Public Links" : "Collegamenti pubblici",
+    "Resharing is not allowed" : "La ri-condivisione non è consentita",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Condividi con persone su altri ownCloud utilizzando la sintassi nomeutente@esempio.com/owncloud",
-    "Share with users or groups …" : "Condividi con utenti o gruppi...",
-    "Share with users, groups or remote users …" : "Condividi con utenti, gruppi o utenti remoti...",
+    "Share with users…" : "Condividi con utenti...",
+    "Share with users, groups or remote users…" : "Condividi con utenti, gruppi o utenti remoti...",
+    "Share with users or groups…" : "Condividi con utenti o gruppi...",
+    "Share with users or remote users…" : "Condividi con utenti o utenti remoti...",
     "Error removing share" : "Errore durante la rimozione della condivisione",
     "Warning" : "Avviso",
-    "Error while sending notification" : "Errore durante l'invio della notifica",
     "Non-existing tag #{tag}" : "Etichetta #{tag} inesistente",
-    "not assignable" : "non assegnabile",
+    "restricted" : "limitato",
     "invisible" : "invisibile",
     "({scope})" : "({scope})",
     "Delete" : "Elimina",
@@ -197,13 +228,14 @@ OC.L10N.register(
     "sunny" : "soleggiato",
     "Hello {name}, the weather is {weather}" : "Ciao {name}, il tempo è {weather}",
     "Hello {name}" : "Ciao {name}",
+    "new" : "nuovo",
     "_download %n file_::_download %n files_" : ["scarica %n file","scarica %s file"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "L'aggiornamento è in corso, l'abbandono di questa pagina potrebbe interrompere il processo in alcuni ambienti.",
-    "Updating {productName} to version {version}, this may take a while." : "Aggiornamento di {productName} alla versione {version}, potrebbe richiedere del tempo.",
+    "Updating to {version}" : "Aggiornamento a {version}",
     "An error occurred." : "Si è verificato un errore.",
     "Please reload the page." : "Ricarica la pagina.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "L'aggiornamento non è riuscito. Per ulteriori informazioni <a href=\"{url}\">controlla l'articolo del nostro forum</a> che riguarda questo problema.",
-    "The update was unsuccessful. " : "L'aggiornamento non è riuscito.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "L'aggiornamento non è riuscito. Segnala il problema alla <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">comunità di ownCloud</a>.",
     "The update was successful. There were warnings." : "L'aggiornamento è stato effettuato correttamente. Ci sono degli avvisi.",
     "The update was successful. Redirecting you to ownCloud now." : "L'aggiornamento è stato effettuato correttamente. Stai per essere reindirizzato a ownCloud.",
     "Searching other places" : "Ricerca in altre posizioni",
@@ -214,13 +246,6 @@ OC.L10N.register(
     "Apps" : "Applicazioni",
     "Admin" : "Admin",
     "Help" : "Aiuto",
-    "Error loading tags" : "Errore di caricamento delle etichette",
-    "Tag already exists" : "L'etichetta esiste già",
-    "Error deleting tag(s)" : "Errore di eliminazione delle etichette",
-    "Error tagging" : "Errore di assegnazione delle etichette",
-    "Error untagging" : "Errore di rimozione delle etichette",
-    "Error favoriting" : "Errore di creazione dei preferiti",
-    "Error unfavoriting" : "Errore di rimozione dai preferiti",
     "Access forbidden" : "Accesso negato",
     "File not found" : "File non trovato",
     "The specified document has not been found on the server." : "Il documento specificato non è stato trovato sul server.",
@@ -241,9 +266,6 @@ OC.L10N.register(
     "File: %s" : "File: %s",
     "Line: %s" : "Riga: %s",
     "Trace" : "Traccia",
-    "Security warning" : "Avviso di sicurezza",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "La cartella dei dati e i file sono probabilmente accessibili da Internet poiché il file .htaccess non funziona.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Per informazioni su come configurare correttamente il tuo server, vedi la <a href=\"%s\" target=\"_blank\">documentazione</a>.",
     "Create an <strong>admin account</strong>" : "Crea un <strong>account amministratore</strong>",
     "Username" : "Nome utente",
     "Storage & database" : "Archiviazione e database",
@@ -257,6 +279,7 @@ OC.L10N.register(
     "Database name" : "Nome del database",
     "Database tablespace" : "Spazio delle tabelle del database",
     "Database host" : "Host del database",
+    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "Specifica il numero di porta insieme al nome host (ad es. localhost:5432).",
     "Performance warning" : "Avviso di prestazioni",
     "SQLite will be used as database." : "SQLite sarà utilizzato come database.",
     "For larger installations we recommend to choose a different database backend." : "Per installazioni più grandi consigliamo di scegliere un motore di database diverso.",
@@ -271,14 +294,16 @@ OC.L10N.register(
     "Search" : "Cerca",
     "Server side authentication failed!" : "Autenticazione lato server non riuscita!",
     "Please contact your administrator." : "Contatta il tuo amministratore di sistema.",
-    "An internal error occured." : "Si è verificato un errore interno.",
+    "An internal error occurred." : "Si è verificato un errore interno.",
     "Please try again or contact your administrator." : "Prova ancora o contatta il tuo amministratore.",
+    "Username or email" : "Nome utente o email",
     "Log in" : "Accedi",
     "Wrong password. Reset it?" : "Password errata. Vuoi reimpostarla?",
     "Wrong password." : "Password errata.",
     "Stay logged in" : "Rimani collegato",
     "Alternative Logins" : "Accessi alternativi",
     "Use the following link to reset your password: {link}" : "Usa il collegamento seguente per ripristinare la password: {link}",
+    "Password changed successfully" : "Password cambiata con successo",
     "New password" : "Nuova password",
     "New Password" : "Nuova password",
     "Reset password" : "Ripristina la password",
@@ -286,6 +311,11 @@ OC.L10N.register(
     "This means only administrators can use the instance." : "Ciò significa che solo gli amministratori possono utilizzare l'istanza.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contatta il tuo amministratore di sistema se questo messaggio persiste o appare inaspettatamente.",
     "Thank you for your patience." : "Grazie per la pazienza.",
+    "Two-step verification" : "Verifica in due fasi",
+    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "La sicurezza migliorata è stata abilitata per il tuo account. Autenticati utilizzando un secondo fattore.",
+    "Cancel login" : "Annulla l'accesso",
+    "Please authenticate using the selected factor." : "Autentica utilizzando il fattore selezionato.",
+    "An error occurred while verifying the token" : "Si è verificato un errore durante la verifica del token",
     "You are accessing the server from an untrusted domain." : "Stai accedendo al server da un dominio non attendibile.",
     "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Contatta il tuo amministratore di sistema. Se sei un amministratore di questa istanza, configura l'impostazione \"trusted_domains\" in config/config.php. Una configurazione di esempio è disponibile in config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "In base alla tua configurazione, come amministratore potrai utilizzare anche il pulsante in basso per rendere attendibile questo dominio.",
@@ -293,14 +323,15 @@ OC.L10N.register(
     "App update required" : "Aggiornamento dell'applicazione richiesto",
     "%s will be updated to version %s" : "%s sarà aggiornato alla versione %s",
     "These apps will be updated:" : "Queste applicazioni saranno aggiornate:",
-    "These incompatible apps will be disabled:" : "Queste applicazioni incompatibili saranno disabilitate:",
     "The theme %s has been disabled." : "Il tema %s è stato disabilitato.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Assicurati di aver creato una copia di sicurezza del database, della cartella config e della cartella data prima di procedere. ",
     "Start update" : "Avvia l'aggiornamento",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Per evitare timeout con installazioni di grandi dimensioni, puoi eseguire il comando che segue dalla cartella di installazione:",
+    "Detailed logs" : "Log dettagliati",
+    "Update needed" : "Aggiornamento necessario",
+    "Please use the command line updater because you have a big instance." : "Utilizza lo strumento da riga di comando per la grandezza della tua istanza.",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Per la guida, vedi la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentazione</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Questa istanza di %s è attualmente in manutenzione, potrebbe richiedere del tempo.",
-    "This page will refresh itself when the %s instance is available again." : "Questa pagina si aggiornerà quando l'istanza di %s sarà nuovamente disponibile.",
-    "Error loading file picker template: {error}" : "Errore durante il caricamento del modello del selettore file: {error}",
-    "Password can not be changed. Please contact your administrator." : "La password non può essere cambiata. Contatta il tuo amministratore."
+    "This page will refresh itself when the %s instance is available again." : "Questa pagina si aggiornerà quando l'istanza di %s sarà nuovamente disponibile."
 },
 "nplurals=2; plural=(n != 1);");
