@@ -1,29 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "次のユーザーにメールを送信できませんでした: %s",
-    "Preparing update" : "アップデートの準備中",
-    "Turned on maintenance mode" : "メンテナンスモードがオンになりました",
-    "Turned off maintenance mode" : "メンテナンスモードがオフになりました",
-    "Maintenance mode is kept active" : "メンテナンスモードが継続中です",
-    "Updating database schema" : "データベースのスキーマを更新",
-    "Updated database" : "データベース更新済み",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "データベーススキーマーがアップデートできるかどうかチェックしています。(この操作の時間はデータベースの容量によります)",
-    "Checked database schema update" : "指定データベースのスキーマを更新",
-    "Checking updates of apps" : "アプリの更新をチェックしています。",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "データベーススキーマー %s がアップデートできるかどうかチェックしています。(この操作の時間はデータベースの容量によります)",
-    "Checked database schema update for apps" : "アプリの指定データベースのスキーマを更新",
-    "Updated \"%s\" to %s" : "\"%s\" を %s にアップデートしました。",
-    "Repair warning: " : "修復警告:",
-    "Repair error: " : "修復エラー:",
-    "Set log level to debug" : "ログをデバッグレベルに設定",
-    "Reset log level" : "ログレベルをリセット",
-    "Starting code integrity check" : "コード整合性の確認を開始",
-    "Finished code integrity check" : "コード整合性の確認が終了",
-    "%s (3rdparty)" : "%s (サードパーティー)",
-    "%s (incompatible)" : "%s (非互換)",
-    "Following apps have been disabled: %s" : "以下のアプリが無効にされています: %s",
-    "Already up to date" : "すべて更新済",
     "Please select a file." : "ファイルを選択してください。",
     "File is too big" : "ファイルが大きすぎます",
     "Invalid file provided" : "無効なファイルが提供されました",
@@ -37,10 +14,35 @@ OC.L10N.register(
     "Crop is not square" : "クロップが正方形ではありません",
     "Couldn't reset password because the token is invalid" : "トークンが無効なため、パスワードをリセットできませんでした",
     "Couldn't reset password because the token is expired" : "トークンが期限切れのため、パスワードをリセットできませんでした",
-    "Couldn't send reset email. Please make sure your username is correct." : "リセットメールを送信できませんでした。ユーザー名が正しいことを確認してください。",
-    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "このユーザー名に紐付けられたメールアドレスがないため、リセットメールを送信できませんでした。管理者に問い合わせてください。",
+    "%s password changed successfully" : "%s パスワードは正常に変更されました",
     "%s password reset" : "%s パスワードリセット",
     "Couldn't send reset email. Please contact your administrator." : "リセットメールを送信できませんでした。管理者に問い合わせてください。",
+    "Couldn't send mail to following users: %s " : "次のユーザーにメールを送信できませんでした: %s",
+    "Preparing update" : "アップデートの準備中",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "修復警告:",
+    "Repair error: " : "修復エラー:",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "config.php で自動更新が無効になっているので、コマンドラインでの更新を利用してください。",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: テーブル %s をチェック中",
+    "Turned on maintenance mode" : "メンテナンスモードがオンになりました",
+    "Turned off maintenance mode" : "メンテナンスモードがオフになりました",
+    "Maintenance mode is kept active" : "メンテナンスモードが継続中です",
+    "Updating database schema" : "データベースのスキーマを更新",
+    "Updated database" : "データベース更新済み",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "データベーススキーマーがアップデートできるかどうかチェックしています。(この操作の時間はデータベースの容量によります)",
+    "Checked database schema update" : "指定データベースのスキーマを更新",
+    "Checking updates of apps" : "アプリの更新をチェックしています。",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "データベーススキーマー %s がアップデートできるかどうかチェックしています。(この操作の時間はデータベースの容量によります)",
+    "Checked database schema update for apps" : "アプリの指定データベースのスキーマを更新",
+    "Updated \"%s\" to %s" : "\"%s\" を %s にアップデートしました。",
+    "Set log level to debug" : "ログをデバッグレベルに設定",
+    "Reset log level" : "ログレベルをリセット",
+    "Starting code integrity check" : "コード整合性の確認を開始",
+    "Finished code integrity check" : "コード整合性の確認が終了",
+    "%s (3rdparty)" : "%s (サードパーティー)",
+    "%s (incompatible)" : "%s (非互換)",
+    "Following apps have been disabled: %s" : "以下のアプリが無効にされています: %s",
+    "Already up to date" : "すべて更新済",
     "Sunday" : "日",
     "Monday" : "月",
     "Tuesday" : "火",
@@ -88,6 +90,7 @@ OC.L10N.register(
     "Dec." : "12月",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">コード整合性の確認で問題が発生しました。詳しくはこちら…</a>",
     "Settings" : "設定",
+    "Problem loading page, reloading in 5 seconds" : "ページ読込に問題がありました。5秒後に再読込します",
     "Saving..." : "保存中...",
     "Dismiss" : "閉じる",
     "seconds ago" : "数秒前",
@@ -119,40 +122,63 @@ OC.L10N.register(
     "Good password" : "良好なパスワード",
     "Strong password" : "強いパスワード",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "WebDAVインターフェースが動作していないようです。Webサーバーは、ファイルの同期を許可するよう適切に設定されていません。",
-    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Webサーバーは適切に\"{url}\"を解決するように設定されていません.より詳しい情報については、<a target=\"_blank\" href=\"{docLink}\">ドキュメント</a> を参照ください。",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Webサーバーは適切にホスト名 \"{url}\" が引けるように設定されていません。より詳しい情報については、<a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">ドキュメント</a> を参照ください。",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "このサーバーはインターネットに接続していません。この場合、外部ストレージのマウント、更新の通知やサードパーティ製のアプリ、といった一部の機能が利用できません。また、リモート接続でのファイルアクセス、通知メールの送信のような機能も利用できないことがあります。すべての機能を利用するには、このサーバーのインターネット接続を有効にすることをお勧めします。",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "メモリキャッシュが設定されていません。パフォーマンスを向上するために、可能であれば memcache を設定してください。 より詳しい情報については、<a target=\"_blank\" href=\"{docLink}\">ドキュメント</a> を参照してください。",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandom は PHP から読み取ることができず、この状態はセキュリティの観点からおすすめできません。より詳しい情報については、<a target=\"_blank\" href=\"{docLink}\">ドキュメント</a> を参照ください。",
-    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "ご利用のPHPのバージョン ({version}) は、<a target=\"_blank\" href=\"{phpLink}\">PHPでサポート</a> されていません。セキュリティ確保とパフォーマンス向上のために、PHPから提供されている新しいバージョンにアップグレードすることを強くお勧めします。",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "リバースプロキシのヘッダー設定が間違っているか、または信頼されたプロキシからownCloudにアクセスしていません。もし、信頼されたプロキシからアクセスしているのでないなら、セキュリティに問題があり、ownCloudを詐称したIPアドレスから攻撃者に対して見えるよう許可していることになります。詳細な情報は、 <a target=\"_blank\" href=\"{docLink}\">ドキュメント</a>を確認してください。",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached は分散キャッシュとして設定されています。しかし、PHPモジュール \"memcache\"が間違ってインストールされています。  \\OC\\Memcache\\Memcached は、\"memcached\" のみをサポートしています。\"memcache\" ではありません。<a target=\"_blank\" href=\"{wikiLink}\">memcached wiki で両方のモジュール</a> について確認してください。",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "いくつかのファイルで整合性の確認に失敗しました。この問題を解決するための詳細情報は<a target=\"_blank\" href=\"{docLink}\">ドキュメント</a>にあります｡ (<a href=\"{codeIntegrityDownloadEndpoint}\">不適正なファイルのリスト…</a> / <a href=\"{rescanEndpoint}\">再スキャン…</a>)",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "メモリキャッシュが設定されていません。パフォーマンスを向上するために、可能であれば memcache を設定してください。 より詳しい情報については、<a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">を参照してください。",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom を PHP から読み取ることができません。この状態はセキュリティの観点からおすすめできません。より詳しい情報については、<a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">ドキュメント</a> を参照ください。",
+    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "このサーバーでは、{version} のPHPを利用しています。パフォーマンスとセキュリティ上のメリットがあるため利用中のディストリビューションで<a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">PHP グループの提供する最新のPHPのバージョン</a>になるべく早くアップデートすることを強くお勧めします。",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "リバースプロキシのヘッダー設定が間違っているか、または信頼されたプロキシからownCloudにアクセスしていません。もし、信頼されたプロキシからアクセスされているのでないなら、攻撃者の詐称されたIPアドレスから ownCloudを見ることができるように許可されていて、セキュリティに問題があります。詳細な情報は、 <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">ドキュメント</a>を確認してください。",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached は分散キャッシュとして設定されています。しかし、PHPモジュール \"memcache\"が間違ってインストールされています。  \\OC\\Memcache\\Memcached は、\"memcached\" のみをサポートしています。\"memcache\" ではありません。<a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki で両方のモジュールの情報</a> について確認してください。",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "いくつかのファイルでチェックサムが適合しませんでした。この問題を解決するためは、<a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">ドキュメント</a>の詳細を見てください。(<a href=\"{codeIntegrityDownloadEndpoint}\">不適合ファイルのリスト…</a> / <a href=\"{rescanEndpoint}\">再チェック…</a>)",
     "Error occurred while checking server setup" : "サーバー設定のチェック中にエラーが発生しました",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "データディレクトリとファイルがインターネットからアクセス可能になっている可能性があります。.htaccessファイルが機能していません。データディレクトリがアクセスされないようにWebサーバーを設定するか、Webサーバーのドキュメントルートからデータディレクトリを移動するように強くお勧めします。",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "\"{header}\" HTTP ヘッダは \"{expected}\" に設定されていません。これは潜在的なセキュリティリスクもしくはプライバシーリスクとなる可能性があるため、この設定を見直すことをおすすめします。",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "\"Strict-Transport-Security\" HTTP ヘッダが最小値の \"{seconds}\" 秒に設定されていません。 セキュリティを強化するため、<a href=\"{docUrl}\">セキュリティのコツ</a>を参照して、HSTS を有効にすることをおすすめします。",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "HTTP ヘッダ の \"Strict-Transport-Security\" が少なくとも \"{seconds}\" 秒に設定されていません。 セキュリティを強化するため、<a href=\"{docUrl}\" rel=\"noreferrer\">セキュリティTips</a>を参照して、HSTS を有効にすることをおすすめします。",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "HTTP経由でアクセスしています。<a href=\"{docUrl}\">security tips</a>を参照して、代わりにHTTPSを使用するようサーバーを設定することを強くおすすめします。 instead as described in our .",
     "Shared" : "共有中",
     "Shared with {recipients}" : "{recipients} と共有",
     "Error" : "エラー",
     "Error while sharing" : "共有でエラー発生",
     "Error while unsharing" : "共有解除でエラー発生",
-    "Error setting expiration date" : "有効期限の設定でエラー発生",
     "The public link will expire no later than {days} days after it is created" : "URLによる共有は、作成してから {days} 日以内に有効期限切れになります",
     "Set expiration date" : "有効期限を設定",
     "Expiration" : "期限切れ",
     "Expiration date" : "有効期限",
+    "Expiration date is required" : "有効期限を設定してください",
+    "Delete {link}" : "{link} を削除",
+    "Remove link" : "リンクを削除",
+    "{fileName} link" : "{fileName} をリンク",
+    "Link" : "リンク",
+    "Create public link" : "公開リンクを作成",
+    "Edit" : "編集",
+    "Remove" : "削除",
+    "Click to copy to clipboard" : "クリックしてクリップボードにコピー",
+    "Social share" : "共有",
+    "There are currently no link shares, you can create one" : "共有可能なリンクを作成できます",
+    "Copied!" : "コピーしました",
+    "Not supported!" : "サポートされていません",
+    "Press ⌘-C to copy." : "⌘-Cを押してコピーします。",
+    "Press Ctrl-C to copy." : "Ctrl-Cを押してコピーします。",
     "Choose a password for the public link" : "URLによる共有のパスワードを入力",
+    "Password required" : "パスワードを入力してください",
+    "Filename" : "ファイル名",
+    "Password" : "パスワード",
+    "Name" : "名前",
+    "Allow editing" : "編集を許可",
+    "Edit link share: {name}" : "共有を編集: {name}",
+    "Save" : "保存",
+    "Create link share: {name}" : "共有を開始: {name}",
+    "Remove password" : "パスワードを削除",
+    "Share to Twitter. Opens in a new window." : "Twitterで共有。新しいウインドウで開く。",
+    "Share to Facebook. Opens in a new window." : "Facebookで共有。新しいウインドウで開く。",
+    "Share to Diaspora. Opens in a new window." : "Diasporaで共有。新しいウインドウで開く。",
+    "Share to Google+. Opens in a new window." : "Google+で共有。新しいウインドウで開く。",
+    "Share via email. Opens your mail client." : "電子メールで共有。メールクライアントを開く。",
+    "Error while sending notification" : "通知送信中にエラーが発生",
     "Sending ..." : "送信中...",
     "Email sent" : "メールを送信しました",
-    "Resharing is not allowed" : "再共有は許可されていません",
-    "Share link" : "URLで共有",
-    "Link" : "リンク",
-    "Password protect" : "パスワード保護を有効化",
-    "Password" : "パスワード",
-    "Allow editing" : "編集を許可",
     "Email link to person" : "メールリンク",
-    "Send" : "送信",
+    "Send link via email" : "メールでリンクを送信",
     "Shared with you and the group {group} by {owner}" : "あなたと {owner} のグループ {group} で共有中",
     "Shared with you by {owner}" : "{owner} と共有中",
     "group" : "グループ",
@@ -168,19 +194,24 @@ OC.L10N.register(
     "Could not unshare" : "共有の解除ができませんでした",
     "Share details could not be loaded for this item." : "共有の詳細はこのアイテムによりロードできませんでした。",
     "No users or groups found for {search}" : "{search} の検索でユーザー、グループが見つかりません",
-    "An error occured. Please try again" : "エラーが発生しました。もう一度トライしてください。",
+    "No users found for {search}" : "{search} のユーザーはいませんでした",
+    "An error occurred. Please try again" : "エラーが発生しました。もう一度実行してください。",
     "{sharee} (group)" : "{sharee} (グループ)",
     "{sharee} (at {server})" : "{sharee} ({server} で)",
     "{sharee} (remote)" : "{sharee} (リモート)",
     "Share" : "共有",
+    "User and Groups" : "ユーザーとグループ",
+    "Public Links" : "公開リンク",
+    "Resharing is not allowed" : "再共有は許可されていません",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "次の形式で指定して他のownCloudのユーザーと、共有",
-    "Share with users or groups …" : "ユーザーもしくはグループと共有 ...",
-    "Share with users, groups or remote users …" : "ユーザー、グループもしくはリモートユーザーと共有 ...",
+    "Share with users…" : "ユーザーと共有...",
+    "Share with users, groups or remote users…" : "ユーザー、グループもしくはリモートユーザーと共有 ...",
+    "Share with users or groups…" : "ユーザーもしくはグループと共有...",
+    "Share with users or remote users…" : "ユーザーもしくはリモートユーザーと共有 ...",
     "Error removing share" : "共有の削除エラー",
     "Warning" : "警告",
-    "Error while sending notification" : "通知送信中にエラーが発生",
     "Non-existing tag #{tag}" : "存在しないタグ#{tag}",
-    "not assignable" : "割り当てできない",
+    "restricted" : "制限済",
     "invisible" : "不可視",
     "({scope})" : "({scope})",
     "Delete" : "削除",
@@ -197,13 +228,14 @@ OC.L10N.register(
     "sunny" : "快晴",
     "Hello {name}, the weather is {weather}" : "こんにちは､ {name}､ 天気は{weather}です",
     "Hello {name}" : " {name}さん､こんにちは",
+    "new" : "新規",
     "_download %n file_::_download %n files_" : ["%n個のファイルをダウンロード"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "アップグレード実行中です。このページを離れると、一部の環境では処理が中断されてしまうことがあります。",
-    "Updating {productName} to version {version}, this may take a while." : "{productName} を バージョン {version} に更新しています。しばらくお待ちください。",
+    "Updating to {version}" : "{version} にアップデート",
     "An error occurred." : "エラーが発生しました。",
     "Please reload the page." : "ページをリロードしてください。",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "アップデートできませんでした。この問題に対する詳細な情報については、<a href=\"{url}\">フォーラムの投稿を確認してください</a> ",
-    "The update was unsuccessful. " : "アップデートに失敗しました。",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "アップデートに失敗しました。この問題を <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a> にレポートしてください。",
     "The update was successful. There were warnings." : "アップデートは成功しました。警告がありました。",
     "The update was successful. Redirecting you to ownCloud now." : "アップデートに成功しました。今すぐownCloudにリダイレクトします。",
     "Searching other places" : "他の場所の検索",
@@ -214,13 +246,6 @@ OC.L10N.register(
     "Apps" : "アプリ",
     "Admin" : "管理",
     "Help" : "ヘルプ",
-    "Error loading tags" : "タグの読み込みエラー",
-    "Tag already exists" : "タグはすでに存在します",
-    "Error deleting tag(s)" : "タグの削除エラー",
-    "Error tagging" : "タグの付与エラー",
-    "Error untagging" : "タグの解除エラー",
-    "Error favoriting" : "お気に入りに追加エラー",
-    "Error unfavoriting" : "お気に入りから削除エラー",
     "Access forbidden" : "アクセスが禁止されています",
     "File not found" : "ファイルが見つかりません",
     "The specified document has not been found on the server." : "サーバーに指定されたファイルが見つかりませんでした。",
@@ -241,9 +266,6 @@ OC.L10N.register(
     "File: %s" : "ファイル: %s",
     "Line: %s" : "行: %s",
     "Trace" : "トレース",
-    "Security warning" : "セキュリティ警告",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccessファイルが動作していないため、おそらくあなたのデータディレクトリまたはファイルはインターネットからアクセス可能になっています。",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "サーバーを適正に設定する情報は、こちらの<a href=\"%s\" target=\"_blank\">ドキュメント</a>を参照してください。",
     "Create an <strong>admin account</strong>" : "<strong>管理者アカウント</strong>を作成してください",
     "Username" : "ユーザー名",
     "Storage & database" : "ストレージとデータベース",
@@ -257,6 +279,7 @@ OC.L10N.register(
     "Database name" : "データベース名",
     "Database tablespace" : "データベースの表領域",
     "Database host" : "データベースのホスト名",
+    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "ホスト名とポート番号を指定してください(例: localhost: 5432)。",
     "Performance warning" : "パフォーマンス警告",
     "SQLite will be used as database." : "SQLiteをデータベースとして使用しています。",
     "For larger installations we recommend to choose a different database backend." : "大規模な運用では別のデータベースを選択することをお勧めします。",
@@ -271,14 +294,16 @@ OC.L10N.register(
     "Search" : "検索",
     "Server side authentication failed!" : "サーバーサイドの認証に失敗しました！",
     "Please contact your administrator." : "管理者に問い合わせてください。",
-    "An internal error occured." : "内部エラーが発生しました。",
+    "An internal error occurred." : "内部エラーが発生しました。",
     "Please try again or contact your administrator." : "もう一度試してみるか、管理者に問い合わせてください。",
+    "Username or email" : "ユーザー名またはメールアドレス",
     "Log in" : "ログイン",
     "Wrong password. Reset it?" : "パスワードが間違っています。リセットしますか？",
     "Wrong password." : "パスワードが間違っています。",
     "Stay logged in" : "ログインしたままにする",
     "Alternative Logins" : "代替ログイン",
     "Use the following link to reset your password: {link}" : "パスワードをリセットするには次のリンクをクリックしてください: {link}",
+    "Password changed successfully" : "パスワードは正常に変更されました",
     "New password" : "新しいパスワードを入力",
     "New Password" : "新しいパスワード",
     "Reset password" : "パスワードをリセット",
@@ -286,6 +311,11 @@ OC.L10N.register(
     "This means only administrators can use the instance." : "これは、管理者のみがインスタンスを利用できることを意味しています。",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "このメッセージが引き続きもしくは予期せず現れる場合は、システム管理者に問い合わせてください。",
     "Thank you for your patience." : "しばらくお待ちください。",
+    "Two-step verification" : "2段階認証",
+    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "あなたのアカウントではセキュリティ拡張が有効になっています。2要素認証を使って認証してください。",
+    "Cancel login" : "ログイン中止",
+    "Please authenticate using the selected factor." : "選択したデバイスを利用して認証してください。",
+    "An error occurred while verifying the token" : "トークンの検証中にエラーが発生しました",
     "You are accessing the server from an untrusted domain." : "信頼されていないドメインからサーバーにアクセスしています。",
     "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "管理者に問い合わせてください。このサーバーの管理者の場合は、\"trusted_domain\" の設定を config/config.php に設定してください。config/config.sample.php にサンプルの設定方法が記載してあります。",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "環境により、下のボタンで信頼するドメインに追加する必要があるかもしれません。",
@@ -293,14 +323,15 @@ OC.L10N.register(
     "App update required" : "アプリの更新が必要",
     "%s will be updated to version %s" : "%s は バーション %s にアップデートされます",
     "These apps will be updated:" : "次のアプリはアップデートされます：",
-    "These incompatible apps will be disabled:" : "次の非互換のないアプリは無効になる：",
     "The theme %s has been disabled." : "テーマ %s が無効になっています。",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "データベースを確認してください。実行前にconfigフォルダーとdataフォルダーをバックアップします。",
     "Start update" : "アップデートを開始",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "大規模なサイトの場合、ブラウザーがタイムアウトする可能性があるため、インストールディレクトリで以下のコマンドを実行することもできます。",
+    "Detailed logs" : "詳細ログ",
+    "Update needed" : "更新が必要です",
+    "Please use the command line updater because you have a big instance." : "データ量が大きいため、コマンドラインでの更新を利用してください。",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "不明な場合、<a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">ドキュメント</a>を参照してください。",
     "This %s instance is currently in maintenance mode, which may take a while." : "このサーバー %s は現在メンテナンスモードです。しばらくお待ちください。",
-    "This page will refresh itself when the %s instance is available again." : "この画面は、サーバー %s の再起動後に自動的に更新されます。",
-    "Error loading file picker template: {error}" : "ファイル選択テンプレートの読み込みエラー: {error}",
-    "Password can not be changed. Please contact your administrator." : "パスワードは変更できません。管理者に問い合わせてください。"
+    "This page will refresh itself when the %s instance is available again." : "この画面は、サーバー %s の再起動後に自動的に更新されます。"
 },
 "nplurals=1; plural=0;");
