@@ -7,13 +7,14 @@ OC.L10N.register(
     "Yes" : "بەڵێ",
     "Ok" : "باشە",
     "Cancel" : "لابردن",
-    "Share" : "هاوبەشی کردن",
     "Error" : "هه‌ڵه",
+    "Edit" : "دەسکاریکردن",
     "Password" : "وشەی تێپەربو",
+    "Name" : "ناو",
+    "Save" : "پاشکه‌وتکردن",
+    "Share" : "هاوبەشی کردن",
     "Warning" : "ئاگاداری",
     "Add" : "زیادکردن",
-    "New password" : "وشەی نهێنی نوێ",
-    "Reset password" : "دووباره‌ كردنه‌وه‌ی وشه‌ی نهێنی",
     "Users" : "به‌كارهێنه‌ر",
     "Apps" : "به‌رنامه‌كان",
     "Admin" : "به‌ڕێوه‌به‌ری سه‌ره‌كی",
@@ -26,6 +27,8 @@ OC.L10N.register(
     "Database host" : "هۆستی داتابه‌یس",
     "Finish setup" : "كۆتایی هات ده‌ستكاریه‌كان",
     "Log out" : "چوونەدەرەوە",
-    "Search" : "بگەڕێ"
+    "Search" : "بگەڕێ",
+    "New password" : "وشەی نهێنی نوێ",
+    "Reset password" : "دووباره‌ كردنه‌وه‌ی وشه‌ی نهێنی"
 },
 "nplurals=2; plural=(n != 1);");
