@@ -1,29 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Klarte ikke å sende mail til følgende brukere: %s",
-    "Preparing update" : "Forbereder oppdatering",
-    "Turned on maintenance mode" : "Slo på vedlikeholdsmodus",
-    "Turned off maintenance mode" : "Slo av vedlikeholdsmodus",
-    "Maintenance mode is kept active" : "Vedlikeholdsmodus blir beholdt aktiv",
-    "Updating database schema" : "Oppdaterer database-skjemaet",
-    "Updated database" : "Oppdaterte databasen",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Sjekker om databaseskjemaet kan oppdateres (dette kan ta lang tid hvis databasens er stor)",
-    "Checked database schema update" : "Sjekket oppdatering av databaseskjema",
-    "Checking updates of apps" : "Ser etter oppdateringer av applikasjoner",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Sjekker om databaseskjemaet for %s kan oppdateres (dette kan ta lang tid hvis databasens er stor)",
-    "Checked database schema update for apps" : "Sjekket databaseskjema-oppdatering for apper",
-    "Updated \"%s\" to %s" : "Oppdaterte \"%s\" til %s",
-    "Repair warning: " : "Advarsel fra reparering: ",
-    "Repair error: " : "Feil ved reparering: ",
-    "Set log level to debug" : "Sett loggnivå til feilsøking",
-    "Reset log level" : "Nullstill loggnivå",
-    "Starting code integrity check" : "Starter sjekk av kode-integritet",
-    "Finished code integrity check" : "Ferdig med sjekk av kode-integritet",
-    "%s (3rdparty)" : "%s (3dje-part)",
-    "%s (incompatible)" : "%s (ikke kompatibel)",
-    "Following apps have been disabled: %s" : "Følgende apper har blitt deaktivert: %s",
-    "Already up to date" : "Allerede oppdatert",
     "Please select a file." : "Vennligst velg en fil.",
     "File is too big" : "Filen er for stor",
     "Invalid file provided" : "Ugyldig fil oppgitt",
@@ -37,10 +14,35 @@ OC.L10N.register(
     "Crop is not square" : "Beskjæringen er ikke kvadratisk",
     "Couldn't reset password because the token is invalid" : "Klarte ikke å tilbakestille passordet fordi token er ugyldig.",
     "Couldn't reset password because the token is expired" : "Klarte ikke å tilbakestille passordet fordi token er utløpt.",
-    "Couldn't send reset email. Please make sure your username is correct." : "Klarte ikke å sende e-post for tilbakestilling av passord. Sjekk at brukernavnet ditt er korrekt.",
-    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Klarte ikke å sende e-post for tilbakestilling av passord fordi det ikke finnes noen e-postadresse for dette brukernavnet. Kontakt administratoren din.",
+    "%s password changed successfully" : "%s passord ble endret",
     "%s password reset" : "%s tilbakestilling av passord",
     "Couldn't send reset email. Please contact your administrator." : "Klarte ikke å sende e-post for tilbakestilling. Kontakt administratoren.",
+    "Couldn't send mail to following users: %s " : "Klarte ikke å sende mail til følgende brukere: %s",
+    "Preparing update" : "Forbereder oppdatering",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "Advarsel fra reparering: ",
+    "Repair error: " : "Feil ved reparering: ",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Vennligst bruk kommandolinje-oppdatering fordi automatisk oppdatering er deaktivert i config.php.",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: Sjekker tabell %s",
+    "Turned on maintenance mode" : "Slo på vedlikeholdsmodus",
+    "Turned off maintenance mode" : "Slo av vedlikeholdsmodus",
+    "Maintenance mode is kept active" : "Vedlikeholdsmodus blir beholdt aktiv",
+    "Updating database schema" : "Oppdaterer database-skjemaet",
+    "Updated database" : "Oppdaterte databasen",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Sjekker om databaseskjemaet kan oppdateres (dette kan ta lang tid hvis databasens er stor)",
+    "Checked database schema update" : "Sjekket oppdatering av databaseskjema",
+    "Checking updates of apps" : "Ser etter oppdateringer av applikasjoner",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Sjekker om databaseskjemaet for %s kan oppdateres (dette kan ta lang tid hvis databasens er stor)",
+    "Checked database schema update for apps" : "Sjekket databaseskjema-oppdatering for apper",
+    "Updated \"%s\" to %s" : "Oppdaterte \"%s\" til %s",
+    "Set log level to debug" : "Sett loggnivå til feilsøking",
+    "Reset log level" : "Nullstill loggnivå",
+    "Starting code integrity check" : "Starter sjekk av kode-integritet",
+    "Finished code integrity check" : "Ferdig med sjekk av kode-integritet",
+    "%s (3rdparty)" : "%s (3dje-part)",
+    "%s (incompatible)" : "%s (ikke kompatibel)",
+    "Following apps have been disabled: %s" : "Følgende apper har blitt deaktivert: %s",
+    "Already up to date" : "Allerede oppdatert",
     "Sunday" : "Søndag",
     "Monday" : "Mandag",
     "Tuesday" : "Tirsdag",
@@ -88,6 +90,7 @@ OC.L10N.register(
     "Dec." : "Des.",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Det oppstod problemer med sjekk av kode-integritet. Mer informasjon…</a>",
     "Settings" : "Innstillinger",
+    "Problem loading page, reloading in 5 seconds" : "Problem med lasting av side, laster på nytt om 5 sekunder",
     "Saving..." : "Lagrer...",
     "Dismiss" : "Forkast",
     "seconds ago" : "for få sekunder siden",
@@ -119,40 +122,63 @@ OC.L10N.register(
     "Good password" : "Bra passord",
     "Strong password" : "Sterkt passord",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Web-serveren din er ikke satt opp til å tillate synkronisering av filer ennå, fordi WebDAV-grensesnittet ikke ser ut til å virke.",
-    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Web-serveren er ikke satt opp riktig for å oppløse \"{url}\". Mer informasjon finnes i <a target=\"_blank\" href=\"{docLink}\">dokumentasjonen</a>.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Web-serveren er ikke satt opp riktig for å oppløse \"{url}\". Mer informasjon finnes i <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentasjonen</a>.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Denne serveren har ingen fungerende internett-forbindelse. Dette betyr at noen funksjoner, som tilknytning av eksterne lagre, varslinger om oppdateringer eller installering av tredjeparts apper ikke vil virke. Fjerntilgang til filer og utsending av varsler på e-post vil kanskje ikke virke heller. Vi anbefaler å aktivere en internett-forbindelse for denne serveren hvis du vil ha full funksjonalitet.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Minne-cache er ikke konfigurert. Hvis det er mulig, installer et minne-cache for å forbedre ytelsen. Finn mer informasjon i <a target=\"_blank\" href=\"{docLink}\">dokumentasjonen</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandom kan ikke leses av PHP, noe som er sterkt frarådet av sikkerhetshensyn. Mer informasjon finnes i <a target=\"_blank\" href=\"{docLink}\">dokumentasjonen</a>.",
-    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "Din PHP-versjon ({version}) er ikke <a target=\"_blank\" href=\"{phpLink}\">støttet av PHP</a> lenger. Vi oppfordrer deg til å oppgradere din PHP-versjon for å nyte fordel av ytelses- og sikkerhetsoppdateringer som tilbys av PHP.",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Konfigurasjon av reverse proxy-headers er ikke korrekt, eller du aksesserer ownCloud fra en \"trusted proxy\". Hvis du ikke aksesserer ownCloud fra en \"trusted proxy\", er dette en sikkerhetsrisiko som kan la en angriper forfalske IP-addressen sin slik den oppfattes av ownCloud. Mer informasjon i <a target=\"_blank\" href=\"{docLink}\">dokumentasjonen</a>.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached er konfigurert som distribuert cache, men feil PHP-module \"memcache\" er installert. \\OC\\Memcache\\Memcached støtter bare \"memcached\" og ikke \"memcache\". Se <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki om begge modulene</a>.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Noen filer feilet integritets-sjekken. Informasjon for å løse problemet finnes i <a target=\"_blank\" href=\"{docLink}\">dokumentasjonen</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Liste med ugyldige filer…</a> / <a href=\"{rescanEndpoint}\">Skann på nytt…</a>)",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Minne-cache er ikke konfigurert. Installer et minne-cache for å forbedre ytelsen hvis det lar seg gjøre. Du finner mer informasjon i <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentasjonen</a>.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom kan ikke leses av PHP, noe som er sterkt frarådet av sikkerhetshensyn. Mer informasjon finnes i <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentasjonen</a>.",
+    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Du kjører PHP {version}. Vi anbefaler at du oppgraderer PHP-versjonen for å dra fordel av <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">ytelses- og sikkerhetsoppdateringer fra PHP Group</a> så snart din distribusjon tillater det.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Konfigurasjon av reverse proxy-headers er ikke korrekt, eller du aksesserer ownCloud fra en \"trusted proxy\". Hvis du ikke aksesserer ownCloud fra en \"trusted proxy\", er dette en sikkerhetsrisiko som kan la en angriper forfalske IP-addressen sin slik den oppfattes av ownCloud. Mer informasjon i <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentasjonen</a>.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached er konfigurert som distribuert cache, men feil PHP-modul \"memcache\" er installert. \\OC\\Memcache\\Memcached støtter var \"memcached\" og ikke \"memcache\". Se <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki om begge modulene</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Noen filer feilet integritets-sjekken. Informasjon for å løse problemet finnes i <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentasjonen</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Liste med ugyldige filer…</a> / <a href=\"{rescanEndpoint}\">Skann på nytt…</a>)",
     "Error occurred while checking server setup" : "Feil oppstod ved sjekking av server-oppsett",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Datamappen og filene dine er sannsynligvis tilgjengelige fra Internett. .htaccess-filen fungerer ikke. Vi anbefaler sterkt at du konfigurerer web-serveren slik at datamappen ikke kan aksesseres eller at du flytter datamappen ut av web-serverens dokumentrot.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "HTTP-header \"{header}\" er ikke konfigurert lik \"{expected}\". Dette kan være en sikkerhetsrisiko og vi anbefaler at denne innstillingen endres.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "HTTP header \"Strict-Transport-Security\" er ikke konfigurert til minst \"{seconds}\" sekunder. For beste sikkerhet anbefaler vi at HSTS aktiveres som beskrevet i <a href=\"{docUrl}\">sikkerhetstips</a>.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "HTTP header \"Strict-Transport-Security\" HTTP er ikke konfigurert til minst \"{seconds}\" sekunder. For beste sikkerhet anbefaler vi at HSTS aktiveres som beskrevet i <a href=\"{docUrl}\" rel=\"noreferrer\">sikkerhetstips</a>.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Du aksesserer denne nettsiden via HTTP. Vi anbefaler på det sterkeste at du konfigurerer serveren til å kreve HTTPS i stedet, som beskrevet i <a href=\"{docUrl}\">sikkerhetstips</a>.",
     "Shared" : "Delt",
     "Shared with {recipients}" : "Delt med {recipients}",
     "Error" : "Feil",
     "Error while sharing" : "Feil under deling",
     "Error while unsharing" : "Feil ved oppheving av deling",
-    "Error setting expiration date" : "Kan ikke sette utløpsdato",
     "The public link will expire no later than {days} days after it is created" : "Den offentlige lenken vil utløpe senest {days} dager etter at den lages",
     "Set expiration date" : "Sett utløpsdato",
     "Expiration" : "Utløpsdato",
     "Expiration date" : "Utløpsdato",
+    "Expiration date is required" : "Utløpsdato kreves",
+    "Delete {link}" : "Slett {link}",
+    "Remove link" : "Fjern lenke",
+    "{fileName} link" : "{fileName}-lenke",
+    "Link" : "Lenke",
+    "Create public link" : "Opprett offentlig lenke",
+    "Edit" : "Endre",
+    "Remove" : "Fjern",
+    "Click to copy to clipboard" : "Klikk for å kopiere til utklippstavlen",
+    "Social share" : "Deling på sosiale nettverk",
+    "There are currently no link shares, you can create one" : "Det er for øyeblikket ingen lenke-delinger. Du kan opprette en",
+    "Copied!" : "Kopiert!",
+    "Not supported!" : "Ikke støttet!",
+    "Press ⌘-C to copy." : "Trykk ⌘-C for å kopiere.",
+    "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere.",
     "Choose a password for the public link" : "Velg et passord for den offentlige lenken",
+    "Password required" : "Passord kreves",
+    "Filename" : "Filnavn",
+    "Password" : "Passord",
+    "Name" : "Navn",
+    "Allow editing" : "Tillat redigering",
+    "Edit link share: {name}" : "Rediger lenke-deling: {name}",
+    "Save" : "Lagre",
+    "Create link share: {name}" : "Opprett lenke-deling: {name}",
+    "Remove password" : "Fjern passord",
+    "Share to Twitter. Opens in a new window." : "Del på Twitter. Åpner et nytt vindu.",
+    "Share to Facebook. Opens in a new window." : "Del på Facebook. Åpner et nytt vindu.",
+    "Share to Diaspora. Opens in a new window." : "Del på Diaspora. Åpner et nytt vindu.",
+    "Share to Google+. Opens in a new window." : "Del på Google+. Åpner et nytt vindu.",
+    "Share via email. Opens your mail client." : "Del via e-post. Åpner epost-klienten din.",
+    "Error while sending notification" : "Feil ved sending av varsling",
     "Sending ..." : "Sender...",
     "Email sent" : "E-post sendt",
-    "Resharing is not allowed" : "Videre deling er ikke tillatt",
-    "Share link" : "Del lenke",
-    "Link" : "Lenke",
-    "Password protect" : "Passordbeskyttet",
-    "Password" : "Passord",
-    "Allow editing" : "Tillat redigering",
     "Email link to person" : "Email lenke til person",
-    "Send" : "Send",
+    "Send link via email" : "Send link i e-post",
     "Shared with you and the group {group} by {owner}" : "Delt med deg og gruppen {group} av {owner}",
     "Shared with you by {owner}" : "Delt med deg av {owner}",
     "group" : "gruppe",
@@ -168,42 +194,48 @@ OC.L10N.register(
     "Could not unshare" : "Kunne ikke avslutte deling",
     "Share details could not be loaded for this item." : "Klarte ikke å laste inn detaljer om deling for dette elementet.",
     "No users or groups found for {search}" : "Ingen brukere eller grupper funnet for {search}",
-    "An error occured. Please try again" : "Det oppstod en feil. Prøv igjen",
+    "No users found for {search}" : "Ingen brukere funnet for {search}",
+    "An error occurred. Please try again" : "Det oppstod en feil. Prøv igjen",
     "{sharee} (group)" : "{sharee} (gruppe)",
     "{sharee} (at {server})" : "{sharee} (på {server})",
     "{sharee} (remote)" : "{sharee} (ekstern)",
     "Share" : "Del",
+    "User and Groups" : "Bruker og grupper",
+    "Public Links" : "Offentlige lenker",
+    "Resharing is not allowed" : "Videre deling er ikke tillatt",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Del med personer på andre ownCloud-installasjoner med syntaksen brukernavn@example.com/owncloud",
-    "Share with users or groups …" : "Del med brukere eller grupper ...",
-    "Share with users, groups or remote users …" : "Del med brukere, grupper eller eksterne brukere ...",
+    "Share with users…" : "Del med brukere...",
+    "Share with users, groups or remote users…" : "Del med brukere, grupper eller eksterne brukere...",
+    "Share with users or groups…" : "Del med brukere eller grupper...",
+    "Share with users or remote users…" : "Del med brukere eller eksterne brukere...",
     "Error removing share" : "Feil ved fjerning av deling",
     "Warning" : "Advarsel",
-    "Error while sending notification" : "Feil ved sending av varsling",
-    "Non-existing tag #{tag}" : "Ikke-eksisterende merkelapp #{tag}",
-    "not assignable" : "kan ikke tilordnes",
+    "Non-existing tag #{tag}" : "Ikke-eksisterende stikkord #{tag}",
+    "restricted" : "begrenset",
     "invisible" : "usynlig",
     "({scope})" : "({scope})",
     "Delete" : "Slett",
     "Rename" : "Gi nytt navn",
-    "Collaborative tags" : "Felles merkelapper",
+    "Collaborative tags" : "Felles stikkord",
     "The object type is not specified." : "Objekttypen er ikke spesifisert.",
     "Enter new" : "Oppgi ny",
     "Add" : "Legg til",
-    "Edit tags" : "Rediger merkelapper",
+    "Edit tags" : "Rediger stikkord",
     "Error loading dialog template: {error}" : "Feil ved lasting av dialogmal: {error}",
-    "No tags selected for deletion." : "Ingen merkelapper valgt for sletting.",
+    "No tags selected for deletion." : "Ingen stikkord valgt for sletting.",
     "unknown text" : "ukjent tekst",
     "Hello world!" : "Hei, Verden!",
     "sunny" : "solfylt",
     "Hello {name}, the weather is {weather}" : "Hallo {name}, været er {weather}",
     "Hello {name}" : "Hallo {name}",
+    "new" : "ny",
     "_download %n file_::_download %n files_" : ["last ned %n fil","last ned %n filer"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "En oppdatering foregår, lukking av denne siden kan forstyrre prosessen for enkelte systemer.",
-    "Updating {productName} to version {version}, this may take a while." : "Oppdaterer {productName} til versjon {version}. Dette kan ta litt tid.",
+    "Updating to {version}" : "Oppdaterer til {version}",
     "An error occurred." : "En feil oppstod.",
     "Please reload the page." : "Vennligst last siden på nytt.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Oppdateringen var mislykket. For mer informasjon <a href=\"{url}\">se vår forum-artikkel</a> som beskriver dette problemet.",
-    "The update was unsuccessful. " : "Oppdateringen var mislykket.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Oppdateringen mislyktes. Vennligst rapporter dette problemet til <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud-fellesskapet</a>.",
     "The update was successful. There were warnings." : "Oppdateringen var vellykket. Det oppstod advarsler.",
     "The update was successful. Redirecting you to ownCloud now." : "Oppdateringen var vellykket. Du omdirigeres nå til ownCloud.",
     "Searching other places" : "Søker andre steder",
@@ -214,13 +246,6 @@ OC.L10N.register(
     "Apps" : "Apper",
     "Admin" : "Admin",
     "Help" : "Hjelp",
-    "Error loading tags" : "Feil ved lasting av merkelapper",
-    "Tag already exists" : "Merkelappen finnes allerede",
-    "Error deleting tag(s)" : "Feil ved sletting av merkelapp(er)",
-    "Error tagging" : "Feil ved merking",
-    "Error untagging" : "Feil ved fjerning av merkelapp",
-    "Error favoriting" : "Feil ved favorittmerking",
-    "Error unfavoriting" : "Feil ved fjerning av favorittmerking",
     "Access forbidden" : "Tilgang nektet",
     "File not found" : "Finner ikke filen",
     "The specified document has not been found on the server." : "Det angitte dokumentet ble ikke funnet på serveren.",
@@ -241,9 +266,6 @@ OC.L10N.register(
     "File: %s" : "Fil: %s",
     "Line: %s" : "Linje: %s",
     "Trace" : "Trace",
-    "Security warning" : "Sikkerhetsadvarsel",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Datamappen og filene dine er sannsynligvis tilgjengelig fra Internett fordi .htaccess-filen ikke fungerer.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "For informasjon om hvordan du setter opp serveren din riktig, se <a href=\"%s\" target=\"_blank\">dokumentasjonen</a>.",
     "Create an <strong>admin account</strong>" : "Opprett en <strong>administrator-konto</strong>",
     "Username" : "Brukernavn",
     "Storage & database" : "Lagring og database",
@@ -257,6 +279,7 @@ OC.L10N.register(
     "Database name" : "Databasenavn",
     "Database tablespace" : "Database tabellområde",
     "Database host" : "Databasevert",
+    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "Vennligst spesifiser portnummer sammen med tjenernavn (feks. localhost:5432).",
     "Performance warning" : "Ytelsesadvarsel",
     "SQLite will be used as database." : "SQLite vil bli brukt som database.",
     "For larger installations we recommend to choose a different database backend." : "For større installasjoner anbefaler vi å velge en annen database.",
@@ -271,14 +294,16 @@ OC.L10N.register(
     "Search" : "Søk",
     "Server side authentication failed!" : "Autentisering feilet på serveren!",
     "Please contact your administrator." : "Vennligst kontakt administratoren din.",
-    "An internal error occured." : "Det oppstod en intern feil.",
+    "An internal error occurred." : "Det oppstod en intern feil.",
     "Please try again or contact your administrator." : "Prøv igjen eller kontakt en administrator.",
+    "Username or email" : "Brukernavn eller e-post",
     "Log in" : "Logg inn",
     "Wrong password. Reset it?" : "Feil passord. Nullstille det?",
     "Wrong password." : "Feil passord.",
     "Stay logged in" : "Forbli innlogget",
     "Alternative Logins" : "Alternative innlogginger",
     "Use the following link to reset your password: {link}" : "Bruk følgende lenke for å tilbakestille passordet ditt: {link}",
+    "Password changed successfully" : "Passordet ble endret",
     "New password" : "Nytt passord",
     "New Password" : "Nytt passord",
     "Reset password" : "Tilbakestill passord",
@@ -286,22 +311,27 @@ OC.L10N.register(
     "This means only administrators can use the instance." : "Dette betyr at kun administratorer kan bruke instansen.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontakt systemadministratoren hvis denne meldingen var uventet eller ikke forsvinner.",
     "Thank you for your patience." : "Takk for din tålmodighet.",
-    "You are accessing the server from an untrusted domain." : "Du aksesserer serveren fra et ikke tiltrodd domene.",
+    "Two-step verification" : "To-stegs verifisering",
+    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Forbedret sikkerhet er aktivert for kontoen din. Vennligst bekreft med en faktor nummer to.",
+    "Cancel login" : "Avbryt innlogging",
+    "Please authenticate using the selected factor." : "Vennligst bekreft med valgt faktor",
+    "An error occurred while verifying the token" : "Det oppstod en feil ved verifisering av nøkkelen",
+    "You are accessing the server from an untrusted domain." : "Du aksesserer serveren fra et ikke-klarert domene.",
     "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Vennligst kontakt administratoren. Hvis du er administrator for denne instansen, konfigurer innstillingen \"trusted_domains\" i config/config.php. Et eksempel på konfigurasjon er gitt i config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Avhengig av konfigurasjonen kan du, som administrator, kanskje også bruke kanppen nedenfor til å stole på dette domenet.",
-    "Add \"%s\" as trusted domain" : "Legg til \"%s\" som et tiltrodd domene",
+    "Add \"%s\" as trusted domain" : "Legg til \"%s\" som et klarert domene",
     "App update required" : "App-oppdatering kreves",
     "%s will be updated to version %s" : "%s vil bli oppdatert til versjon %s",
     "These apps will be updated:" : "Disse appene vil bli oppdatert:",
-    "These incompatible apps will be disabled:" : "Disse ikke-kompatible appene vil bli deaktivert:",
-    "The theme %s has been disabled." : "Temaet %s har blitt deaktivert.",
+    "The theme %s has been disabled." : "Drakten %s har blitt avskrudd.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Forsikre deg om at databasen, config-mappen og datamappen er blitt sikkerhetskopiert før du fortsetter.",
     "Start update" : "Start oppdatering",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "For å unngå tidsavbrudd ved store installasjoner, kan du i stedet kjøre følgende kommando fra installasjonsmappen:",
+    "Detailed logs" : "Detaljerte logger",
+    "Update needed" : "Oppdatering kreves",
+    "Please use the command line updater because you have a big instance." : "Vennligst bruk kommandolinje-oppdatering fordi du har en stor instans.",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "For hjelp, se  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentasjonen</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Denne %s-instansen er for øyeblikket i vedlikeholdsmodus, noe som kan vare en stund.",
-    "This page will refresh itself when the %s instance is available again." : "Denne siden vil bli lastet på nytt når %s-instansen er tilgjengelig igjen.",
-    "Error loading file picker template: {error}" : "Feil ved lasting av filvelger-mal: {error}",
-    "Fri." : "Fr.",
-    "Password can not be changed. Please contact your administrator." : "Passordet kan ikke endres. Kontakt administratoren din."
+    "This page will refresh itself when the %s instance is available again." : "Denne siden vil bli lastet på nytt når %s-instansen er tilgjengelig igjen."
 },
 "nplurals=2; plural=(n != 1);");
