@@ -1,19 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Senden der E-Mail an folgende Benutzer fehlgeschlagen: %s",
-    "Preparing update" : "Bereite Aktualisierung vor",
-    "Turned on maintenance mode" : "Wartungsmodus eingeschaltet",
-    "Turned off maintenance mode" : "Wartungsmodus ausgeschaltet",
-    "Maintenance mode is kept active" : "Wartungsmodus wird fortgeführt",
-    "Updated database" : "Datenbank wurde aktualisiert",
-    "Checked database schema update" : "Datenbankschemaaktualisierung wurde geprüft",
-    "Checked database schema update for apps" : "Datenbankschemaaktualisierung für Apps wurde geprüft",
-    "Updated \"%s\" to %s" : "\"%s\" auf %s aktualisiert",
-    "Repair warning: " : "Reparaturwarnung",
-    "Repair error: " : "Reparaturfehler",
-    "Following apps have been disabled: %s" : "Folgende Apps wurden deaktiviert: %s",
-    "Already up to date" : "Bereits aktuell",
     "File is too big" : "Datei ist zu groß",
     "Invalid file provided" : "Ungültige Datei geliefert",
     "No image or file provided" : "Kein Bild oder keine Datei geliefert",
@@ -24,6 +11,19 @@ OC.L10N.register(
     "No valid crop data provided" : "Keine gültigen Angaben zum Zuschnitt geliefert",
     "Crop is not square" : "Zuschnitt ist nicht quadratisch",
     "Couldn't send reset email. Please contact your administrator." : "E-Mail zum Zurücksetzen konnte nicht gesendet werden. Bitte wende Dich an Deinem Administrator.",
+    "Couldn't send mail to following users: %s " : "Senden der E-Mail an folgende Benutzer fehlgeschlagen: %s",
+    "Preparing update" : "Bereite Aktualisierung vor",
+    "Repair warning: " : "Reparaturwarnung",
+    "Repair error: " : "Reparaturfehler",
+    "Turned on maintenance mode" : "Wartungsmodus eingeschaltet",
+    "Turned off maintenance mode" : "Wartungsmodus ausgeschaltet",
+    "Maintenance mode is kept active" : "Wartungsmodus wird fortgeführt",
+    "Updated database" : "Datenbank wurde aktualisiert",
+    "Checked database schema update" : "Datenbankschemaaktualisierung wurde geprüft",
+    "Checked database schema update for apps" : "Datenbankschemaaktualisierung für Apps wurde geprüft",
+    "Updated \"%s\" to %s" : "\"%s\" auf %s aktualisiert",
+    "Following apps have been disabled: %s" : "Folgende Apps wurden deaktiviert: %s",
+    "Already up to date" : "Bereits aktuell",
     "Sunday" : "Sonntag",
     "Monday" : "Montag",
     "Tuesday" : "Dienstag",
@@ -103,15 +103,28 @@ OC.L10N.register(
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Dieser Server ist nicht mit dem Internet verbunden. Das bedeutet, dass manche Funktionen, wie das Einbinden von externen Speichern, Benachrichtigungen über Aktualisierungen oder die Installation von Drittanbieter Apps nicht zur Verfügung stehen. Auch der Fernzugriff auf Dateien und das Senden von Hinweis-E-Mails könnte nicht funktionieren. Wir empfehlen die Internetverbindung dieses Servers zu aktivieren, wenn Du diese Funktionen nutzen möchtest.",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Der Zugriff auf Dein Datenverzeichnis und Deine Dateien ist über das Internet vermutlich möglich. Die .htaccess-Datei greift nicht. Wir empfehlen dringend den Webserver derart zu konfigurieren, dass das Datenverzeichnis nicht mehr zugreifbar ist oder das Datenverzeichnis nach außerhalb des Dokumentenwurzelverzeichnisses des Webservers zu verschieben.",
     "Error" : "Fehler",
+    "Error while sharing" : "Fehler beim Teilen",
+    "Set expiration date" : "Setze ein Auslaufdatum",
+    "Expiration date" : "Auslaufdatum",
+    "Link" : "Link",
+    "Choose a password for the public link" : "Wähle ein Passwort für den öffentlichen Link",
     "Password" : "Passwort",
-    "Send" : "Senden",
+    "Name" : "Name",
+    "Allow editing" : "Erlaube bearbeiten",
+    "Sending ..." : "Sende...",
+    "Email sent" : "eMail gesendet",
+    "Email link to person" : "Sende diesen Link zu einer Person",
+    "Shared with you by {owner}" : "Von {owner} mit dir geteilt",
+    "group" : "Gruppe",
     "can share" : "kann teilen",
     "can edit" : "kann editieren",
+    "change" : "Verändern",
+    "delete" : "Löschen",
     "Share" : "Teilen",
+    "Resharing is not allowed" : "Weiterteilen ist nicht erlaubt",
+    "Warning" : "Warnung",
     "Delete" : "Löschen",
     "Personal" : "Persönlich",
-    "Username" : "Benutzername",
-    "Error loading file picker template: {error}" : "Fehler beim Laden der Vorlage zum Auswählen von Dateien: {error}",
-    "Password can not be changed. Please contact your administrator." : "Das Passwort kann nicht geändert werden. Bitte wende Dich an Deinen Administrator."
+    "Username" : "Benutzername"
 },
 "nplurals=2; plural=(n != 1);");
