@@ -1,24 +1,46 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Impossible de mandar un corrièl als utilizaires seguents : %s",
-    "Turned on maintenance mode" : "Mòde de mantenença activat",
-    "Turned off maintenance mode" : "Mòde de mantenença desactivat",
-    "Updated database" : "Banca de donadas mesa a jorn",
-    "Checked database schema update" : "Mesa a jorn de l'esquèma de la banca de donadas verificada",
-    "Checked database schema update for apps" : "Mesa a jorn de l'esquèma de la banca de donadas per las aplicacions verificada",
-    "Updated \"%s\" to %s" : "Mesa a jorn de « %s » cap a %s",
-    "Repair warning: " : "Avertiment de reparacion :",
-    "Repair error: " : "Error de reparacion :",
-    "Following incompatible apps have been disabled: %s" : "Las aplicacions incompatiblas seguentas son estadas desactivadas : %s",
+    "Please select a file." : "Seleccionatz un fichièr.",
+    "File is too big" : "Fichièr tròp voluminós",
     "Invalid file provided" : "Fichièr invalid",
     "No image or file provided" : "Cap de fichièr pas provesit",
     "Unknown filetype" : "Tipe de fichièr desconegut",
     "Invalid image" : "Imatge pas valable",
+    "An error occurred. Please contact your admin." : "Una error s'es produita. Contactatz vòstre administrator.",
     "No temporary profile picture available, try again" : "Cap d'imatge temporari pas disponible pel profil. Ensajatz tornamai.",
     "No crop data provided" : "Cap de donada de requadratge pas provesida",
     "No valid crop data provided" : "Donadas de requadratge invalidas",
     "Crop is not square" : "Lo requadratge es pas carrat",
+    "Couldn't reset password because the token is invalid" : "Impossible de reïnicializar lo senhal perque lo geton es pas valable.",
+    "Couldn't reset password because the token is expired" : "Impossible de reïnicializar lo senhal perque lo geton a expirat.",
+    "%s password reset" : "Reïnicializacion de vòstre senhal %s",
+    "Couldn't send reset email. Please contact your administrator." : "Impossible de mandar lo corrièl de reïnicializacion. Contactatz vòstre administrator.",
+    "Couldn't send mail to following users: %s " : "Impossible de mandar un corrièl als utilizaires seguents : %s",
+    "Preparing update" : "Preparacion de la mesa a jorn",
+    "[%d / %d]: %s" : "[%d / %d] : %s",
+    "Repair warning: " : "Avertiment de reparacion :",
+    "Repair error: " : "Error de reparacion :",
+    "[%d / %d]: Checking table %s" : "[%d / %d] : Verificacion de la taula %s",
+    "Turned on maintenance mode" : "Mòde de mantenença activat",
+    "Turned off maintenance mode" : "Mòde de mantenença desactivat",
+    "Maintenance mode is kept active" : "Lo mòde de mantenença es daissat actiu",
+    "Updating database schema" : "Mesa a jorn de l'esquèma de la banca de donadas",
+    "Updated database" : "Basa de donadas mesa a jorn",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Verificacion de la possibilitat de metre a jorn l'esquèma de la basa de donadas (aquò pòt prene un certan temps que depend de la talha de la banca de donadas)",
+    "Checked database schema update" : "Mesa a jorn de l'esquèma de la banca de donadas verificada",
+    "Checking updates of apps" : "Recèrca de mesas a jorn d'aplicacions",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Verificacion de la possibilitat de metre a jorn l'esquèma de la basa de donadas per %s (aquò pòt préner un certan temps que depend de la talha de la banca de donadas)",
+    "Checked database schema update for apps" : "Mesa a jorn de l'esquèma de la basa de donadas per las aplicacions verificada",
+    "Updated \"%s\" to %s" : "Mesa a jorn de « %s » cap a %s",
+    "Set log level to debug" : "Reglatge del nivèl de jornalizacion de \"desbugar\"",
+    "Reset log level" : "Reïnicializacion del nivèl de jornalizacion",
+    "Starting code integrity check" : "Aviada de la verificacion d'integritat del còdi",
+    "Finished code integrity check" : "Fin de la verificacion d’integritat del còdi",
+    "%s (3rdparty)" : "%s (origina tèrça)",
+    "%s (incompatible)" : "%s (incompatible)",
+    "Following apps have been disabled: %s" : "Las aplicacions seguentas son estadas desactivadas : %s",
+    "Already up to date" : "Ja a jorn",
     "Sunday" : "Dimenge",
     "Monday" : "Diluns",
     "Tuesday" : "Dimars",
@@ -27,24 +49,31 @@ OC.L10N.register(
     "Friday" : "Divendres",
     "Saturday" : "Dissabte",
     "Sun." : "Dim.",
-    "Mon." : "Luns.",
-    "Tue." : "Març.",
-    "Wed." : "Mec.",
+    "Mon." : "Lun.",
+    "Tue." : "Mar.",
+    "Wed." : "Mèc.",
     "Thu." : "Jòu.",
     "Fri." : "Ven.",
     "Sat." : "Sab.",
-    "January" : "genièr",
-    "February" : "febrièr",
-    "March" : "març",
-    "April" : "abril",
-    "May" : "mai",
-    "June" : "junh",
-    "July" : "julhet",
-    "August" : "agost",
-    "September" : "setembre",
-    "October" : "octobre",
-    "November" : "novembre",
-    "December" : "decembre",
+    "Su" : "Di",
+    "Mo" : "Lu",
+    "Tu" : "Ma",
+    "We" : "Mè",
+    "Th" : "Jò",
+    "Fr" : "Ve",
+    "Sa" : "Sa",
+    "January" : "Genièr",
+    "February" : "Febrièr",
+    "March" : "Març",
+    "April" : "Abril",
+    "May" : "Mai",
+    "June" : "Junh",
+    "July" : "Julhet",
+    "August" : "Agost",
+    "September" : "Setembre",
+    "October" : "Octobre",
+    "November" : "Novembre",
+    "December" : "Decembre",
     "Jan." : "Gen.",
     "Feb." : "Feb.",
     "Mar." : "Mar.",
@@ -53,14 +82,14 @@ OC.L10N.register(
     "Jun." : "Jun.",
     "Jul." : "Jul.",
     "Aug." : "Ago.",
-    "Sep." : "Sep.",
+    "Sep." : "Set.",
     "Oct." : "Oct.",
     "Nov." : "Nov.",
     "Dec." : "Dec.",
     "Settings" : "Paramètres",
     "Saving..." : "Enregistrament…",
+    "Dismiss" : "Ignorar",
     "seconds ago" : "i a qualques segondas",
-    "Couldn't send reset email. Please contact your administrator." : "Impossible de mandar lo corrièl de reïnicializacion. Contactatz vòstre administrator.",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Lo ligam que permet de reïnicializar vòstre senhal ven d'èsser mandat a vòstra adreça de corrièl.<br>Se o recebètz pas dins un relambi rasonable, contactatz vòstre administrator.<br>Doblidetz pas de verificar dins vòstre dorsièr corrièr indesirable / spam!",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Vòstres fichièrs son chifrats. Se avètz pas activat la clau de recuperacion, i aurà pas cap de mejan de recuperar vòstras donadas un còp lo senhal reïnicializat.<br />Se sètz pas segur(a) de çò que fasètz, contactatz vòstre administrator abans de contunhar. <br />Sètz segur que volètz contunhar ?",
     "I know what I'm doing" : "Sabi çò que fau",
@@ -90,36 +119,44 @@ OC.L10N.register(
     "Strong password" : "Senhal fòrt",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Vòstre servidor web es pas corrèctament configurat per la sincronizacion de fichièrs : sembla que l'interfàcia WebDAV fonciona pas.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Aqueste servidor se pòt pas connectar a internet. Aquò significa que certanas foncionalitats, talas coma lo montatge de supòrts d'emmagazinatge distants, las notificacions de mesas a jorn o l'installacion d'aplicacions tèrças foncionaràn pas. L'accès als fichièrs a distància, e tanben las notificacions per mail pòdon tanben èsser indisponiblas. Es recomandat d'activar la connexion internet per aqueste servidor se volètz dispausar de l'ensemble de las foncionalitats ofèrtas.",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Vòstre dorsièr de donadas e vòstres fichièrs son probablament accessibles dempuèi internet. Lo fichièr .htaccess fonciona pas. Vos recomandam bravament de configurar vòstre servidor web de manièra qu'aqueste dorsièr de donadas siá pas mai accessible, o de lo desplaçar en defòra de la raiç del servidor web.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Cap d'escondedor de la memòria es pas configurat. Se possible, configuratz un \"memcache\" per aumentar las performàncias. Per mai d'information consultatz la <a href=\"{docLink}\">documentacion</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "/dev/urandom es pas legible per PHP, aquò es bravament desconselhat per de rasons de seguretat. Mai d'informacions pòdon èsser trobadas dins nòstra <a href=\"{docLink}\">documentacion</a>.",
     "Error occurred while checking server setup" : "Una error s'es produsida al moment de la verificacion de la configuracion del servidor",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Vòstre dorsièr de donadas e vòstres fichièrs son probablament accessibles dempuèi internet. Lo fichièr .htaccess fonciona pas. Vos recomandam bravament de configurar vòstre servidor web de manièra qu'aqueste dorsièr de donadas siá pas mai accessible, o de lo desplaçar en defòra de la raiç del servidor web.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "L'entèsta HTTP \"{header}\" es pas configurada per èsser egala a \"{expected}\" en creant potencialament un risc religat a la seguretat e a la vida privada. Es doncas recomandat d'ajustar aqueste paramètre.",
+    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Accedissètz a aqueste site via HTTP. Vos recomandam fòrtament de configurar vòstre servidor per forçar l'utilizacion de HTTPS, coma explicat dins nòstre <a href=\"{docUrl}\">Guida pel renfortiment e la seguretat</a>.",
     "Shared" : "Partejat",
     "Shared with {recipients}" : "Partejat amb {recipients}",
     "Error" : "Error",
     "Error while sharing" : "Error al moment de la mesa en partiment",
     "Error while unsharing" : "Error al moment de l'anullacion del partiment",
-    "Error while changing permissions" : "Error al moment del cambiament de las permissions",
-    "Error setting expiration date" : "Error al moment de l'especificacion de la data d'expiracion",
     "The public link will expire no later than {days} days after it is created" : "Aqueste ligam public expirarà al mai tard {days} jorns aprèp sa creacion.",
     "Set expiration date" : "Especificar una data d'expiracion",
     "Expiration" : "Expiracion",
     "Expiration date" : "Data d'expiracion",
+    "Link" : "Ligam",
+    "Edit" : "Modificar",
+    "Remove" : "Suprimir",
+    "Copied!" : "Copiat !",
+    "Not supported!" : "Pas suportat !",
+    "Press ⌘-C to copy." : "Quichar sus ⌘-C per copiar.",
+    "Press Ctrl-C to copy." : "Quichar sus Ctrl-C per copiar.",
+    "Choose a password for the public link" : "Causissètz un senhal pel ligam public",
+    "Filename" : "Nom del fichièr",
+    "Password" : "Senhal",
+    "Name" : "Nom",
+    "Allow editing" : "Permetre la modificacion",
+    "Save" : "Enregistrar",
+    "Share to Twitter. Opens in a new window." : "Partejar sus Twitter. Dobrís una novèla fenèstra.",
+    "Share to Facebook. Opens in a new window." : "Partejar sus Facebook. Dobrís una novèla fenèstra.",
+    "Share to Diaspora. Opens in a new window." : "Partejar sus Diaspora. Dobrís una novèla fenèstra.",
+    "Share to Google+. Opens in a new window." : "Partejar sus Google+. Dobrís una novèla fenèstra.",
+    "Share via email. Opens your mail client." : "Partejar per corrièr electronic. Dobrís una novèla fenèstra.",
+    "Error while sending notification" : "Error al moment del mandadís de la notificacion",
     "Sending ..." : "Mandadís…",
     "Email sent" : "Corrièl mandat",
-    "Resharing is not allowed" : "Lo repartiment es pas autorizat",
-    "Share link" : "Partejar per ligam public",
-    "Link" : "Ligam",
-    "Password protect" : "Protegir per un senhal",
-    "Password" : "Senhal",
-    "Choose a password for the public link" : "Causissètz un senhal pel ligam public",
-    "Allow editing" : "Permetre la modificacion",
     "Email link to person" : "Mandar lo ligam per corrièl",
-    "Send" : "Mandar",
+    "Send link via email" : "Mandar lo ligam per mail",
     "Shared with you and the group {group} by {owner}" : "Partejat amb vos e lo grop {group} per {owner}",
     "Shared with you by {owner}" : "Partejat amb vos per {owner}",
-    "Shared in {item} with {user}" : "Partejat dins {item} amb {user}",
     "group" : "grop",
     "remote" : "distant",
     "notify by email" : "notificar per corrièl",
@@ -130,15 +167,26 @@ OC.L10N.register(
     "change" : "modificacion",
     "delete" : "suprimir",
     "access control" : "contraròtle d'accès",
-    "An error occured. Please try again" : "Una error s'es produsida. Mercé d'ensajar tornamai",
+    "Could not unshare" : "Impossible d'arrestar de partejar",
+    "Share details could not be loaded for this item." : "Las informacions de partiment an pas pogut èsser cargadas per aqueste element.",
+    "{sharee} (group)" : "{sharee} (grop)",
+    "{sharee} (at {server})" : "{sharee} (sus {server})",
+    "{sharee} (remote)" : "{sharee} (distant)",
     "Share" : "Partejar",
+    "Resharing is not allowed" : "Lo repartiment es pas autorizat",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Partejatz amb de personas sus d'autres ownClouds en utilizant la sintaxi utilizaire@exemple.com/owncloud",
-    "Share with users or groups …" : "Partejar amb d'utilizaires o gropes...",
-    "Share with users, groups or remote users …" : "Partejar amb d'utilizaires, gropes, o utilizaires distants",
+    "Share with users…" : "Partejar amb d'utilizaires...",
+    "Error removing share" : "Error al moment de l'arrèst del partiment",
     "Warning" : "Atencion",
+    "Non-existing tag #{tag}" : "Etiqueta #{tag} inexistenta",
+    "restricted" : "Restrent",
+    "invisible" : "invisible",
+    "({scope})" : "({scope})",
+    "Delete" : "Suprimir",
+    "Rename" : "Renomenar",
+    "Collaborative tags" : "Etiquetas collaborativas",
     "The object type is not specified." : "Lo tipe d'objècte es pas especificat.",
     "Enter new" : "Picar un novèl",
-    "Delete" : "Suprimir",
     "Add" : "Apondre",
     "Edit tags" : "Modificar las etiquetas",
     "Error loading dialog template: {error}" : "Error al moment del cargament del modèl de dialòg : {error}",
@@ -148,33 +196,22 @@ OC.L10N.register(
     "sunny" : "ensolelhat",
     "Hello {name}, the weather is {weather}" : "Bonjorn {name}, lo temps es {weather}",
     "Hello {name}" : "Adiu {name}",
+    "new" : "Novèl",
     "_download %n file_::_download %n files_" : ["Telecargar %n fichièr","Telecargar %n fichièrs"],
-    "{version} is available. Get more information on how to update." : "La version {version} es disponibla. Obtenètz mai d'informacions a prepaus d'aquesta mesa a jorn.",
-    "Updating {productName} to version {version}, this may take a while." : "La mesa a jorn de {productName} cap a la version {version} es en cors. Aquò pòt prene un certan temps.",
+    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "La mesa a jorn es en cors. Segon la configuracion, lo fach de quitar aquesta pagina pòt entraïnar l'interrupcion de la procedura.",
+    "Updating to {version}" : "En cors de mesa a jorn cap a la version {version}",
+    "An error occurred." : "Una error s'es produsida.",
     "Please reload the page." : "Recargatz la pagina.",
-    "The update was unsuccessful. " : "La mesa a jorn a fracassat.",
+    "The update was successful. There were warnings." : "La mesa a jorn a capitat, mas i a agut d'avertiments",
     "The update was successful. Redirecting you to ownCloud now." : "La mesa a jorn a capitat. Ara sètz redirigit cap a ownCloud.",
-    "Couldn't reset password because the token is invalid" : "Impossible de reïnicializar lo senhal perque lo geton es pas valable.",
-    "Couldn't send reset email. Please make sure your username is correct." : "Impossible de mandar lo corrièl de reïnicializacion. Verificatz que vòstre nom d'utilizaire es corrècte.",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Impossible de mandar lo corrièl de reïnicializacion perque i a pas cap d'adreça de corrièl per aqueste utilizaire. Contactatz vòstre administrator.",
-    "%s password reset" : "Reïnicializacion de vòstre senhal %s",
-    "Use the following link to reset your password: {link}" : "Utilizatz lo ligam seguent per reïnicializar vòstre senhal : {link}",
-    "New password" : "Senhal novèl",
-    "New Password" : "Senhal novèl",
-    "Reset password" : "Reïnicializar lo senhal",
     "Searching other places" : "Recèrca en cors dins d'autres emplaçaments",
+    "No search results in other folders" : "Pas cap de resultat dins d'autres dorsièrs",
+    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} resultat dins un autre dorsièr","{count} resultats dins d'autres dorsièrs"],
     "Personal" : "Personal",
     "Users" : "Utilizaires",
     "Apps" : "Aplicacions",
     "Admin" : "Administracion",
     "Help" : "Ajuda",
-    "Error loading tags" : "Error al moment del cargament de las etiquetas",
-    "Tag already exists" : "L'etiqueta existís ja.",
-    "Error deleting tag(s)" : "Error de supression d'etiqueta(s)",
-    "Error tagging" : "Error al moment de l'etiquetatge",
-    "Error untagging" : "Error al moment del desetiquetatge",
-    "Error favoriting" : "Error al moment de la mesa en favorit",
-    "Error unfavoriting" : "Error al moment de la supression dels favorits",
     "Access forbidden" : "Accès interdich",
     "File not found" : "Fichièr pas trobat",
     "The specified document has not been found on the server." : "Impossible de trobar lo document especificat sul servidor.",
@@ -195,9 +232,6 @@ OC.L10N.register(
     "File: %s" : "Fichièr : %s",
     "Line: %s" : "Linha : %s",
     "Trace" : "Traça",
-    "Security warning" : "Avertiment de seguretat",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Vòstre repertòri de donadas es segurament accessible dempuèi l'internet perque lo fichièr .htaccess fonciona pas.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Per las informacions de configuracion de vòstre servidor, legissètz la <a href=\"%s\" target=\"_blank\">documentacion</a>.",
     "Create an <strong>admin account</strong>" : "Crear un <strong>compte administrator</strong>",
     "Username" : "Nom d'utilizaire",
     "Storage & database" : "Emmagazinatge & banca de donadas",
@@ -219,29 +253,42 @@ OC.L10N.register(
     "Finishing …" : "Finalizacion …",
     "Need help?" : "Besonh d'ajuda ?",
     "See the documentation" : "Legir la documentacion",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Bonjorn,<br><br>Vos informam que %s a partejat <strong>%s</strong> amb vos.<br><a href=\"%s\">Clicatz aicí per i accedir !</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aquesta aplicacion requerís JavaScript per foncionar corrèctament. {linkstart}Activatz JavaScript{linkend} e recargatz la pagina.",
     "Log out" : "Se desconnectar",
     "Search" : "Recercar",
     "Server side authentication failed!" : "L'autentificacion sul servidor a fracassat !",
     "Please contact your administrator." : "Contactatz vòstre administrator.",
-    "An internal error occured." : "Una error intèrna s'es produsida.",
+    "An internal error occurred." : "Una error intèrna s'es produita.",
     "Please try again or contact your administrator." : "Reensajatz o contactatz vòstre administrator.",
+    "Username or email" : "Nom d'utilizaire o e-mail",
     "Log in" : "Connexion",
-    "remember" : "se remembrar de ieu",
+    "Wrong password. Reset it?" : "Senhal incorrècte. Reïnicializar ?",
+    "Wrong password." : "Senhal incorrècte.",
+    "Stay logged in" : "Demorar connectat",
     "Alternative Logins" : "Identificants alternatius",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Bonjorn,<br><br>Vos informam que %s a partejat <strong>%s</strong> amb vos.<br><a href=\"%s\">Clicatz aicí per i accedir !</a><br><br>",
+    "Use the following link to reset your password: {link}" : "Utilizatz lo ligam seguent per reïnicializar vòstre senhal : {link}",
+    "New password" : "Senhal novèl",
+    "New Password" : "Senhal novèl",
+    "Reset password" : "Reïnicializar lo senhal",
     "This ownCloud instance is currently in single user mode." : "Aquesta instància de ownCloud es actualament en mòde utilizaire unic.",
     "This means only administrators can use the instance." : "Aquò significa que sols los administrators pòdon utilizar l'instància.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contactatz vòstre administrator sistèma se aqueste messatge persistís o apareis de faiçon imprevista.",
     "Thank you for your patience." : "Mercé de vòstra paciéncia.",
+    "Two-step verification" : "Verificacion en doas etapas",
+    "Cancel login" : "Anullar la connexion",
     "You are accessing the server from an untrusted domain." : "Accedissètz al servidor a partir d'un domeni pas aprovat.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Contactatz vòstre administrator. Se sètz administrator d'aquesta instància, configuratz lo paramètre « trusted_domain » dins lo fichièr config/config.php. Un exemple de configuracion es provesit dins lo fichièr config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "En foncion de vòstra configuracion, en tant qu'administrator podètz tanben utilizar lo boton çaijós per aprovar aqueste domeni.",
     "Add \"%s\" as trusted domain" : "Apondre \"%s\" a la lista dels domenis aprovats",
+    "App update required" : "Mesa a jorn de l'aplicacion necessària",
+    "%s will be updated to version %s" : "%s serà mes a jorn cap a la version %s.",
+    "These apps will be updated:" : "Las aplicacions seguentas seràn mesas a jorn :",
     "The theme %s has been disabled." : "Lo tèma %s es estat desactivat.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Asseguratz-vos qu'una còpia de salvament de la banca de donadas, del dorsièr de configuracion (config) e del dorsièr de donadas (data) es estat realizada abans de començar.",
     "Start update" : "Aviar la mesa a jorn",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Per fin d'evitar los timeouts amb las installacions de volum consequent, podètz executar la comanda seguenta dempuèi lo repertòri d'installacion :",
+    "Detailed logs" : "Jornals detalhats",
+    "Update needed" : "Mesa a jorn necessària",
     "This %s instance is currently in maintenance mode, which may take a while." : "Aquesta instància de %s es en cors de mantenença, aquò pòt prene de temps.",
     "This page will refresh itself when the %s instance is available again." : "Aquesta pagina se refrescarà d'ela-meteissa quand l'instància %s serà disponibla tornamai."
 },
