@@ -1,29 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Não foi possível enviar e-mail para os seguintes usuários: %s",
-    "Preparing update" : "Preparando atualização",
-    "Turned on maintenance mode" : "Ativar modo de manutenção",
-    "Turned off maintenance mode" : "Desligar o modo de manutenção",
-    "Maintenance mode is kept active" : "O modo de manutenção está sendo mantido como ativo",
-    "Updating database schema" : "Actualização de esquema do banco de dados",
-    "Updated database" : "Atualizar o banco de dados",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Verificar se o esquema do banco de dados pode ser atualizado (isso pode levar muito tempo, dependendo do tamanho do banco de dados)",
-    "Checked database schema update" : "Verificado atualização do esquema de banco de dados",
-    "Checking updates of apps" : "Verificar atualizações de aplicativos",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Verificar se o esquema do banco de dados para %s pode ser atualizado (isso pode levar muito tempo, dependendo do tamanho do banco de dados)",
-    "Checked database schema update for apps" : "Verificar atualização do esquema de banco de dados para aplicativos",
-    "Updated \"%s\" to %s" : "Atualizado \"%s\" para %s",
-    "Repair warning: " : "Aviso de reparação:",
-    "Repair error: " : "Reparação de erro:",
-    "Set log level to debug" : "Definir o nível de log para debug",
-    "Reset log level" : "Redefinição do nível do log",
-    "Starting code integrity check" : "Inicializando verificação da integridade do código",
-    "Finished code integrity check" : "Finalizada a verificação de integridade do código",
-    "%s (3rdparty)" : "%s (3ºterceiros)",
-    "%s (incompatible)" : "%s (incompatível)",
-    "Following apps have been disabled: %s" : "Os seguintes aplicativos foram desabilitados: %s",
-    "Already up to date" : "Já está atualizado",
     "Please select a file." : "Por favor selecione um arquivo.",
     "File is too big" : "O arquivo é muito grande",
     "Invalid file provided" : "Arquivo fornecido inválido",
@@ -37,10 +14,35 @@ OC.L10N.register(
     "Crop is not square" : "Recorte não é quadrado",
     "Couldn't reset password because the token is invalid" : "Não foi possível redefinir a senha porque o token é inválido",
     "Couldn't reset password because the token is expired" : "Não foi possível redefinir a senha porque o token expirou",
-    "Couldn't send reset email. Please make sure your username is correct." : "Não foi possível enviar e-mail de redefinição. Verifique se o seu nome de usuário está correto.",
-    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Não foi possível enviar email de redefinição porque não há nenhum endereço de e-mail para este nome de usuário. Entre em contato com o administrador.",
+    "%s password changed successfully" : "%s senha alterada com sucesso",
     "%s password reset" : "%s redefinir senha",
     "Couldn't send reset email. Please contact your administrator." : "Não foi possível enviar e-mail de redefinição. Por favor, contate o administrador.",
+    "Couldn't send mail to following users: %s " : "Não foi possível enviar e-mail para os seguintes usuários: %s",
+    "Preparing update" : "Preparando atualização",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "Aviso de reparação:",
+    "Repair error: " : "Reparação de erro:",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Por favor, use a atualização de linha de comando, porque a atualização automática está desativado no config.php.",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: Verificando tabela %s",
+    "Turned on maintenance mode" : "Ativar modo de manutenção",
+    "Turned off maintenance mode" : "Desligar o modo de manutenção",
+    "Maintenance mode is kept active" : "O modo de manutenção está sendo mantido como ativo",
+    "Updating database schema" : "Actualização de esquema do banco de dados",
+    "Updated database" : "Atualizar o banco de dados",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Verificar se o esquema do banco de dados pode ser atualizado (isso pode levar muito tempo, dependendo do tamanho do banco de dados)",
+    "Checked database schema update" : "Verificado atualização do esquema de banco de dados",
+    "Checking updates of apps" : "Verificar atualizações de aplicativos",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Verificar se o esquema do banco de dados para %s pode ser atualizado (isso pode levar muito tempo, dependendo do tamanho do banco de dados)",
+    "Checked database schema update for apps" : "Verificar atualização do esquema de banco de dados para aplicativos",
+    "Updated \"%s\" to %s" : "Atualizado \"%s\" para %s",
+    "Set log level to debug" : "Definir o nível de log para debug",
+    "Reset log level" : "Redefinição do nível do log",
+    "Starting code integrity check" : "Inicializando verificação da integridade do código",
+    "Finished code integrity check" : "Finalizada a verificação de integridade do código",
+    "%s (3rdparty)" : "%s (3ºterceiros)",
+    "%s (incompatible)" : "%s (incompatível)",
+    "Following apps have been disabled: %s" : "Os seguintes aplicativos foram desabilitados: %s",
+    "Already up to date" : "Já está atualizado",
     "Sunday" : "Domingo",
     "Monday" : "Segunda-feira",
     "Tuesday" : "Terça-feira",
@@ -88,6 +90,7 @@ OC.L10N.register(
     "Dec." : "Dez.",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Houve problemas com a verificação de integridade do código. Mais informações…</a>",
     "Settings" : "Configurações",
+    "Problem loading page, reloading in 5 seconds" : "Problema no carregamento da página, recarregando em 5 segundos",
     "Saving..." : "Salvando...",
     "Dismiss" : "Dispensar",
     "seconds ago" : "segundos atrás",
@@ -119,40 +122,65 @@ OC.L10N.register(
     "Good password" : "Boa senha",
     "Strong password" : "Senha forte",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Seu servidor web ainda não está configurado corretamente para permitir a sincronização de arquivos, pois a interface WebDAV parece ser desconfigurada.",
-    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "O seu servidor web não está configurado corretamente para resolver \"{url}\". Mais informações podem ser encontradas em nossa <a target=\"_blank\" href=\"{docLink}\">documentação</a>.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Seu servidor web não está configurado corretamente para resolver \"{url}\". Mais informação pode ser encontrada na nossa <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentação</a>.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Este servidor não tem nenhuma conexão com a Internet. Isto significa que algumas das características como a montagem de armazenamento externo, notificações sobre atualizações ou instalação de aplicativos de terceiros não vai funcionar. Acessar arquivos remotamente e envio de e-mails de notificação pode não funcionar, também. Sugerimos permitir conexão com a Internet para este servidor, se você quer ter todas as funcionalidades.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Nenhuma memória cache foi configurada. Para melhorar o seu desempenho, por favor configure um cache de memória, se disponível. Mais informação podem ser encontradas em nossa <a target=\"_blank\" href=\"{docLink}\">documentação</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandom não pode ser lido pelo PHP o que é altamente desencorajado por razões de segurança. Mais informações podem ser encontradas na nossa <a target=\"_blank\" href=\"{docLink}\">documentação</a>.",
-    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "A sua versão do PHP ({version}) não é mais <a target=\"_blank\" href=\"{phpLink}\">suportada pelo PHP</a>. Nós o incentivamos a atualizar sua versão do PHP para tirar proveito de atualizações de desempenho e de segurança fornecidas pelo PHP.",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "A configuração de cabeçalhos do proxy reverso está incorreta, ou você está acessando ownCloud de um proxy confiável. Se você não está acessando ownCloud de um proxy confiável, esta é uma questão de segurança e pode permitir a um invasor falsificar seu endereço IP como visível para ownCloud. Mais informação pode ser encontrada na nossa <a target=\"_blank\" href=\"{docLink}\">documentação</a>.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached está configurado como cache distribuído, mas o módulo PHP \"memcache\" errado está instalado. \\OC\\Memcache\\Memcached suporta apenas \"memcached\" e não \"memcache\". Veja a <a target=\"_blank\" href=\"{wikiLink}\">o wiki sobre memcached sobre ambos os módulos</a>.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Alguns arquivos não passaram na verificação de integridade. Mais informações sobre como resolver este problema podem ser encontradas na nossa <a target=\"_blank\" href=\"{docLink}\">documentação</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Lista de arquivos inválidos…</a> / <a href=\"{rescanEndpoint}\">Reexaminar…</a>)",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Nenhum cache de memória foi configurado. Para melhorar o seu desempenho, por favor configurar um memcached se disponível. Mais informação pode ser encontrada na nossa <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentação</a>.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom não pode ser lido pelo PHP e é altamente desencorajado por razões de segurança. Mais informação pode ser encontrada na nossa <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentação</a>.",
+    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Você stá atualmente em executando PHP {version}. Nós o incentivamos a atualizar sua versão do PHP para aproveitar<a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">atualizações de segurança e desempenho proporcionados pelo Grupo PHP</a> assim que sua distribuição suportar.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "A configuração de cabeçalhos do proxy reverso está incorreta, ou você está acessando ownCloud de um proxy confiável. Se você não estiver acessando ownCloud de um proxy de confiança, esta é uma questão de segurança e pode permitir a um invasor falsificar o endereço IP como visíveis para ownCloud. Mais informação pode ser encontrada na nossa <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentação</a>.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached é configurado como cache distribuído, mas o módulo PHP errado \"memcache\" está instalado. \\OC\\Memcache\\Memcached suporta apenas \"memcached\" e não \"memcache\". Veja a <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">wiki memcached sobre ambos os módulos </a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Alguns arquivos não passaram na verificação de integridade. Mais informações sobre como resolver este problema pode ser encontrado em nossa <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentação</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Lista de arquivos inválidos…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)",
     "Error occurred while checking server setup" : "Erro ao verificar a configuração do servidor",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "O seu diretório de dados e os arquivos estão, provavelmente, acessíveis a partir da Internet. O arquivo .htaccess não está funcionando. Nós sugerimos que você configure o servidor web de uma forma que o diretório de dados não seja acessível ou mova o diretório de dados para fora do diretório raiz de documentos do servidor web.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "O \"{header}\" cabeçalho HTTP não está configurado igual ao \"{expected}\". Este é um risco potencial para a segurança e recomendamos ajustar essa configuração.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "O \"Strict-Transport-Security\" cabeçalho HTTP não está configurado para pelo menos \"{seconds}\" segundos. Para maior segurança recomendamos a ativação HSTS como descrito em nossas <a href=\"{docUrl}\">dicas de segurança</a>.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "O \"Strict-Transport-Security\" cabeçalho HTTP não está configurado para pelo menos \"{segundos}\" segundos. Para maior segurança recomendamos a ativação HSTS como descrito em nossas <a href=\"{docUrl}\" rel=\"noreferrer\">dicas de segurança</a>.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Você está acessando este site via HTTP. Nós fortemente sugerimos que você ao invéz, configure o servidor para exigir o uso de HTTPS como descrito em nossas  <a href=\"{docUrl}\">dicas de segurança</a>.",
     "Shared" : "Compartilhado",
     "Shared with {recipients}" : "Compartilhado com {recipients}",
     "Error" : "Erro",
     "Error while sharing" : "Erro ao compartilhar",
     "Error while unsharing" : "Erro ao descompartilhar",
-    "Error setting expiration date" : "Erro ao definir data de expiração",
     "The public link will expire no later than {days} days after it is created" : "O link público irá expirar não antes de {days} depois de ser criado",
     "Set expiration date" : "Definir data de expiração",
     "Expiration" : "Expiração",
     "Expiration date" : "Data de expiração",
+    "Expiration date is required" : "Data de expiração é requerida",
+    "Delete {link}" : "Excluir {link}",
+    "Remove link" : "Remover link",
+    "{fileName} link" : "{fileName} link",
+    "Link" : "Link",
+    "Create public link" : "Criar link público",
+    "Edit" : "Editar",
+    "Remove" : "Remover",
+    "Click to copy to clipboard" : "Clique para copiar para a área de transferência",
+    "Social share" : "Compartilhamento social",
+    "There are currently no link shares, you can create one" : "Atualmente não há links compartilhados, você pode criar um",
+    "Anyone with the link has access to the file/folder" : "Qualquer pessoa com o link tem acesso ao arquivo/pasta",
+    "Copied!" : "Copiado!",
+    "Not supported!" : "Não suportado!",
+    "Press ⌘-C to copy." : "Pressione ⌘-C para copiar.",
+    "Press Ctrl-C to copy." : "Pressione Ctrl-C para copiar.",
     "Choose a password for the public link" : "Escolha uma senha para o link público",
+    "Password required" : "Senha requerida",
+    "Filename" : "Nome do Arquivo",
+    "Password" : "Senha",
+    "Name" : "Nome",
+    "Allow editing" : "Permitir edição",
+    "Show file listing" : "Mostrar lista de arquivos",
+    "Edit link share: {name}" : "Editar link de compartilhamento: {name}",
+    "Save" : "Salvar",
+    "Create link share: {name}" : "Cliar link de compartilhamento: {name}",
+    "Remove password" : "Remover a senha",
+    "Share to Twitter. Opens in a new window." : "Compartilhar no Twitter. Abrir em uma nova janela.",
+    "Share to Facebook. Opens in a new window." : "Compartilhar no Facebook. Abrir em uma nova janela.",
+    "Share to Diaspora. Opens in a new window." : "Compartilhar no Diaspora. Abrir em uma nova janela.",
+    "Share to Google+. Opens in a new window." : "Compartilhar no Google+. Abrir em uma nova janela.",
+    "Share via email. Opens your mail client." : "Compartilhar via Email. Abrir seu cliente de email.",
+    "Error while sending notification" : "Erro ao enviar notificação",
     "Sending ..." : "Enviando ...",
     "Email sent" : "E-mail enviado",
-    "Resharing is not allowed" : "Não é permitido re-compartilhar",
-    "Share link" : "Compartilhar link",
-    "Link" : "Link",
-    "Password protect" : "Proteger com senha",
-    "Password" : "Senha",
-    "Allow editing" : "Permitir edição",
     "Email link to person" : "Enviar link por e-mail",
-    "Send" : "Enviar",
+    "Send link via email" : "Enviar link por email",
     "Shared with you and the group {group} by {owner}" : "Compartilhado com você e com o grupo {group} por {owner}",
     "Shared with you by {owner}" : "Compartilhado com você por {owner}",
     "group" : "grupo",
@@ -168,19 +196,24 @@ OC.L10N.register(
     "Could not unshare" : "Não foi possível descompartilhar",
     "Share details could not be loaded for this item." : "Detalhes de compartilhamento não puderam ser carregados para este item.",
     "No users or groups found for {search}" : "Nenhum usuário grupo encontrado para {search}",
-    "An error occured. Please try again" : "Ocorreu um erro. Por favor tente novamente",
+    "No users found for {search}" : "Nenhum usuário encontrado para {search}",
+    "An error occurred. Please try again" : "Ocorreu um erro. Por favor tente novamente",
     "{sharee} (group)" : "{sharee} (grupo)",
     "{sharee} (at {server})" : "{sharee} (no {server})",
     "{sharee} (remote)" : "{sharee} (remoto)",
     "Share" : "Compartilhar",
+    "User and Groups" : "Usuário e Grupos",
+    "Public Links" : "Links Públicos",
+    "Resharing is not allowed" : "Não é permitido re-compartilhar",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Compartilhar com usuários em outros ownClouds usando a sintaxe username@example.com/owncloud",
-    "Share with users or groups …" : "Compartilhar com usuários ou grupos ...",
-    "Share with users, groups or remote users …" : "Compartilhar com usuários, grupos ou usuários remoto ...",
+    "Share with users…" : "Compartilhar com os usuários...",
+    "Share with users, groups or remote users…" : "Compartilhar com usuários, grupos ou usuários remoto…",
+    "Share with users or groups…" : "Compartilhar com usuários ou grupos…",
+    "Share with users or remote users…" : "Compartilhar com usuários ou usuários remoto…",
     "Error removing share" : "Erro na remoção do compartilhamento",
     "Warning" : "Aviso",
-    "Error while sending notification" : "Erro ao enviar notificação",
     "Non-existing tag #{tag}" : "Etiqueta não existente #{tag}",
-    "not assignable" : "não atribuível",
+    "restricted" : "restrito",
     "invisible" : "invisível",
     "({scope})" : "({scope})",
     "Delete" : "Eliminar",
@@ -197,13 +230,14 @@ OC.L10N.register(
     "sunny" : "ensolarado",
     "Hello {name}, the weather is {weather}" : "Olá {name}, o clima está {weather}",
     "Hello {name}" : "Olá {name}",
+    "new" : "novo",
     "_download %n file_::_download %n files_" : ["baixar %n arquivo","baixar %n arquivos"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "A atualização está em andamento, deixando esta página pode haver interrupção do processo em alguns ambientes.",
-    "Updating {productName} to version {version}, this may take a while." : "Atualizando {productName} para a versão {version}, isso pode demorar um pouco.",
+    "Updating to {version}" : "Atualizando para  {version}",
     "An error occurred." : "Ocorreu um erro.",
     "Please reload the page." : "Por favor recarregue a página",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "A atualização não foi bem sucedida. Para mais informações <a href=\"{url}\">verificar o nosso post no fórum</a> que abrange esta questão.",
-    "The update was unsuccessful. " : "A atualização não foi bem sucedida.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "A atualização falhou. Por favor, relate este problema para a <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">comunidade ownCloud</a>.",
     "The update was successful. There were warnings." : "A atualização foi bem sucedida. Havia advertências.",
     "The update was successful. Redirecting you to ownCloud now." : "A atualização teve êxito. Você será redirecionado ao ownCloud agora.",
     "Searching other places" : "Pesquisando em outros lugares",
@@ -214,13 +248,6 @@ OC.L10N.register(
     "Apps" : "Aplicações",
     "Admin" : "Admin",
     "Help" : "Ajuda",
-    "Error loading tags" : " Erro carregando etiqueta",
-    "Tag already exists" : "Etiqueta já existe",
-    "Error deleting tag(s)" : "Erro deletando etiqueta(s)",
-    "Error tagging" : "Erro etiquetando",
-    "Error untagging" : "Erro retirando etiqueta",
-    "Error favoriting" : "Erro colocando nos favoritos",
-    "Error unfavoriting" : "Erro retirando do favoritos",
     "Access forbidden" : "Acesso proibido",
     "File not found" : "Arquivo não encontrado",
     "The specified document has not been found on the server." : "O documento especificado não foi encontrado no servidor.",
@@ -241,9 +268,6 @@ OC.L10N.register(
     "File: %s" : "Arquivo: %s",
     "Line: %s" : "Linha: %s",
     "Trace" : "Rastreamento",
-    "Security warning" : "Alerta de Segurança",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Seu diretório de dados e arquivos são provavelmente acessíveis pela internet, porque o .htaccess não funciona.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Para obter informações sobre como configurar corretamente o seu servidor, consulte a <a href=\"%s\" target=\"_blank\">documentação</a>.",
     "Create an <strong>admin account</strong>" : "Criar uma <strong>conta de administrador</strong>",
     "Username" : "Nome de usuário",
     "Storage & database" : "Armazenamento & banco de dados",
@@ -257,6 +281,7 @@ OC.L10N.register(
     "Database name" : "Nome do banco de dados",
     "Database tablespace" : "Espaço de tabela do banco de dados",
     "Database host" : "Host do banco de dados",
+    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "Por favor especifique o número da porta juntamente com o nome do host (por exemplo, localhost: 5432).",
     "Performance warning" : "Performance de alerta",
     "SQLite will be used as database." : "SQLite será usado como banco de dados",
     "For larger installations we recommend to choose a different database backend." : "Para instalações maiores é recomendável escolher um backend de banco de dados diferente.",
@@ -271,14 +296,16 @@ OC.L10N.register(
     "Search" : "Perquisar",
     "Server side authentication failed!" : "Autenticação do servidor falhou!",
     "Please contact your administrator." : "Por favor, contate o administrador.",
-    "An internal error occured." : "Ocorreu um erro interno.",
+    "An internal error occurred." : "Ocorreu um erro interno.",
     "Please try again or contact your administrator." : "Por favor tente novamente ou faça contato com o seu administrador.",
+    "Username or email" : "Nome de usuário ou email",
     "Log in" : "Entrar",
     "Wrong password. Reset it?" : "Senha incorreta. Redefini-la?",
     "Wrong password." : "Senha errada",
     "Stay logged in" : "Permaneça logado",
     "Alternative Logins" : "Logins Alternativos",
     "Use the following link to reset your password: {link}" : "Use o seguinte link para redefinir sua senha: {link}",
+    "Password changed successfully" : "Senha alterada com sucesso",
     "New password" : "Nova senha",
     "New Password" : "Nova Senha",
     "Reset password" : "Redefinir senha",
@@ -286,6 +313,11 @@ OC.L10N.register(
     "This means only administrators can use the instance." : "Isso significa que apenas os administradores podem usar esta instância.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte o seu administrador do sistema se esta mensagem persistir ou aparecer inesperadamente.",
     "Thank you for your patience." : "Obrigado pela sua paciência.",
+    "Two-step verification" : "Verificação em dois passos",
+    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Segurança reforçada foi ativada para sua conta. Por favor autenticar usando um segundo fator.",
+    "Cancel login" : "Cancelar o login",
+    "Please authenticate using the selected factor." : "Por favor autenticar usando o fator selecionado.",
+    "An error occurred while verifying the token" : "Ocorreu um erro enquanto verificava o token",
     "You are accessing the server from an untrusted domain." : "Você está acessando o servidor a partir de um domínio não confiável.",
     "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Por favor entre em contato com o administrador. Se você é um administrador deste exemplo, configure a definição \"trusted_domains\" em config/config.php. Um exemplo de configuração é fornecido em config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Dependendo da configuração, como administrador, você também pode ser capaz de usar o botão abaixo para confiar neste domínio.",
@@ -293,14 +325,15 @@ OC.L10N.register(
     "App update required" : "Atualização de aplicativo é requerida",
     "%s will be updated to version %s" : "%s será atualizado para a versão %s",
     "These apps will be updated:" : "Esses aplicativos serão atualizados:",
-    "These incompatible apps will be disabled:" : "Esses aplicativos inconpatíveis serão desabilitados:",
     "The theme %s has been disabled." : "O tema %s foi desativado.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Por favor, certifique-se de que o banco de dados, a pasta config e a pasta de dados foram copiados antes de prosseguir.",
     "Start update" : "Iniciar atualização",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tempos de espera com instalações maiores, você pode em vez disso executar o seguinte comando a partir do diretório de instalação:",
+    "Detailed logs" : "Logs detalhados",
+    "Update needed" : "Atualização necessária",
+    "Please use the command line updater because you have a big instance." : "Por favor, use a atualização de linha de comando, porque você tem um grande exemplo.",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Para obter ajuda, consulte a  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentação</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instância %s está em modo de manutenção, o que pode demorar um pouco.",
-    "This page will refresh itself when the %s instance is available again." : "Esta página será atualizada automaticamente quando esta instância %s estiver disponível novamente.",
-    "Error loading file picker template: {error}" : "Erro no seletor de carregamento modelo de arquivos: {error}",
-    "Password can not be changed. Please contact your administrator." : "A senha não pode ser alterada. Por favor, contate o administrador."
+    "This page will refresh itself when the %s instance is available again." : "Esta página será atualizada automaticamente quando esta instância %s estiver disponível novamente."
 },
 "nplurals=2; plural=(n > 1);");
