@@ -1,29 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Невозможно отправить письмо следующим пользователям: %s",
-    "Preparing update" : "Подготовка к обновлению",
-    "Turned on maintenance mode" : "Режим отладки включён",
-    "Turned off maintenance mode" : "Режим отладки отключён",
-    "Maintenance mode is kept active" : "Режим обслуживания оставлен включенным",
-    "Updating database schema" : "Обновление схемы базы данных",
-    "Updated database" : "База данных обновлена",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Проверка возможности обновления схемы базы данных (это может занять длительное время в зависимости от размера базы данных)",
-    "Checked database schema update" : "Проверено обновление схемы БД",
-    "Checking updates of apps" : "Проверка обновлений для приложений",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Проверка возможности обновления схемы базы данных для %s (это может занять длительное время в зависимости от размера базы данных)",
-    "Checked database schema update for apps" : "Проверено обновление схемы БД приложений",
-    "Updated \"%s\" to %s" : "Обновлено \"%s\" до %s",
-    "Repair warning: " : "Предупреждение восстановления:",
-    "Repair error: " : "Ошибка восстановления:",
-    "Set log level to debug" : "Установить журнал в режим отладки",
-    "Reset log level" : "Сбросить уровень журнала",
-    "Starting code integrity check" : "Начинается проверка целостности кода",
-    "Finished code integrity check" : "Проверка целостности кода завершина",
-    "%s (3rdparty)" : "%s (стороннее)",
-    "%s (incompatible)" : "%s (несовместим)",
-    "Following apps have been disabled: %s" : "Были отключены следующие приложения: %s",
-    "Already up to date" : "Не нуждается в обновлении",
     "Please select a file." : "Пожалуйста выберите файл.",
     "File is too big" : "Файл слишком велик",
     "Invalid file provided" : "Указан неправильный файл",
@@ -37,10 +14,35 @@ OC.L10N.register(
     "Crop is not square" : "Кадр не является квадратом",
     "Couldn't reset password because the token is invalid" : "Не удалось сбросить пароль из-за неверного токена",
     "Couldn't reset password because the token is expired" : "Не удалось сбросить пароль, так как срок действия токена истек.",
-    "Couldn't send reset email. Please make sure your username is correct." : "Не удалось отправить письмо для сброса пароля. Убедитесь, что имя пользователя указано верно.",
-    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Не удалось отправить письмо сброса так как у данного пользователя не задан адрес электронной почты. Пожалуйста, обратитесь к администратору.",
+    "%s password changed successfully" : "Пароль %s изменён успешно",
     "%s password reset" : "Сброс пароля %s",
     "Couldn't send reset email. Please contact your administrator." : "Не удалось отправить письмо для сброса пароля. Пожалуйста, свяжитесь с вашим администратором.",
+    "Couldn't send mail to following users: %s " : "Невозможно отправить письмо следующим пользователям: %s",
+    "Preparing update" : "Подготовка к обновлению",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "Предупреждение восстановления:",
+    "Repair error: " : "Ошибка восстановления:",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Пожалуйста, используйте обновление через командную строку, так как автоматические обновления отключены в config.php.",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: Проверка таблицы %s",
+    "Turned on maintenance mode" : "Режим отладки включён",
+    "Turned off maintenance mode" : "Режим отладки отключён",
+    "Maintenance mode is kept active" : "Режим обслуживания оставлен включенным",
+    "Updating database schema" : "Обновление схемы базы данных",
+    "Updated database" : "База данных обновлена",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Проверка возможности обновления схемы базы данных (это может занять длительное время в зависимости от размера базы данных)",
+    "Checked database schema update" : "Проверено обновление схемы БД",
+    "Checking updates of apps" : "Проверка обновлений для приложений",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Проверка возможности обновления схемы базы данных для %s (это может занять длительное время в зависимости от размера базы данных)",
+    "Checked database schema update for apps" : "Проверено обновление схемы БД приложений",
+    "Updated \"%s\" to %s" : "Обновлено \"%s\" до %s",
+    "Set log level to debug" : "Установить журнал в режим отладки",
+    "Reset log level" : "Сбросить уровень журнала",
+    "Starting code integrity check" : "Начинается проверка целостности кода",
+    "Finished code integrity check" : "Проверка целостности кода завершина",
+    "%s (3rdparty)" : "%s (стороннее)",
+    "%s (incompatible)" : "%s (несовместим)",
+    "Following apps have been disabled: %s" : "Были отключены следующие приложения: %s",
+    "Already up to date" : "Не нуждается в обновлении",
     "Sunday" : "Воскресенье",
     "Monday" : "Понедельник",
     "Tuesday" : "Вторник",
@@ -88,8 +90,9 @@ OC.L10N.register(
     "Dec." : "Дек.",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\"> Были обнаружены проблемы с проверкой целостности кода. Подробнее ...",
     "Settings" : "Настройки",
+    "Problem loading page, reloading in 5 seconds" : "Возникла проблема при загрузке страницы, повторная попытка через 5 секунд",
     "Saving..." : "Сохранение...",
-    "Dismiss" : "Прекратить",
+    "Dismiss" : "Закрыть",
     "seconds ago" : "несколько секунд назад",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Ссылка для сброса пароля была отправлена на ваш email. Если вы не получили письмо в течении разумного промежутка времени, проверьте папку со спамом.<br>Если его там нет, то обратитесь к вашему администратору.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Ваши файлы зашифрованы. Если вы не включили ключ восстановления, то ваши данные будут недоступны после сброса пароля.<br />Если вы не уверены что делать дальше - обратитесь к вашему администратору.<br />Вы действительно хотите продолжить?",
@@ -119,39 +122,65 @@ OC.L10N.register(
     "Good password" : "Хороший пароль",
     "Strong password" : "Устойчивый к взлому пароль",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Ваш веб-сервер еще не настроен должным образом чтобы позволить синхронизацию файлов, потому что интерфейс WebDAV, кажется, испорчен.",
-    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Ваш сервер не настроен для правильного разрешения \"{url}\". За дополнительной информацией обратитесь к нашей <a target=\"_blank\" href=\"{docLink}\">документации</a>.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Ваш веб-сервер настроен не корректно для разрешения \"{url}\". Дополнительная информация может быть найдена в нашей <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">документации</a>.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Этот сервер не имеет подключения к Интернету. Это означает, что некоторые из функций, таких как внешнее хранилище, уведомления об обновлениях и установка сторонних приложений не будут работать. Доступ к файлам удаленно и отправки уведомлений по почте могут не работать. Рекомендуется разрешить данному серверу доступ в Интернет если хотите, чтобы все функции работали.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Кэш-памяти не настроено. Для повышения производительности, пожалуйста, настройте кэш-памяти (memcache) если есть такая возможность. Дополнительную информацию можно найти в нашей <a target=\"_blank\" href=\"{docLink}\"> документации </a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandom не доступно чтение для PHP, что крайне нежелательно по соображениям безопасности. Дополнительную информацию можно найти в нашей <a target=\"_blank\" href=\"{docLink}\"> документации </a>.",
-    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "Ваша версия PHP  ({version}) больше не <a target=\"_blank\" href=\"{phpLink}\"> поддерживается разработчиками PHP</a>. Мы рекомендуем Вам обновить версию PHP, чтобы воспользоваться производительностью и безопасностью, предусмотренных в обновленной версии PHP.",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Конфигурация заголовков обратного прокси не верна, либо доступ к ownCloud осуществлён через доверенный прокси. Если ownCloud открыт не через доверенный прокси то это проблема безопасности, которая может позволить атакующему подделать IP адрес, который видит ownCloud. Дополнительная информация доступна в нашей  <a target=\"_blank\" href=\"{docLink}\">документации</a>.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "В качестве распределённого кеша настроен memcached, но установлен неверный модуль PHP \"memcache\". \\OC\\Memcache\\Memcached поддерживает только \"memcached\", но не \"memcache\". Изучите <a target=\"_blank\" href=\"{wikiLink}\">оба модуля в memcached wiki</a>.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Некоторые файлы не прошли проверку целостности. Дополнительная информация о том, как устранить данную проблему доступна в нашей <a target=\"_blank\" href=\"{docLink}\">документации</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Список проблемных файлов…</a> / <a href=\"{rescanEndpoint}\">Сканировать ещё раз…</a>)",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Не настроена система кеширования. Для увеличения производительности сервера, по возможности, настройте memcache. Более подробная информация в нашей <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">документации</a>.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "PHP не имеет доступа на чтение к /dev/urandom, что крайне нежелательно по соображениям безопасности. Дополнительную информацию можно найти в нашей <a target=\"_blank\" href=\"{docLink}\"> документации </a>.",
+    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Вы используете PHP {version}. Рекомендуется обновить версию PHP, чтобы воспользоваться <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">улучшениями производительности и безопасности, внедрёнными PHP Group</a> как только новая версия будет доступна в Вашем дистрибутиве. ",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Конфигурация заголовков обратного прокси не верна, либо доступ к ownCloud осуществлён через доверенный прокси. Если ownCloud открыт не через доверенный прокси то это проблема безопасности, которая может позволить атакующему подделать IP адрес, который видит ownCloud. Дополнительная информация доступна в нашей  <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">документации</a>.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached настроен на распределенный кеш, но установлен не поддерживаемый модуль PHP \"memcache\". \\OC\\Memcache\\Memcached поддерживает только модуль \"memcached\", но не \"memcache\". Больше информации на <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">wiki странице memcached о обоих модулях</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Некоторые файлы не прошли проверку целостности. Дополнительная информация о том, как устранить данную проблему доступна в нашей <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">документации</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Список проблемных файлов…</a> / <a href=\"{rescanEndpoint}\">Сканировать ещё раз…</a>)",
     "Error occurred while checking server setup" : "Произошла ошибка при проверке настроек сервера",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Ваш каталог данных и ваши файлы возможно доступны из Интернета. Файл .htaccess не работает. Мы настоятельно рекомендуем Вам настроить веб сервер таким образом, чтобы каталог данных не был больше доступен или переместить каталог данных за пределы корня веб сервера.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "Заголовок HTTP \"{header}\" не настроен на значение \"{expected}\". Это потенциальная проблема безопасности и мы рекомендуем изменить эти настройки.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "Заголовок HTTP \"Strict-Transport-Security\" должен быть настроен как минимум на \"{seconds}\" секунд. Для улучшения безопасности рекомендуется включить HSTS согласно нашим <a href=\"{docUrl}\">подсказкам по безопасности</a>.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Вы зашли на этот сайт через HTTP. Мы настоятельно рекомендуем настроить ваш сервер на использование HTTPS согласно нашим <a href=\"{docUrl}\">подсказкам по безопасности</a>.",
     "Shared" : "Общий доступ",
     "Shared with {recipients}" : "Вы поделились с {recipients}",
     "Error" : "Ошибка",
     "Error while sharing" : "При попытке поделиться произошла ошибка",
     "Error while unsharing" : "При закрытии доступа произошла ошибка",
-    "Error setting expiration date" : "Ошибка при установке срока доступа",
     "The public link will expire no later than {days} days after it is created" : "Срок действия публичной ссылки истекает не позже чем через {days} дней после её создания",
     "Set expiration date" : "Установить срок действия",
     "Expiration" : "Срок действия",
     "Expiration date" : "Дата окончания",
+    "Expiration date is required" : "Срок действия обязателен",
+    "Delete {link}" : "Удалить {link}",
+    "Remove link" : "Удалить ссылку",
+    "{fileName} link" : "Ссылка {fileName}",
+    "Link" : "Ссылка",
+    "Create public link" : "Создать общедоступную ссылку",
+    "Edit" : "Редактировать",
+    "Remove" : "Удалить",
+    "Click to copy to clipboard" : "Копировать ссылку в буфер обмена",
+    "Social share" : "Поделиться в соцсетях",
+    "There are currently no link shares, you can create one" : "Сейчас нет ссылок для доступа, вы можете создать первую",
+    "Anyone with the link has access to the file/folder" : "Каждый, у кого есть эта ссылка, имеет доступ к файлу/каталогу",
+    "Copied!" : "Скопировано!",
+    "Not supported!" : "Не поддерживается!",
+    "Press ⌘-C to copy." : "Нажмите ⌘-C чтобы скопировать.",
+    "Press Ctrl-C to copy." : "Нажмите Ctrl-C чтобы скопировать.",
     "Choose a password for the public link" : "Укажите пароль для публичной ссылки",
+    "Password required" : "Требуется пароль",
+    "Filename" : "Имя файла",
+    "Password" : "Пароль",
+    "Name" : "Название",
+    "Allow editing" : "Разрешить редактирование",
+    "Show file listing" : "Показать список файлов",
+    "Edit link share: {name}" : "Изменить доступ по ссылке: {name}",
+    "Save" : "Сохранить",
+    "Create link share: {name}" : "Создать доступ по ссылке: {name}",
+    "Remove password" : "Удалить пароль",
+    "Share to Twitter. Opens in a new window." : "Поделиться в Twitter. Откроется в новом окне",
+    "Share to Facebook. Opens in a new window." : "Поделиться в Facebook. Откроется в новом окне",
+    "Share to Diaspora. Opens in a new window." : "Поделиться в Diaspora. Откроется в новом окне",
+    "Share to Google+. Opens in a new window." : "Поделиться в Google+. Откроется в новом окне",
+    "Share via email. Opens your mail client." : "Поделиться через  email. Откроется в вашем почтовом клиенте",
+    "Error while sending notification" : "Ошибка при отправке уведомления",
     "Sending ..." : "Отправляется ...",
     "Email sent" : "Письмо отправлено",
-    "Resharing is not allowed" : "Повторное открытие доступа запрещено",
-    "Share link" : "Поделиться ссылкой",
-    "Link" : "Ссылка",
-    "Password protect" : "Защитить паролем",
-    "Password" : "Пароль",
-    "Allow editing" : "Разрешить редактирование",
     "Email link to person" : "Отправить ссылку по электронной почте",
-    "Send" : "Отправить",
+    "Send link via email" : "Отправить ссылку по электронной почте",
     "Shared with you and the group {group} by {owner}" : "{owner} поделился с вами и группой {group} ",
     "Shared with you by {owner}" : "С вами поделился {owner} ",
     "group" : "группа",
@@ -164,26 +193,32 @@ OC.L10N.register(
     "change" : "изменить",
     "delete" : "удалить",
     "access control" : "контроль доступа",
-    "Could not unshare" : "Не удается отменить доступ",
+    "Could not unshare" : "Не удалось отменить доступ",
     "Share details could not be loaded for this item." : "Не удалось загрузить информацию об общем доступе для этого элемента.",
     "No users or groups found for {search}" : "Не найдено пользователей или групп по запросу {search}",
-    "An error occured. Please try again" : "Произошла ошибка. Попробуйте ещё раз",
+    "No users found for {search}" : "Не найдено пользователей по запросу {search}",
+    "An error occurred. Please try again" : "Произошла ошибка. Попробуйте ещё раз",
     "{sharee} (group)" : "{sharee} (группа)",
     "{sharee} (at {server})" : "{sharee} (на {server})",
     "{sharee} (remote)" : "{sharee} (удалённо)",
     "Share" : "Поделиться",
+    "User and Groups" : "Пользователь и группы",
+    "Public Links" : "Общедоступные ссылки",
+    "Resharing is not allowed" : "Повторное открытие доступа запрещено",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Поделиться с людьми на других серверах ownCloud используя формат username@example.com/owncloud",
-    "Share with users or groups …" : "Поделиться с пользователями или группами ...",
-    "Share with users, groups or remote users …" : "Поделиться с пользователями, группами или удаленными пользователями ...",
+    "Share with users…" : "Поделиться с пользователями...",
+    "Share with users, groups or remote users…" : "Поделиться с пользователями, группами или удаленными пользователями...",
+    "Share with users or groups…" : "Поделиться с пользователями или группами...",
+    "Share with users or remote users…" : "Общий доступ с пользователями или удалеными пользователями",
     "Error removing share" : "Ошибка удаления общего доступа",
     "Warning" : "Предупреждение",
-    "Error while sending notification" : "Ошибка при отправке уведомления",
     "Non-existing tag #{tag}" : "Несуществующий тег #{tag}",
-    "not assignable" : "не назначаемый",
+    "restricted" : "ограниченный",
     "invisible" : "невидимый",
     "({scope})" : "({scope})",
     "Delete" : "Удалить",
     "Rename" : "Переименовать",
+    "Collaborative tags" : "Совместные теги",
     "The object type is not specified." : "Тип объекта не указан",
     "Enter new" : "Ввести новое",
     "Add" : "Добавить",
@@ -195,13 +230,14 @@ OC.L10N.register(
     "sunny" : "солнечно",
     "Hello {name}, the weather is {weather}" : "Здравствуйте {name}, погода {weather}",
     "Hello {name}" : "Здравствуйте {name}",
+    "new" : "новый",
     "_download %n file_::_download %n files_" : ["скачать %n файл","скачать %n файла","скачать %n файлов","скачать %n файлов"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Идет обновление. Покидая эту страницу, вы можете прервать процесс обновления.",
-    "Updating {productName} to version {version}, this may take a while." : "Идет обновление {productName} до версии {version}, это может занять некоторое время.",
+    "Updating to {version}" : "Обновляем до {version}",
     "An error occurred." : "Произошла ошибка.",
     "Please reload the page." : "Пожалуйста, обновите страницу.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Обновление прошло не успешно. За дополнительной информацией по этой проблеме <a href=\"{url}\">обратитесь к нашему форуму</a>.",
-    "The update was unsuccessful. " : "Обновление окончилось неудачей.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Обновление прошло не успешно. Больше информации  о данной проблеме можно найти <a href=\"{url}\">в сообщении на нащем форуме</a>.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "При обновлении произошла ошибка. Пожалуйста сообщите об этом <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">сообществу ownCloud</a>.",
     "The update was successful. There were warnings." : "Обновление прошло успешно. Были предупреждения.",
     "The update was successful. Redirecting you to ownCloud now." : "Обновление прошло успешно. Перенаправляем в ownCloud.",
     "Searching other places" : "Идет поиск в других местах",
@@ -212,13 +248,6 @@ OC.L10N.register(
     "Apps" : "Приложения",
     "Admin" : "Администрирование",
     "Help" : "Помощь",
-    "Error loading tags" : "Ошибка загрузки меток",
-    "Tag already exists" : "Метка уже существует",
-    "Error deleting tag(s)" : "Ошибка удаления метки(ок)",
-    "Error tagging" : "Ошибка присваивания метки",
-    "Error untagging" : "Ошибка снятия метки",
-    "Error favoriting" : "Ошибка добавления в избранные",
-    "Error unfavoriting" : "Ошибка удаления из избранного",
     "Access forbidden" : "Доступ запрещён",
     "File not found" : "Файл не найден",
     "The specified document has not been found on the server." : "Указанный документ не найден на сервере.",
@@ -239,9 +268,6 @@ OC.L10N.register(
     "File: %s" : "Файл: %s",
     "Line: %s" : "Линия: %s",
     "Trace" : "Трассировка",
-    "Security warning" : "Предупреждение безопасности",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Правила файла .htaccess не выполняются. Возможно, каталог данных и файлы свободно доступны из интернета.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Что-бы правильно настроить сервер, воспользуйтесь <a hrev=\"%s\"target=\"blank\">документацией</a>.",
     "Create an <strong>admin account</strong>" : "Создать <strong>учётную запись администратора</strong>",
     "Username" : "Имя пользователя",
     "Storage & database" : "Хранилище и база данных",
@@ -255,6 +281,7 @@ OC.L10N.register(
     "Database name" : "Название базы данных",
     "Database tablespace" : "Табличое пространство базы данных",
     "Database host" : "Хост базы данных",
+    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "Пожалуйста, вместе с именем хоста укажите и номер порта (например, localhost: 5432).",
     "Performance warning" : "Предупреждение о производительности",
     "SQLite will be used as database." : "В качестве базы данных будет использована SQLite.",
     "For larger installations we recommend to choose a different database backend." : "Для крупных проектов мы советуем выбрать другой тип базы данных.",
@@ -269,14 +296,16 @@ OC.L10N.register(
     "Search" : "Найти",
     "Server side authentication failed!" : "Ошибка аутентификации на стороне сервера!",
     "Please contact your administrator." : "Пожалуйста, обратитесь к администратору.",
-    "An internal error occured." : "Произошла внутренняя ошибка.",
+    "An internal error occurred." : "Произошла внутренняя ошибка.",
     "Please try again or contact your administrator." : "Пожалуйста попробуйте ещё раз или свяжитесь с вашим администратором",
+    "Username or email" : "Имя пользователя / email",
     "Log in" : "Войти",
     "Wrong password. Reset it?" : "Неправильный пароль. Сбросить его?",
     "Wrong password." : "Неправильный пароль.",
     "Stay logged in" : "Оставаться в системе",
     "Alternative Logins" : "Альтернативные имена пользователя",
     "Use the following link to reset your password: {link}" : "Используйте следующую ссылку чтобы сбросить пароль: {link}",
+    "Password changed successfully" : "Пароль изменён успешно",
     "New password" : "Новый пароль",
     "New Password" : "Новый пароль",
     "Reset password" : "Сбросить пароль",
@@ -284,6 +313,11 @@ OC.L10N.register(
     "This means only administrators can use the instance." : "Это значит, что только администраторы могут использовать сервер.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Обратитесь к вашему системному администратору если это сообщение не исчезает или появляется неожиданно.",
     "Thank you for your patience." : "Спасибо за терпение.",
+    "Two-step verification" : "Двухшаговая проверка",
+    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Для вашей учётной записи включена повышенная безопасность. Пожалуйста, аутентифицируйтесь через второй фактор.",
+    "Cancel login" : "Отменить вход",
+    "Please authenticate using the selected factor." : "Пожалуйста, аутентифицируйтесь выбранным фактором.",
+    "An error occurred while verifying the token" : "Произошла ошибка при проверке токена",
     "You are accessing the server from an untrusted domain." : "Вы пытаетесь получить доступ к серверу с недоверенного домена.",
     "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Пожалуйста, обратитесь к администратору. Если вы являетесь администратором этого сервера, настройте параметры \"trusted_domains\" в файле config/config.php. Пример настройки можно найти в config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "В зависимости от конфигурации, как администратор вы можете также внести домен в доверенные с помощью кнопки, расположенной ниже.",
@@ -291,14 +325,15 @@ OC.L10N.register(
     "App update required" : "Требуется обновление приложения",
     "%s will be updated to version %s" : "%s будет обновлен до версии %s",
     "These apps will be updated:" : "Следующие приложения будут обновлены:",
-    "These incompatible apps will be disabled:" : "Эти несовместимые приложения будут отключены:",
     "The theme %s has been disabled." : "Тема %s была отключена.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Перед продолжением убедитесь, что вы сделали резервную копию базы данных, каталога конфигурации и каталога с данными.",
     "Start update" : "Запустить обновление",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Чтобы избежать тайм-аутов в крупных установках, вместо этого можно выполнить следующую команду в каталоге установки:",
+    "Detailed logs" : "Подбробные логи",
+    "Update needed" : "Требуется обновление",
+    "Please use the command line updater because you have a big instance." : "Пожалуйста, используйте обновление через командную строку, так как данная установка имеет большой размер.",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Для помощи, ознакомьтесь с  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">документацией</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Этот сервер %s находится в режиме технического обслуживания, которое может занять некоторое время.",
-    "This page will refresh itself when the %s instance is available again." : "Эта страница автоматически обновится, когда сервер %s снова станет доступен.",
-    "Error loading file picker template: {error}" : "Ошибка при загрузке шаблона выбора файлов: {error}",
-    "Password can not be changed. Please contact your administrator." : "Пароль не может быть изменён. Пожалуйста, свяжитесь с вашим администратором."
+    "This page will refresh itself when the %s instance is available again." : "Эта страница автоматически обновится, когда сервер %s снова станет доступен."
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
