@@ -14,20 +14,14 @@ OC.L10N.register(
     "Crop is not square" : "Orezanie nie je štvorcové",
     "Couldn't reset password because the token is invalid" : "Nemožno zmeniť heslo pre neplatnosť tokenu.",
     "Couldn't reset password because the token is expired" : "Nepodarilo sa obnoviť heslo, pretože platnosť tokenu uplynula.",
-    "Couldn't send reset email. Please make sure your username is correct." : "Nemožno poslať email pre obnovu. Uistite sa, či vkladáte správne používateľské meno.",
     "%s password reset" : "reset hesla %s",
     "Couldn't send reset email. Please contact your administrator." : "Nemožno poslať email pre obnovu. Kontaktujte prosím vášho administrátora.",
-    "Error loading tags" : "Chyba pri načítaní štítkov",
-    "Tag already exists" : "Štítok už existuje",
-    "Error deleting tag(s)" : "Chyba pri mazaní štítka(ov)",
-    "Error tagging" : "Chyba pri pridaní štítka",
-    "Error untagging" : "Chyba pri odobratí štítka",
-    "Error favoriting" : "Chyba pri pridaní do obľúbených",
-    "Error unfavoriting" : "Chyba pri odobratí z obľúbených",
     "Couldn't send mail to following users: %s " : "Nebolo možné odoslať email týmto používateľom: %s ",
     "Preparing update" : "Pripravuje sa aktualizácia",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair warning: " : "Oznámenie opravy:",
     "Repair error: " : "Chyba opravy:",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Prosím, použite aktualizáciu z príkazového riadka, pretože automatické aktualizácie boli vypnuté v súbore config.php.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Kontrola tabuľky %s",
     "Turned on maintenance mode" : "Mód údržby je zapnutý",
     "Turned off maintenance mode" : "Mód údržby je vypnutý",
@@ -95,6 +89,7 @@ OC.L10N.register(
     "Dec." : "Dec.",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Pri kontrole integrity kódu sa vyskytli chyby. Viac informácií…</a>",
     "Settings" : "Nastavenia",
+    "Problem loading page, reloading in 5 seconds" : "Problém pri načítavaní stránky. Ďalší pokus o načítanie prebehne o 5 sekúne.",
     "Saving..." : "Ukladám...",
     "Dismiss" : "Odmietnuť",
     "seconds ago" : "pred sekundami",
@@ -126,33 +121,46 @@ OC.L10N.register(
     "Good password" : "Dobré heslo",
     "Strong password" : "Silné heslo",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Váš webový server nie je zatiaľ správne nastavený, aby umožnil synchronizáciu súborov, pretože rozhranie WebDAV sa zdá byť nefunkčné.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Váš webový server nie je správne nastavený na preklad „{url}“. Ďalšie informácie nájdete v našej <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentácii</a>.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Server nemá funkčné pripojenie k internetu. Niektoré moduly ako napr. externé úložisko, oznámenie o dostupných aktualizáciách alebo inštalácia aplikácií tretích strán nebudú fungovať. Vzdialený prístup k súborom a odosielanie oznamovacích emailov tiež nemusí fungovať. Ak chcete využívať všetky funkcie, odporúčame povoliť tomuto serveru pripojenie k internetu.",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Nebola nastavený vyrovnávacia pamäť v RAM. Ak chcete zlepšiť výkon, prosím, nastavte si memcache. Ďalšie informácie nájdete v našej <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentácii</a>.",
     "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "dev/urandom nie je prístupný na čítanie procesom PHP, čo z bezpečnostných dôvodov nie je vôbec odporúčané. Viac informácií nájdete v našej <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentácii</a>.",
+    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Momentálne používate PHP {version}. Odporúčame vám aktualizovať vašu verziu PHP, aby ste mohli využiť <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">výkonnostné a bezpečnostné aktualizácie, ktoré poskytuje PHP Group</a> akonáhle ich vaša distribúcia začne podporovať.",
     "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Konfigurácia hlavičiek reverse proxy nie je správna alebo pristupujete k ownCloud z dôveryhodného proxy servera. Ak k ownCloud nepristupujete z dôveryhodného proxy servera, vzniká bezpečnostné riziko - IP adresa potenciálneho útočníka, ktorú vidí ownCloud, môže byť falošná. Viac informácií nájdete v našej <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentácii</a>.",
     "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached je nakonfigurovaný ako distribuovaná vyrovnávacia pamäť, ale v PHP je nainštalovaný nesprávny modul - \"memcache\". \\OC\\Memcache\\Memcached podporuje len modul \"memcached\", \"memcache\" nie je podporovaný. Viac informácií nájdete na <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki stránke o oboch moduloch</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Niektoré súbory neprešli úspešne kontrolou integrity. Ďalšie informácie o tom, ako tento problém vyriešiť, nájdete v našej <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentácii</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Zoznam neplatných súborov…</a> / <a href=\"{rescanEndpoint}\">Skontrolovať znovu…</a>)",
     "Error occurred while checking server setup" : "Počas kontroly nastavenia serveru sa stala chyba",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Váš priečinok s dátami aj vaše súbory sú pravdepodobne prístupné z internetu. Súbor .htaccess nefunguje. Dôrazne odporúčame nakonfigurovať webový server tak, aby priečinok s dátami nebol naďalej prístupný alebo presunúť priečinok s dátami mimo priestoru, ktorý webový server sprístupňuje.",
+    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "Hlavička HTTP „{header}“ nie je nastavená, aby sa rovnala „{expected}“. To je potenciálne bezpečnostné riziko alebo ohrozenie ochrany súkromia a odporúčame toto nastavenie zmeniť.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "Hlavička HTTP „Strict-Transport-Security“ nie je nastavená na aspoň „{seconds}“ sekúnd. Odporúčame zvyšiť bezpečnosť nastavením HSTS podľa inštrukcií v našich <a href=\"{docUrl}\" rel=\"noreferrer\">tipoch k zabezpečeniu</a>.",
+    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Pristupujete k tejto webovej stránke prostredníctvom HTTP. Dôrazne odporúčame, anu ste nastavili svoj server, aby vyžadoval prihlásenie prostredníctvom HTTPS podľa inštrukcií v našich <a href=\"{docUrl}\">tipoch k zabezpečeniu</a>.",
     "Shared" : "Zdieľané",
     "Shared with {recipients}" : "Zdieľa s {recipients}",
     "Error" : "Chyba",
     "Error while sharing" : "Chyba počas zdieľania",
     "Error while unsharing" : "Chyba počas ukončenia zdieľania",
-    "Error setting expiration date" : "Chyba pri nastavení dátumu expirácie",
     "The public link will expire no later than {days} days after it is created" : "Verejný odkaz nevyprší skôr než za {days} dní po vytvorení",
     "Set expiration date" : "Nastaviť dátum expirácie",
     "Expiration" : "Koniec platnosti",
     "Expiration date" : "Dátum expirácie",
-    "Choose a password for the public link" : "Zadajte heslo pre tento verejný odkaz",
-    "Resharing is not allowed" : "Zdieľanie už zdieľanej položky nie je povolené",
-    "Share link" : "Zdieľať linku",
     "Link" : "Odkaz",
-    "Password protect" : "Chrániť heslom",
+    "Edit" : "Upraviť",
+    "Remove" : "Odobrať",
+    "Copied!" : "Skopírované!",
+    "Not supported!" : "Nepodporované!",
+    "Press ⌘-C to copy." : "Skopírujte stlačením ⌘-C.",
+    "Press Ctrl-C to copy." : "Skopírujte stlačením Ctrl-C.",
+    "Choose a password for the public link" : "Zadajte heslo pre tento verejný odkaz",
+    "Filename" : "Názov súboru",
     "Password" : "Heslo",
+    "Name" : "Názov",
     "Allow editing" : "Povoliť úpravy",
-    "Email link to person" : "Odoslať odkaz emailom",
-    "Send" : "Odoslať",
+    "Save" : "Uložiť",
+    "Error while sending notification" : "Chyba pri posielaní oznámenia",
     "Sending ..." : "Odosielam ...",
     "Email sent" : "Email odoslaný",
+    "Email link to person" : "Odoslať odkaz emailom",
+    "Send link via email" : "Poslať odkaz emailom",
     "Shared with you and the group {group} by {owner}" : "Zdieľané s vami a so skupinou {group} používateľom {owner}",
     "Shared with you by {owner}" : "Zdieľané s vami používateľom {owner}",
     "group" : "skupina",
@@ -167,8 +175,14 @@ OC.L10N.register(
     "access control" : "prístupové práva",
     "Could not unshare" : "Nepodarilo sa zrušiť sprístupnenie",
     "Share details could not be loaded for this item." : "Nebolo možné načítať údaje o zdieľaní tejto položky.",
+    "No users or groups found for {search}" : "{search} nenašlo žiadnych používateľov alebo skupiny",
+    "No users found for {search}" : "{search} nenašlo žiadnych používateľov",
+    "An error occurred. Please try again" : "Nastala chyba. Prosím, skúste to znovu.",
+    "{sharee} (group)" : "{sharee} (skupina)",
     "{sharee} (at {server})" : "{sharee} (na {server})",
+    "{sharee} (remote)" : "{sharee} (vzdialený)",
     "Share" : "Zdieľať",
+    "Resharing is not allowed" : "Zdieľanie už zdieľanej položky nie je povolené",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Zdieľať s ľuďmi na iných serveroch ownClouds pomocou syntaxe používateľ@doména.com/owncloud",
     "Share with users…" : "Sprístupniť používateľom...",
     "Share with users, groups or remote users…" : "Sprístupniť používateľom, skupinám alebo vzdialeným používateľom...",
@@ -176,10 +190,13 @@ OC.L10N.register(
     "Share with users or remote users…" : "Sprístupniť používateľom alebo vzdialeným používateľom...",
     "Error removing share" : "Chyba pri rušení sprístupnenia",
     "Warning" : "Varovanie",
-    "Error while sending notification" : "Chyba pri posielaní oznámenia",
+    "Non-existing tag #{tag}" : "Neexistujúca značka #{tag}",
+    "restricted" : "obmedzené",
     "invisible" : "neviditeľný",
+    "({scope})" : "({scope})",
     "Delete" : "Zmazať",
     "Rename" : "Premenovať",
+    "Collaborative tags" : "Zdieľané značky",
     "The object type is not specified." : "Nešpecifikovaný typ objektu.",
     "Enter new" : "Zadať nový",
     "Add" : "Pridať",
@@ -229,8 +246,6 @@ OC.L10N.register(
     "File: %s" : "Súbor: %s",
     "Line: %s" : "Riadok: %s",
     "Trace" : "Trasa",
-    "Security warning" : "Bezpečnostné varovanie",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Váš priečinok s dátami a súbormi je dostupný z internetu, lebo súbor .htaccess nefunguje.",
     "Create an <strong>admin account</strong>" : "Vytvoriť <strong>administrátorský účet</strong>",
     "Username" : "Meno používateľa",
     "Storage & database" : "Úložislo & databáza",
@@ -260,6 +275,7 @@ OC.L10N.register(
     "Please contact your administrator." : "Kontaktujte prosím vášho administrátora.",
     "An internal error occurred." : "Došlo k vnútornej chybe.",
     "Please try again or contact your administrator." : "Skúste to znovu, alebo sa obráťte na vášho administrátora.",
+    "Username or email" : "Používateľské meno alebo emailová adresa",
     "Log in" : "Prihlásiť sa",
     "Wrong password. Reset it?" : "Chybné heslo. Chcete ho obnoviť?",
     "Wrong password." : "Nesprávne heslo.",
@@ -273,18 +289,25 @@ OC.L10N.register(
     "This means only administrators can use the instance." : "Len správca systému môže používať túto inštanciu.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktujte prosím správcu systému, ak sa táto správa objavuje opakovane alebo neočakávane.",
     "Thank you for your patience." : "Ďakujeme za Vašu trpezlivosť.",
+    "Two-step verification" : "Dvojstupňové overenie",
+    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Vo vašom účte bola zapnutá vyššia bezpečnosť. Prosím, ovarte svoju totožnosť druhým krokom.",
+    "Cancel login" : "Zrušiť prihlásenie",
+    "Please authenticate using the selected factor." : "Prosím, overte svoju totožnosť vybraným krokom.",
     "You are accessing the server from an untrusted domain." : "Pristupujete na server v nedôveryhodnej doméne.",
+    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Kontaktujte administrátora. Ak ste administrátorom tejto inštancie, nakonfigurujte správne nastavenie „trusted_domains“ v config/config.php. Vzorová konfigurácia je uvedená v config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "V závislosti na konfigurácii, vám môže byť ako správcovi umožnené použitie tlačidla nižšie pre označenie tejto domény ako dôveryhodnej.",
     "Add \"%s\" as trusted domain" : "Pridať \"%s\" ako dôveryhodnú doménu",
     "App update required" : "Je nutná aktualizácia aplikácie",
     "%s will be updated to version %s" : "%s bude zaktualizovaný na verziu %s.",
     "These apps will be updated:" : "Tieto aplikácie budú aktualizované:",
-    "These incompatible apps will be disabled:" : "Tieto nekompatibilné aplikácie budú vypnuté:",
     "The theme %s has been disabled." : "Téma %s bola zakázaná.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Pred vykonaním ďalšieho kroku sa presvedčte, že databáza, konfiguračný a dátový priečinok sú zazálohované.",
     "Start update" : "Spustiť aktualizáciu",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Aby nedošlo k vypršaniu časového limitu vo väčších inštaláciách, môžete namiesto toho použiť nasledujúci príkaz z inštalačného priečinka:",
     "Detailed logs" : "Podrobné záznamy",
+    "Update needed" : "Je potrebná aktualizácia",
+    "Please use the command line updater because you have a big instance." : "Prosím, použite aktualizáciu z príkazového riadka, pretože vaša inštalácia je veľká.",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Pomoc nájdete v  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentácii</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Táto %s inštancia je v súčasnej dobe v režime údržby. Počkajte prosím.",
     "This page will refresh itself when the %s instance is available again." : "Táto stránka sa obnoví sama hneď ako bude %s inštancia znovu dostupná."
 },
