@@ -1,18 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Не могу да пошаљем е-пошту следећим корисницима: %s ",
-    "Preparing update" : "Припремам надоградњу",
-    "Turned on maintenance mode" : "Режим одржавања укључен",
-    "Turned off maintenance mode" : "Режим одржавања искључен",
-    "Maintenance mode is kept active" : "Режим одржавања се држи активним",
-    "Updated database" : "База података ажурирана",
-    "Checked database schema update" : "Ажурирање шеме базе података, проверено",
-    "Checked database schema update for apps" : "Ажурирање шеме базе података за апликације, проверено",
-    "Updated \"%s\" to %s" : "„%s“ ажириран на %s",
-    "Repair warning: " : "Упозорење о поправци :",
-    "Repair error: " : "Грешка поправке:",
-    "Following apps have been disabled: %s" : "Следеће апликације су искључене: %s",
     "File is too big" : "Фајл је превелик",
     "Invalid file provided" : "Понуђени фајл је неисправан",
     "No image or file provided" : "Није дата ни слика ни фајл",
@@ -23,9 +11,20 @@ OC.L10N.register(
     "No valid crop data provided" : "Нема података о опсецању",
     "Crop is not square" : "Опсецање није квадрат",
     "Couldn't reset password because the token is invalid" : "Није могуће ресетовати лозинку јер je токен неважећи",
-    "Couldn't send reset email. Please make sure your username is correct." : "Не могу да пошаљем поруку за ресетовање лозинке. Проверите да ли је корисничко име исправно.",
     "%s password reset" : "%s лозинка ресетована",
     "Couldn't send reset email. Please contact your administrator." : "Не могу да пошаљем е-пошту за ресетовање лозинке. Контактирајте администратора.",
+    "Couldn't send mail to following users: %s " : "Не могу да пошаљем е-пошту следећим корисницима: %s ",
+    "Preparing update" : "Припремам надоградњу",
+    "Repair warning: " : "Упозорење о поправци :",
+    "Repair error: " : "Грешка поправке:",
+    "Turned on maintenance mode" : "Режим одржавања укључен",
+    "Turned off maintenance mode" : "Режим одржавања искључен",
+    "Maintenance mode is kept active" : "Режим одржавања се држи активним",
+    "Updated database" : "База података ажурирана",
+    "Checked database schema update" : "Ажурирање шеме базе података, проверено",
+    "Checked database schema update for apps" : "Ажурирање шеме базе података за апликације, проверено",
+    "Updated \"%s\" to %s" : "„%s“ ажириран на %s",
+    "Following apps have been disabled: %s" : "Следеће апликације су искључене: %s",
     "Sunday" : "недеља",
     "Monday" : "понедељак",
     "Tuesday" : "уторак",
@@ -112,22 +111,22 @@ OC.L10N.register(
     "Error" : "Грешка",
     "Error while sharing" : "Грешка при дељењу",
     "Error while unsharing" : "Грешка при укидању дељења",
-    "Error setting expiration date" : "Грешка при постављању датума истека",
     "The public link will expire no later than {days} days after it is created" : "Јавна веза ће престати да важи {days} дана након стварања",
     "Set expiration date" : "Постави датум истека",
     "Expiration" : "Истиче",
     "Expiration date" : "Датум истека",
+    "Link" : "Веза",
+    "Edit" : "Уреди",
+    "Remove" : "Уклони",
     "Choose a password for the public link" : "Одредите лозинку за јавну везу",
+    "Filename" : "Назив фајла",
+    "Password" : "Лозинка",
+    "Name" : "Назив",
+    "Allow editing" : "уређивање",
+    "Save" : "Сачувај",
     "Sending ..." : "Шаљем...",
     "Email sent" : "Порука је послата",
-    "Resharing is not allowed" : "Поновно дељење није дозвољено",
-    "Share link" : "Веза дељења",
-    "Link" : "Веза",
-    "Password protect" : "Заштићено лозинком",
-    "Password" : "Лозинка",
-    "Allow editing" : "Дозволи уређивање",
     "Email link to person" : "Пошаљи е-поштом",
-    "Send" : "Пошаљи",
     "Shared with you and the group {group} by {owner}" : "{owner} дели са вама и са групом {group}.",
     "Shared with you by {owner}" : "{owner} дели са вама",
     "group" : "група",
@@ -140,11 +139,9 @@ OC.L10N.register(
     "change" : "измени",
     "delete" : "обриши",
     "access control" : "права приступа",
-    "An error occured. Please try again" : "Дошло је до грешке. Покушајте поново",
     "Share" : "Дели",
+    "Resharing is not allowed" : "Поновно дељење није дозвољено",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Поделите са људима у другим облацима користећи синтаксу корисничкоиме@сервер.com/owncloud",
-    "Share with users or groups …" : "Дели са корисницима или групама...",
-    "Share with users, groups or remote users …" : "Дели са корисницима, групама или удаљеним корисницима...",
     "Warning" : "Упозорење",
     "Delete" : "Обриши",
     "Rename" : "Преименуј",
@@ -160,9 +157,7 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Здраво {name}, време је {weather}",
     "Hello {name}" : "Здраво {name}",
     "_download %n file_::_download %n files_" : ["преузми %n фајл","преузми %n фајла","преузми %n фајлова"],
-    "Updating {productName} to version {version}, this may take a while." : "Надограђујем {productName} на издање {version}. Ово би могло да потраје.",
     "Please reload the page." : "Поново учитајте страницу.",
-    "The update was unsuccessful. " : "Ажурирање није успело.",
     "The update was successful. There were warnings." : "Ажурирање је успело. Било је упозорења.",
     "The update was successful. Redirecting you to ownCloud now." : "Ажурирање је успело. Преусмеравам вас на оунКлауд.",
     "Searching other places" : "Претражујем остала места",
@@ -171,13 +166,6 @@ OC.L10N.register(
     "Apps" : "Апликације",
     "Admin" : "Администрација",
     "Help" : "Помоћ",
-    "Error loading tags" : "Грешка при учитавању ознака",
-    "Tag already exists" : "Ознака већ постоји",
-    "Error deleting tag(s)" : "Грешка при брисању ознака",
-    "Error tagging" : "Грешка означавања",
-    "Error untagging" : "Грешка при скидању ознака",
-    "Error favoriting" : "Грешка при постављању омиљеног",
-    "Error unfavoriting" : "Грешка при укидању омиљеног",
     "Access forbidden" : "Забрањен приступ",
     "File not found" : "Фајл није нађен",
     "The specified document has not been found on the server." : "Наведени документ није нађен на серверу.",
@@ -198,9 +186,6 @@ OC.L10N.register(
     "File: %s" : "Фајл: %s",
     "Line: %s" : "Линија: %s",
     "Trace" : "Траг",
-    "Security warning" : "Безбедносно упозорење",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ваш директоријум са подацима и фајлови су вероватно доступни са интернета јер .htaccess не ради.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Информације о томе како исправно подесити серверможете наћи у<a href=\"%s\" target=\"_blank\">документацији</a>.",
     "Create an <strong>admin account</strong>" : "Направи <strong>административни налог</strong>",
     "Username" : "Корисничко име",
     "Storage & database" : "Складиште и база података",
@@ -228,7 +213,6 @@ OC.L10N.register(
     "Search" : "Претражи",
     "Server side authentication failed!" : "Аутентификација на серверу није успела!",
     "Please contact your administrator." : "Контактирајте вашег администратора.",
-    "An internal error occured." : "Дошло је до интерне грешке.",
     "Please try again or contact your administrator." : "Покушајте поново или контактирајте вашег администратора.",
     "Log in" : "Пријава",
     "Alternative Logins" : "Алтернативне пријаве",
@@ -248,8 +232,6 @@ OC.L10N.register(
     "Start update" : "Почни надоградњу",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Да избегнете прекорачење времена одзива на већим инсталацијама, можете покренути следећу команду у инсталационом директоријуму:",
     "This %s instance is currently in maintenance mode, which may take a while." : "Овај %s је тренутно у режиму одржавања а то може потрајати.",
-    "This page will refresh itself when the %s instance is available again." : "Ова страница ће се сама освежити када %s постане поново доступан.",
-    "Error loading file picker template: {error}" : "Грешка при учитавању шаблона бирача фајлова: {error}",
-    "Password can not be changed. Please contact your administrator." : "Лозинка се не може променити. Контактирајте администратора."
+    "This page will refresh itself when the %s instance is available again." : "Ова страница ће се сама освежити када %s постане поново доступан."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
