@@ -31,14 +31,14 @@
 // because base.php will already use 5.6 syntax.
 if (version_compare(PHP_VERSION, '5.6.0') === -1) {
 	echo 'This version of ownCloud requires at least PHP 5.6.0<br/>';
-	echo 'You are currently running ' . PHP_VERSION . '. Please update your PHP version.';
+	echo 'You are currently running PHP ' . PHP_VERSION . '. Please update your PHP version.';
 	return;
 }
 
-// Show warning if PHP 7.2 is used as ownCloud is not compatible with PHP 7.2
-if (version_compare(PHP_VERSION, '7.2.0alpha1') !== -1) {
-	echo 'This version of ownCloud is not compatible with PHP 7.2<br/>';
-	echo 'You are currently running ' . PHP_VERSION . '.';
+// Show warning if PHP 7.3 is used as ownCloud is not compatible with PHP 7.3
+if (version_compare(PHP_VERSION, '7.3.0alpha1') !== -1) {
+	echo 'This version of ownCloud is not compatible with PHP 7.3<br/>';
+	echo 'You are currently running PHP ' . PHP_VERSION . '.';
 	return;
 }
 
@@ -52,30 +52,24 @@ if (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') {
 try {
 
 	require_once __DIR__ . '/lib/base.php';
-
 	OC::handleRequest();
 
 } catch(\OC\ServiceUnavailableException $ex) {
-	\OC::loadDefaultEnabledAppTheme();
 	\OC::$server->getLogger()->logException($ex, array('app' => 'index'));
 
 	//show the user a detailed error page
 	OC_Response::setStatus(OC_Response::STATUS_SERVICE_UNAVAILABLE);
 	OC_Template::printExceptionErrorPage($ex);
 } catch (\OC\HintException $ex) {
-	\OC::loadDefaultEnabledAppTheme();
 	OC_Response::setStatus(OC_Response::STATUS_SERVICE_UNAVAILABLE);
 	OC_Template::printErrorPage($ex->getMessage(), $ex->getHint());
 } catch (\OC\User\LoginException $ex) {
-	\OC::loadDefaultEnabledAppTheme();
 	OC_Response::setStatus(OC_Response::STATUS_FORBIDDEN);
 	OC_Template::printErrorPage($ex->getMessage());
 } catch (\OCP\Files\ForbiddenException $ex) {
-	\OC::loadDefaultEnabledAppTheme();
 	OC_Response::setStatus(OC_Response::STATUS_FORBIDDEN);
 	OC_Template::printErrorPage($ex->getMessage());
 } catch (Exception $ex) {
-	\OC::loadDefaultEnabledAppTheme();
 	try {
 		\OC::$server->getLogger()->logException($ex, array('app' => 'index'));
 
@@ -91,7 +85,6 @@ try {
 		echo('</body></html>');
 	}
 } catch (Error $ex) {
-	\OC::loadDefaultEnabledAppTheme();
 	\OC::$server->getLogger()->logException($ex, array('app' => 'index'));
 	OC_Response::setStatus(OC_Response::STATUS_INTERNAL_SERVER_ERROR);
 	OC_Template::printExceptionErrorPage($ex);
