@@ -497,7 +497,7 @@ class OC {
 		spl_autoload_register([self::$loader, 'load']);
 		$loaderEnd = microtime(true);
 
-		self::$CLI = (php_sapi_name() == 'cli');
+		self::$CLI = (in_array(php_sapi_name(), ['cli', 'phpdbg']));
 
 		// setup 3rdparty autoloader
 		$vendorAutoLoad = OC::$SERVERROOT . '/lib/composer/autoload.php';
@@ -578,8 +578,10 @@ class OC {
 		\OC::$server->getEventLogger()->start('init_session', 'Initialize session');
 		OC_App::loadApps(['session']);
 		if (!self::$CLI) {
+			\OC_App::loadApps(['theme']);
 			self::initSession();
 		}
+
 		\OC::$server->getEventLogger()->end('init_session');
 
 		// incognito mode for now
@@ -825,22 +827,6 @@ class OC {
 		}
 	}
 
-	/**
-	 * Enables the defaultEnabled app theme
-	 * __do not__ call this for every request, as this parses all apps info.xml
-	 * files in order to determine which app is a default enabled theme while
-	 * not accessing the database which might not be available.
-	 */
-	public static function loadDefaultEnabledAppTheme() {
-		$defaultEnabledAppTheme = \OC_App::getDefaultEnabledAppTheme();
-
-		if ($defaultEnabledAppTheme !== false) {
-			/** @var \OC\Theme\ThemeService $themeService */
-			$themeService = \OC::$server->query('ThemeService');
-			$themeService->setAppTheme($defaultEnabledAppTheme);
-		}
-	}
-
 	/**
 	 * Handle the request
 	 */
@@ -859,8 +845,6 @@ class OC {
 				\OC::$server->getL10N('lib'), new \OC_Defaults(), \OC::$server->getLogger(),
 				\OC::$server->getSecureRandom());
 
-			self::loadDefaultEnabledAppTheme();
-
 			$controller = new OC\Core\Controller\SetupController($setupHelper);
 			$controller->run($_POST);
 			exit();
@@ -908,7 +892,8 @@ class OC {
 		if (!self::checkUpgrade(false)
 			&& !$systemConfig->getValue('maintenance', false)) {
 			// For logged-in users: Load everything
-			if(OC_User::isLoggedIn()) {
+			$userSession = \OC::$server->getUserSession();
+			if($userSession->isLoggedIn() && $userSession->verifyAuthHeaders($request)) {
 				OC_App::loadApps();
 			} else {
 				// For guests: Load only filesystem and logging
@@ -952,7 +937,7 @@ class OC {
 		}
 
 		// Someone is logged in
-		if (OC_User::isLoggedIn()) {
+		if($userSession->isLoggedIn() && $userSession->verifyAuthHeaders($request)) {
 			OC_App::loadApps();
 			OC_User::setupBackends();
 			OC_Util::setupFS();
