@@ -6,11 +6,6 @@ OC.L10N.register(
     "See %s" : "%s দেখ",
     "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "সাধারণতঃ ওয়বসার্ভারকে কনফিগ ডিরেক্টরি%sতে লেখার অধিকার দিয়ে%s এই সমস্যা সমাধান করা যায়",
     "Sample configuration detected" : "নমুনা কনফিগারেশন পাওয়া গেছে",
-    "Help" : "সহায়িকা",
-    "Personal" : "ব্যক্তিগত",
-    "Users" : "ব্যবহারকারী",
-    "Admin" : "প্রশাসন",
-    "No app name specified" : "কোন অ্যাপ নাম সুনির্দিষ্ট নয়",
     "Unknown filetype" : "অজানা প্রকৃতির ফাইল",
     "Invalid image" : "অবৈধ চিত্র",
     "today" : "আজ",
@@ -18,7 +13,9 @@ OC.L10N.register(
     "last month" : "গত মাস",
     "last year" : "গত বছর",
     "seconds ago" : "সেকেন্ড পূর্বে",
-    "web services under your control" : "ওয়েব সার্ভিস আপনার হাতের মুঠোয়",
+    "None" : "কোনটিই নয়",
+    "Username" : "ব্যবহারকারী",
+    "Password" : "কূটশব্দ",
     "App directory already exists" : "এই অ্যাপ ডিরেক্টরিটি পূর্ব থেকেই বিদ্যমান",
     "Can't create app folder. Please fix permissions. %s" : "অ্যাপ ফোল্ডার বানানো হেলনা। অনুমতি নির্ধারণ করুন। %s",
     "No source specified when installing app" : "অ্যাপ ইনস্টল করতে যেয়ে কোন উৎস নির্দিষ্ট করা হয়নি",
@@ -26,14 +23,23 @@ OC.L10N.register(
     "App does not provide an info.xml file" : "অ্যাপের সঙ্গে একটি  info.xml ফাইল নেই",
     "App can't be installed because of not allowed code in the App" : "অ্যাপের সাথে অননুমোদিত কোড থাকায় অ্যাপটি ইনস্টল করা যাবেনা",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "অ্যাপ ইনস্টল করা যাবেনা কারণ এতে ননশিপড অ্যাপ এর জন্য অননুমোদিত <shipped>true</shipped> ট্যাগ বিদ্যমান ",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : " info.xml/version এর উল্লেখিত সংষ্করণ এবং অ্যাপ স্টোর হতে প্রদান করা সংষ্করণ একরকম না হওয়াতে অ্যাপটি ইনস্টল করা যাবেনা",
-    "Application is not enabled" : "অ্যাপ্লিকেসনটি সক্রিয় নয়",
-    "Authentication error" : "অনুমোদন ঘটিত সমস্যা",
-    "Token expired. Please reload page." : "টোকেন মেয়াদোত্তীর্ণ। দয়া করে পৃষ্ঠাটি পূনরায় লোড করুন।",
-    "Unknown user" : "অপরিচিত ব্যবহারকারী",
+    "Apps" : "অ্যাপ",
+    "General" : "সাধারণ",
+    "Storage" : "সংরক্ষণাগার",
+    "Security" : "নিরাপত্তা",
+    "Encryption" : "সংকেতায়ন",
+    "Sharing" : "ভাগাভাগিরত",
+    "Search" : "অনুসন্ধান",
     "%s shared »%s« with you" : "%s আপনার সাথে »%s« ভাগাভাগি করেছে",
     "Sharing %s failed, because the file does not exist" : "%s ভাগাভাগি ব্যার্থ, কারণ ফাইলটি নেই",
     "You are not allowed to share %s" : "আপনি %s ভাগাভাগি করতে পারবেননা",
-    "Apps" : "অ্যাপ"
+    "Help" : "সহায়িকা",
+    "Settings" : "নিয়ামকসমূহ",
+    "Users" : "ব্যবহারকারী",
+    "web services under your control" : "ওয়েব সার্ভিস আপনার হাতের মুঠোয়",
+    "Application is not enabled" : "অ্যাপ্লিকেসনটি সক্রিয় নয়",
+    "Authentication error" : "অনুমোদন ঘটিত সমস্যা",
+    "Token expired. Please reload page." : "টোকেন মেয়াদোত্তীর্ণ। দয়া করে পৃষ্ঠাটি পূনরায় লোড করুন।",
+    "Unknown user" : "অপরিচিত ব্যবহারকারী"
 },
 "nplurals=2; plural=(n != 1);");
