@@ -18,6 +18,9 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["fa %n hora","fa %n hores"],
     "_%n minute ago_::_%n minutes ago_" : ["fa %n minut","fa %n minuts"],
     "seconds ago" : "segons enrere",
+    "None" : "Cap",
+    "Username" : "Nom d'usuari",
+    "Password" : "Contrasenya",
     "File name contains at least one invalid character" : "El nom del fitxer conté al menys un caràcter invàlid",
     "App directory already exists" : "La carpeta de l'aplicació ja existeix",
     "Can't create app folder. Please fix permissions. %s" : "No es pot crear la carpeta de l'aplicació. Arregleu els permisos. %s",
@@ -30,6 +33,14 @@ OC.L10N.register(
     "App can't be installed because of not allowed code in the App" : "L'aplicació no es pot instal·lar perquè hi ha codi no autoritzat en l'aplicació",
     "App can't be installed because it is not compatible with this version of ownCloud" : "L'aplicació no es pot instal·lar perquè no és compatible amb aquesta versió d'ownCloud",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "L'aplicació no es pot instal·lar perquè conté l'etiqueta <shipped>vertader</shipped> que no es permet per aplicacions no enviades",
+    "Apps" : "Aplicacions",
+    "General" : "General",
+    "Storage" : "Emmagatzemament",
+    "Security" : "Seguretat",
+    "Encryption" : "Xifrat",
+    "Sharing" : "Compartir",
+    "Search" : "Cerca",
+    "Updates" : "Actualitzacions",
     "%s enter the database username." : "%s escriviu el nom d'usuari de la base de dades.",
     "%s enter the database name." : "%s escriviu el nom de la base de dades.",
     "%s you may not use dots in the database name" : "%s no podeu usar punts en el nom de la base de dades",
@@ -70,16 +81,12 @@ OC.L10N.register(
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Ha fallat en compartir %s, perquè el rerefons de compartir per %s no pot trobar la seva font",
     "Sharing %s failed, because the file could not be found in the file cache" : "Ha fallat en compartir %s, perquè el fitxer no s'ha trobat en el fitxer cau",
     "Could not find category \"%s\"" : "No s'ha trobat la categoria \"%s\"",
-    "Apps" : "Aplicacions",
     "A valid username must be provided" : "Heu de facilitar un nom d'usuari vàlid",
     "A valid password must be provided" : "Heu de facilitar una contrasenya vàlida",
     "The username is already being used" : "El nom d'usuari ja està en ús",
     "Help" : "Ajuda",
-    "Personal" : "Personal",
+    "Settings" : "Configuració",
     "Users" : "Usuaris",
-    "Admin" : "Administració",
-    "Recommended" : "Recomanat",
-    "No app name specified" : "No heu especificat cap nom d'aplicació",
     "web services under your control" : "controleu els vostres serveis web",
     "Application is not enabled" : "L'aplicació no està habilitada",
     "Authentication error" : "Error d'autenticació",
@@ -89,7 +96,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory" : "No es pot escriure a la carpeta \"config\"",
     "Cannot write into \"apps\" directory" : "No es pot escriure a la carpeta \"apps\"",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Això normalment es pot solucionar donant a %s permís d'escriptura a la carpeta d'aplicacions %s o inhabilitant la botiga d'aplicacions en el fitxer de configuració.",
-    "Cannot create \"data\" directory (%s)" : "No es pot crear la carpeta \"data\" (%s)",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Això normalment es pot solucionar donant a %s permís d'escriptura a la carpeta de configuració %s",
     "Setting locale to %s failed" : "Ha fallat en establir la llengua a %s",
     "Please install one of these locales on your system and restart your webserver." : "Siusplau, instal·li un d'aquests arxius de localització en el seu sistema, i reinicii el seu servidor web.",
@@ -101,10 +107,7 @@ OC.L10N.register(
     "PostgreSQL >= 9 required" : "Es requereix PostgreSQL >= 9",
     "Please upgrade your database version" : "Actualitzeu la versió de la base de dades",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Canvieu els permisos a 0770 per tal que la carpeta no es pugui llistar per altres usuaris.",
-    "Data directory (%s) is readable by other users" : "La carpeta de dades (%s) és llegible per altres usuaris",
-    "Data directory (%s) is invalid" : "La carpeta de dades (%s) no és vàlida",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Comproveu que la carpeta de dades contingui un fitxer \".ocdata\" a la seva arrel.",
-    "Could not obtain lock type %d on \"%s\"." : "No s'ha pogut obtenir un bloqueig tipus %d a \"%s\".",
-    "Storage not available" : "Emmagatzemament no disponible"
+    "Could not obtain lock type %d on \"%s\"." : "No s'ha pogut obtenir un bloqueig tipus %d a \"%s\"."
 },
 "nplurals=2; plural=(n != 1);");
