@@ -9,6 +9,7 @@ OC.L10N.register(
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Pravděpodobně byla zkopírována konfigurační nastavení ze vzorových souborů. Toto není podporováno a může poškodit vaši instalaci. Nahlédněte prosím do dokumentace před prováděním změn v souboru config.php",
     "PHP %s or higher is required." : "Je vyžadováno PHP %s nebo vyšší.",
     "PHP with a version lower than %s is required." : "Je vyžadováno PHP ve verzi nižší než %s.",
+    "%sbit or higher PHP required." : "Je vyžadováno PHP %sbit nebo vyšší.",
     "Following databases are supported: %s" : "Jsou podporovány následující databáze: %s",
     "The command line tool %s could not be found" : "Nástroj příkazového řádku %s nebyl nalezen",
     "The library %s is not available." : "Knihovna %s není dostupná.",
@@ -17,16 +18,9 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "Jsou podporovány následující systémy: %s",
     "ownCloud %s or higher is required." : "Je vyžadován ownCloud %s nebo vyšší.",
     "ownCloud %s or lower is required." : "Je vyžadován ownCloud %s nebo nižší.",
-    "Help" : "Nápověda",
-    "Personal" : "Osobní",
-    "Users" : "Uživatelé",
-    "Admin" : "Administrace",
-    "Recommended" : "Doporučené",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "Aplikace \"%s\" nemůže být nainstalována, protože není kompatibilní s touto verzí ownCloud.",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Aplikaci \"%s\" nelze nainstalovat, protože nejsou splněny následující závislosti: %s",
-    "No app name specified" : "Nebyl zadan název aplikace",
     "Unknown filetype" : "Neznámý typ souboru",
     "Invalid image" : "Chybný obrázek",
+    "Avatar image is not square" : "Obrázek avatara není čtvercový",
     "today" : "dnes",
     "yesterday" : "včera",
     "_%n day ago_::_%n days ago_" : ["včera","před %n dny","před %n dny"],
@@ -37,18 +31,21 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["před %n hodinou","před %n hodinami","před %n hodinami"],
     "_%n minute ago_::_%n minutes ago_" : ["před %n minutou","před %n minutami","před %n minutami"],
     "seconds ago" : "před pár sekundami",
-    "web services under your control" : "webové služby pod Vaší kontrolou",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul s id: %s neexistuje. Povolte ho prosím ve svých nastaveních aplikací nebo kontaktujte svého administrátora.",
+    "Builtin" : "Zabudované",
+    "None" : "Žádné",
+    "Username and password" : "Uživatelské jméno a heslo",
+    "Username" : "Uživatelské jméno",
+    "Password" : "Heslo",
+    "Log-in credentials, save in session" : "Přihlašovací údaje, ukládat v sezení",
     "Empty filename is not allowed" : "Prázdné jméno souboru není povoleno",
     "Dot files are not allowed" : "Jména souborů začínající tečkou nejsou povolena",
     "4-byte characters are not supported in file names" : "4-bytové znaky nejsou podporovány ve jménech souborů",
     "File name is a reserved word" : "Jméno souboru je rezervované slovo",
     "File name contains at least one invalid character" : "Jméno souboru obsahuje nejméně jeden neplatný znak",
     "File name is too long" : "Jméno souboru je moc dlouhé",
-    "File is currently busy, please try again later" : "Soubor je používán, zkus to později",
-    "Can't read file" : "Nelze přečíst soubor",
     "App directory already exists" : "Adresář aplikace již existuje",
-    "Can't create app folder. Please fix permissions. %s" : "Nelze vytvořit složku aplikace. Opravte práva souborů. %s",
+    "Can't create app folder. Please fix permissions. %s" : "Nelze vytvořit adresář aplikace. Opravte práva souborů. %s",
     "Archive does not contain a directory named %s" : "Archiv neobsahuje adresář pojmenovaný %s",
     "No source specified when installing app" : "Nebyl zadán zdroj při instalaci aplikace",
     "No href specified when installing app from http" : "Nebyl zadán odkaz pro instalaci aplikace z HTTP",
@@ -56,15 +53,24 @@ OC.L10N.register(
     "Archives of type %s are not supported" : "Archivy typu %s nejsou podporovány",
     "Failed to open archive when installing app" : "Chyba při otevírání archivu během instalace aplikace",
     "App does not provide an info.xml file" : "Aplikace neposkytuje soubor info.xml",
+    "App cannot be installed because appinfo file cannot be read." : "Aplikaci nelze nainstalovat, soubor appinfo nelze číst.",
     "Signature could not get checked. Please contact the app developer and check your admin screen." : "Podpis nelze ověřit. Kontaktujte prosím vývojáře aplikace a zkontrolujte obrazovku administrace.",
     "App can't be installed because of not allowed code in the App" : "Aplikace nemůže být nainstalována, protože obsahuje nepovolený kód",
     "App can't be installed because it is not compatible with this version of ownCloud" : "Aplikace nemůže být nainstalována, protože není kompatibilní s touto verzí ownCloud",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Aplikace nemůže být nainstalována, protože obsahuje značku\n<shipped>\n\ntrue\n</shipped>\n\ncož není povoleno pro nedodávané aplikace",
     "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "Aplikace nemůže být nainstalována, protože verze uvedená v info.xml nesouhlasí s verzí oznámenou z úložiště aplikací.",
-    "Application is not enabled" : "Aplikace není povolena",
-    "Authentication error" : "Chyba ověření",
-    "Token expired. Please reload page." : "Token vypršel. Obnovte prosím stránku.",
-    "Unknown user" : "Neznámý uživatel",
+    "Apps" : "Aplikace",
+    "General" : "Hlavní",
+    "Storage" : "Úložiště",
+    "Security" : "Zabezpečení",
+    "Encryption" : "Šifrování",
+    "Workflows & Tags" : "Pracovní postupy & Značky",
+    "Sharing" : "Sdílení",
+    "Search" : "Hledat",
+    "Updates" : "Aktualizace",
+    "Help & Tips" : "Nápověda & Triky",
+    "Additional" : "Dodatečný",
+    "%s enter the database username and name." : "%s zadejte uživatelské jméno a jméno databáze.",
     "%s enter the database username." : "Zadejte uživatelské jméno %s databáze.",
     "%s enter the database name." : "Zadejte název databáze pro %s databáze.",
     "%s you may not use dots in the database name" : "V názvu databáze %s nesmíte používat tečky.",
@@ -114,23 +120,35 @@ OC.L10N.register(
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Sdílení položky %s selhalo, protože úložiště sdílení %s nenalezla zdroj",
     "Sharing %s failed, because the file could not be found in the file cache" : "Sdílení položky %s selhalo, protože soubor nebyl nalezen ve vyrovnávací paměti",
     "Cannot increase permissions of %s" : "Nelze navýšit oprávnění  u %s",
+    "Files can't be shared with delete permissions" : "Soubory nelze sdílet s oprávněními ke smazání",
+    "Files can't be shared with create permissions" : "Soubory nelze sdílet s vytvořenými oprávněními",
     "Expiration date is in the past" : "Datum vypršení je v minulosti",
     "Cannot set expiration date more than %s days in the future" : "Datum vypršení nelze nastavit na více než %s dní do budoucnosti",
     "Could not find category \"%s\"" : "Nelze nalézt kategorii \"%s\"",
-    "Apps" : "Aplikace",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Pouze následující znaky jsou povoleny pro uživatelské jméno: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
     "A valid username must be provided" : "Musíte zadat platné uživatelské jméno",
     "Username contains whitespace at the beginning or at the end" : "Uživatelské jméno obsahuje mezery na svém začátku nebo konci",
     "A valid password must be provided" : "Musíte zadat platné heslo",
     "The username is already being used" : "Uživatelské jméno je již využíváno",
+    "Login canceled by app" : "Přihlášení zrušeno aplikací",
+    "User disabled" : "Uživatel zakázán",
+    "Help" : "Nápověda",
+    "Settings" : "Nastavení",
+    "Users" : "Uživatelé",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Aplikaci \"%s\" nelze nainstalovat, protože nejsou splněny následující závislosti: %s",
+    "web services under your control" : "webové služby pod vlastní kontrolou",
+    "File is currently busy, please try again later" : "Soubor je používán, zkus to později",
+    "Can't read file" : "Nelze přečíst soubor",
+    "Application is not enabled" : "Aplikace není povolena",
+    "Authentication error" : "Chyba ověření",
+    "Token expired. Please reload page." : "Token vypršel. Obnovte prosím stránku.",
+    "Unknown user" : "Neznámý uživatel",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Nejsou instalovány ovladače databází (sqlite, mysql nebo postresql).",
-    "Microsoft Windows Platform is not supported" : "Platforma Microsoft Windows není podporována",
-    "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Použití ownCloud Server na platformě Microsoft Windows není podporováno. Doporučujeme použít Linux server ve virtuálním stroji, pokud nemáte možnost migrace na samostatný stroj. Najití Linux balíčků je stejně snadné jako nasazení virtuálních strojů na <a href=\"%s\">%s</a>. Pro migraci stávajících zařízení na Linuxu najdete několik tipů a migrační skript v <a href=\"%s\"> naší dokumentaci</a>.",
     "Cannot write into \"config\" directory" : "Nelze zapisovat do adresáře \"config\"",
     "Cannot write into \"apps\" directory" : "Nelze zapisovat do adresáře \"apps\"",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "To lze obvykle vyřešit %spovolením zápisu webovému serveru do adresáře apps%s nebo zakázáním appstore v konfiguračním souboru.",
-    "Cannot create \"data\" directory (%s)" : "Nelze vytvořit adresář \"data\" (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "To lze obvykle vyřešit <a href=\"%s\" target=\"_blank\">povolením zápisu webovému serveru do kořenového adresáře</a>.",
+    "Cannot create \"data\" directory" : "Nelze vytvořit \"data\" adresář",
+    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Toto může být obvykle opraveno <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">nastavením přístupových práv webového serveru pro zápis do kořenového adresáře</a>.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Oprávnění lze obvykle napravit %spovolením zápisu webovému serveru do kořenového adresáře%s.",
     "Setting locale to %s failed" : "Nastavení jazyka na %s selhalo",
     "Please install one of these locales on your system and restart your webserver." : "Prosím nainstalujte alespoň jeden z těchto jazyků do svého systému a restartujte webový server.",
@@ -140,6 +158,8 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make ownCloud run again" : "Úprava tohoto nastavení v php.ini opět rozběhne ownCloud",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload je nastaven na \"%s\" místo očekávané hodnoty \"0\"",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Pro nápravu nastavte <code>mbstring.func_overload</code> na <code>0</code> v souboru php.ini",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Je požadováno minimálně libxml2 2.7.0. Aktuálně je nainstalována verze %s.",
+    "To fix this issue update your libxml2 version and restart your web server." : "Pro opravu tohoto problému aktualizujte libxml2 a restartujte web server.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP je patrně nastaveno tak, aby odstraňovalo bloky komentářů. Toto bude mít za následek znepřístupnění mnoha důležitých aplikací.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Toto je pravděpodobně způsobeno aplikacemi pro urychlení načítání jako jsou Zend OPcache nebo eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP moduly jsou nainstalovány, ale stále se tváří jako chybějící?",
@@ -147,16 +167,16 @@ OC.L10N.register(
     "PostgreSQL >= 9 required" : "Je vyžadováno PostgreSQL >= 9",
     "Please upgrade your database version" : "Aktualizujte prosím verzi své databáze",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Změňte prosím práva na 0770, aby adresář nemohl být otevřen ostatními uživateli.",
-    "Data directory (%s) is readable by other users" : "Datový adresář (%s) je čitelný i ostatními uživateli",
-    "Data directory (%s) must be an absolute path" : "Cesta k datovému adresáři (%s) musí být uvedena absolutně",
+    "Your Data directory is readable by other users" : "Váš datový adresář je čitelný i ostatními uživateli",
+    "Your Data directory must be an absolute path" : "Cesta k datovému adresáři musí být uvedena absolutně",
     "Check the value of \"datadirectory\" in your configuration" : "Ověřte hodnotu \"datadirectory\" ve své konfiguraci",
-    "Data directory (%s) is invalid" : "Datový adresář (%s) je neplatný",
+    "Your Data directory  is invalid" : "Váš datový adresář není platný",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Ověřte prosím, že kořenový adresář s daty obsahuje soubor \".ocdata\".",
     "Could not obtain lock type %d on \"%s\"." : "Nelze získat zámek typu %d na \"%s\".",
     "Storage unauthorized. %s" : "Úložiště neověřeno. %s",
     "Storage incomplete configuration. %s" : "Nekompletní konfigurace úložiště. %s",
     "Storage connection error. %s" : "Chyba připojení úložiště. %s",
-    "Storage not available" : "Úložiště není dostupné",
+    "Storage is temporarily not available" : "Úložiště je dočasně nedostupné",
     "Storage connection timeout. %s" : "Vypršení připojení k úložišti. %s"
 },
 "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
