@@ -1,19 +1,18 @@
 OC.L10N.register(
     "lib",
     {
-    "Help" : "Cymorth",
-    "Personal" : "Personol",
-    "Users" : "Defnyddwyr",
-    "Admin" : "Gweinyddu",
     "today" : "heddiw",
     "yesterday" : "ddoe",
     "last month" : "mis diwethaf",
     "last year" : "y llynedd",
     "seconds ago" : "eiliad yn ôl",
-    "web services under your control" : "gwasanaethau gwe a reolir gennych",
-    "Application is not enabled" : "Nid yw'r pecyn wedi'i alluogi",
-    "Authentication error" : "Gwall dilysu",
-    "Token expired. Please reload page." : "Tocyn wedi dod i ben. Ail-lwythwch y dudalen.",
+    "None" : "Dim",
+    "Username" : "Enw defnyddiwr",
+    "Password" : "Cyfrinair",
+    "Apps" : "Pecynnau",
+    "General" : "Cyffredinol",
+    "Encryption" : "Amgryptiad",
+    "Search" : "Chwilio",
     "%s enter the database username." : "%s rhowch enw defnyddiwr y gronfa ddata.",
     "%s enter the database name." : "%s rhowch enw'r gronfa ddata.",
     "%s you may not use dots in the database name" : "%s does dim hawl defnyddio dot yn enw'r gronfa ddata",
@@ -26,6 +25,12 @@ OC.L10N.register(
     "Set an admin username." : "Creu enw defnyddiwr i'r gweinyddwr.",
     "Set an admin password." : "Gosod cyfrinair y gweinyddwr.",
     "Could not find category \"%s\"" : "Methu canfod categori \"%s\"",
-    "Apps" : "Pecynnau"
+    "Help" : "Cymorth",
+    "Settings" : "Gosodiadau",
+    "Users" : "Defnyddwyr",
+    "web services under your control" : "gwasanaethau gwe a reolir gennych",
+    "Application is not enabled" : "Nid yw'r pecyn wedi'i alluogi",
+    "Authentication error" : "Gwall dilysu",
+    "Token expired. Please reload page." : "Tocyn wedi dod i ben. Ail-lwythwch y dudalen."
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
