@@ -20,6 +20,7 @@ OC.L10N.register(
     "ownCloud %s or lower is required." : "ownCloud %s oder niedriger wird benötigt.",
     "Unknown filetype" : "Unbekannter Dateityp",
     "Invalid image" : "Ungültiges Bild",
+    "Avatar image is not square" : "Avatar-Bild ist nicht quadratisch",
     "today" : "Heute",
     "yesterday" : "Gestern",
     "_%n day ago_::_%n days ago_" : ["Vor %n Tag","Vor %n Tagen"],
@@ -31,6 +32,12 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["Vor %n Minute","Vor %n Minuten"],
     "seconds ago" : "Gerade eben",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Das Modul mit der ID: %s existiert nicht. Bitte aktiviere es in Deinen App-Einstellungen oder kontaktiere Deinen Administrator.",
+    "Builtin" : "eingebaut",
+    "None" : "Keine",
+    "Username and password" : "Benutzername und Passwort",
+    "Username" : "Benutzername",
+    "Password" : "Passwort",
+    "Log-in credentials, save in session" : "Anmeldedaten in Sitzung speichern",
     "Empty filename is not allowed" : "Ein leerer Dateiname ist nicht erlaubt",
     "Dot files are not allowed" : "Dateinamen mit einem Punkt am Anfang sind nicht erlaubt",
     "4-byte characters are not supported in file names" : "4-Byte Zeichen sind in Dateinamen nicht erlaubt",
@@ -52,6 +59,18 @@ OC.L10N.register(
     "App can't be installed because it is not compatible with this version of ownCloud" : "Die App kann nicht installiert werden, weil sie mit dieser Version von ownCloud nicht kompatibel ist",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Die App kann nicht installiert werden, weil sie den <shipped>true</shipped>-Tag enthält, der bei Apps, die nicht zum Standardumfang von ownCloud gehören, nicht erlaubt ist",
     "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "Diese App kann nicht installiert werden, da die Version in info.xml nicht die gleiche Version wie die aus dem App Store ist.",
+    "Apps" : "Apps",
+    "General" : "Allgemein",
+    "Storage" : "Speicher",
+    "Security" : "Sicherheit",
+    "User Authentication" : "Nutzer-Authentifizierung",
+    "Encryption" : "Verschlüsselung",
+    "Workflows & Tags" : "Arbeitsabläufe & Tags",
+    "Sharing" : "Teilen",
+    "Search" : "Suche",
+    "Updates" : "Updates",
+    "Help & Tips" : "Hilfe & Tipps",
+    "Additional" : "Zusätzlich",
     "%s enter the database username and name." : "%s bitte gib den Datenbank Benutzernamen und den Datenbank Namen ein.",
     "%s enter the database username." : "%s gib den Datenbank-Benutzernamen an.",
     "%s enter the database name." : "%s gib den Datenbanknamen an.",
@@ -107,7 +126,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "Ablaufdatum ist in der Vergangenheit",
     "Cannot set expiration date more than %s days in the future" : "Das Ablaufdatum kann nicht mehr als %s Tage in die Zukunft liegen",
     "Could not find category \"%s\"" : "Die Kategorie „%s“ konnte nicht gefunden werden",
-    "Apps" : "Apps",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Folgende Zeichen sind im Benutzernamen erlaubt: „a-z“, „A-Z“, „0-9“ und „_.@-'“",
     "A valid username must be provided" : "Es muss ein gültiger Benutzername angegeben werden",
     "Username contains whitespace at the beginning or at the end" : "Der Benutzername enthält Leerzeichen am Anfang oder am Ende",
@@ -116,14 +134,9 @@ OC.L10N.register(
     "Login canceled by app" : "Anmeldung durch die App abgebrochen",
     "User disabled" : "Nutzer deaktiviert",
     "Help" : "Hilfe",
-    "Personal" : "Persönlich",
+    "Settings" : "Einstellungen",
     "Users" : "Benutzer",
-    "Admin" : "Administration",
-    "Recommended" : "Empfohlen",
-    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Die Anwendung \"%s\" kann nicht installiert werden, weil die Anwendungsinfodatei nicht gelesen werden kann.",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "Die App „%s“ kann nicht installiert werden, da sie mit dieser ownCloud-Version nicht kompatibel ist.",
     "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Die App „%s“ kann nicht installiert werden, da die folgenden Abhängigkeiten nicht erfüllt sind: %s",
-    "No app name specified" : "Es wurde kein App-Name angegeben",
     "web services under your control" : "Web-Dienste unter Deiner Kontrolle",
     "File is currently busy, please try again later" : "Die Datei ist zur Zeit in Benutzung, bitte versuche es später noch einmal",
     "Can't read file" : "Datei kann nicht gelesen werden",
@@ -132,12 +145,10 @@ OC.L10N.register(
     "Token expired. Please reload page." : "Token abgelaufen. Bitte lade die Seite neu.",
     "Unknown user" : "Unbekannter Benutzer",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Keine Datenbanktreiber (SQLite, MySQL oder PostgreSQL) installiert.",
-    "Microsoft Windows Platform is not supported" : "Microsoft Windows-Plattform wird nicht unterstützt",
-    "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Der Betrieb von ownCloud Server auf der Microsoft Windows-Plattform wird nicht unterstützt. Falls Du keine Möglichkeit zur Migration des Servers an sich hast, wird die Benutzung eines Linux-Servers innerhalb einer virtuellen Maschine empfohlen. Linux-Pakete wie auch leicht in Betrieb zu nehmende Abbilder virtueller Maschinen findest Du auf <a href=\"%s\">%s</a>. Einige Tipps zur Migration bestehender Installationen auf Linux und ein Migrationsskript findest Du in <a href=\"%s\">unserer Dokumentation</a>.",
     "Cannot write into \"config\" directory" : "Das Schreiben in das „config“-Verzeichnis ist nicht möglich",
     "Cannot write into \"apps\" directory" : "Das Schreiben in das „apps“-Verzeichnis ist nicht möglich",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Dies kann normalerweise behoben werden, %sindem dem Webserver Schreibzugriff auf das App-Verzeichnis gegeben wird%s oder der App Store in der Konfigurationsdatei deaktiviert wird.",
-    "Cannot create \"data\" directory (%s)" : "Das Erstellen des „data“-Verzeichnisses ist nicht möglich (%s)",
+    "Cannot create \"data\" directory" : "Das Erstellen des „data“-Verzeichnisses ist nicht möglich",
     "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Dies kann normalerweise repariert werden, indem dem Webserver <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\"> Schreibzugriff auf das Wurzelverzeichnis gegeben wird</a>.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Berechtigungen können normalerweise repariert werden, indem dem Webserver %s Schreibzugriff auf das Wurzelverzeichnis %s gegeben wird.",
     "Setting locale to %s failed" : "Das Setzen der Umgebungslokale auf %s fehlgeschlagen",
@@ -157,16 +168,16 @@ OC.L10N.register(
     "PostgreSQL >= 9 required" : "PostgreSQL >= 9 benötigt",
     "Please upgrade your database version" : "Bitte aktualisiere Deine Datenbankversion",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Bitte ändere die Berechtigungen auf 0770 sodass das Verzeichnis nicht von anderen Nutzer angezeigt werden kann.",
-    "Data directory (%s) is readable by other users" : "Daten-Verzeichnis (%s) ist von anderen Nutzern lesbar",
-    "Data directory (%s) must be an absolute path" : "Das Datenverzeichnis (%s) muss ein absoluter Pfad sein",
+    "Your Data directory is readable by other users" : "Dein Daten-Verzeichnis ist von anderen Benutzern lesbar",
+    "Your Data directory must be an absolute path" : "Dein Datenverzeichnis muss ein absoluter Pfad sein",
     "Check the value of \"datadirectory\" in your configuration" : "Überprüfe bitte die Angabe unter „datadirectory“ in Deiner Konfiguration",
-    "Data directory (%s) is invalid" : "Daten-Verzeichnis (%s) ist ungültig",
+    "Your Data directory  is invalid" : "Dein Daten-Verzeichnis ist ungültig",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Bitte stelle sicher, dass das Datenverzeichnis auf seiner ersten Ebene eine Datei namens „.ocdata“ enthält.",
     "Could not obtain lock type %d on \"%s\"." : "Sperrtyp %d auf „%s“ konnte nicht ermittelt werden.",
     "Storage unauthorized. %s" : "Speichern nicht erlaubt. %s",
     "Storage incomplete configuration. %s" : "Unvollständige Konfiguration des Storage. %s",
     "Storage connection error. %s" : "Verbindungsfehler zum Storage. %s",
-    "Storage not available" : "Speicher nicht verfügbar",
+    "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
     "Storage connection timeout. %s" : "Zeitüberschreitung der Verbindung zum Storage. %s"
 },
 "nplurals=2; plural=(n != 1);");
