@@ -2,11 +2,6 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "¡No se puede escribir en el directorio \"config\"!",
-    "Help" : "Ayuda",
-    "Personal" : "Personal",
-    "Users" : "Usuarios",
-    "Admin" : "Administración",
-    "No app name specified" : "No fue especificado el nombre de la app",
     "Unknown filetype" : "Tipo de archivo desconocido",
     "Invalid image" : "Imagen inválida",
     "today" : "hoy",
@@ -17,7 +12,9 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["Hace %n hora","Hace %n horas"],
     "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","Hace %n minutos"],
     "seconds ago" : "segundos atrás",
-    "web services under your control" : "servicios web sobre los que tenés control",
+    "None" : "Ninguno",
+    "Username" : "Nombre de usuario",
+    "Password" : "Contraseña",
     "App directory already exists" : "El directorio de la app ya existe",
     "Can't create app folder. Please fix permissions. %s" : "No se puede crear el directorio para la app. Corregí los permisos. %s",
     "No source specified when installing app" : "No se especificó el origen al instalar la app",
@@ -29,9 +26,14 @@ OC.L10N.register(
     "App can't be installed because of not allowed code in the App" : "No puede ser instalada la app por tener código no autorizado",
     "App can't be installed because it is not compatible with this version of ownCloud" : "No se puede instalar la app porque no es compatible con esta versión de ownCloud",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "La app no se puede instalar porque contiene la etiqueta <shipped>true</shipped> que no está permitida para apps no distribuidas",
-    "Application is not enabled" : "La aplicación no está habilitada",
-    "Authentication error" : "Error al autenticar",
-    "Token expired. Please reload page." : "Token expirado. Por favor, recargá la página.",
+    "Apps" : "Apps",
+    "General" : "General",
+    "Storage" : "Almacenamiento",
+    "Security" : "Seguridad",
+    "Encryption" : "Encriptación",
+    "Sharing" : "Compartiendo",
+    "Search" : "Buscar",
+    "Updates" : "Actualizaciones",
     "%s enter the database username." : "%s Entrá el usuario de la base de datos",
     "%s enter the database name." : "%s Entrá el nombre de la base de datos.",
     "%s you may not use dots in the database name" : "%s no podés usar puntos en el nombre de la base de datos",
@@ -46,9 +48,14 @@ OC.L10N.register(
     "Set an admin password." : "Configurar una contraseña de administrador.",
     "%s shared »%s« with you" : "%s compartió \"%s\" con vos",
     "Could not find category \"%s\"" : "No fue posible encontrar la categoría \"%s\"",
-    "Apps" : "Apps",
     "A valid username must be provided" : "Debe ingresar un nombre de usuario válido",
     "A valid password must be provided" : "Debe ingresar una contraseña válida",
-    "Storage not available" : "Almacenamiento no disponible"
+    "Help" : "Ayuda",
+    "Settings" : "Configuración",
+    "Users" : "Usuarios",
+    "web services under your control" : "servicios web sobre los que tenés control",
+    "Application is not enabled" : "La aplicación no está habilitada",
+    "Authentication error" : "Error al autenticar",
+    "Token expired. Please reload page." : "Token expirado. Por favor, recargá la página."
 },
 "nplurals=2; plural=(n != 1);");
