@@ -9,6 +9,7 @@ OC.L10N.register(
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Il a été détecté que la configuration donnée à titre d'exemple a été copiée. Cela peut rendre votre installation inopérante et n'est pas pris en charge. Veuillez lire la documentation avant d'effectuer des modifications dans config.php",
     "PHP %s or higher is required." : "PHP %s ou supérieur est requis.",
     "PHP with a version lower than %s is required." : "PHP avec une version antérieure à %s est requis.",
+    "%sbit or higher PHP required." : "%sbit ou PHP supérieur est requis.",
     "Following databases are supported: %s" : "Les bases de données suivantes sont supportées : %s",
     "The command line tool %s could not be found" : "La commande %s est introuvable",
     "The library %s is not available." : "La librairie %s n'est pas disponible.",
@@ -17,16 +18,9 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "Les plateformes suivantes sont prises en charge : %s",
     "ownCloud %s or higher is required." : "ownCloud %s ou supérieur est requis.",
     "ownCloud %s or lower is required." : "ownCloud %s ou inférieur est requis.",
-    "Help" : "Aide",
-    "Personal" : "Personnel",
-    "Users" : "Utilisateurs",
-    "Admin" : "Administration",
-    "Recommended" : "Recommandée",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "L'application \"%s\" ne peut pas être installée car elle n'est pas compatible avec cette version de ownCloud.",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "L'application \"%s\" ne peut pas être installée à cause des dépendances suivantes non satisfaites : %s",
-    "No app name specified" : "Aucun nom d'application spécifié",
     "Unknown filetype" : "Type de fichier inconnu",
     "Invalid image" : "Image non valable",
+    "Avatar image is not square" : "L'image de l'avatar n'est pas carrée",
     "today" : "aujourd'hui",
     "yesterday" : "hier",
     "_%n day ago_::_%n days ago_" : ["il y a %n jour","il y a %n jours"],
@@ -37,16 +31,19 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["Il y a %n heure","Il y a %n heures"],
     "_%n minute ago_::_%n minutes ago_" : ["il y a %n minute","il y a %n minutes"],
     "seconds ago" : "il y a quelques secondes",
-    "web services under your control" : "services web sous votre contrôle",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Le module avec l'id: %s n'existe pas. Merci de l'activer dans les paramètres d'applications ou de contacter votre administrateur.",
+    "Builtin" : "Intégré",
+    "None" : "Aucun",
+    "Username and password" : "Nom d'utilisateur et mot de passe",
+    "Username" : "Nom d'utilisateur",
+    "Password" : "Mot de passe",
+    "Log-in credentials, save in session" : "Identifiants de connexion, sauvegardés pour la session",
     "Empty filename is not allowed" : "Le nom de fichier ne peut pas être vide",
     "Dot files are not allowed" : "Le nom de fichier ne peut pas commencer par un point",
     "4-byte characters are not supported in file names" : "Les caractères sur 4 octets ne sont pas pris en charge dans les noms de fichiers",
     "File name is a reserved word" : "Ce nom de fichier est un mot réservé",
     "File name contains at least one invalid character" : "Le nom de fichier contient un (des) caractère(s) non valide(s)",
     "File name is too long" : "Nom de fichier trop long",
-    "File is currently busy, please try again later" : "Le fichier est actuellement utilisé, veuillez réessayer plus tard",
-    "Can't read file" : "Impossible de lire le fichier",
     "App directory already exists" : "Le dossier de l'application existe déjà",
     "Can't create app folder. Please fix permissions. %s" : "Impossible de créer le dossier de l'application. Corrigez les droits d'accès. %s",
     "Archive does not contain a directory named %s" : "Le fichier archive ne contient pas de répertoire %s",
@@ -56,15 +53,23 @@ OC.L10N.register(
     "Archives of type %s are not supported" : "Les archives de type %s ne sont pas prises en charge",
     "Failed to open archive when installing app" : "Échec de l'ouverture de l'archive lors de l'installation de l'application",
     "App does not provide an info.xml file" : "L'application ne fournit pas de fichier info.xml",
+    "App cannot be installed because appinfo file cannot be read." : "L'application ne peut pas être installée car le fichier appinfo ne peut pas être lu.",
     "Signature could not get checked. Please contact the app developer and check your admin screen." : "La signature n'a pas pu être vérifiée. Merci de contacter le développeur de l'application et de vérifier votre page d'administration.",
     "App can't be installed because of not allowed code in the App" : "L'application ne peut être installée car elle contient du code non-autorisé",
     "App can't be installed because it is not compatible with this version of ownCloud" : "L'application ne peut être installée car elle n'est pas compatible avec cette version de ownCloud",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "L'application ne peut être installée car elle contient la balise <shipped>true</shipped> qui n'est pas autorisée pour les applications non incluses par défaut",
     "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "L'App ne peut pas être installé car la version dans info.xml diffère de la version signalée par l' app store",
-    "Application is not enabled" : "L'application n'est pas activée",
-    "Authentication error" : "Erreur d'authentification",
-    "Token expired. Please reload page." : "La session a expiré. Veuillez recharger la page.",
-    "Unknown user" : "Utilisateur inconnu",
+    "Apps" : "Applications",
+    "General" : "Généraux",
+    "Storage" : "Stockage",
+    "Security" : "Sécurité",
+    "Encryption" : "Chiffrement",
+    "Sharing" : "Partage",
+    "Search" : "Rechercher",
+    "Updates" : "Mises à jour",
+    "Help & Tips" : "Aide et Astuces",
+    "Additional" : "Suppléments",
+    "%s enter the database username and name." : "%s entrez le nom d'utilisateur et le nom de la base de données.",
     "%s enter the database username." : "%s entrez le nom d'utilisateur de la base de données.",
     "%s enter the database name." : "%s entrez le nom de la base de données.",
     "%s you may not use dots in the database name" : "%s vous ne pouvez pas utiliser de points dans le nom de la base de données",
@@ -114,23 +119,35 @@ OC.L10N.register(
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Le partage de %s a échoué car le service %s n'a pas trouvé sa source..",
     "Sharing %s failed, because the file could not be found in the file cache" : "Le partage de %s a échoué car le fichier n'a pas été trouvé dans les fichiers mis en cache.",
     "Cannot increase permissions of %s" : "Impossible d'augmenter les permissions de %s",
+    "Files can't be shared with delete permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de suppression",
+    "Files can't be shared with create permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de création",
     "Expiration date is in the past" : "La date d'expiration est dans le passé",
     "Cannot set expiration date more than %s days in the future" : "Impossible de définir la date d'expiration à plus de %s jours dans le futur",
     "Could not find category \"%s\"" : "Impossible de trouver la catégorie \"%s\"",
-    "Apps" : "Applications",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Seuls les caractères suivants sont autorisés dans un nom d'utilisateur : \"a-z\", \"A-Z\", \"0-9\", \"_@-\" et \".\" (le point)",
     "A valid username must be provided" : "Un nom d'utilisateur valide doit être saisi",
     "Username contains whitespace at the beginning or at the end" : "Le nom d'utilisateur contient des espaces au début ou à la fin",
     "A valid password must be provided" : "Un mot de passe valide doit être saisi",
     "The username is already being used" : "Ce nom d'utilisateur est déjà utilisé",
+    "Login canceled by app" : "L'authentification a été annulé par l'application",
+    "User disabled" : "Utilisateur désactivé",
+    "Help" : "Aide",
+    "Settings" : "Paramètres",
+    "Users" : "Utilisateurs",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "L'application \"%s\" ne peut pas être installée à cause des dépendances suivantes non satisfaites : %s",
+    "web services under your control" : "services web sous votre contrôle",
+    "File is currently busy, please try again later" : "Le fichier est actuellement utilisé, veuillez réessayer plus tard",
+    "Can't read file" : "Impossible de lire le fichier",
+    "Application is not enabled" : "L'application n'est pas activée",
+    "Authentication error" : "Erreur d'authentification",
+    "Token expired. Please reload page." : "La session a expiré. Veuillez recharger la page.",
+    "Unknown user" : "Utilisateur inconnu",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Aucun pilote de base de données n’est installé (sqlite, mysql ou postgresql).",
-    "Microsoft Windows Platform is not supported" : "La plate-forme Microsoft Windows n'est pas prise en charge.",
-    "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Executer un serveur ownCloud sur une plate-forme Microsoft Windows n'est pas pris en charge. Si vous n'avez pas la possibilité de migrer votre serveur, nous vous suggérons d'utiliser un serveur Linux dans une machine virtuelle . Les paquets Linux nécessaires ainsi que des images virtuelles faciles à déployer se trouvent sur <a href=\"%s\">%s</a>. Pour migrer des installations existantes vers Linux, vous trouverez des conseils et des scripts de migration dans <a href=\"%s\">notre documentation</a>.",
     "Cannot write into \"config\" directory" : "Impossible d’écrire dans le répertoire \"config\"",
     "Cannot write into \"apps\" directory" : "Impossible d’écrire dans le répertoire \"apps\"",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Ce problème est généralement résolu %sen donnant au serveur web un accès en écriture au répertoire apps%s ou en désactivant l'appstore dans le fichier de configuration.",
-    "Cannot create \"data\" directory (%s)" : "Impossible de créer le répertoire \"data\" (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Ce problème est généralement résolu <a href=\"%s\" target=\"_blank\">en donnant au serveur web un accès en écriture au répertoire racine</a>.",
+    "Cannot create \"data\" directory" : "Impossible de créer le dossier \"data\"",
+    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Ce problème est généralement résolu <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">en donnant au serveur web un accès en écriture au répertoire racine</a>.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Le problème de permissions peut généralement être résolu %sen donnant au serveur web un accès en écriture au répertoire racine%s",
     "Setting locale to %s failed" : "Echec de la spécification des paramètres régionaux à %s",
     "Please install one of these locales on your system and restart your webserver." : "Veuillez installer l'un de ces paramètres régionaux sur votre système et redémarrer votre serveur web.",
@@ -140,6 +157,8 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make ownCloud run again" : "Ajuster ce paramètre dans php.ini permettra à ownCloud de fonctionner à nouveau",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload est à \"%s\" alors que la valeur \"0\" est attendue",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Pour corriger ce problème mettez <code>mbstring.func_overload</code> à <code>0</code> dans votre php.ini",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 au moins est requis. Actuellement %s est installé.",
+    "To fix this issue update your libxml2 version and restart your web server." : "Pour régler ce problème, mettez à jour votre version de libxml2 et redémarrez votre serveur web.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP semble configuré de manière à supprimer les blocs PHPdoc du code. Cela rendra plusieurs applications de base inaccessibles.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "La raison est probablement l'utilisation d'un cache / accélérateur tel que Zend OPcache ou eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Les modules PHP ont été installés mais sont toujours indiqués comme manquants ?",
@@ -147,16 +166,16 @@ OC.L10N.register(
     "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requis",
     "Please upgrade your database version" : "Veuillez mettre à jour votre gestionnaire de base de données",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Veuillez changer les permissions du répertoire en mode 0770 afin que son contenu ne puisse pas être listé par les autres utilisateurs.",
-    "Data directory (%s) is readable by other users" : "Le répertoire de données (%s) est lisible par les autres utilisateurs",
-    "Data directory (%s) must be an absolute path" : "Le chemin du dossier de données (%s) doit être absolu",
+    "Your Data directory is readable by other users" : "Votre dossier Data est lisible par les autres utilisateurs",
+    "Your Data directory must be an absolute path" : "Votre dossier Data doit être un chemin absolu",
     "Check the value of \"datadirectory\" in your configuration" : "Verifiez la valeur de \"datadirectory\" dans votre configuration",
-    "Data directory (%s) is invalid" : "Le répertoire (%s) n'est pas valide",
+    "Your Data directory  is invalid" : "Votre dossier Data n'est pas valide",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Veuillez vérifier que le répertoire de données contient un fichier \".ocdata\" à sa racine.",
     "Could not obtain lock type %d on \"%s\"." : "Impossible d'obtenir le verrouillage de type %d sur \"%s\".",
     "Storage unauthorized. %s" : "Espace de stockage non autorisé. %s",
     "Storage incomplete configuration. %s" : "Configuration de l'espace de stockage incomplète. %s",
     "Storage connection error. %s" : "Erreur de connexion à l'espace stockage. %s",
-    "Storage not available" : "Support de stockage non disponible",
+    "Storage is temporarily not available" : "Espace de stockage temporairement indisponible",
     "Storage connection timeout. %s" : "Le délai d'attente pour la connexion à l'espace de stockage a été dépassé. %s"
 },
 "nplurals=2; plural=(n > 1);");
