@@ -9,6 +9,7 @@ OC.L10N.register(
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "サンプル設定がコピーされてそのままです。このままではインストールが失敗し、サポート対象外になります。config.phpを変更する前にドキュメントを確認してください。",
     "PHP %s or higher is required." : "PHP %s 以上が必要です。",
     "PHP with a version lower than %s is required." : "%s 以前のバージョンのPHPが必要です。",
+    "%sbit or higher PHP required." : "%sbit 以上の新しいバージョンのPHPが必要です。",
     "Following databases are supported: %s" : "次のデータベースをサポートしています: %s",
     "The command line tool %s could not be found" : "コマンド '%s' は見つかりませんでした。",
     "The library %s is not available." : " %s ライブラリーが利用できません。",
@@ -17,16 +18,9 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "次のプラットフォームをサポートしています: %s",
     "ownCloud %s or higher is required." : "ownCloud %s 以上が必要です。",
     "ownCloud %s or lower is required." : "ownCloud %s 以下が必要です。",
-    "Help" : "ヘルプ",
-    "Personal" : "個人",
-    "Users" : "ユーザー",
-    "Admin" : "管理",
-    "Recommended" : "おすすめ",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : " \"%s\" アプリは、このバージョンのownCloudと互換性がない為、インストールできません。",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "次の依存関係が満たされないため、\"%s\" アプリをインストールできません：%s",
-    "No app name specified" : "アプリ名が未指定",
     "Unknown filetype" : "不明なファイルタイプ",
     "Invalid image" : "無効な画像",
+    "Avatar image is not square" : "アバターイメージが正方形ではありません",
     "today" : "今日",
     "yesterday" : "1日前",
     "_%n day ago_::_%n days ago_" : ["%n 日前"],
@@ -37,32 +31,46 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n 時間前"],
     "_%n minute ago_::_%n minutes ago_" : ["%n 分前"],
     "seconds ago" : "数秒前",
-    "web services under your control" : "あなたが管理するウェブサービス",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "id: %sのモジュールは存在しません。アプリ設定で有効にするか、管理者に問い合わせてください。",
+    "Builtin" : "ビルトイン",
+    "None" : "なし",
+    "Username and password" : "ユーザー名とパスワード",
+    "Username" : "ユーザー名",
+    "Password" : "パスワード",
+    "Log-in credentials, save in session" : "ログイン認証情報は、セッションに保存されます。",
     "Empty filename is not allowed" : "空のファイル名は許可されていません",
     "Dot files are not allowed" : "ドットファイルは許可されていません",
     "4-byte characters are not supported in file names" : "ファイル名に4バイト文字を使用するのはサポートされていません",
     "File name is a reserved word" : "ファイル名が予約された単語です",
     "File name contains at least one invalid character" : "ファイル名に1文字以上の無効な文字が含まれています",
     "File name is too long" : "ファイル名が長すぎます",
-    "File is currently busy, please try again later" : "現在ファイルはビジーです。後でもう一度試してください。",
-    "Can't read file" : "ファイルを読み込めません",
     "App directory already exists" : "アプリディレクトリはすでに存在します",
     "Can't create app folder. Please fix permissions. %s" : "アプリフォルダーを作成できませんでした。%s のパーミッションを修正してください。",
+    "Archive does not contain a directory named %s" : "%s という名前のディレクトリは、アーカイブに含まれていません",
     "No source specified when installing app" : "アプリインストール時のソースが未指定",
     "No href specified when installing app from http" : "アプリインストール時のhttpの URL が未指定",
     "No path specified when installing app from local file" : "アプリインストール時のローカルファイルのパスが未指定",
     "Archives of type %s are not supported" : "\"%s\"タイプのアーカイブ形式は未サポート",
     "Failed to open archive when installing app" : "アプリをインストール中にアーカイブファイルを開けませんでした。",
     "App does not provide an info.xml file" : "アプリにinfo.xmlファイルが入っていません",
+    "App cannot be installed because appinfo file cannot be read." : "appinfoファイルが読み込めないため、アプリがインストールできません。",
+    "Signature could not get checked. Please contact the app developer and check your admin screen." : "署名が確認できませんでした｡このアプリの開発者へ連絡し、管理画面を確認してください。",
     "App can't be installed because of not allowed code in the App" : "アプリで許可されないコードが入っているのが原因でアプリがインストールできません",
     "App can't be installed because it is not compatible with this version of ownCloud" : "アプリは、このバージョンのownCloudと互換性がないためインストールできません。",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "非shippedアプリには許可されない<shipped>true</shipped>タグが含まれているためにアプリをインストールできません。",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "info.xml/versionのバージョンがアプリストアのバージョンと合っていないため、アプリはインストールされません",
-    "Application is not enabled" : "アプリケーションは無効です",
-    "Authentication error" : "認証エラー",
-    "Token expired. Please reload page." : "トークンが無効になりました。ページを再読込してください。",
-    "Unknown user" : "不明なユーザー",
+    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "info.xmlのバージョンがアプリストアのバージョンと合っていないため、アプリはインストールされません",
+    "Apps" : "アプリ",
+    "General" : "一般",
+    "Storage" : "ストレージ",
+    "Security" : "セキュリティ",
+    "User Authentication" : "ユーザー認証",
+    "Encryption" : "暗号化",
+    "Workflows & Tags" : "ワークフロー＆タグ",
+    "Sharing" : "共有",
+    "Search" : "検索",
+    "Updates" : "アップデート",
+    "Help & Tips" : "ヘルプ＆ヒント",
+    "%s enter the database username and name." : "%s データベース名とデータベースのユーザー名を入力してください。",
     "%s enter the database username." : "%s のデータベースのユーザー名を入力してください。",
     "%s enter the database name." : "%s のデータベース名を入力してください。",
     "%s you may not use dots in the database name" : "%s ではデータベース名にドットを利用できないかもしれません。",
@@ -80,49 +88,67 @@ OC.L10N.register(
     "Set an admin username." : "管理者のユーザー名を設定",
     "Set an admin password." : "管理者のパスワードを設定。",
     "Can't create or write into the data directory %s" : "%s データディレクトリに作成、書き込みができません",
-    "Invalid Federated Cloud ID" : "無効な統合されたクラウドID",
+    "Invalid Federated Cloud ID" : "クラウド連携IDが無効です",
     "%s shared »%s« with you" : "%sが あなたと »%s«を共有しました",
     "%s via %s" : "%s に %s から",
-    "Sharing %s failed, because the backend does not allow shares from type %i" : "%s の共有に失敗しました。%i タイプからの共有は許可されていないからです。",
-    "Sharing %s failed, because the file does not exist" : "%s の共有に失敗しました。そのようなファイルは存在しないからです。",
+    "Sharing %s failed, because the backend does not allow shares from type %i" : "%s を共有できませんでした。%i タイプからの共有は許可されていません。",
+    "Sharing %s failed, because the file does not exist" : "%s を共有できませんでした。そのファイルは存在しません。",
     "You are not allowed to share %s" : "%s を共有することを許可されていません。",
-    "Sharing %s failed, because the user %s is the item owner" : "%s の共有に失敗しました。ユーザー %s がアイテム所有者です。",
-    "Sharing %s failed, because the user %s does not exist" : "%s の共有に失敗しました。ユーザー %s が存在しません。",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s の共有に失敗しました。ユーザー %s はどのグループにも属していません。%s は、??のメンバーです。",
-    "Sharing %s failed, because this item is already shared with %s" : "%s の共有に失敗しました。このアイテムはすでに %s で共有されています。",
-    "Sharing %s failed, because the group %s does not exist" : "%s の共有に失敗しました。グループ %s は存在しません。",
-    "Sharing %s failed, because %s is not a member of the group %s" : "%s の共有に失敗しました。%s は、グループ %s のメンバーではありません。",
+    "Sharing %s failed, because you can not share with yourself" : "%s を共有できませんでした。自分自身に共有することはできません。",
+    "Sharing %s failed, because the user %s does not exist" : "%s を共有できませんでした。ユーザー %s が存在しません。",
+    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s を共有できませんでした。ユーザー %s はどのグループにも属していません。%s は、??のメンバーです。",
+    "Sharing %s failed, because this item is already shared with %s" : "%s を共有できませんでした。このアイテムはすでに %s に共有されています。",
+    "Sharing %s failed, because this item is already shared with user %s" : "%s を共有できませんでした。このアイテムは、ユーザー %s によりすでに共有されています。",
+    "Sharing %s failed, because the group %s does not exist" : "%s を共有できませんでした。グループ %s は存在しません。",
+    "Sharing %s failed, because %s is not a member of the group %s" : "%s を共有できませんでした。%s は、グループ %s のメンバーではありません。",
     "You need to provide a password to create a public link, only protected links are allowed" : "公開用リンクの作成にはパスワードの設定が必要です",
-    "Sharing %s failed, because sharing with links is not allowed" : "%s の共有に失敗しました。リンクでの共有は許可されていません。",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s の共有に失敗しました。%s が見つかりませんでした。現在サーバーに接続できないようです。",
+    "Sharing %s failed, because sharing with links is not allowed" : "%s を共有できませんでした。リンクでの共有は許可されていません。",
+    "Not allowed to create a federated share with the same user" : "同じユーザーではサーバー連携共有は作成できません",
+    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s を共有できませんでした。%s が見つかりませんでした。現在サーバーに接続できないようです。",
     "Share type %s is not valid for %s" : "%s の共有方法は、%s には適用できません。",
-    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "%s の権限設定に失敗しました。%s に許可されている権限を越えています。",
-    "Setting permissions for %s failed, because the item was not found" : "%s の権限設定に失敗しました。アイテムが存在しません。",
+    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "%s を共有できませんでした。%s に許可されている権限を越えています。",
+    "Setting permissions for %s failed, because the item was not found" : "%s を共有できませんでした。アイテムが存在しません。",
     "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "有効期限を設定できません。共有開始から %s 以降に有効期限を設定することはできません。",
     "Cannot set expiration date. Expiration date is in the past" : "有効期限を設定できません。有効期限が過去を示しています。",
     "Cannot clear expiration date. Shares are required to have an expiration date." : "有効期限を解除できません。共有するには有効期限を設定する必要があります。",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "%s のバックエンドの共有には、OCP\\Share_Backend インターフェースを実装しなければなりません。",
     "Sharing backend %s not found" : "共有バックエンド %s が見つかりません",
     "Sharing backend for %s not found" : "%s のための共有バックエンドが見つかりません",
-    "Sharing %s failed, because the user %s is the original sharer" : "%s の共有に失敗しました。ユーザー %s が元々の共有者であるからです。",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "%s の共有に失敗しました。%s に付与されている許可を超えているからです。",
-    "Sharing %s failed, because resharing is not allowed" : "%s の共有に失敗しました。再共有が許されていないからです。",
+    "Sharing failed, because the user %s is the original sharer" : "共有できませんでした。ユーザー %sは元々の共有者です。",
+    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "%s を共有できませんでした。%s に許可されている権限を越えています。",
+    "Sharing %s failed, because resharing is not allowed" : "%s を共有できませんでした。再共有は許可されていません。",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s の共有に失敗しました。%s のバックエンド共有に必要なソースが見つかりませんでした。",
     "Sharing %s failed, because the file could not be found in the file cache" : "%s の共有に失敗しました。ファイルキャッシュにファイルがありませんでした。",
+    "Cannot increase permissions of %s" : "%s　の権限を強化できません",
+    "Files can't be shared with delete permissions" : "削除権限つきでファイルを共有できません。",
+    "Files can't be shared with create permissions" : "作成権限つきでファイルを共有できません。",
+    "Expiration date is in the past" : "有効期限が切れています",
+    "Cannot set expiration date more than %s days in the future" : "有効期限を%s日以降に設定できません。",
     "Could not find category \"%s\"" : "カテゴリ \"%s\" が見つかりませんでした",
-    "Apps" : "アプリ",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "ユーザー名で利用できる文字列は、次のものです： \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "ユーザー名で利用できる文字列は、次のものです： \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"",
     "A valid username must be provided" : "有効なユーザー名を指定する必要があります",
+    "Username contains whitespace at the beginning or at the end" : "ユーザー名の最初か最後に空白が含まれています",
     "A valid password must be provided" : "有効なパスワードを指定する必要があります",
     "The username is already being used" : "ユーザー名はすでに使われています",
+    "Login canceled by app" : "アプリによりログインが中止されました",
+    "User disabled" : "ユーザーは無効です",
+    "Help" : "ヘルプ",
+    "Settings" : "設定",
+    "Users" : "ユーザー",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "次の依存関係が満たされないため、\"%s\" アプリをインストールできません：%s",
+    "web services under your control" : "あなたが管理するウェブサービス",
+    "File is currently busy, please try again later" : "現在ファイルはビジーです。後でもう一度試してください。",
+    "Can't read file" : "ファイルを読み込めません",
+    "Application is not enabled" : "アプリケーションは無効です",
+    "Authentication error" : "認証エラー",
+    "Token expired. Please reload page." : "トークンが無効になりました。ページを再読込してください。",
+    "Unknown user" : "不明なユーザー",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "データベースドライバー (sqlite, mysql, postgresql) がインストールされていません。",
-    "Microsoft Windows Platform is not supported" : "Microsoft Windows サーバーはサポートしていません。",
-    "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Microsoft Windowsサーバー上での ownCloud の動作は、サポートされていません。現在のサーバーOSを変更することができないのであれば、仮想マシン上で Linuxサーバーを動かすことをお勧めします。仮想マシンイメージを配置するのと同じぐらい簡単にLinuxパッケージを<a href=\"%s\">%s</a>で見つけられます。現在稼働中の設定をLinuxに移行する 移行スクリプトと注意点をこちらの<a href=\"%s\">ドキュメント</a>で確認してください。",
     "Cannot write into \"config\" directory" : "\"config\" ディレクトリに書き込みができません",
     "Cannot write into \"apps\" directory" : "\"apps\" ディレクトリに書き込みができません",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "多くの場合、これは %s Webサーバーにappsディレクトリ %s への書き込み権限を与えるか、設定ファイルでアプリストアを無効化することで解決できます。",
-    "Cannot create \"data\" directory (%s)" : "\"data\" ディレクトリ (%s) を作成できません",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "多くの場合、これは<a href=\"%s\" target=\"_blank\">Webサーバーにルートディレクトリへの書き込み権限を与える</a>ことで解決できます。",
+    "Cannot create \"data\" directory" : "\"データ\" ディレクトリを作成できません",
+    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "通常、<a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">Webサーバーにルートディレクトリへの書き込み権限を与える</a>ことで解決できます。",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "多くの場合、パーミッションは %s Webサーバーにルートディレクトリ %s への書き込み権限を与えることで解決できます。",
     "Setting locale to %s failed" : "ロケールを %s に設定できませんでした",
     "Please install one of these locales on your system and restart your webserver." : "これらのロケールのうちいずれかをシステムにインストールし、Webサーバーを再起動してください。",
@@ -132,20 +158,25 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make ownCloud run again" : "php.ini 中の設定を調整するとownCloudはもう一度動作するでしょう。 ",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload の値は \"0\" であるべきですが、\"%s\" に設定されています",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "この問題を修正するには、php.ini ファイルの <code>mbstring.func_overload</code> を <code>0</code> に設定してください。",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "最低バージョン 2.7.0  のlibxml2 が必要です。現在 %s がインストールされています。",
+    "To fix this issue update your libxml2 version and restart your web server." : "この問題を解決するには、libxml2 を更新して、ウェブサーバーを再起動してください。",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHPでインラインドキュメントブロックを取り除く設定になっています。これによりコアアプリで利用できないものがいくつかあります。",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "これは、Zend OPcacheやeAccelerator 等のキャッシュ/アクセラレーターが原因かもしれません。",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP モジュールはインストールされていますが、まだ一覧に表示されていますか？",
     "Please ask your server administrator to restart the web server." : "サーバー管理者にWebサーバーを再起動するよう依頼してください。",
     "PostgreSQL >= 9 required" : "PostgreSQL >= 9 が必要です",
     "Please upgrade your database version" : "新しいバージョンのデータベースにアップグレードしてください",
-    "Error occurred while checking PostgreSQL version" : "PostgreSQL のバージョンチェック中にエラーが発生しました",
-    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "PostgreSQL >= 9 がインストールされているかどうか確認してください。もしくは、ログからエラーに関する詳細な情報を確認してください。",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "ディレクトリが他のユーザーから見えないように、パーミッションを 0770 に変更してください。",
-    "Data directory (%s) is readable by other users" : "データディレクトリ (%s) は他のユーザーも閲覧することができます",
-    "Data directory (%s) must be an absolute path" : "データディレクトリ (%s) は、絶対パスである必要があります。",
+    "Your Data directory is readable by other users" : "あなたのデータディレクトリが他のユーザーから閲覧できる状態です。",
+    "Your Data directory must be an absolute path" : "データディレクトリは絶対パスである必要があります。",
     "Check the value of \"datadirectory\" in your configuration" : "設定ファイル内の \"datadirectory\" の値を確認してください。",
-    "Data directory (%s) is invalid" : "データディレクトリ (%s) は無効です",
+    "Your Data directory  is invalid" : "あなたのデータディレクトリが無効です",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "データディレクトリに \".ocdata\" ファイルが含まれていることを確認してください。",
-    "Could not obtain lock type %d on \"%s\"." : "\"%s\" で %d タイプのロックを取得できませんでした。"
+    "Could not obtain lock type %d on \"%s\"." : "\"%s\" で %d タイプのロックを取得できませんでした。",
+    "Storage unauthorized. %s" : "権限のないストレージです。 %s",
+    "Storage incomplete configuration. %s" : "設定が未完了のストレージです。 %s",
+    "Storage connection error. %s" : "ストレージへの接続エラー｡ %s",
+    "Storage is temporarily not available" : "ストレージが一時的に利用できません",
+    "Storage connection timeout. %s" : "ストレージへの接続がタイムアウト。 %s"
 },
 "nplurals=1; plural=0;");
