@@ -9,6 +9,7 @@ OC.L10N.register(
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "예제 설정이 복사된 것 같습니다. 올바르게 작동하지 않을 수도 있기 때문에 지원되지 않습니다. config.php를 변경하기 전 문서를 읽어 보십시오",
     "PHP %s or higher is required." : "PHP 버전 %s 이상이 필요합니다.",
     "PHP with a version lower than %s is required." : "PHP 버전 %s 미만이 필요합니다.",
+    "%sbit or higher PHP required." : "%s비트 이상의 PHP가 필요합니다.",
     "Following databases are supported: %s" : "다음 데이터베이스를 지원합니다: %s",
     "The command line tool %s could not be found" : "명령행 도구 %s을(를) 찾을 수 없습니다",
     "The library %s is not available." : "%s 라이브러리를 사용할 수 없습니다.",
@@ -17,16 +18,9 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "다음 플랫폼을 지원합니다: %s",
     "ownCloud %s or higher is required." : "ownCloud 버전 %s 이상이 필요합니다.",
     "ownCloud %s or lower is required." : "ownCloud %s 이하가 필요합니다.",
-    "Help" : "도움말",
-    "Personal" : "개인",
-    "Users" : "사용자",
-    "Admin" : "관리자",
-    "Recommended" : "추천",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "앱 \"%s\"이(가) 이 버전의 ownCloud와 호환되지 않으므로 설치할 수 없습니다.",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "앱 \"%s\"의 다음 의존성을 만족하지 못하므로 설치할 수 없습니다: %s",
-    "No app name specified" : "앱 이름이 지정되지 않았습니다.",
     "Unknown filetype" : "알 수 없는 파일 형식",
     "Invalid image" : "잘못된 사진",
+    "Avatar image is not square" : "아바타 사진이 정사각형이 아님",
     "today" : "오늘",
     "yesterday" : "어제",
     "_%n day ago_::_%n days ago_" : ["%n일 전"],
@@ -37,16 +31,19 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n시간 전"],
     "_%n minute ago_::_%n minutes ago_" : ["%n분 전"],
     "seconds ago" : "초 전",
-    "web services under your control" : "내가 관리하는 웹 서비스",
-    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "id: %s인 모듈이 존재하지 않습니다. 앱 설정에서 활성화하거나 관리자에게 연락하십시오.",
+    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "ID: %s인 모듈이 존재하지 않습니다. 앱 설정에서 활성화하거나 관리자에게 연락하십시오.",
+    "Builtin" : "내장",
+    "None" : "없음",
+    "Username and password" : "사용자 이름과 암호",
+    "Username" : "사용자 이름",
+    "Password" : "암호",
+    "Log-in credentials, save in session" : "로그인 인증 정보, 세션에 저장됨",
     "Empty filename is not allowed" : "파일 이름을 비워 둘 수 없음",
     "Dot files are not allowed" : "점으로 시작하는 파일은 허용되지 않음",
     "4-byte characters are not supported in file names" : "파일 이름에 4바이트 글자를 사용할 수 없음",
     "File name is a reserved word" : "파일 이름이 예약된 단어임",
     "File name contains at least one invalid character" : "파일 이름에 잘못된 글자가 한 자 이상 있음",
     "File name is too long" : "파일 이름이 너무 김",
-    "File is currently busy, please try again later" : "파일이 현재 사용 중, 나중에 다시 시도하십시오",
-    "Can't read file" : "파일을 읽을 수 없음",
     "App directory already exists" : "앱 디렉터리가 이미 존재합니다.",
     "Can't create app folder. Please fix permissions. %s" : "앱 폴더를 만들 수 없습니다. 권한을 수정하십시오. %s",
     "Archive does not contain a directory named %s" : "압축 파일에 디렉터리 %s이(가) 없습니다",
@@ -56,13 +53,24 @@ OC.L10N.register(
     "Archives of type %s are not supported" : "%s 타입 압축 파일은 지원되지 않습니다.",
     "Failed to open archive when installing app" : "앱을 설치할 때 압축 파일을 열지 못했습니다.",
     "App does not provide an info.xml file" : "앱에서 info.xml 파일이 제공되지 않았습니다.",
-    "App can't be installed because of not allowed code in the App" : "앱에 허용되지 않는 코드가 있어서 앱을 설치할 수 없습니다.",
-    "App can't be installed because it is not compatible with this version of ownCloud" : "현재 ownCloud 버전과 호환되지 않기 때문에 앱을 설치할 수 없습니다.",
-    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "출시되지 않은 앱에 허용되지 않는 <shipped>true</shipped> 태그를 포함하고 있기 때문에 앱을 설치할 수 없습니다.",
-    "Application is not enabled" : "앱이 활성화되지 않았습니다",
-    "Authentication error" : "인증 오류",
-    "Token expired. Please reload page." : "토큰이 만료되었습니다. 페이지를 새로 고치십시오.",
-    "Unknown user" : "알려지지 않은 사용자",
+    "App cannot be installed because appinfo file cannot be read." : "appinfo 파일을 읽을 수 없어서 앱을 설치할 수 없습니다.",
+    "Signature could not get checked. Please contact the app developer and check your admin screen." : "서명을 확인할 수 없습니다. 앱 개발자에게 연락하고 관리자 화면을 다시 확인하십시오.",
+    "App can't be installed because of not allowed code in the App" : "앱에 허용되지 않는 코드가 있어서 앱을 설치할 수 없습니다",
+    "App can't be installed because it is not compatible with this version of ownCloud" : "현재 ownCloud 버전과 호환되지 않기 때문에 앱을 설치할 수 없습니다",
+    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "출시되지 않은 앱에 허용되지 않는 <shipped>true</shipped> 태그를 포함하고 있기 때문에 앱을 설치할 수 없습니다",
+    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "앱 스토어에 있는 버전과 info.xml의 버전이 일치하지 않아서 앱을 설치할 수 없습니다",
+    "Apps" : "앱",
+    "General" : "일반",
+    "Storage" : "저장소",
+    "Security" : "보안",
+    "Encryption" : "암호화",
+    "Workflows & Tags" : "작업 흐름과 태그",
+    "Sharing" : "공유",
+    "Search" : "검색",
+    "Updates" : "업데이트",
+    "Help & Tips" : "도움말과 팁",
+    "Additional" : "추가",
+    "%s enter the database username and name." : "%s 데이터베이스 사용자 이름과 이름을 입력해 주십시오.",
     "%s enter the database username." : "%s 데이터베이스 사용자 이름을 입력해 주십시오.",
     "%s enter the database name." : "%s 데이터베이스 이름을 입력하십시오.",
     "%s you may not use dots in the database name" : "%s 데이터베이스 이름에는 마침표를 사용할 수 없습니다",
@@ -95,6 +103,7 @@ OC.L10N.register(
     "Sharing %s failed, because %s is not a member of the group %s" : "%s을(를) 공유할 수 없습니다. %s 님이 그룹 %s의 구성원이 아닙니다",
     "You need to provide a password to create a public link, only protected links are allowed" : "공개 링크를 만들려면 암호를 입력해야 합니다. 보호된 링크만 사용 가능합니다",
     "Sharing %s failed, because sharing with links is not allowed" : "%s을(를) 공유할 수 없습니다. 링크 공유가 허용되지 않았습니다",
+    "Not allowed to create a federated share with the same user" : "같은 사용자와 연합 공유를 만들 수 없음",
     "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s을(를) 공유할 수 없습니다. %s을(를) 찾을 수 없습니다. 서버에 접근하지 못할 수도 있습니다.",
     "Share type %s is not valid for %s" : "공유 형식 %s을(를) %s에 대해서 사용할 수 없음",
     "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "%s의 권한을 설정할 수 없습니다. %s 님에게 허용된 것 이상의 권한을 필요로 합니다",
@@ -110,19 +119,36 @@ OC.L10N.register(
     "Sharing %s failed, because resharing is not allowed" : "%s을(를) 공유할 수 없습니다. 다시 공유할 수 없습니다",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s을(를) 공유할 수 없습니다. %s의 공유 백엔드에서 원본 파일을 찾을 수 없습니다",
     "Sharing %s failed, because the file could not be found in the file cache" : "%s을(를) 공유할 수 없습니다. 파일 캐시에서 찾을 수 없습니다",
-    "Could not find category \"%s\"" : "분류 \"%s\"을(를) 찾을 수 없습니다.",
-    "Apps" : "앱",
+    "Cannot increase permissions of %s" : "%s의 권한을 늘릴 수 없습니다",
+    "Files can't be shared with delete permissions" : "파일을 삭제 권한으로 공유할 수 없습니다",
+    "Files can't be shared with create permissions" : "파일을 생성 권한으로 공유할 수 없습니다",
+    "Expiration date is in the past" : "만료 날짜가 과거입니다",
+    "Cannot set expiration date more than %s days in the future" : "만료 날짜를 %s일 이상 이후로 설정할 수 없습니다",
+    "Could not find category \"%s\"" : "분류 \"%s\"을(를) 찾을 수 없습니다",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "다음 문자만 이름에 사용할 수 있습니다: \"a-z\", \"A-Z\", \"0-9\", 및 \"_.@-'\"",
     "A valid username must be provided" : "올바른 사용자 이름을 입력해야 합니다",
+    "Username contains whitespace at the beginning or at the end" : "사용자 이름의 시작이나 끝에 공백이 있습니다",
     "A valid password must be provided" : "올바른 암호를 입력해야 합니다",
     "The username is already being used" : "사용자 이름이 이미 존재합니다",
+    "Login canceled by app" : "앱에서 로그인 취소함",
+    "User disabled" : "사용자 비활성화됨",
+    "Help" : "도움말",
+    "Settings" : "설정",
+    "Users" : "사용자",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "앱 \"%s\"의 다음 의존성을 만족하지 못하므로 설치할 수 없습니다: %s",
+    "web services under your control" : "내가 관리하는 웹 서비스",
+    "File is currently busy, please try again later" : "파일이 현재 사용 중, 나중에 다시 시도하십시오",
+    "Can't read file" : "파일을 읽을 수 없음",
+    "Application is not enabled" : "앱이 활성화되지 않았습니다",
+    "Authentication error" : "인증 오류",
+    "Token expired. Please reload page." : "토큰이 만료되었습니다. 페이지를 새로 고치십시오.",
+    "Unknown user" : "알려지지 않은 사용자",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "데이터베이스 드라이버(sqlite, mysql, postgresql)가 설치되지 않았습니다.",
-    "Microsoft Windows Platform is not supported" : "Microsoft Windows 플랫폼은 지원하지 않음",
-    "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "ownCloud 서버를 Microsoft Windows 환경에서 실행하는 것은 지원되지 않습니다. 서버를 이전할 수 없다면 가상 Linux 서버를 사용하는 것을 추천합니다. Linux 패키지 및 쉽게 배포 가능한 가상 머신 이미지는 <a href=\"%s\">%s</a>에서 찾을 수 있습니다. 기존 설치본을 Linux로 이전할 때 참고할 팁과 이전 스크립트는 <a href=\"%s\">문서</a>에서 찾을 수 있습니다.",
     "Cannot write into \"config\" directory" : "\"config\" 디렉터리에 기록할 수 없습니다",
     "Cannot write into \"apps\" directory" : "\"apps\" 디렉터리에 기록할 수 없습니다",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "%sapps 디렉터리에 웹 서버 쓰기 권한%s을 주거나 설정 파일에서 앱 스토어를 비활성화하면 해결됩니다.",
-    "Cannot create \"data\" directory (%s)" : "\"data\" 디렉터리를 만들 수 없음(%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "<a href=\"%s\" target=\"_blank\">루트 디렉터리에 웹 서버 쓰기 권한</a>을 주면 해결됩니다.",
+    "Cannot create \"data\" directory" : "\"data\" 디렉터리를 만들 수 없음",
+    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "<a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">루트 디렉터리에 웹 서버 쓰기 권한</a>을 주면 해결됩니다.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "%s루트 디렉터리에 웹 서버 쓰기 권한%s을 주면 해결됩니다.",
     "Setting locale to %s failed" : "로캘을 %s(으)로 설정할 수 없음",
     "Please install one of these locales on your system and restart your webserver." : "다음 중 하나 이상의 로캘을 시스템에 설치하고 웹 서버를 다시 시작하십시오.",
@@ -132,6 +158,8 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make ownCloud run again" : "php.ini에서 이 설정을 변경하면 ownCloud가 다시 실행됩니다",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload 값이 \"%s\"(으)로 설정되어 있으나 \"0\"으로 설정해야 함",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "이 문제를 해결하려면 php.ini에서 <code>mbstring.func_overload</code> 값을 <code>0</code>으로 설정하십시오",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 이상이 필요합니다. 현재 버전은 %s입니다.",
+    "To fix this issue update your libxml2 version and restart your web server." : "이 문제를 해결하려면 libxml2 버전을 업데이트하고 웹 서버를 다시 시작하십시오.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP에서 인라인 문서 블록을 삭제하도록 설정되어 있습니다. 일부 코어 앱을 사용하지 못할 수도 있습니다.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Zend OPcache, eAccelerator 같은 캐시/가속기 문제일 수도 있습니다.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP 모듈이 설치되었지만 여전히 없는 것으로 나타납니까?",
@@ -139,12 +167,16 @@ OC.L10N.register(
     "PostgreSQL >= 9 required" : "PostgreSQL 버전 9 이상이 필요합니다",
     "Please upgrade your database version" : "데이터베이스 버전을 업그레이드 하십시오",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "권한을 0770으로 변경하여 다른 사용자가 읽을 수 없도록 하십시오.",
-    "Data directory (%s) is readable by other users" : "데이터 디렉터리(%s)를 다른 사용자가 읽을 수 있음",
-    "Data directory (%s) must be an absolute path" : "데이터 디렉터리(%s)는 반드시 절대 경로여야 함",
+    "Your Data directory is readable by other users" : "내 데이터 디렉터리를 다른 사용자가 읽을 수 있음",
+    "Your Data directory must be an absolute path" : "내 데이터 디렉터리는 절대 경로여야 함",
     "Check the value of \"datadirectory\" in your configuration" : "설정 중 \"datadirectory\" 값을 확인하십시오",
-    "Data directory (%s) is invalid" : "데이터 디렉터리(%s)가 잘못됨",
+    "Your Data directory  is invalid" : "내 데이터 디렉터리가 잘못됨",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "데이터 디렉터리의 최상위 경로에 \".ocdata\" 파일이 있는지 확인하십시오.",
     "Could not obtain lock type %d on \"%s\"." : "잠금 형식 %d을(를) \"%s\"에 대해 얻을 수 없습니다.",
-    "Storage not available" : "저장소를 사용할 수 없음"
+    "Storage unauthorized. %s" : "저장소가 인증되지 않았습니다. %s",
+    "Storage incomplete configuration. %s" : "저장소 설정이 완전하지 않습니다. %s",
+    "Storage connection error. %s" : "저장소 연결 오류입니다. %s",
+    "Storage is temporarily not available" : "저장소를 임시로 사용할 수 없음",
+    "Storage connection timeout. %s" : "저장소 연결 시간이 초과되었습니다. %s"
 },
 "nplurals=1; plural=0;");
