@@ -9,6 +9,7 @@ OC.L10N.register(
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Det ble oppdaget at eksempelkonfigurasjonen er blitt kopiert. Dette kan ødelegge installasjonen din og støttes ikke. Les dokumentasjonen før du gjør endringer i config.php",
     "PHP %s or higher is required." : "PHP %s eller nyere kreves.",
     "PHP with a version lower than %s is required." : "PHP med en versjon lavere enn %s kreves.",
+    "%sbit or higher PHP required." : "%sbit eller høyere PHP kreves.",
     "Following databases are supported: %s" : "Følgende databaser støttes: %s",
     "The command line tool %s could not be found" : "Kommandolinjeverktøyet %s ble ikke funnet",
     "The library %s is not available." : "Biblioteket %s er ikke tilgjengelig.",
@@ -17,16 +18,9 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "Følgende plattformer støttes: %s",
     "ownCloud %s or higher is required." : "ownCloud %s eller høyere kreves.",
     "ownCloud %s or lower is required." : "ownCloud %s eller lavere kreves.",
-    "Help" : "Hjelp",
-    "Personal" : "Personlig",
-    "Users" : "Brukere",
-    "Admin" : "Admin",
-    "Recommended" : "Anbefalt",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "App \"%s\" kan ikke installeres fordi den ikke er kompatibel med denne versjonen av ownCloud.",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "App \"%s\" kan ikke installeres fordi følgende avhengigheter ikke er tilfredsstilt: %s",
-    "No app name specified" : "Intet app-navn spesifisert",
     "Unknown filetype" : "Ukjent filtype",
     "Invalid image" : "Ugyldig bilde",
+    "Avatar image is not square" : "Bildet er ikke kvadratisk",
     "today" : "i dag",
     "yesterday" : "i går",
     "_%n day ago_::_%n days ago_" : ["%n dag siden","%n dager siden"],
@@ -37,16 +31,19 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["for %n time siden","for %n timer siden"],
     "_%n minute ago_::_%n minutes ago_" : ["for %n minutt siden","for %n minutter siden"],
     "seconds ago" : "for få sekunder siden",
-    "web services under your control" : "webtjenester som du kontrollerer",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul med id: %s eksisterer ikke. Aktiver den i app-innstillingene eller kontakt en administrator.",
+    "Builtin" : "Innebygget",
+    "None" : "Ingen",
+    "Username and password" : "Brukernavn og passord",
+    "Username" : "Brukernavn",
+    "Password" : "Passord",
+    "Log-in credentials, save in session" : "Påloggingsdetaljer, lagre i økten",
     "Empty filename is not allowed" : "Tomt filnavn er ikke tillatt",
     "Dot files are not allowed" : "Punktum-filer er ikke tillatt",
     "4-byte characters are not supported in file names" : "4-byte tegn er ikke tillatt i filnavn",
     "File name is a reserved word" : "Filnavnet er et reservert ord",
     "File name contains at least one invalid character" : "Filnavnet inneholder minst ett ulovlig tegn",
     "File name is too long" : "Filnavnet er for langt",
-    "File is currently busy, please try again later" : "Filen er opptatt for øyeblikket, prøv igjen senere",
-    "Can't read file" : "Kan ikke lese fil",
     "App directory already exists" : "App-mappe finnes allerede",
     "Can't create app folder. Please fix permissions. %s" : "Kan ikke opprette app-mappe.  Vennligst ordne opp i tillatelser. %s",
     "Archive does not contain a directory named %s" : "Arkivet inneholder ikke en mappe med navn %s",
@@ -56,15 +53,24 @@ OC.L10N.register(
     "Archives of type %s are not supported" : "Arkiver av type %s støttes ikke",
     "Failed to open archive when installing app" : "Klarte ikke å åpne arkiv ved installering av app",
     "App does not provide an info.xml file" : "App-en inneholder ikke filen info.xml",
+    "App cannot be installed because appinfo file cannot be read." : "App kan ikke installeres fordi appinfo-filen ikke kan leses.",
     "Signature could not get checked. Please contact the app developer and check your admin screen." : "Signatur kunne ikke sjekkes. Kontakt app-utvikleren og sjekk admin-bildet.",
     "App can't be installed because of not allowed code in the App" : "App kan ikke installeres på grunn av ulovlig kode i appen.",
     "App can't be installed because it is not compatible with this version of ownCloud" : "App kan ikke installeres fordi den ikke er kompatibel med denne versjonen av ownCloud",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "App kan ikke installeres fordi den er merket med <shipped>true</shipped> som ikke er tillatt for apper som ikke leveres med systemet",
     "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "App kan ikke installeres fordi versjonen i info.xml ikke er den samme som versjonen som rapporteres fra app-butikken",
-    "Application is not enabled" : "Applikasjon er ikke påslått",
-    "Authentication error" : "Autentikasjonsfeil",
-    "Token expired. Please reload page." : "Symbol utløpt. Vennligst last inn siden på nytt.",
-    "Unknown user" : "Ukjent bruker",
+    "Apps" : "Apper",
+    "General" : "Generelt",
+    "Storage" : "Lager",
+    "Security" : "Sikkerhet",
+    "Encryption" : "Kryptering",
+    "Workflows & Tags" : "Arbeidsflyt og stikkord",
+    "Sharing" : "Deling",
+    "Search" : "Søk",
+    "Updates" : "Oppdateringer",
+    "Help & Tips" : "Hjelp og tips",
+    "Additional" : "Flere",
+    "%s enter the database username and name." : "%s legg inn brukernavn og navn for databasen.",
     "%s enter the database username." : "%s legg inn brukernavn for databasen.",
     "%s enter the database name." : "%s legg inn navnet på databasen.",
     "%s you may not use dots in the database name" : "%s du kan ikke bruke punktum i databasenavnet",
@@ -82,7 +88,7 @@ OC.L10N.register(
     "Set an admin username." : "Sett et admin-brukernavn.",
     "Set an admin password." : "Sett et admin-passord.",
     "Can't create or write into the data directory %s" : "Kan ikke opprette eller skrive i datamappen %s",
-    "Invalid Federated Cloud ID" : "Ugyldig ID for sammenknyttet sky",
+    "Invalid Federated Cloud ID" : "Ugyldig ID for Forent Sky",
     "%s shared »%s« with you" : "%s delte »%s« med deg",
     "%s via %s" : "%s via %s",
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Deling av %s feilet, fordi serveren ikke tillater delinger fra type %i",
@@ -97,7 +103,7 @@ OC.L10N.register(
     "Sharing %s failed, because %s is not a member of the group %s" : "Deling av %s feilet, fordi %s ikke er medlem av gruppen %s",
     "You need to provide a password to create a public link, only protected links are allowed" : "Du må oppgi et passord for å lage en offentlig lenke. Bare beskyttede lenker er tillatt",
     "Sharing %s failed, because sharing with links is not allowed" : "Deling av %s feilet, fordi deling med lenker ikke er tillatt",
-    "Not allowed to create a federated share with the same user" : "Ikke tillatt å opprette en Sammenknyttet sky-deling med den samme brukeren",
+    "Not allowed to create a federated share with the same user" : "Ikke tillatt å opprette en forent sky-deling med den samme brukeren",
     "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Deling %s feilet, fant ikke %s, kanskje servern er utilgjengelig for øyeblikket.",
     "Share type %s is not valid for %s" : "Delingstype %s er ikke gyldig for %s",
     "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Setting av tillatelser for %s feilet, fordi tillatelsene gikk ut over tillatelsene som er gitt til %s",
@@ -114,23 +120,35 @@ OC.L10N.register(
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Deling av %s feilet, fordi delings-serveren for %s ikke kunne finne kilden",
     "Sharing %s failed, because the file could not be found in the file cache" : "Deling av %s feilet, fordi filen ikke ble funnet i fil-mellomlageret",
     "Cannot increase permissions of %s" : "Kan ikke øke tillatelser for %s",
+    "Files can't be shared with delete permissions" : "Filer kan ikke deles med rettighet til å slette",
+    "Files can't be shared with create permissions" : "Filer kan ikke deles med rettighet til å opprette",
     "Expiration date is in the past" : "Utløpsdato er tilbake i tid",
     "Cannot set expiration date more than %s days in the future" : "Kan ikke sette utløpsdato mer enn  %s dager fram i tid",
     "Could not find category \"%s\"" : "Kunne ikke finne kategori \"%s\"",
-    "Apps" : "Apper",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Bare disse tegnene tillates i et brukernavn: \"a-z\", \"A-Z\", \"0-9\" og \"_.@-'\"",
     "A valid username must be provided" : "Oppgi et gyldig brukernavn",
     "Username contains whitespace at the beginning or at the end" : "Brukernavn inneholder blanke på begynnelsen eller slutten",
     "A valid password must be provided" : "Oppgi et gyldig passord",
     "The username is already being used" : "Brukernavnet er allerede i bruk",
+    "Login canceled by app" : "Pålogging avbrutt av ap",
+    "User disabled" : "Bruker deaktivert",
+    "Help" : "Hjelp",
+    "Settings" : "Innstillinger",
+    "Users" : "Brukere",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "App \"%s\" kan ikke installeres fordi følgende avhengigheter ikke er tilfredsstilt: %s",
+    "web services under your control" : "webtjenester som du kontrollerer",
+    "File is currently busy, please try again later" : "Filen er opptatt for øyeblikket, prøv igjen senere",
+    "Can't read file" : "Kan ikke lese fil",
+    "Application is not enabled" : "Applikasjon er ikke påslått",
+    "Authentication error" : "Autentikasjonsfeil",
+    "Token expired. Please reload page." : "Symbol utløpt. Vennligst last inn siden på nytt.",
+    "Unknown user" : "Ukjent bruker",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Ingen databasedrivere (sqlite, mysql, or postgresql) installert.",
-    "Microsoft Windows Platform is not supported" : "Microsoft Windows-plattform støttes ikke",
-    "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Kjøring av ownCloud Server på Microsoft Windows-plattformen er ikke støttet. Vi foreslår at du bruker en Linux-server i en virtuell maskin hvis du ikke har mulighet til å migrere selve serveren. Du finner Linux-pakker og lett installerbare avbildninger for virtuelle maskiner på <a href=\"%s\">%s</a>. For å migrere eksisterende installasjoner til Linux finner du tips og et migrerings-script i <a href=\"%s\">dokumentasjonen vår</a>.",
     "Cannot write into \"config\" directory" : "Kan ikke skrive i \"config\"-mappen",
     "Cannot write into \"apps\" directory" : "Kan ikke skrive i \"apps\"-mappen",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Dette kan vanligvis ordnes ved %så gi web-serveren skrivetilgang til apps-mappen%s eller ved å deaktivere app-butikken i config-filen.",
-    "Cannot create \"data\" directory (%s)" : "Kan ikke opprette \"data\"-mappen (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Dette kan vanligvis ordnes ved <a href=\"%s\" target=\"_blank\">gi web-serveren skrivetilgang til rotmappen</a>.",
+    "Cannot create \"data\" directory" : "Kan ikke opprette \"data\"-mappen",
+    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Dette kan vanligvis ordnes ved å <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">gi web-serveren skrivetilgang til rotmappen</a>.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Tillatelser kan vanligvis ordnes ved %så gi web-serveren skrivetilgang til rotmappen%s.",
     "Setting locale to %s failed" : "Setting av nasjonale innstillinger til %s feilet.",
     "Please install one of these locales on your system and restart your webserver." : "Vennligst installer en av disse nasjonale innstillingene på systemet ditt og start webserveren på nytt.",
@@ -140,6 +158,8 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make ownCloud run again" : "Endring av denne innstillingen i php.ini vil få ownCloud til å kjøre igjen.",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload er satt til \"%s\" i stedet for den forventede verdien \"0\"",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Sett <code>mbstring.func_overload</code> til <code>0</code> in php.ini for å fikse dette problemet",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 kreves minst. Nå er %s installert.",
+    "To fix this issue update your libxml2 version and restart your web server." : "Oppdater libxml2-versjonen og start web-serveren på nytt for å ordne dette problemet.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Det ser ut for at PHP er satt opp til å fjerne innebygde doc blocks. Dette gjør at flere av kjerneapplikasjonene blir utilgjengelige.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dette forårsakes sannsynligvis av en bufrer/akselerator, som f.eks. Zend OPcache eller eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP-moduler har blitt installert, men de listes fortsatt som fraværende?",
@@ -147,16 +167,16 @@ OC.L10N.register(
     "PostgreSQL >= 9 required" : "PostgreSQL >= 9 kreves",
     "Please upgrade your database version" : "Vennligst oppgrader versjonen av databasen din",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Endre tillatelsene til 0770 slik at mappen ikke kan listes av andre brukere.",
-    "Data directory (%s) is readable by other users" : "Data-mappen (%s) kan leses av andre brukere",
-    "Data directory (%s) must be an absolute path" : "Datamappen (%s) må være en absolutt sti",
+    "Your Data directory is readable by other users" : "Datamappen din kan leses av andre brukere",
+    "Your Data directory must be an absolute path" : "Datamappen din må være en absolutt sti",
     "Check the value of \"datadirectory\" in your configuration" : "Sjekk verdien for \"datadirectory\" i konfigurasjonen din",
-    "Data directory (%s) is invalid" : "Data-mappe (%s) er ugyldig",
+    "Your Data directory  is invalid" : "Datamappen din er ugyldig",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Sjekk at det ligger en fil \".ocdata\" i roten av data-mappen.",
     "Could not obtain lock type %d on \"%s\"." : "Klarte ikke å låse med type %d på \"%s\".",
     "Storage unauthorized. %s" : "Lager uautorisert: %s",
     "Storage incomplete configuration. %s" : "Ikke komplett oppsett for lager. %s",
     "Storage connection error. %s" : "Tilkoblingsfeil for lager. %s",
-    "Storage not available" : "Lagringsplass ikke tilgjengelig",
+    "Storage is temporarily not available" : "Lagring er for tiden ikke tilgjengelig",
     "Storage connection timeout. %s" : "Tidsavbrudd ved tilkobling av lager: %s"
 },
 "nplurals=2; plural=(n != 1);");
