@@ -9,6 +9,7 @@ OC.L10N.register(
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Es estat detectat que la configuracion donada a títol d'exemple es estada copiada. Aquò pòt rendre vòstra installacion inoperanta e es pas pres en carga. Legissètz la documentacion abans d'efectuar de modifications dins config.php",
     "PHP %s or higher is required." : "PHP %s o superior es requesit.",
     "PHP with a version lower than %s is required." : "PHP amb una version anteriora a %s es requesit.",
+    "%sbit or higher PHP required." : "%sbit o PHP superior es requesit.",
     "Following databases are supported: %s" : "Les bases de donadas seguentas son suportadas : %s",
     "The command line tool %s could not be found" : "La comanda %s es introbabla",
     "The library %s is not available." : "La bibliotèca %s es pas disponibla.",
@@ -17,16 +18,9 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "Las plataformas seguentas son presas en carga : %s",
     "ownCloud %s or higher is required." : "ownCloud %s o superior es requesit.",
     "ownCloud %s or lower is required." : "ownCloud %s o inferior es requesit.",
-    "Help" : "Ajuda",
-    "Personal" : "Personal",
-    "Users" : "Utilizaires",
-    "Admin" : "Administracion",
-    "Recommended" : "Recomandada",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "L'aplicacion \"%s\" pòt pas èsser installada perque es pas compatibla amb aquesta version d'ownCloud.",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "L'aplicacion \"%s\" pòt pas èsser installada a causa de las dependéncias seguentas pas satisfachas : %s",
-    "No app name specified" : "Cap de nom d'aplicacion pas especificat",
     "Unknown filetype" : "Tipe de fichièr desconegut",
     "Invalid image" : "Imatge pas valable",
+    "Avatar image is not square" : "L'imatge de l'avatar es pas carrat",
     "today" : "uèi",
     "yesterday" : "ièr",
     "_%n day ago_::_%n days ago_" : ["i a %n jorn","i a %n jorns"],
@@ -36,16 +30,19 @@ OC.L10N.register(
     "_%n year ago_::_%n years ago_" : ["i a %n an","i a %n ans"],
     "_%n minute ago_::_%n minutes ago_" : ["i a %n minuta","i a %n minutas"],
     "seconds ago" : "i a qualques segondas",
-    "web services under your control" : "servicis web jos vòstre contraròtle",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Lo modul amb l'id: %s existís pas. Mercé de l'activar dins los paramètres d'aplicacions o de contactar vòstre administrator.",
+    "Builtin" : "Integrat",
+    "None" : "Pas cap",
+    "Username and password" : "Nom d'utilizaire e senhal",
+    "Username" : "Identificant",
+    "Password" : "Senhal",
+    "Log-in credentials, save in session" : "Identificants de connexion, salvats per la session",
     "Empty filename is not allowed" : "Lo nom de fichièr pòt pas èsser void",
     "Dot files are not allowed" : "Lo nom de fichièr pòt pas començar per un punt",
     "4-byte characters are not supported in file names" : "Los caractèrs sus 4 octets son pas preses en carga dins los noms de fichièrs",
     "File name is a reserved word" : "Aqueste nom de fichièr es un mot reservat",
     "File name contains at least one invalid character" : "Lo nom de fichièr conten un (de) caractèr(s) invalid(s)",
     "File name is too long" : "Nom de fichièr tròp long",
-    "File is currently busy, please try again later" : "Lo fichièr es actualament utilizat, tornatz ensajar pus tard",
-    "Can't read file" : "Impossible de legir lo fichièr",
     "App directory already exists" : "Lo dorsièr de l'aplicacion existís ja",
     "Can't create app folder. Please fix permissions. %s" : "Impossible de crear lo dorsièr de l'aplicacion. Corregissètz los dreches d'accès. %s",
     "Archive does not contain a directory named %s" : "Lo fichièr archiu conten pas de repertòri %s",
@@ -58,16 +55,21 @@ OC.L10N.register(
     "App can't be installed because of not allowed code in the App" : "L'aplicacion pòt pas èsser installada perque conten de còde pas autorizat",
     "App can't be installed because it is not compatible with this version of ownCloud" : "L'aplicacion pòt pas èsser installada perque es pas compatibla amb aquesta version d'ownCloud",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "L'aplicacion pòt pas èsser installada perque conten la balisa <shipped>true</shipped> qu'es pas autorizada per las aplicacions non inclusas per defaut",
-    "Application is not enabled" : "L'aplicacion es pas activada",
-    "Authentication error" : "Error d'autentificacion",
-    "Token expired. Please reload page." : "La session a expirat. Recargatz la pagina.",
-    "Unknown user" : "Utilizaire desconegut",
+    "Apps" : "Aplicacions",
+    "General" : "Generals",
+    "Storage" : "Emmagazinatge",
+    "Security" : "Seguretat",
+    "Encryption" : "Chiframent",
+    "Sharing" : "Partiment",
+    "Search" : "Recercar",
+    "Updates" : "Mesas a jorn",
+    "%s enter the database username and name." : "%s entratz lo nom d'utilizaire e lo nom de la basa de donadas.",
     "%s enter the database username." : "%s entratz lo nom d'utilizaire de la banca de donadas.",
     "%s enter the database name." : "%s entratz lo nom de la banca de donadas.",
     "%s you may not use dots in the database name" : "%s podètz pas utilizar de punts dins lo nom de la banca de donadas",
     "Oracle connection could not be established" : "La connexion Oracle pòt pas èsser establida",
     "Oracle username and/or password not valid" : "Nom d'utilizaire e/o senhal de la basa Oracle invalid(s)",
-    "DB Error: \"%s\"" : "Error de la banca de donadas : \"%s\"",
+    "DB Error: \"%s\"" : "Error de la basa de donadas : \"%s\"",
     "Offending command was: \"%s\"" : "La requèsta en causa es : \"%s\"",
     "You need to enter either an existing account or the administrator." : "Vos cal especificar lo nom d'un compte existent, o lo de l'administrator.",
     "Offending command was: \"%s\", name: %s, password: %s" : "La requèsta en causa es : \"%s\", nom : %s, senhal : %s",
@@ -94,6 +96,7 @@ OC.L10N.register(
     "Sharing %s failed, because %s is not a member of the group %s" : "Lo partiment de %s a fracassat perque %s es pas membre del grop %s",
     "You need to provide a password to create a public link, only protected links are allowed" : "Vos cal provesir un senhal per crear un ligam public, sols los ligams protegits son autorizats.",
     "Sharing %s failed, because sharing with links is not allowed" : "Lo partiment de %s a fracassat perque lo partiment per ligam es pas permés",
+    "Not allowed to create a federated share with the same user" : "Pas autorizat a crear un partiment federat amb lo meteis utilizaire",
     "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Lo partiment de %s a fracassat : impossible de trobar %s. Benlèu que lo servidor es momentanèament injonhable.",
     "Share type %s is not valid for %s" : "Lo tipe de partiment %s es pas valid per %s",
     "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Lo reglatge de las permissions per %s a fracassat perque las permissions depassan las que son acordadas a %s",
@@ -109,19 +112,31 @@ OC.L10N.register(
     "Sharing %s failed, because resharing is not allowed" : "Lo partiment de %s a fracassat perque lo repartatge es pas autorizat",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Lo partiment de %s a fracassat perque la font es pas estada trobada pel partiment %s.",
     "Sharing %s failed, because the file could not be found in the file cache" : "Lo partiment de %s a fracassat perque lo fichièr es pas estat trobat dins los fichièrs meses en escondedor.",
+    "Cannot increase permissions of %s" : "Impossible d'aumentar las permissions de %s",
+    "Files can't be shared with delete permissions" : "Los fichièrs pòdon pas èsser partejats amb las autorizacions de supression",
+    "Files can't be shared with create permissions" : "Los fichièrs pòdon pas èsser partejats amb las autorizacions de creacion",
+    "Expiration date is in the past" : "La data d'expiracion es dins lo passat",
+    "Cannot set expiration date more than %s days in the future" : "Impossible de definir la data d'expiracion a mai de %s jorns dins lo futur",
     "Could not find category \"%s\"" : "Impossible de trobar la categoria \"%s\"",
-    "Apps" : "Aplicacions",
     "A valid username must be provided" : "Un nom d'utilizaire valid deu èsser sasit",
     "A valid password must be provided" : "Un senhal valid deu èsser sasit",
     "The username is already being used" : "Aqueste nom d'utilizaire es ja utilizat",
+    "User disabled" : "Utilizaire desactivat",
+    "Help" : "Ajuda",
+    "Settings" : "Paramètres",
+    "Users" : "Utilizaires",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "L'aplicacion \"%s\" pòt pas èsser installada a causa de las dependéncias seguentas pas satisfachas : %s",
+    "web services under your control" : "servicis web jos vòstre contraròtle",
+    "File is currently busy, please try again later" : "Lo fichièr es actualament utilizat, tornatz ensajar pus tard",
+    "Can't read file" : "Impossible de legir lo fichièr",
+    "Application is not enabled" : "L'aplicacion es pas activada",
+    "Authentication error" : "Error d'autentificacion",
+    "Token expired. Please reload page." : "La session a expirat. Recargatz la pagina.",
+    "Unknown user" : "Utilizaire desconegut",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Cap de pilòt de banca de donadas es pas installat (sqlite, mysql o postgresql).",
-    "Microsoft Windows Platform is not supported" : "La plataforma Microsoft Windows es pas presa en carga.",
-    "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Executar un servidor ownCloud sus una plataforma Microsoft Windows es pas pres en carga. Se avètz pas la possibilitat de migrar vòstre servidor, vos suggerissèm d'utilizar un servidor Linux dins una maquina virtuala. Los paquets Linux necessaris amai los imatges virtuals de bon desplegar se tròban sus <a href=\"%s\">%s</a>. Per migrar d'installacions existentas cap a Linux, trobaretz de conselhs e d'escripts de migracion dins <a href=\"%s\">nòstra documentacion</a>.",
     "Cannot write into \"config\" directory" : "Impossible d’escriure dins lo repertòri \"config\"",
     "Cannot write into \"apps\" directory" : "Impossible d’escriure dins lo repertòri \"apps\"",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Aqueste problèma es generalament resolgut %sen donant al servidor web un accès en escritura al repertòri apps%s o en desactivant l'appstore dins lo fichièr de configuracion.",
-    "Cannot create \"data\" directory (%s)" : "Impossible de crear lo repertòri \"data\" (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Aqueste problèma es generalament resolgut <a href=\"%s\" target=\"_blank\">en donant al servidor web un accès en escritura al repertòri raiç</a>.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Lo problèma de permissions pòt generalament èsser resolgut %sen donant al servidor web un accès en escritura al repertòri raiç%s",
     "Setting locale to %s failed" : "Fracàs de l'especificacion dels paramètres regionals a %s",
     "Please install one of these locales on your system and restart your webserver." : "Installatz un d'aqueles paramètres regionals sus vòstre sistèma e reaviatz vòstre servidor web.",
@@ -138,12 +153,12 @@ OC.L10N.register(
     "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requesit",
     "Please upgrade your database version" : "Metètz a jorn vòstre gestionari de banca de donadas",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Cambiatz las permissions del repertòri en mòde 0770 per fin que son contengut pòsca èsser listat pels autres utilizaires.",
-    "Data directory (%s) is readable by other users" : "Lo repertòri de donadas (%s) es legible pels autres utilizaires",
-    "Data directory (%s) must be an absolute path" : "Lo camin del dorsièr de donadas (%s) deu èsser absolut",
     "Check the value of \"datadirectory\" in your configuration" : "Verificatz la valor de \"datadirectory\" dins vòstra configuracion",
-    "Data directory (%s) is invalid" : "Lo repertòri (%s) es pas valid",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Verificatz que lo repertòri de donadas conten un fichièr \".ocdata\" a sa raiç.",
     "Could not obtain lock type %d on \"%s\"." : "Impossible d'obténer lo varrolhatge de tipe %d sus \"%s\".",
-    "Storage not available" : "Supòrt d'emmagazinatge pas disponible"
+    "Storage unauthorized. %s" : "Espaci d'emmagazinatge pas autorizat. %s",
+    "Storage incomplete configuration. %s" : "Configuracion de l'espaci d'emmagazinatge incompleta. %s",
+    "Storage connection error. %s" : "Error de connexion a l'espaci d'emmagazinatge. %s",
+    "Storage is temporarily not available" : "Espaci d'emmagazinatge temporàriament indisponible"
 },
 "nplurals=2; plural=(n > 1);");
