@@ -1,19 +1,25 @@
 OC.L10N.register(
     "lib",
     {
-    "Help" : "උදව්",
-    "Personal" : "පෞද්ගලික",
-    "Users" : "පරිශීලකයන්",
-    "Admin" : "පරිපාලක",
     "today" : "අද",
     "yesterday" : "ඊයේ",
     "last month" : "පෙර මාසයේ",
     "last year" : "පෙර අවුරුද්දේ",
     "seconds ago" : "තත්පරයන්ට පෙර",
+    "None" : "කිසිවක් නැත",
+    "Username" : "පරිශීලක නම",
+    "Password" : "මුර පදය",
+    "Apps" : "යෙදුම්",
+    "General" : "සාමාන්‍යයෙන්",
+    "Encryption" : "ගුප්ත කේතනය",
+    "Sharing" : "හුවමාරු කිරීම",
+    "Search" : "සොයන්න",
+    "Help" : "උදව්",
+    "Settings" : "සිටුවම්",
+    "Users" : "පරිශීලකයන්",
     "web services under your control" : "ඔබට පාලනය කළ හැකි වෙබ් සේවාවන්",
     "Application is not enabled" : "යෙදුම සක්‍රිය කර නොමැත",
     "Authentication error" : "සත්‍යාපන දෝෂයක්",
-    "Token expired. Please reload page." : "ටෝකනය කල් ඉකුත් වී ඇත. පිටුව නැවුම් කරන්න",
-    "Apps" : "යෙදුම්"
+    "Token expired. Please reload page." : "ටෝකනය කල් ඉකුත් වී ඇත. පිටුව නැවුම් කරන්න"
 },
 "nplurals=2; plural=(n != 1);");
