@@ -9,6 +9,7 @@ OC.L10N.register(
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Zistilo sa, že konfigurácia bola skopírovaná zo vzorových súborov. Takáto konfigurácia nie je podporovaná a môže poškodiť vašu inštaláciu. Prečítajte si dokumentáciu pred vykonaním zmien v config.php",
     "PHP %s or higher is required." : "Požadovaná verzia PHP %s alebo vyššia.",
     "PHP with a version lower than %s is required." : "PHP je vyžadované vo vyššej verzii ako %s.",
+    "%sbit or higher PHP required." : "Vyžaduje sa PHP %sbit alebo vyššie.",
     "Following databases are supported: %s" : "Podporované sú tieto databázy: %s",
     "The command line tool %s could not be found" : "Nástroj príkazového riadka %s nebol nájdený",
     "The library %s is not available." : "Knižnica %s je nedostupná.",
@@ -30,6 +31,11 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["pred %n minútou","pred %n minútami","pred %n minútami"],
     "seconds ago" : "pred sekundami",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul s ID: %s neexistuje. Povoľte ho prosím vo vašom nastavení aplikácií alebo konaktujte správcu.",
+    "Builtin" : "Vstavaný",
+    "None" : "Žiadny",
+    "Username and password" : "Meno a heslo",
+    "Username" : "Používateľské meno",
+    "Password" : "Heslo",
     "Empty filename is not allowed" : "Prázdny názov súboru nie je povolený",
     "Dot files are not allowed" : "Názov súboru začínajúci bodkou nie je povolený.",
     "4-byte characters are not supported in file names" : "V názve súbou nie sú podporované 4-bajtové znaky.",
@@ -45,9 +51,21 @@ OC.L10N.register(
     "Archives of type %s are not supported" : "Tento typ archívu %s nie je podporovaný",
     "Failed to open archive when installing app" : "Zlyhanie pri otváraní archívu počas inštalácie aplikácie",
     "App does not provide an info.xml file" : "Aplikácia neposkytuje súbor info.xml",
+    "App cannot be installed because appinfo file cannot be read." : "Aplikáciu nebolo možné nainštalovať, pretože nie je možné prečítať súbor appinfo.",
+    "Signature could not get checked. Please contact the app developer and check your admin screen." : "Podpis nebolo možné skontrolovať. Prosím, kontaktujte vývojára aplikácie a pozrite sa na vašu obrazovku správcu.",
     "App can't be installed because of not allowed code in the App" : "Aplikácia nemôže byť nainštalovaná pre nepovolený kód v aplikácii",
     "App can't be installed because it is not compatible with this version of ownCloud" : "Aplikácia nemôže byť nainštalovaná pre nekompatibilitu z touto verziou ownCloudu",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Aplikácia nemôže byť nainštalovaná pretože obsahuje značku<shipped>true</shipped>, ktorá nie je povolená pre nedodávané aplikácie",
+    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "Aplikáciu nebolo možné nainštalovať, pretože verzia v info.xml nie je rovnaká ako verzia nahlásená z app store.",
+    "Apps" : "Aplikácie",
+    "General" : "Všeobecné",
+    "Storage" : "Úložisko",
+    "Security" : "Zabezpečenie",
+    "Encryption" : "Šifrovanie",
+    "Sharing" : "Zdieľanie",
+    "Search" : "Hľadať",
+    "Updates" : "Aktualizácie",
+    "%s enter the database username and name." : "%s zadajte používateľské meno do databázy a meno.",
     "%s enter the database username." : "Zadajte používateľské meno %s databázy.",
     "%s enter the database name." : "Zadajte názov databázy pre %s databázy.",
     "%s you may not use dots in the database name" : "V názve databázy %s nemôžete používať bodky",
@@ -71,6 +89,7 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Zdieľanie %s zlyhalo, pretože backend nepodporuje typ zdieľania %i",
     "Sharing %s failed, because the file does not exist" : "Zdieľanie %s zlyhalo, pretože súbor neexistuje",
     "You are not allowed to share %s" : "Nemôžete zdieľať %s",
+    "Sharing %s failed, because you can not share with yourself" : "Zdieľanie %s zlyhalo, pretože nemôžete zdieľať sami so sebou.",
     "Sharing %s failed, because the user %s does not exist" : "Zdieľanie %s zlyhalo, pretože používateľ %s neexistuje",
     "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Zdieľanie %s zlyhalo, pretože používateľ %s nie je členom žiadnej skupiny spoločnej s používateľom %s",
     "Sharing %s failed, because this item is already shared with %s" : "Zdieľanie %s zlyhalo, pretože táto položka už je zdieľaná s %s",
@@ -79,6 +98,7 @@ OC.L10N.register(
     "Sharing %s failed, because %s is not a member of the group %s" : "Zdieľanie %s zlyhalo, pretože %s nie je členom skupiny %s",
     "You need to provide a password to create a public link, only protected links are allowed" : "Musíte zadať heslo ak chcete vytvoriť verejný odkaz, lebo iba odkazy chránené heslom sú povolené",
     "Sharing %s failed, because sharing with links is not allowed" : "Zdieľanie %s zlyhalo, pretože zdieľanie odkazom nie je povolené",
+    "Not allowed to create a federated share with the same user" : "Nie je dovolené vytvoriť feredované zdieľanie s rovnakým používateľom.",
     "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Zdieľanie %s zlyhalo, nepodarilo sa nájsť %s, možno je server v súčasnej dobe nedostupný.",
     "Share type %s is not valid for %s" : "Typ zdieľania %s nie je platný pre %s",
     "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Nastavenie povolení pre %s zlyhalo, pretože povolenia prekračujú povolenia udelené %s",
@@ -89,23 +109,28 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend zdieľania %s musí implementovať rozhranie OCP\\Share_Backend",
     "Sharing backend %s not found" : "Backend zdieľania %s nebol nájdený",
     "Sharing backend for %s not found" : "Backend zdieľania pre %s nebol nájdený",
+    "Sharing failed, because the user %s is the original sharer" : "Zdieľanie zlyhalo, pretože %s je pôvodný používateľ, ktorý zdieľa.",
     "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Zdieľanie %s zlyhalo, pretože povolenia prekračujú povolenia udelené %s",
     "Sharing %s failed, because resharing is not allowed" : "Zdieľanie %s zlyhalo, pretože zdieľanie ďalším nie je povolené",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Zdieľanie %s zlyhalo, backend zdieľania nenašiel zdrojový %s",
     "Sharing %s failed, because the file could not be found in the file cache" : "Zdieľanie %s zlyhalo, pretože súbor sa nenašiel vo vyrovnávacej pamäti súborov",
+    "Cannot increase permissions of %s" : "Nie je možné zvýšiť oprávnenia %s",
+    "Files can't be shared with delete permissions" : "Súbory nie je možné zdieľať s oprávnením na mazanie",
+    "Files can't be shared with create permissions" : "Súbory nie je možné zdieľať s oprávnením na vytvorenie",
+    "Expiration date is in the past" : "Dátum vypršania platnosti je v minulosti",
+    "Cannot set expiration date more than %s days in the future" : "Nie je možné nastaviť dátum vypršania platnosti viac ako %s dní do budúcnosti",
     "Could not find category \"%s\"" : "Nemožno nájsť danú kategóriu \"%s\"",
-    "Apps" : "Aplikácie",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "V používateľskom mene sú povolené iba nasledovné znaky: „a-z“, „A-Z“, „0-9“ a „_.@-'“",
     "A valid username must be provided" : "Musíte zadať platné používateľské meno",
+    "Username contains whitespace at the beginning or at the end" : "Používateľské meno obsahuje na začiatku alebo na konci netlačiteľné znaky",
     "A valid password must be provided" : "Musíte zadať platné heslo",
     "The username is already being used" : "Meno používateľa je už použité",
+    "Login canceled by app" : "Aplikácia zrušila prihlásenie",
+    "User disabled" : "Používateľ je deaktivovaný",
     "Help" : "Pomoc",
-    "Personal" : "Osobné",
+    "Settings" : "Nastavenia",
     "Users" : "Používatelia",
-    "Admin" : "Administrátor",
-    "Recommended" : "Odporúčané",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "Aplikáciu \"%s\" nie je možné inštalovať, pretože nie je kompatibilná s touto verziou ownCloudu.",
     "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Aplikáciu \"%s\" nie je možné inštalovať, pretože nie sú splnené nasledovné závislosti: %s",
-    "No app name specified" : "Nešpecifikované meno aplikácie",
     "web services under your control" : "webové služby pod Vašou kontrolou",
     "File is currently busy, please try again later" : "Súbor sa práve používa, skúste prosím neskôr",
     "Can't read file" : "Nemožno čítať súbor.",
@@ -114,12 +139,10 @@ OC.L10N.register(
     "Token expired. Please reload page." : "Token vypršal. Obnovte, prosím, stránku.",
     "Unknown user" : "Neznámy používateľ",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Ovládače databázy (sqlite, mysql, alebo postgresql) nie sú nainštalované.",
-    "Microsoft Windows Platform is not supported" : "Microsoft Windows platforma nieje podporovaná",
-    "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Beh ownCloud servera na platforme Microsoft Windows nie je podporovaný. Navrhujeme použitie Linux server na virtuálnom počítači, pokiaľ nie je k dispozícii priamo server. Linux distribúcie a tiež aj ľahko použiteľné obrazy (image) virtuálnych počítačov nájdete na <a href=\"%s\">%s</a>. Pár tipov pre migráciu existujúcich inštalácii na Linux a migračné skripty nájdete v <a href=\"%s\">našej dokumentácii</a>.",
     "Cannot write into \"config\" directory" : "Nie je možné zapisovať do priečinka \"config\"",
     "Cannot write into \"apps\" directory" : "Nie je možné zapisovať do priečinka \"apps\"",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Toto je zvyčajne možné opraviť tým, že %s udelíte webovému serveru oprávnenie na zápis do priečinka aplikácií %s alebo vypnete obchod s aplikáciami v konfiguračnom súbore.",
-    "Cannot create \"data\" directory (%s)" : "Nie je možné vytvoriť priečinok \"data\" (%s)",
+    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "To sa zvyčajne dá opraviť <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">nastavením prístupu na zápis webovému serveru do koreňového adresára</a>.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Oprávnenia je zvyčajne možné opraviť tým, že %sudelíte webovému serveru oprávnenie na zápis do koreňového priečinka%s.",
     "Setting locale to %s failed" : "Nastavenie locale na %s zlyhalo",
     "Please install one of these locales on your system and restart your webserver." : "Prosím, nainštalujte si aspoň jeden z týchto jazykov so svojho systému a reštartujte webserver.",
@@ -129,6 +152,8 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make ownCloud run again" : "Zmenou tejto voľby v php.ini znovu uvediete váš ownCloud do prevádzky",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload je nastavený na \"%s\", namiesto predpokladanej hodnoty \"0\"",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Oprava problému spočíva v nastavení <code>mbstring.func_overload</code> na <code>0</code> vo vašom php.ini",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Vužaduje sa libxml2 aspoň verzie 2.7.0. Momentálne je nainštalovaná %s.",
+    "To fix this issue update your libxml2 version and restart your web server." : "Aby ste opravili tento problém, aktualizujte svoju verziu libxml2 a reštartujte webový server.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP je zjavne nastavené, aby odstraňovalo bloky vloženej dokumentácie. To zneprístupní niekoľko základných aplikácií.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "To je pravdepodobne spôsobené cache/akcelerátorom ako napr. Zend OPcache alebo eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP moduly boli nainštalované, ale stále sa tvária, že chýbajú?",
@@ -136,12 +161,12 @@ OC.L10N.register(
     "PostgreSQL >= 9 required" : "Vyžadované PostgreSQL >= 9",
     "Please upgrade your database version" : "Prosím, aktualizujte verziu svojej databázy",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Prosím, zmeňte oprávnenia na 0770, aby tento priečinok nemohli ostatní používatelia otvoriť.",
-    "Data directory (%s) is readable by other users" : "Priečinok dát (%s) je prístupný na čítanie ostatným používateľom",
-    "Data directory (%s) must be an absolute path" : "Priečinok dát (%s) musí byť zadaný ako absolútna cesta",
     "Check the value of \"datadirectory\" in your configuration" : "Skontrolujte hodnotu \"datadirectory\" vo vašej konfigurácii",
-    "Data directory (%s) is invalid" : "Priečinok dát (%s) je neplatný",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Prosím, skontrolujte, či priečinok dát obsahuje súbor \".ocdata\".",
     "Could not obtain lock type %d on \"%s\"." : "Nepodarilo sa získať zámok typu %d na „%s“.",
-    "Storage not available" : "Úložisko nie je dostupné"
+    "Storage unauthorized. %s" : "Neoprávnené úložisko. %s",
+    "Storage incomplete configuration. %s" : "Neúplná konfigurácia úložiska. %s",
+    "Storage connection error. %s" : "Chyba pripojenia k úložisku. %s",
+    "Storage connection timeout. %s" : "Čas na nadviazanie pripojenia k úložisku vypršal. %s"
 },
 "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
