@@ -9,6 +9,7 @@ OC.L10N.register(
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "U pa se është kopjuar shembulli për formësime. Kjo mund të prishë instalimin tuaj dhe nuk mbulohet. Ju lutemi, lexoni dokumentimin, përpara se të kryeni ndryshime te config.php",
     "PHP %s or higher is required." : "Lypse PHP %s ose më sipër.",
     "PHP with a version lower than %s is required." : "Lypset PHP me një version më të ulët se sa %s.",
+    "%sbit or higher PHP required." : "Lypset PHP %sbit ose më i ri.",
     "Following databases are supported: %s" : "Mbulohen bazat vijuese të të dhënave: %s",
     "The command line tool %s could not be found" : "Mjeti rresht urdhrash %s s’u gjet dot",
     "The library %s is not available." : "Libraria %s s’është e passhme.",
@@ -17,16 +18,9 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "Mbulohen platformat vijuese: %s",
     "ownCloud %s or higher is required." : "Lypset ownCloud %s ose më sipër.",
     "ownCloud %s or lower is required." : "Lypset ownCloud %s ose më poshtë.",
-    "Help" : "Ndihmë",
-    "Personal" : "Personale",
-    "Users" : "Përdorues",
-    "Admin" : "Admin",
-    "Recommended" : "E rekomanduar",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "Përditësimi \"%s\" s’instalohet dot, ngaqë s’është i përputhshëm me këtë version të ownCloud-it.",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Përditësimi \"%s\" s’instalohet dot, ngaqë s’plotësohen varësitë vijuese: %s.",
-    "No app name specified" : "S’u dha emër aplikacioni",
     "Unknown filetype" : "Lloj i panjohur kartele",
     "Invalid image" : "Figurë e pavlefshme",
+    "Avatar image is not square" : "Figura e avatarit s’është katrore",
     "today" : "sot",
     "yesterday" : "dje",
     "_%n day ago_::_%n days ago_" : ["%n ditë më parë","%n ditë më parë"],
@@ -37,16 +31,19 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n orë më parë","%n orë më parë"],
     "_%n minute ago_::_%n minutes ago_" : ["%n minutë më parë","%n minuta më parë"],
     "seconds ago" : "sekonda më parë",
-    "web services under your control" : "shërbime web nën kontrollin tuaj",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "S’ka modul me id: %s. Ju lutemi, aktivizojeni te rregullimet tuaja për aplikacionin ose lidhuni me përgjegjësin tuaj.",
+    "Builtin" : "I brendshëm",
+    "None" : "Asnjë",
+    "Username and password" : "Emër përdoruesi dhe fjalëkalim",
+    "Username" : "Emër përdoruesi",
+    "Password" : "Fjalëkalim",
+    "Log-in credentials, save in session" : "Kredenciale hyrjesh, ruaji për sesion",
     "Empty filename is not allowed" : "Nuk lejohen emra të zbrazët kartelash",
     "Dot files are not allowed" : "Nuk lejohen kartela të fshehura",
     "4-byte characters are not supported in file names" : "Shenjat 4-bajtshe nuk mbulohet në emra kartelash",
     "File name is a reserved word" : "Emri i kartelës është një emër i rezervuar",
     "File name contains at least one invalid character" : "Emri i kartelës përmban të paktën një shenjë të pavlefshme",
     "File name is too long" : "Emri i kartelës është shumë i gjatë",
-    "File is currently busy, please try again later" : "Kartela tani është e zënë, ju lutemi, riprovoni më vonë.",
-    "Can't read file" : "S'lexohet dot kartela",
     "App directory already exists" : "Drejtoria e aplikacionit ekziston tashmë",
     "Can't create app folder. Please fix permissions. %s" : "S’krijohet dot dosje aplikacioni. Ju lutemi, ndreqni lejet. %s",
     "Archive does not contain a directory named %s" : "Arkivi s’përmban një drejtori të quajtur %s",
@@ -56,15 +53,25 @@ OC.L10N.register(
     "Archives of type %s are not supported" : "Nuk mbulohen arkivat e llojit %s",
     "Failed to open archive when installing app" : "Dështoi në hapje arkivi teksa instalohej aplikacioni",
     "App does not provide an info.xml file" : "Aplikacioni s’ofron kartele të vlefshme .xml",
+    "App cannot be installed because appinfo file cannot be read." : "Aplikacioni s’mund të instalohet, ngaqë s’lexohet dot kartela appinfo.",
     "Signature could not get checked. Please contact the app developer and check your admin screen." : "Nënshkrimi s’u kontrollua dot. Ju lutemi, lidhuni me zhvilluesin e aplikacionit dhe kontrolloni te skena juaj e përgjegjësit.",
     "App can't be installed because of not allowed code in the App" : "Aplikacioni s’mund të instalohet, për shkak kodi të palejuar te Aplikacioni",
     "App can't be installed because it is not compatible with this version of ownCloud" : "Aplikacioni s’mund të instalohet, ngaqë s’është i përputhshëm me këtë version të ownCloud-it",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Aplikacioni s’mund të instalohet, ngaqë përmban etiketën <shipped>true</shipped> e cila nuk lejohet për aplikacione që s’janë hedhur në qarkullim",
     "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "Aplikacioni s’mund të instalohet, ngaqë versioni te info.xml s’është i njëjti me versionin e treguar nga shitorja e aplikacioneve",
-    "Application is not enabled" : "Aplikacioni s’është aktivizuar",
-    "Authentication error" : "Gabim mirëfilltësimi",
-    "Token expired. Please reload page." : "Token-i ka skaduar. Ju lutemi, ringarkoni faqen.",
-    "Unknown user" : "Përdorues i panjohur",
+    "Apps" : "Aplikacione",
+    "General" : "Të përgjithshme",
+    "Storage" : "Depozitë",
+    "Security" : "Siguri",
+    "User Authentication" : "Mirëfilltësim Përdoruesi",
+    "Encryption" : "Fshehtëzim",
+    "Workflows & Tags" : "Rrjedha pune & Etiketa",
+    "Sharing" : "Ndarje me të tjerët",
+    "Search" : "Kërko",
+    "Updates" : "Përditësime",
+    "Help & Tips" : "Ndihmë & Këshilla",
+    "Additional" : "Shtesë",
+    "%s enter the database username and name." : "%s jepni emrin e bazës së të dhënave dhe emrin e përdoruesit për të.",
     "%s enter the database username." : "%s jepni emrin e përdoruesit të bazës së të dhënave.",
     "%s enter the database name." : "%s jepni emrin e bazës së të dhënave.",
     "%s you may not use dots in the database name" : "%s s’mund të përdorni pika te emri i bazës së të dhënave",
@@ -114,23 +121,35 @@ OC.L10N.register(
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Ndarja e %s dështoi, ngaqë mekanizmi i shërbimit për ndarje për %s s’gjeti dot burimin për të",
     "Sharing %s failed, because the file could not be found in the file cache" : "Ndarja e %s me të tjerët dështoi, ngaqë kartela s’u gjet dot te fshehtina e kartelave",
     "Cannot increase permissions of %s" : "S’mund të shtohen lejet për %s",
+    "Files can't be shared with delete permissions" : "Kartelat s’mund të ndahen me leje fshirjeje",
+    "Files can't be shared with create permissions" : "Kartelat s’mund të ndahen me leje krijimi",
     "Expiration date is in the past" : "Data e skadimit bie në të kaluarën",
     "Cannot set expiration date more than %s days in the future" : "S’mund të caktohet data e skadimit më shumë se %s ditë në të ardhmen",
     "Could not find category \"%s\"" : "S’u gjet kategori \"%s\"",
-    "Apps" : "Aplikacione",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Në një emër përdoruesi lejohen vetëm shenjat vijuese: \"a-z\", \"A-Z\", \"0-9\", dhe \"_.@-\"",
     "A valid username must be provided" : "Duhet dhënë një emër i vlefshëm përdoruesi",
     "Username contains whitespace at the beginning or at the end" : "Emri i përdoruesit përmban hapësirë në fillim ose në fund",
     "A valid password must be provided" : "Duhet dhënë një fjalëkalim i vlefshëm",
     "The username is already being used" : "Emri i përdoruesit është tashmë i përdorur",
+    "Login canceled by app" : "Hyrja u anulua nga aplikacioni",
+    "User disabled" : "Përdorues i çaktivizuar",
+    "Help" : "Ndihmë",
+    "Settings" : "Rregullime",
+    "Users" : "Përdorues",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Përditësimi \"%s\" s’instalohet dot, ngaqë s’plotësohen varësitë vijuese: %s.",
+    "web services under your control" : "shërbime web nën kontrollin tuaj",
+    "File is currently busy, please try again later" : "Kartela tani është e zënë, ju lutemi, riprovoni më vonë.",
+    "Can't read file" : "S'lexohet dot kartela",
+    "Application is not enabled" : "Aplikacioni s’është aktivizuar",
+    "Authentication error" : "Gabim mirëfilltësimi",
+    "Token expired. Please reload page." : "Token-i ka skaduar. Ju lutemi, ringarkoni faqen.",
+    "Unknown user" : "Përdorues i panjohur",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "S’ka baza të dhënash (sqlite, mysql, ose postgresql) të instaluara.",
-    "Microsoft Windows Platform is not supported" : "Microsoft Windows Platform nuk mbulohet",
-    "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Xhirimi i shërbyesit ownCloud në platformën Microsoft Windows nuk mbulohet. Nëse nuk mundeni të migroni vetë shërbyesin, këshillojmë të përdorni një shërbyes Linux në një makinë virtuale. Gjeni paketa Linux, si dhe paketa makinash virtuale të lehta për t’u vënë në punë, te <a href=\"%s\">%s</a>. Rreth migrimit në Linux të instalimeve ekzistuese mund të gjeni disa këshilla dhe një programth migrimi te <a href=\"%s\">dokumentimi ynë</a>.",
     "Cannot write into \"config\" directory" : "S’shkruhet dot te drejtoria \"config\"",
     "Cannot write into \"apps\" directory" : "S’shkruhet dot te drejtoria \"apps\"",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Zakonisht kjo mund të ndreqet duke %si akorduar shërbyesit web të drejta shkrimi mbi drejtorinë e aplikacionit%s ose duke e çaktivizuar appstore-in te kartela e formësimit.",
-    "Cannot create \"data\" directory (%s)" : "S’krijohet dot drejtoria \"data\" (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Zakonisht kjo mund të ndreqet duke <a href=\"%s\" target=\"_blank\">i akorduar shërbyesit web të drejta shkrimi mbi drejtorinë rrënjë</a>.",
+    "Cannot create \"data\" directory" : "S’krijohet dot drejtoria \"data\" ",
+    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Zakonisht kjo mund të ndreqet duke <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">i akorduar shërbyesit web të drejta shkrimi mbi drejtorinë rrënjë</a>.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Zakonisht lejet mund të ndreqen duke %si akorduar shërbyesit web të drejta shkrimi mbi drejtorinë rrënjë%s.",
     "Setting locale to %s failed" : "Caktimi i gjuhës si %s dështoi",
     "Please install one of these locales on your system and restart your webserver." : "Ju lutemi, instaloni te sistemi juaj një prej këtyre vendoreve dhe rinisni shërbyesin tuaj web.",
@@ -140,6 +159,8 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make ownCloud run again" : "Saktësimi i këtij rregullimi te php.ini do të bëjë që ownCloud-i të punojë sërish",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload është caktuar si \"%s\", në vend të vlerës së pritshme \"0\"",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Për ta ndrequr këtë problem, caktoni për <code>mbstring.func_overload</code> vlerën <code>0</code> te php.ini juaj",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Lypset të paktën libxml2 2.7.0. Hëpërhë e instaluar është %s.",
+    "To fix this issue update your libxml2 version and restart your web server." : "Për të ndrequr këtë problem, përditësoni libxml2 dhe rinisni shërbyesin tuaj web.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Me sa duket, PHP-ja është rregulluar që të heqë blloqe të brendshëm dokumentimi. Kjo do t’i nxjerrë nga funksionimi disa aplikacione bazë.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Kjo ka gjasa të jetë shkaktuar nga një fshehtinë/përshpejtues i tillë si Zend OPcache ose eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Modulet PHP janë instaluar, por tregohen ende sikur mungojnë?",
@@ -147,16 +168,16 @@ OC.L10N.register(
     "PostgreSQL >= 9 required" : "Lypset PostgreSQL >= 9",
     "Please upgrade your database version" : "Ju lutemi, përmirësoni bazën tuaj të të dhënave me një version më të ri.",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Ju lutemi, kalojani lejet në 0770, që kështu atë drejtori të mos mund ta shfaqin përdorues të tjerë.",
-    "Data directory (%s) is readable by other users" : "Drejtoria e të dhënave (%s) është e lexueshme nga përdorues të tjerë",
-    "Data directory (%s) must be an absolute path" : "Drejtoria e të dhënave (%s) duhet të jepë një shteg absolut",
+    "Your Data directory is readable by other users" : "Drejtoria juaj Data është e lexueshme nga përdorues të tjerë",
+    "Your Data directory must be an absolute path" : "Drejtoria juaj Data duhet të përfaqësohet nga një shteg absolut",
     "Check the value of \"datadirectory\" in your configuration" : "Kontrolloni vlerën e \"datadirectory\" te formësimi juaj",
-    "Data directory (%s) is invalid" : "Drejtoria e të dhënave (%s) është e pavlefshme",
+    "Your Data directory  is invalid" : "Drejtoria juaj Data është e pavlefshme",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Ju lutemi, kontrolloni që drejtoria e të dhënave përmban në rrënjën e saj një kartelë \".ocdata\".",
     "Could not obtain lock type %d on \"%s\"." : "S’u mor dot lloj kyçjeje %d në \"%s\".",
     "Storage unauthorized. %s" : "Depozitë e paautorizuar. %s",
     "Storage incomplete configuration. %s" : "Formësim jo i plotë i depozitës. %s",
     "Storage connection error. %s" : "Gabim lidhje te depozita. %s",
-    "Storage not available" : "Pa depozitë gati",
+    "Storage is temporarily not available" : "Depozita është përkohësisht jashtë pune",
     "Storage connection timeout. %s" : "Mbarim kohe lidhjeje për depozitën. %s"
 },
 "nplurals=2; plural=(n != 1);");
