@@ -8,7 +8,8 @@ OC.L10N.register(
     "Sample configuration detected" : "ตรวจพบการกำหนดค่าตัวอย่าง",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "ตรวจพบว่าการกำหนดค่าตัวอย่างที่ถูกคัดลอก นี้สามารถทำลายการติดตั้งของคุณและไม่ได้รับการสนับสนุน โปรดอ่านเอกสารก่อนที่จะดำเนินการเปลี่ยนแปลงใน config.php",
     "PHP %s or higher is required." : "จำเป็นต้องมี PHP รุ่น %s หรือที่สูงกว่า ",
-    "PHP with a version lower than %s is required." : "PHP จะต้องมีรุ่นที่ต่ำกว่า %s",
+    "PHP with a version lower than %s is required." : "รุ่น PHP ของคุณต่ำกว่า %s",
+    "%sbit or higher PHP required." : "%sบิต หรือ PHP จะต้องเป็นรุ่นสูงกว่าที่กำหนด",
     "Following databases are supported: %s" : "ฐานข้อมูลต่อไปนี้ได้รับการสนับสนุน: %s",
     "The command line tool %s could not be found" : "ไม่พบเครื่องมือบรรทัดคำสั่ง %s ",
     "The library %s is not available." : "ไลบรารี %s ไม่สามารถใช้ได้",
@@ -17,16 +18,9 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "แพลตฟอร์มต่อไปนี้ได้รับการสนับสนุน: %s",
     "ownCloud %s or higher is required." : "จำเป็นต้องมี ownCloud รุ่น %s หรือรุ่นที่สูงกว่า",
     "ownCloud %s or lower is required." : "ต้องการ ownCloud %s หรือรุ่นที่ต่ำกว่า",
-    "Help" : "ช่วยเหลือ",
-    "Personal" : "ส่วนตัว",
-    "Users" : "ผู้ใช้งาน",
-    "Admin" : "ผู้ดูแล",
-    "Recommended" : "แนะนำ",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "แอพฯ \"%s\" ไม่สามารถติดตั้งได้เพราะเข้ากันไม่ได้กับรุ่นของ ownCloud นี้",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "แอพฯ \"%s\" ไม่สามารถติดตั้งเพราะไม่ได้ปฏิบัติตามการอ้างอิงต่อไปนี้: %s",
-    "No app name specified" : "ไม่ได้ระบุชื่อแอพพลิเคชัน",
     "Unknown filetype" : "ไม่รู้จักชนิดของไฟล์",
     "Invalid image" : "รูปภาพไม่ถูกต้อง",
+    "Avatar image is not square" : "รูปประจำตัวจะต้องเป็นสี่เหลี่ยมจัตุรัส",
     "today" : "วันนี้",
     "yesterday" : "เมื่อวานนี้",
     "_%n day ago_::_%n days ago_" : ["%n วันที่ผ่านมา"],
@@ -37,16 +31,19 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n ชั่วโมงที่ผ่านมา"],
     "_%n minute ago_::_%n minutes ago_" : ["%n นาทีที่ผ่านมา"],
     "seconds ago" : "วินาที ก่อนหน้านี้",
-    "web services under your control" : "เว็บเซอร์วิสที่คุณควบคุมการใช้งานได้",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "โมดูลที่มีไอดี: %s ไม่มีอยู่ กรุณาเปิดใช้งานได้ในการตั้งค่าแอพพลิเคชันของคุณหรือติดต่อผู้ดูแลระบบ",
+    "Builtin" : "ในตัว",
+    "None" : "ไม่มี",
+    "Username and password" : "ชื่อผู้ใช้และรหัสผ่าน",
+    "Username" : "ชื่อผู้ใช้",
+    "Password" : "รหัสผ่าน",
+    "Log-in credentials, save in session" : "ข้อมูลประจำตัวสำหรับเข้าสู่ระบบ, บันทึกลงในช่วงเวลาเข้าใช้งาน",
     "Empty filename is not allowed" : "ชื่อไฟล์ห้ามว่างเปล่า",
     "Dot files are not allowed" : "ชื่อไฟล์ห้ามมีจุด",
     "4-byte characters are not supported in file names" : "ตัวอักษร 4 ไบต์ไม่ได้รับการสนับสนุนในชื่อไฟล์",
     "File name is a reserved word" : "ชื่อแฟ้มเป็นคำสงวน",
     "File name contains at least one invalid character" : "ชื่อแฟ้มมีหนึ่งตัวอักษรที่ไม่ถูกต้อง",
     "File name is too long" : "ชื่อแฟ้มยาวเกินไป",
-    "File is currently busy, please try again later" : "ขณะนี้ไฟล์กำลังใช้งานอยู่ โปรดลองอีกครั้งในภายหลัง",
-    "Can't read file" : "ไม่สามารถอ่านไฟล์",
     "App directory already exists" : "มีไดเรกทอรีแอพฯอยู่แล้ว",
     "Can't create app folder. Please fix permissions. %s" : "ไม่สามารถสร้างโฟลเดอร์แอพพลิเคชัน โปรดแก้ไขการอนุญาต: %s",
     "Archive does not contain a directory named %s" : "เอกสารไม่สามารถประกอบด้วยไดเรกทอรีชื่อ %s",
@@ -56,17 +53,28 @@ OC.L10N.register(
     "Archives of type %s are not supported" : "ประเภทข้อมูลที่เก็บของ %s ไม่ได้รับการสนับสนุน",
     "Failed to open archive when installing app" : "ไม่สามารถเปิดที่เก็บข้อมูลเมื่อกำลังติดตั้งแอพพลิเคชั่น",
     "App does not provide an info.xml file" : "แอพฯ ไม่ได้ระบุไฟล์ info.xml",
+    "App cannot be installed because appinfo file cannot be read." : "ไม่สามารถติดตั้งแอพฯเพราะไม่สามารถอ่านไฟล์ AppInfo ได้",
+    "Signature could not get checked. Please contact the app developer and check your admin screen." : "ไม่สามารถตรวจสอบลายเซ็น โปรดติดต่อนักพัฒนาแอพพลิเคชันและตรวจสอบหน้าจอแผงควบคุมระบบของคุณ",
     "App can't be installed because of not allowed code in the App" : "ไม่สามารถติดตั้งแอพพลิเคชันเพราะไม่ได้อนุญาตรหัสในแอพพลิเคชัน",
     "App can't be installed because it is not compatible with this version of ownCloud" : "ไม่สามารถติดตั้งแอพพลิเคชันเพราะมันเข้ากันไม่ได้กับรุ่นของ ownCloud นี้",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "ไม่สามารถติดตั้งแอพพลิเคชันเพราะมันมี <shipped>จริง</shipped> แท็กที่ไม่ได้รับอนุญาต",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "ไม่สามารถติดตั้งแอพพลิเคเพราะรุ่นใน info.xml/version ไม่เหมือนกันกับรุ่นที่มีรายงานจากร้านค้าแอพ",
-    "Application is not enabled" : "แอพพลิเคชั่นดังกล่าวยังไม่ได้เปิดใช้งาน",
-    "Authentication error" : "เกิดข้อผิดพลาดในสิทธิ์การเข้าใช้งาน",
-    "Token expired. Please reload page." : "รหัสยืนยันความถูกต้องหมดอายุแล้ว กรุณาโหลดหน้าเว็บใหม่อีกครั้ง",
-    "Unknown user" : "ไม่รู้จักผู้ใช้",
+    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "ไม่สามารถติดตั้งแอพฯ เพราะว่ารุ่นของ info.xml ไม่ตรงกับรุ่นที่ระบุไว้จากแอพสโตร์",
+    "Apps" : "แอพฯ",
+    "General" : "ทั่วไป",
+    "Storage" : "พื้นที่จัดเก็บข้อมูล",
+    "Security" : "ความปลอดภัย",
+    "User Authentication" : "การตรวจสอบผู้ใช้",
+    "Encryption" : "การเข้ารหัส",
+    "Workflows & Tags" : "เวิร์กโฟลว์และแท็ก",
+    "Sharing" : "แชร์ข้อมูล",
+    "Search" : "ค้นหา",
+    "Updates" : "อัพเดท",
+    "Help & Tips" : "ความช่วยเหลือและเคล็ดลับ",
+    "Additional" : "เพิ่มเติม",
+    "%s enter the database username and name." : "%s ป้อนชื่อผู้ใช้ฐานข้อมูล และชื่อ",
     "%s enter the database username." : "%s ใส่ชื่อผู้ใช้ฐานข้อมูล",
     "%s enter the database name." : "%s ใส่ชื่อฐานข้อมูล",
-    "%s you may not use dots in the database name" : "%s  บางที่คุณไม่ควรใช้จุดในชื่อฐานข้อมูล",
+    "%s you may not use dots in the database name" : "%s บางที่คุณไม่ควรมีจุดในชื่อฐานข้อมูล",
     "Oracle connection could not be established" : "ไม่สามารถสร้างการเชื่อมต่อกับ Oracle ",
     "Oracle username and/or password not valid" : "Oracle ชื่อผู้ใช้ และ/หรือ รหัสผ่านไม่ถูกต้อง",
     "DB Error: \"%s\"" : "ข้อผิดพลาดในฐานข้อมูล: \"%s\"",
@@ -87,7 +95,7 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "การแชร์ %s ล้มเหลวเพราะแบ็กเอนด์ไม่อนุญาตให้แชร์จากไฟล์ประเภท %i",
     "Sharing %s failed, because the file does not exist" : "การแชร์ %s ล้มเหลวเพราะไม่มีไฟล์นี้อยู่",
     "You are not allowed to share %s" : "คุณยังไม่ได้รับอนุญาตให้แชร์ %s",
-    "Sharing %s failed, because the user %s is the item owner" : "การแชร์ %s ล้มเหลวเนื่องจากผู้ใช้ %s เป็นเจ้าของรายการ",
+    "Sharing %s failed, because you can not share with yourself" : "การแขร์ %s ล้มเหลวเพราะคุณไม่สามารถแชร์ให้กับตัวเอง",
     "Sharing %s failed, because the user %s does not exist" : "การแชร์ %s ล้มเหลวเนื่องจากไม่ได้มีผู้ใช้ %s อยู่",
     "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "การแชร์ %s ล้มเหลวเนื่องจากผู้ใช้ %s ไม่ได้เป็นสมาชิกของกลุ่มใดๆ %s เป็นสมาชิกของ",
     "Sharing %s failed, because this item is already shared with %s" : "การแชร์ %s ล้มเหลวเพราะรายการนี้ถูกแชร์กับ %s",
@@ -96,6 +104,7 @@ OC.L10N.register(
     "Sharing %s failed, because %s is not a member of the group %s" : "การแชร์ %s ล้มเหลวเพราะ %s ไม่ได้เป็นสมาชิกของกลุ่ม %s",
     "You need to provide a password to create a public link, only protected links are allowed" : "คุณจำเป็นต้องระบุรหัสผ่านเพื่อสร้างลิงค์สาธารณะ, ลิงค์ที่มีการป้องกันเท่านั้นที่ได้รับอนุญาต",
     "Sharing %s failed, because sharing with links is not allowed" : "การแชร์ %s ล้มเหลวเพราะมีการแชร์ลิงค์ไม่ได้รับอนุญาต",
+    "Not allowed to create a federated share with the same user" : "ไม่อนุญาตให้สร้างแชร์สหพันธรัฐกับผู้ใช้คนเดียวกัน",
     "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "การแชร์ %s ล้มเหลวไม่สามารถหา %s, บางทีอาจจะยังไม่สามารถเข้าถึงเซิร์ฟเวอร์ปัจจุบัน",
     "Share type %s is not valid for %s" : "ประเภท %s ที่แชร์ไม่ถูกต้องสำหรับ %s",
     "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "การตั้งค่าสิทธิ์สำหรับ %s ล้มเหลวเพราะเกินสิทธิ์ที่ได้อนุญาตให้ %s",
@@ -106,25 +115,41 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "การแชร์แบ็กเอนด์ %s ต้องใช้อินเตอร์เฟซ OCP\\Share_Backend",
     "Sharing backend %s not found" : "ไม่พบการแชร์แบ็กเอนด์ %s",
     "Sharing backend for %s not found" : "ไม่พบการแชร์แบ็กเอนด์สำหรับ %s",
-    "Sharing %s failed, because the user %s is the original sharer" : "การแชร์ %s ล้มเหลวเนื่องจากผู้ใช้ %s เป็นผู้เริ่มต้นแชร์",
+    "Sharing failed, because the user %s is the original sharer" : "การแชร์ล้มเหลวเพราะผู้ใช้ %s เป็นต้นฉบับการแชร์นี้",
     "Sharing %s failed, because the permissions exceed permissions granted to %s" : "การแชร์ %s ล้มเหลวเพราะใช้สิทธิ์เกินที่อนุญาตให้ %s",
     "Sharing %s failed, because resharing is not allowed" : "การแชร์ %s ล้มเหลวเพราะการแชร์ต่อไม่ได้รับอนุญาต",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "การแชร์ %s ล้มเหลวเพราะการแชร์แบ็กเอนด์สำหรับ %s ไม่สามารถหาแหล่งที่มา",
     "Sharing %s failed, because the file could not be found in the file cache" : "การแชร์ %s ล้มเหลวเพราะไม่พบไฟล์ในแคชไฟล์",
+    "Cannot increase permissions of %s" : "ไม่สามารถเพิ่มสิทธิ์ของ %s",
+    "Files can't be shared with delete permissions" : "ไม่สามารถแชร์ไฟล์และลบสิทธิ์",
+    "Files can't be shared with create permissions" : "ไม่สามารถแชร์ไฟล์และสร้างสิทธิ์",
+    "Expiration date is in the past" : "วันหมดอายุอยู่ในอดีตที่ผ่านมา",
+    "Cannot set expiration date more than %s days in the future" : "ไม่สามารถกำหนดวันหมดอายุให้มากกว่า %s วันในอนาคต",
     "Could not find category \"%s\"" : "ไม่พบหมวดหมู่ \"%s\"",
-    "Apps" : "แอปฯ",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "ตัวอักษรที่อนุญาตให้ใช้ในชื่อผู้ใช้: \"a-z\", \"A-Z\", \"0-9\"  และ \"_.@-\"",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "ชื่อผู้ใช้จะใช้ได้แค่อักษรดังต่อไปนี้: \"a-z\", \"A-Z\", \"0-9\" และ \"_.@-'\"",
     "A valid username must be provided" : "จะต้องระบุชื่อผู้ใช้ที่ถูกต้อง",
+    "Username contains whitespace at the beginning or at the end" : "ชื่อผู้ใช้ที่ประกอบด้วยช่องว่างในส่วนต้น-ท้ายของข้อความ",
     "A valid password must be provided" : "รหัสผ่านที่ถูกต้องจะต้องให้",
     "The username is already being used" : "มีคนใช้ชื่อผู้ใช้นี้ไปแล้ว",
+    "Login canceled by app" : "การเข้าสู่ระบบถูกยกเลิกโดยแอพฯ",
+    "User disabled" : "ปิดการใช้งานผู้ใช้แล้ว",
+    "Help" : "ช่วยเหลือ",
+    "Settings" : "ตั้งค่า",
+    "Users" : "ผู้ใช้งาน",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "แอพฯ \"%s\" ไม่สามารถติดตั้งเพราะไม่ได้ปฏิบัติตามการอ้างอิงต่อไปนี้: %s",
+    "web services under your control" : "Translate by <a href=\"https://fb.me/kauw5164\">kauw5164</a>",
+    "File is currently busy, please try again later" : "ขณะนี้ไฟล์กำลังใช้งานอยู่ โปรดลองอีกครั้งในภายหลัง",
+    "Can't read file" : "ไม่สามารถอ่านไฟล์",
+    "Application is not enabled" : "แอพพลิเคชั่นดังกล่าวยังไม่ได้เปิดใช้งาน",
+    "Authentication error" : "เกิดข้อผิดพลาดในสิทธิ์การเข้าใช้งาน",
+    "Token expired. Please reload page." : "รหัสยืนยันความถูกต้องหมดอายุแล้ว กรุณาโหลดหน้าเว็บใหม่อีกครั้ง",
+    "Unknown user" : "ไม่รู้จักผู้ใช้",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "ไม่มีไดรเวอร์ฐานข้อมูล (sqlite, mysql, or postgresql) ที่ถูกติดตั้ง",
-    "Microsoft Windows Platform is not supported" : "ไม่สนับสนุนแพลตฟอร์ม Microsoft Windows",
-    "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "ไม่สนับสนุนการเรียกใช้เซิร์ฟเวอร์ ownCloud บนแพลตฟอร์ม Microsoft Windows เราขอแนะนำให้คุณใช้เซิร์ฟเวอร์ลินุกซ์ในเครื่องเสมือนถ้าคุณไม่มีตัวเลือกสำหรับการย้ายเซิร์ฟเวอร์เอง ค้นหาแพคเกจลินุกซ์เช่นเดียวกับที่ง่ายต่อการปรับใช้อิมเมจบนเครื่องเสมือน <a href=\"%s\">%s</a> สำหรับการย้ายการติดตั้งลินุกซ์ที่มีอยู่เพื่อให้คุณสามารถค้นหาเคล็ดลับและการย้ายในสคริปต์ <a href=\"%s\">เอกสารของเรา</a>",
     "Cannot write into \"config\" directory" : "ไม่สามารถเขียนลงในไดเรกทอรี \"การตั้งค่า\"",
     "Cannot write into \"apps\" directory" : "ไม่สามารถเขียนลงในไดเรกทอรี \"แอพฯ\"",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "นี้มักจะสามารถแก้ไขโดย %s ให้เข้าถึงการเขียนเว็บเซิร์ฟเวอร์ไปยังไดเรกทอรีแอพพลิเคชัน %s หรือปิดการใช้ AppStore ในไฟล์ config",
-    "Cannot create \"data\" directory (%s)" : "ไม่สามารถสร้าง \"data\" ไดเรกทอรี (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "นี้มักจะสามารถแก้ไขโดย <a href=\"%s\" target=\"_blank\">ให้เข้าถึงการเขียนเว็บเซิร์ฟเวอร์ไปยังไดเรกทอรีราก</a>",
+    "Cannot create \"data\" directory" : "ไม่สามารถสร้าง \"ข้อมูล\" ไดเรกทอรี",
+    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "นี้สามารถแก้ไขได้โดยการ <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">ให้เข้าถึงการเขียนเว็บเซิร์ฟเวอร์ไปยังไดเรกทอรีราก</a>",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "สิทธิ์จะสามารถได้รับการแก้ไขโดย %s ให้เข้าถึงการเขียนเว็บเซิร์ฟเวอร์ไปยังไดเรกทอรีราก %s",
     "Setting locale to %s failed" : "ตั้งค่าต้นทาง %s ล้มเหลว",
     "Please install one of these locales on your system and restart your webserver." : "กรุณาติดตั้งหนึ่งในต้นทางเหล่านี้บนระบบของคุณและเริ่มต้นเว็บเซิร์ฟเวอร์ของคุณ",
@@ -134,20 +159,25 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make ownCloud run again" : "การปรับตั้งค่าใน php.ini นี้ ownCloud จะทำงานอีกครั้ง",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload ถูกตั้งเป็น \"%s\" แทนที่จะเป็น \"0\"",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "หากต้องการแก้ไขปัญหานี้กรุณาแก้ <code>mbstring.func_overload</code> เป็น <code>0</code> ในไฟล์ php.ini ของคุณ",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "จะต้องมี libxml2 รุ่น 2.7.0 ขึ้นไป ปัจจุบันกำลังใช้รุ่น %s อยู่",
+    "To fix this issue update your libxml2 version and restart your web server." : "เพื่อแก้ไขปัญหานี้ กรุณาอัพเดทรุ่นของ libxml2 และรีสตาร์ทเว็บเซิร์ฟเวอร์ของคุณ",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "เห็นได้ชัดว่า PHP มีการตั้งค่าเพื่อดึงบล็อกเอกสารแบบอินไลน์ ซึ่งจะทำให้แอพพลิเคชันไม่สามารถเข้าถึงได้",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "นี้อาจเกิดจาก cache/accelerator อย่างเช่น Zend OPcache หรือ eAccelerator",
     "PHP modules have been installed, but they are still listed as missing?" : "โมดูล PHP ได้รับการติดตั้ง แต่พวกเขาไม่ได้ระบุไว้หรือมันอาจหายไป?",
     "Please ask your server administrator to restart the web server." : "โปรดสอบถามผู้ดูแลระบบเซิร์ฟเวอร์ของคุณเพื่อเริ่มการทำงานของเว็บเซิร์ฟเวอร์",
     "PostgreSQL >= 9 required" : "จำเป็นต้องใช้ PostgreSQL รุ่น >= 9",
     "Please upgrade your database version" : "กรุณาอัพเดทฐานข้อมูลของคุณ",
-    "Error occurred while checking PostgreSQL version" : "เกิดข้อผิดพลาดขึ้นขณะที่การตรวจสอบรุ่นของ PostgreSQL",
-    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "กรุณาให้แน่ใจว่าคุณมี PostgreSQL รุ่น >= 9 หรือตรวจสอบบันทึกสำหรับข้อมูลเพิ่มเติมเกี่ยวกับข้อผิดพลาด",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "กรุณาเปลี่ยนสิทธิ์การเข้าถึงเป็น 0770 เพื่อให้ไดเรกทอรีไม่สามารถแก้ไขโดยผู้ใช้อื่น",
-    "Data directory (%s) is readable by other users" : "ไดเรกทอรีข้อมูล (%s) สามารถอ่านได้โดยผู้ใช้อื่น",
-    "Data directory (%s) must be an absolute path" : "ไดเรกทอรีข้อมูล (%s) จะต้องเป็นเส้นทางที่แน่นอน",
+    "Your Data directory is readable by other users" : "ข้อมูลไดเรกทอรีของคุณสามารถอ่านได้โดยผู้ใช้อื่นๆ",
+    "Your Data directory must be an absolute path" : "ข้อมูลไดเรกทอรีของคุณต้องมีเส้นทางที่แน่นอน",
     "Check the value of \"datadirectory\" in your configuration" : "ตรวจสอบค่าของ \"datadirectory\" ในการกำหนดค่าของคุณ",
-    "Data directory (%s) is invalid" : "ไดเรกทอรีข้อมูล (%s) ไม่ถูกต้อง",
+    "Your Data directory  is invalid" : "ข้อมูลไดเรกทอรีของคุณไม่ถูกต้อง",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "กรุณาตรวจสอบว่าไดเรกทอรีข้อมูลมีแฟ้ม \".ocdata\" อยู่ในราก",
-    "Could not obtain lock type %d on \"%s\"." : "ไม่สามารถรับล็อคชนิด %d บน \"%s\""
+    "Could not obtain lock type %d on \"%s\"." : "ไม่สามารถรับล็อคชนิด %d บน \"%s\"",
+    "Storage unauthorized. %s" : "การจัดเก็บข้อมูลไม่ได้รับอนุญาต %s",
+    "Storage incomplete configuration. %s" : "การตั้งค่าการจัดเก็บข้อมูลไม่สำเร็จ %s",
+    "Storage connection error. %s" : "ข้อผิดพลาดการเชื่อมต่อพื้นที่จัดเก็บข้อมูล %s",
+    "Storage is temporarily not available" : "ไม่สามารถใช้พื้นที่จัดเก็บได้ชั่วคราว",
+    "Storage connection timeout. %s" : "หมดเวลาการเชื่อมต่อพื้นที่จัดเก็บข้อมูล %s"
 },
 "nplurals=1; plural=0;");
