@@ -9,6 +9,7 @@ OC.L10N.register(
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Örnek yapılandırmanın kopyalanmış olabileceği tespit edildi. Bu kurulumunuzu bozabilir ve desteklenmemektedir. Lütfen config.php dosyasında değişiklik yapmadan önce belgelendirmeyi okuyun",
     "PHP %s or higher is required." : "PHP %s veya daha üst sürümü gerekli.",
     "PHP with a version lower than %s is required." : "PHP'nin %s sürümü öncesi gerekli.",
+    "%sbit or higher PHP required." : "%s-bit veya daha üst PHP sürümü gerekli.",
     "Following databases are supported: %s" : "Şu veritabanları desteklenmekte: %s",
     "The command line tool %s could not be found" : "Komut satırı aracı %s bulunamadı",
     "The library %s is not available." : "%s kütüphanesi mevcut değil.",
@@ -17,14 +18,6 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "Aşağıdaki platformlar destekleniyor: %s",
     "ownCloud %s or higher is required." : "ownCloud %s veya daha üstü gerekli.",
     "ownCloud %s or lower is required." : "ownCloud %s veya daha düşük sürüm gerekli.",
-    "Help" : "Yardım",
-    "Personal" : "Kişisel",
-    "Users" : "Kullanıcılar",
-    "Admin" : "Yönetici",
-    "Recommended" : "Önerilen",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "ownCloud yazılımının bu sürümü ile uyumlu olmadığı için \"%s\" uygulaması kurulamaz.",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "\"%s\" uygulaması, şu bağımlılıklar sağlanmadığı için yüklenemiyor: %s",
-    "No app name specified" : "Uygulama adı belirtilmedi",
     "Unknown filetype" : "Bilinmeyen dosya türü",
     "Invalid image" : "Geçersiz resim",
     "today" : "bugün",
@@ -37,16 +30,19 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n saat önce","%n saat önce"],
     "_%n minute ago_::_%n minutes ago_" : ["%n dakika önce","%n dakika önce"],
     "seconds ago" : "saniyeler önce",
-    "web services under your control" : "denetiminizdeki web hizmetleri",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "%s kimlikli modül mevcut değil. Lütfen uygulamalar içerisinden etkinleştirin veya sistem yöneticinize danışın.",
+    "Builtin" : "Yerleşik",
+    "None" : "Hiçbiri",
+    "Username and password" : "Kullanıcı adı ve parola",
+    "Username" : "Kullanıcı adı",
+    "Password" : "Parola",
+    "Log-in credentials, save in session" : "Oturum kimlik bilgileri, oturumda kaydet",
     "Empty filename is not allowed" : "Boş dasya adına izin verilmiyor",
     "Dot files are not allowed" : "Nokta dosyalarına izin verilmiyor",
     "4-byte characters are not supported in file names" : "4 bayt karakterler dosya adlarında desteklenmez",
     "File name is a reserved word" : "Bu dosya adı özel bir kullanıma aittir",
     "File name contains at least one invalid character" : "Dosya adı en az bir geçersiz karakter içeriyor",
     "File name is too long" : "Dosya adı çok uzun",
-    "File is currently busy, please try again later" : "Dosya şu anda meşgul, lütfen daha sonra deneyin",
-    "Can't read file" : "Dosya okunamıyor",
     "App directory already exists" : "Uygulama dizini zaten mevcut",
     "Can't create app folder. Please fix permissions. %s" : "Uygulama dizini oluşturulamıyor. Lütfen izinleri düzeltin. %s",
     "Archive does not contain a directory named %s" : "Arşivde %s adında bir dizin bulunmuyor",
@@ -56,14 +52,21 @@ OC.L10N.register(
     "Archives of type %s are not supported" : "%s arşiv türü desteklenmiyor",
     "Failed to open archive when installing app" : "Uygulama kurulurken arşiv dosyası açılamadı",
     "App does not provide an info.xml file" : "Uygulama info.xml dosyası sağlamıyor",
+    "App cannot be installed because appinfo file cannot be read." : "Appinfo dosyası okunamadığından uygulama yüklenemiyor.",
+    "Signature could not get checked. Please contact the app developer and check your admin screen." : "İmza denetlenemedi. Lütfen uygulama yöneticisi ile iletişime geçin ve yönetici ekranınıza bakın.",
     "App can't be installed because of not allowed code in the App" : "Uygulama, izin verilmeyen kodlar barındırdığından kurulamıyor",
     "App can't be installed because it is not compatible with this version of ownCloud" : "ownCloud sürümünüz ile uyumsuz olduğu için uygulama kurulamıyor",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Uygulama, birlikte gelmeyen uygulama olmasına rağmen <shipped>true</shipped> etiketi içerdiği için kurulamıyor",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "Uygulama info.xml/version ile uygulama marketinde belirtilen sürüm aynı olmadığından kurulamıyor",
-    "Application is not enabled" : "Uygulama etkin değil",
-    "Authentication error" : "Kimlik doğrulama hatası",
-    "Token expired. Please reload page." : "Belirteç süresi geçti. Lütfen sayfayı yenileyin.",
-    "Unknown user" : "Bilinmeyen kullanıcı",
+    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "Uygulama info.xml içindeki sürüm ile uygulama marketinde belirtilen sürüm aynı olmadığından kurulamıyor",
+    "Apps" : "Uygulamalar",
+    "General" : "Genel",
+    "Storage" : "Depolama",
+    "Security" : "Güvenlik",
+    "Encryption" : "Şifreleme",
+    "Sharing" : "Paylaşım",
+    "Search" : "Ara",
+    "Updates" : "Güncellemeler",
+    "%s enter the database username and name." : "%s veritabanı adı ve kullanıcı adını girin.",
     "%s enter the database username." : "%s veritabanı kullanıcı adını girin.",
     "%s enter the database name." : "%s veritabanı adını girin.",
     "%s you may not use dots in the database name" : "%s veritabanı adında nokta kullanamayabilirsiniz",
@@ -87,7 +90,7 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Arka uç %i türündeki paylaşımlara izin vermediğinden %s paylaşımı başarısız",
     "Sharing %s failed, because the file does not exist" : "%s paylaşımı, dosya mevcut olmadığından başarısız oldu",
     "You are not allowed to share %s" : "%s paylaşımını yapma izniniz yok",
-    "Sharing %s failed, because the user %s is the item owner" : "%s paylaşımı, %s öge sahibi olduğundan başarısız oldu",
+    "Sharing %s failed, because you can not share with yourself" : "%s paylaşımı başarısız, kendiniz ile paylaşamazsınız",
     "Sharing %s failed, because the user %s does not exist" : "%s paylaşımı, %s kullanıcısı mevcut olmadığından başarısız oldu",
     "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s paylaşımı, %s kullanıcısının %s üyeliklerinden birine sahip olmadığından başarısız oldu",
     "Sharing %s failed, because this item is already shared with %s" : "%s paylaşımı, %s ile zaten paylaşıldığından dolayı başarısız oldu",
@@ -96,6 +99,7 @@ OC.L10N.register(
     "Sharing %s failed, because %s is not a member of the group %s" : "%s paylaşımı, %s kullanıcısı %s grup üyesi olmadığından başarısız oldu",
     "You need to provide a password to create a public link, only protected links are allowed" : "Herkese açık bir bağlantı oluşturmak için bir parola belirtmeniz gerekiyor. Sadece korunmuş bağlantılara izin verilmektedir",
     "Sharing %s failed, because sharing with links is not allowed" : "%s paylaşımı, bağlantılar ile paylaşım izin verilmediğinden başarısız oldu",
+    "Not allowed to create a federated share with the same user" : "Aynı kullanıcı ile bir birleşik paylaşım oluşturulamaz",
     "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s paylaşımı başarısız. %s bulunamadı veya sunucu şu anda ulaşılamıyor olabilir.",
     "Share type %s is not valid for %s" : "%s paylaşım türü %s için geçerli değil",
     "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "%s için izinler, izinler %s için verilen izinleri aştığından dolayı ayarlanamadı",
@@ -106,25 +110,40 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Paylaşma arka ucu %s OCP\\Share_Backend arayüzünü desteklemeli",
     "Sharing backend %s not found" : "Paylaşım arka ucu %s bulunamadı",
     "Sharing backend for %s not found" : "%s için paylaşım arka ucu bulunamadı",
-    "Sharing %s failed, because the user %s is the original sharer" : "%s paylaşımı, %s kullanıcısı özgün paylaşan kişi olduğundan başarısız oldu",
+    "Sharing failed, because the user %s is the original sharer" : "%s kullanıcısı özgün paylaşan kişi olduğundan başarısız oldu",
     "Sharing %s failed, because the permissions exceed permissions granted to %s" : "%s paylaşımı, izinler %s için verilen izinleri aştığından dolayı başarısız oldu",
     "Sharing %s failed, because resharing is not allowed" : "%s paylaşımı, tekrar paylaşımın izin verilmemesinden dolayı başarısız oldu",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s paylaşımı, %s için arka ucun kaynağını bulamamasından dolayı başarısız oldu",
     "Sharing %s failed, because the file could not be found in the file cache" : "%s paylaşımı, dosyanın dosya önbelleğinde bulunamamasınndan dolayı başarısız oldu",
+    "Cannot increase permissions of %s" : "%s izinleri yükseltilemiyor",
+    "Files can't be shared with delete permissions" : "Dosyalar silme izni ile paylaşılamaz",
+    "Files can't be shared with create permissions" : "Dosyalar oluşturma izni ile paylaşılamaz",
+    "Expiration date is in the past" : "Son kullanma tarihi geçmişte",
+    "Cannot set expiration date more than %s days in the future" : "Paylaşımların son kullanım süreleri, gelecekte %s günden fazla olamaz",
     "Could not find category \"%s\"" : "\"%s\" kategorisi bulunamadı",
-    "Apps" : "Uygulamalar",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Kullanıcı adında sadece bu karakterlere izin verilmektedir: \"a-z\", \"A-Z\", \"0-9\", ve \"_.@-\"",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Kullanıcı adında sadece bu karakterlere izin verilmektedir: \"a-z\", \"A-Z\", \"0-9\", ve \"_.@-'\"",
     "A valid username must be provided" : "Geçerli bir kullanıcı adı mutlaka sağlanmalı",
+    "Username contains whitespace at the beginning or at the end" : "Kullanıcı adı başlangıç veya sonda boşluk içeriyor",
     "A valid password must be provided" : "Geçerli bir parola mutlaka sağlanmalı",
     "The username is already being used" : "Bu kullanıcı adı zaten kullanımda",
+    "Login canceled by app" : "Giriş uygulama tarafından iptal edildi",
+    "User disabled" : "Kullanıcı devre dışı",
+    "Help" : "Yardım",
+    "Settings" : "Ayarlar",
+    "Users" : "Kullanıcılar",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "\"%s\" uygulaması, şu bağımlılıklar sağlanmadığı için yüklenemiyor: %s",
+    "web services under your control" : "denetiminizdeki web hizmetleri",
+    "File is currently busy, please try again later" : "Dosya şu anda meşgul, lütfen daha sonra deneyin",
+    "Can't read file" : "Dosya okunamıyor",
+    "Application is not enabled" : "Uygulama etkin değil",
+    "Authentication error" : "Kimlik doğrulama hatası",
+    "Token expired. Please reload page." : "Belirteç süresi geçti. Lütfen sayfayı yenileyin.",
+    "Unknown user" : "Bilinmeyen kullanıcı",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Yüklü veritabanı sürücüsü (sqlite, mysql veya postgresql) yok.",
-    "Microsoft Windows Platform is not supported" : "Microsoft Windows Platformu desteklenmiyor",
-    "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "ownCloud Sunucusu'nun Microsoft Windows platformunda çalıştırılması desteklenmiyor. Sunucuyu taşıma imkanınız yoksa bir sanal makine içerisinde Linux sunucusu kullanmanızı öneriyoruz. Linux paketleri ile birlikte sanal makinelere kolaylıkla açılabilen kalıpları <a href=\"%s\">%s</a> adresinden bulabilirsiniz. Mevcut kurulumları Linux'a aktarmak için yazılmış bazı ipuçları ve aktarım betiğine <a href=\"%s\">belgelendirmemizden</a> ulaşabilirsiniz.",
     "Cannot write into \"config\" directory" : "\"config\" dizinine yazılamıyor",
     "Cannot write into \"apps\" directory" : "\"apps\" dizinine yazılamıyor",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Bu genellikle, %sweb sunucusuna apps dizinine yazma erişimi verilerek%s veya yapılandırma dosyasında appstore (uygulama mağazası) devre dışı bırakılarak çözülebilir.",
-    "Cannot create \"data\" directory (%s)" : "\"Veri\" dizini oluşturulamıyor (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "İzinler genellikle, <a href=\"%s\" target=\"_blank\">web sunucusuna kök dizinine yazma erişimi verilerek</a> çözülebilir.",
+    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Bu genellikle, <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">web sunucusuna kök dizinine yazma erişimi verilerek</a> çözülebilir.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "İzinler genellikle, %sweb sunucusuna kök dizinine yazma erişimi verilerek%s çözülebilir",
     "Setting locale to %s failed" : "Dili %s olarak ayarlama başarısız",
     "Please install one of these locales on your system and restart your webserver." : "Lütfen bu yerellerden birini sisteminize yükleyin ve web sunucunuzu yeniden başlatın.",
@@ -134,20 +153,21 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make ownCloud run again" : "Bu ayarı php.ini içerisinde ayarlamak ownCloud'ı tekrar çalıştıracak.",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload, beklenen \"0\" değerinin aksine \"%s\" olarak ayarlanmış",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Bu hatayı düzeltmek için php.ini içerisindeki <code>mbstring.func_overload</code> ayarını <code>0</code> olarak ayarlayın",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "En düşük libxml2 2.7.0 gerekli. Şu anda %s kurulu.",
+    "To fix this issue update your libxml2 version and restart your web server." : "Bu sorunu çözmek için libxml2 sürümünüzü güncelleyin ve web sunucusunu yeniden başlatın.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP satıriçi doc bloklarını ayıklamak üzere yapılandırılmış gibi görünüyor. Bu, bazı çekirdek uygulamalarını erişilemez yapacak.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Bu, muhtemelen Zend OPcache veya eAccelerator gibi bir önbellek/hızlandırıcı nedeniyle meydana gelir.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP modülleri yüklü, ancak hala eksik olarak mı görünüyorlar?",
     "Please ask your server administrator to restart the web server." : "Lütfen web sunucusunu yeniden başlatması için sunucu yöneticinize danışın.",
     "PostgreSQL >= 9 required" : "PostgreSQL >= 9 gerekli",
     "Please upgrade your database version" : "Lütfen veritabanı sürümünüzü yükseltin",
-    "Error occurred while checking PostgreSQL version" : "PostgreSQL sürümü denetlenirken hata oluştu",
-    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "PostgreSQL >= 9 sürümüne sahip olduğunuzu doğrulayın veya hata hakkında daha fazla bilgi için günlükleri denetleyin",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Lütfen izinleri 0770 olarak ayarlayıp dizinin diğer kullanıcılar tarafından görülememesini sağlayın.",
-    "Data directory (%s) is readable by other users" : "Veri dizini (%s) diğer kullanıcılar tarafından okunabilir",
-    "Data directory (%s) must be an absolute path" : "Veri dizini (%s) tam yol olmalıdır",
     "Check the value of \"datadirectory\" in your configuration" : "Yapılandırmanızdaki \"datadirectory\" değerini denetleyin",
-    "Data directory (%s) is invalid" : "Veri dizini (%s) geçersiz",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Lütfen veri dizininin kökünde \".ocdata\" adlı bir dosyanın bulunduğunu denetleyin.",
-    "Could not obtain lock type %d on \"%s\"." : "\"%s\" üzerinde %d kilit türü alınamadı."
+    "Could not obtain lock type %d on \"%s\"." : "\"%s\" üzerinde %d kilit türü alınamadı.",
+    "Storage unauthorized. %s" : "Depolamaya erişim izni yok. %s",
+    "Storage incomplete configuration. %s" : "Depolamada tamamlanmamış yapılandırma. %s",
+    "Storage connection error. %s" : "Depolama bağlantı hatası. %s",
+    "Storage connection timeout. %s" : "Depolama bağlantı zaman aşımı. %s"
 },
 "nplurals=2; plural=(n > 1);");
