@@ -3,10 +3,6 @@ OC.L10N.register(
     {
     "Cannot write into \"config\" directory!" : "Không thể ghi vào thư mục \"config\"!",
     "See %s" : "Xem %s",
-    "Help" : "Giúp đỡ",
-    "Personal" : "Cá nhân",
-    "Users" : "Người dùng",
-    "Admin" : "Quản trị",
     "Unknown filetype" : "Không biết kiểu tập tin",
     "Invalid image" : "Hình ảnh không hợp lệ",
     "today" : "hôm nay",
@@ -17,13 +13,23 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n giờ trước"],
     "_%n minute ago_::_%n minutes ago_" : ["%n phút trước"],
     "seconds ago" : "vài giây trước",
+    "None" : "Không gì cả",
+    "Username" : "Tên đăng nhập",
+    "Password" : "Mật khẩu",
+    "Apps" : "Ứng dụng",
+    "General" : "Tổng hợp",
+    "Storage" : "Bộ nhớ",
+    "Encryption" : "Mã hóa",
+    "Sharing" : "Chia sẻ",
+    "Search" : "Tìm kiếm",
+    "%s shared »%s« with you" : "%s đã chia sẻ »%s« với bạn",
+    "Could not find category \"%s\"" : "không thể tìm thấy mục \"%s\"",
+    "Help" : "Giúp đỡ",
+    "Settings" : "Cài đặt",
+    "Users" : "Người dùng",
     "web services under your control" : "dịch vụ web dưới sự kiểm soát của bạn",
     "Application is not enabled" : "Ứng dụng không được BẬT",
     "Authentication error" : "Lỗi xác thực",
-    "Token expired. Please reload page." : "Mã Token đã hết hạn. Hãy tải lại trang.",
-    "%s shared »%s« with you" : "%s đã chia sẻ »%s« với bạn",
-    "Could not find category \"%s\"" : "không thể tìm thấy mục \"%s\"",
-    "Apps" : "Ứng dụng",
-    "Storage not available" : "Lưu trữ không có sẵn"
+    "Token expired. Please reload page." : "Mã Token đã hết hạn. Hãy tải lại trang."
 },
 "nplurals=1; plural=0;");
