@@ -364,7 +364,8 @@ class DIContainer extends SimpleContainer implements IAppContainer {
 			return new CORSMiddleware(
 				$c['Request'],
 				$c['ControllerMethodReflector'],
-				$c['OCP\IUserSession']
+				$c['OCP\IUserSession'],
+				$c['OCP\IConfig']
 			);
 		});
 
@@ -442,7 +443,7 @@ class DIContainer extends SimpleContainer implements IAppContainer {
 	 * @return boolean
 	 */
 	function isLoggedIn() {
-		return \OC_User::isLoggedIn();
+		return $this->getServer()->getUserSession()->isLoggedIn();
 	}
 
 	/**
