@@ -38,18 +38,17 @@ use GuzzleHttp\Message\ResponseInterface;
 use OC\Files\Filesystem;
 use OC\Files\Stream\Close;
 use Icewind\Streams\IteratorDirectory;
-use OC\MemCache\ArrayCache;
+use OC\Memcache\ArrayCache;
 use OCP\AppFramework\Http;
 use OCP\Constants;
-use OCP\Files;
 use OCP\Files\FileInfo;
 use OCP\Files\StorageInvalidException;
 use OCP\Files\StorageNotAvailableException;
 use OCP\Util;
-use Sabre\DAV\Client;
 use Sabre\DAV\Xml\Property\ResourceType;
-use Sabre\HTTP\ClientException;
 use Sabre\HTTP\ClientHttpException;
+use Sabre\DAV\Exception\InsufficientStorage;
+use OCA\DAV\Connector\Sabre\Exception\Forbidden;
 
 /**
  * Class DAV
@@ -82,6 +81,9 @@ class DAV extends Common {
 	/** @var \OCP\Http\Client\IClientService */
 	private $httpClientService;
 
+	/** @var \OCP\Http\Client\IWebDavClientService */
+	private $webDavClientService;
+
 	/**
 	 * @param array $params
 	 * @throws \Exception
@@ -89,6 +91,7 @@ class DAV extends Common {
 	public function __construct($params) {
 		$this->statCache = new ArrayCache();
 		$this->httpClientService = \OC::$server->getHTTPClientService();
+		$this->webDavClientService = \OC::$server->getWebDavClientService();
 		if (isset($params['host']) && isset($params['user']) && isset($params['password'])) {
 			$host = $params['host'];
 			//remove leading http[s], will be generated in createBaseUri()
@@ -109,17 +112,6 @@ class DAV extends Common {
 			} else {
 				$this->secure = false;
 			}
-			if ($this->secure === true) {
-				// inject mock for testing
-				$certManager = \OC::$server->getCertificateManager();
-				if (is_null($certManager)) { //no user
-					$certManager = \OC::$server->getCertificateManager(null);
-				}
-				$certPath = $certManager->getAbsoluteBundlePath();
-				if (file_exists($certPath)) {
-					$this->certPath = $certPath;
-				}
-			}
 			$this->root = isset($params['root']) ? $params['root'] : '/';
 			if (!$this->root || $this->root[0] != '/') {
 				$this->root = '/' . $this->root;
@@ -128,11 +120,11 @@ class DAV extends Common {
 				$this->root .= '/';
 			}
 		} else {
-			throw new \Exception('Invalid webdav storage configuration');
+			throw new \InvalidArgumentException('Invalid webdav storage configuration');
 		}
 	}
 
-	private function init() {
+	protected function init() {
 		if ($this->ready) {
 			return;
 		}
@@ -141,22 +133,13 @@ class DAV extends Common {
 		$settings = [
 			'baseUri' => $this->createBaseUri(),
 			'userName' => $this->user,
-			'password' => $this->password,
+			'password' => $this->password
 		];
 		if (isset($this->authType)) {
 			$settings['authType'] = $this->authType;
 		}
 
-		$proxy = \OC::$server->getConfig()->getSystemValue('proxy', '');
-		if($proxy !== '') {
-			$settings['proxy'] = $proxy;
-		}
-
-		$this->client = new Client($settings);
-		$this->client->setThrowExceptions(true);
-		if ($this->secure === true && $this->certPath) {
-			$this->client->addCurlSetting(CURLOPT_CAINFO, $this->certPath);
-		}
+		$this->client = $this->webDavClientService->newClient($settings);
 	}
 
 	/**
@@ -234,6 +217,13 @@ class DAV extends Common {
 				$content[] = $file;
 			}
 			return IteratorDirectory::wrap($content);
+		} catch (ClientHttpException $e) {
+			if ($e->getHttpStatus() === Http::STATUS_NOT_FOUND) {
+				$this->statCache->clear($path . '/');
+				$this->statCache->set($path, false);
+				return false;
+			}
+			$this->convertException($e, $path);
 		} catch (\Exception $e) {
 			$this->convertException($e, $path);
 		}
@@ -355,7 +345,7 @@ class DAV extends Common {
 						&& $e->getResponse()->getStatusCode() === Http::STATUS_NOT_FOUND) {
 						return false;
 					} else {
-						throw $e;
+						$this->convertException($e);
 					}
 				}
 
@@ -364,6 +354,7 @@ class DAV extends Common {
 						throw new \OCP\Lock\LockedException($path);
 					} else {
 						Util::writeLog("webdav client", 'Guzzle get returned status code ' . $response->getStatusCode(), Util::ERROR);
+						// FIXME: why not returning false here ?!
 					}
 				}
 
@@ -442,7 +433,7 @@ class DAV extends Common {
 	public function touch($path, $mtime = null) {
 		$this->init();
 		if (is_null($mtime)) {
-			$mtime = time();
+			$mtime = \OC::$server->getTimeFactory()->getTime();
 		}
 		$path = $this->cleanPath($path);
 
@@ -454,6 +445,7 @@ class DAV extends Common {
 				// non-owncloud clients might not have accepted the property, need to recheck it
 				$response = $this->client->propfind($this->encodePath($path), ['{DAV:}getlastmodified'], 0);
 				if ($response === false) {
+					// file disappeared since ?
 					return false;
 				}
 				if (isset($response['{DAV:}getlastmodified'])) {
@@ -503,14 +495,17 @@ class DAV extends Common {
 		$this->statCache->remove($target);
 		$source = fopen($path, 'r');
 
-		$this->httpClientService
-			->newClient()
-			->put($this->createBaseUri() . $this->encodePath($target), [
-				'body' => $source,
-				'auth' => [$this->user, $this->password]
-			]);
-
 		$this->removeCachedFile($target);
+		try {
+			$this->httpClientService
+				->newClient()
+				->put($this->createBaseUri() . $this->encodePath($target), [
+					'body' => $source,
+					'auth' => [$this->user, $this->password]
+				]);
+		} catch (\Exception $e) {
+			$this->convertException($e);
+		}
 	}
 
 	/** {@inheritdoc} */
@@ -661,6 +656,9 @@ class DAV extends Common {
 				$this->statCache->set($path, false);
 				return false;
 			}
+			if ($e->getHttpStatus() === Http::STATUS_METHOD_NOT_ALLOWED && $method === 'MKCOL') {
+				return false;
+			}
 
 			$this->convertException($e, $path);
 		} catch (\Exception $e) {
@@ -775,10 +773,7 @@ class DAV extends Common {
 			}
 			if (isset($response['{DAV:}getetag'])) {
 				$cachedData = $this->getCache()->get($path);
-				$etag = null;
-				if (isset($response['{DAV:}getetag'])) {
-					$etag = trim($response['{DAV:}getetag'], '"');
-				}
+				$etag = trim($response['{DAV:}getetag'], '"');
 				if (!empty($etag) && $cachedData['etag'] !== $etag) {
 					return true;
 				} else if (isset($response['{http://open-collaboration-services.org/ns}share-permissions'])) {
@@ -828,30 +823,48 @@ class DAV extends Common {
 		\OC::$server->getLogger()->logException($e);
 		Util::writeLog('files_external', $e->getMessage(), Util::ERROR);
 		if ($e instanceof ClientHttpException) {
-			if ($e->getHttpStatus() === Http::STATUS_LOCKED) {
-				throw new \OCP\Lock\LockedException($path);
+			$this->throwByStatusCode($e->getHttpStatus(), $e, $path);
+		} else if ($e instanceof \GuzzleHttp\Exception\RequestException) {
+			if ($e->getResponse() instanceof ResponseInterface) {
+				$this->throwByStatusCode($e->getResponse()->getStatusCode(), $e);
 			}
-			if ($e->getHttpStatus() === Http::STATUS_UNAUTHORIZED) {
-				// either password was changed or was invalid all along
-				throw new StorageInvalidException(get_class($e) . ': ' . $e->getMessage());
-			} else if ($e->getHttpStatus() === Http::STATUS_METHOD_NOT_ALLOWED) {
-				// ignore exception for MethodNotAllowed, false will be returned
-				return;
-			}
-			throw new StorageNotAvailableException(get_class($e) . ': ' . $e->getMessage());
-		} else if ($e instanceof ClientException) {
 			// connection timeout or refused, server could be temporarily down
 			throw new StorageNotAvailableException(get_class($e) . ': ' . $e->getMessage());
 		} else if ($e instanceof \InvalidArgumentException) {
 			// parse error because the server returned HTML instead of XML,
 			// possibly temporarily down
 			throw new StorageNotAvailableException(get_class($e) . ': ' . $e->getMessage());
-		} else if (($e instanceof StorageNotAvailableException) || ($e instanceof StorageInvalidException)) {
+		} else if (($e instanceof StorageNotAvailableException)
+			|| ($e instanceof StorageInvalidException)
+			|| ($e instanceof \Sabre\DAV\Exception
+		)) {
 			// rethrow
 			throw $e;
 		}
 
 		// TODO: only log for now, but in the future need to wrap/rethrow exception
 	}
+
+	/**
+	 * Throw exception by status code
+	 *
+	 * @param int $statusCode status code
+	 * @param string $path optional path for some exceptions
+	 * @throws \Exception Sabre or ownCloud exceptions
+	 */
+	private function throwByStatusCode($statusCode, $e, $path = '') {
+		switch ($statusCode) {
+			case Http::STATUS_LOCKED:
+				throw new \OCP\Lock\LockedException($path);
+			case Http::STATUS_UNAUTHORIZED:
+				// either password was changed or was invalid all along
+				throw new StorageInvalidException(get_class($e) . ': ' . $e->getMessage());
+			case Http::STATUS_INSUFFICIENT_STORAGE:
+				throw new InsufficientStorage();
+			case Http::STATUS_FORBIDDEN:
+				throw new Forbidden('Forbidden');
+		}
+		throw new StorageNotAvailableException(get_class($e) . ': ' . $e->getMessage());
+	}
 }
 
