@@ -1,10 +1,13 @@
 <?php
 /**
  * @author Björn Schießle <bjoern@schiessle.org>
- * @author Joas Schilling <nickvergessen@owncloud.com>
+ * @author Joas Schilling <coding@schilljs.com>
+ * @author phisch <git@philippschaffrath.de>
  * @author Roeland Jago Douma <rullzer@owncloud.com>
+ * @author Vincent Petry <pvince81@owncloud.com>
+ * @author Piotr Mrowczynski <piotr@owncloud.com>
  *
- * @copyright Copyright (c) 2016, ownCloud, Inc.
+ * @copyright Copyright (c) 2017, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -92,9 +95,11 @@ class DefaultShareProvider implements IShareProvider {
 	 * @param \OCP\Share\IShare $share
 	 * @return \OCP\Share\IShare The share object
 	 * @throws ShareNotFound
+	 * @throws InvalidArgumentException if the share validation failed
 	 * @throws \Exception
 	 */
 	public function create(\OCP\Share\IShare $share) {
+		$this->validate($share);
 		$qb = $this->dbConn->getQueryBuilder();
 
 		$qb->insert('share');
@@ -123,6 +128,9 @@ class DefaultShareProvider implements IShareProvider {
 			if (method_exists($share, 'getParent')) {
 				$qb->setValue('parent', $qb->createNamedParameter($share->getParent()));
 			}
+
+			// Set user-defined name
+			$qb->setValue('share_name', $qb->createNamedParameter($share->getName()));
 		} else {
 			throw new \Exception('invalid share type!');
 		}
@@ -183,8 +191,10 @@ class DefaultShareProvider implements IShareProvider {
 	 *
 	 * @param \OCP\Share\IShare $share
 	 * @return \OCP\Share\IShare The share object
+	 * @throws InvalidArgumentException if the share validation failed
 	 */
 	public function update(\OCP\Share\IShare $share) {
+		$this->validate($share);
 		if ($share->getShareType() === \OCP\Share::SHARE_TYPE_USER) {
 			/*
 			 * We allow updating the recipient on user shares.
@@ -244,6 +254,7 @@ class DefaultShareProvider implements IShareProvider {
 				->set('file_source', $qb->createNamedParameter($share->getNode()->getId()))
 				->set('token', $qb->createNamedParameter($share->getToken()))
 				->set('expiration', $qb->createNamedParameter($share->getExpirationDate(), IQueryBuilder::PARAM_DATE))
+				->set('share_name', $qb->createNamedParameter($share->getName()))
 				->execute();
 		}
 
@@ -457,6 +468,59 @@ class DefaultShareProvider implements IShareProvider {
 		return $share;
 	}
 
+	/**
+	 * @inheritdoc
+	 */
+	public function getAllSharesBy($userId, $shareTypes, $nodeIDs, $reshares) {
+		$shares = [];
+		$qb = $this->dbConn->getQueryBuilder();
+
+		$nodeIdsChunks = array_chunk($nodeIDs, 100);
+		foreach ($nodeIdsChunks as $nodeIdsChunk) {
+			$qb->select('*')
+				->from('share')
+				->andWhere($qb->expr()->orX(
+					$qb->expr()->eq('item_type', $qb->createNamedParameter('file')),
+					$qb->expr()->eq('item_type', $qb->createNamedParameter('folder'))
+				));
+
+			$orX = $qb->expr()->orX();
+
+			foreach ($shareTypes as $shareType) {
+				$orX->add($qb->expr()->eq('share_type', $qb->createNamedParameter($shareType)));
+			}
+
+			$qb->andWhere($orX);
+
+			/**
+			 * Reshares for this user are shares where they are the owner.
+			 */
+			if ($reshares === false) {
+				$qb->andWhere($qb->expr()->eq('uid_initiator', $qb->createNamedParameter($userId)));
+			} else {
+				$qb->andWhere(
+					$qb->expr()->orX(
+						$qb->expr()->eq('uid_owner', $qb->createNamedParameter($userId)),
+						$qb->expr()->eq('uid_initiator', $qb->createNamedParameter($userId))
+					)
+				);
+			}
+
+			$qb->andWhere($qb->expr()->in('file_source', $qb->createParameter('file_source_ids')));
+			$qb->setParameter('file_source_ids', $nodeIdsChunk, IQueryBuilder::PARAM_INT_ARRAY);
+
+			$qb->orderBy('id');
+
+			$cursor = $qb->execute();
+			while($data = $cursor->fetch()) {
+				$shares[] = $this->createShare($data);
+			}
+			$cursor->closeCursor();
+		}
+		
+		return $shares;
+	}
+
 	/**
 	 * @inheritdoc
 	 */
@@ -546,7 +610,14 @@ class DefaultShareProvider implements IShareProvider {
 
 		// If the recipient is set for a group share resolve to that user
 		if ($recipientId !== null && $share->getShareType() === \OCP\Share::SHARE_TYPE_GROUP) {
-			$share = $this->resolveGroupShare($share, $recipientId);
+			$resolvedShares = $this->resolveGroupShares([$share], $recipientId);
+			if (count($resolvedShares) === 1){
+				// If we pass to resolveGroupShares() an with one element,
+				// we expect to receive exactly one element, otherwise it is error
+				$share = $resolvedShares[0];
+			} else {
+				throw new ProviderException("ResolveGroupShares() returned wrong result");
+			}
 		}
 
 		return $share;
@@ -604,6 +675,116 @@ class DefaultShareProvider implements IShareProvider {
 		return true;
 	}
 
+	/*
+	 * Get shared with user shares for the given userId and node
+	 *
+	 * @param string $userId
+	 * @param Node|null $node
+	 * @return DB\QueryBuilder\IQueryBuilder $qb
+	 */
+	public function getSharedWithUserQuery($userId, $node) {
+		$qb = $this->dbConn->getQueryBuilder();
+		$qb->select('s.*', 'f.fileid', 'f.path')
+			->selectAlias('st.id', 'storage_string_id')
+			->from('share', 's')
+			->leftJoin('s', 'filecache', 'f', $qb->expr()->eq('s.file_source', 'f.fileid'))
+			->leftJoin('f', 'storages', 'st', $qb->expr()->eq('f.storage', 'st.numeric_id'));
+
+		// Order by id
+		$qb->orderBy('s.id');
+
+		$qb->where($qb->expr()->eq('share_type', $qb->createNamedParameter(\OCP\Share::SHARE_TYPE_USER)))
+			->andWhere($qb->expr()->eq('share_with', $qb->createNamedParameter($userId)))
+			->andWhere($qb->expr()->orX(
+				$qb->expr()->eq('item_type', $qb->createNamedParameter('file')),
+				$qb->expr()->eq('item_type', $qb->createNamedParameter('folder'))
+			));
+
+		// Filter by node if provided
+		if ($node !== null) {
+			$qb->andWhere($qb->expr()->eq('file_source', $qb->createNamedParameter($node->getId())));
+		}
+
+		return $qb;
+	}
+
+	/*
+	 * Get shared with group shares for the given groups and node
+	 *
+	 * @param IGroup[] $groups
+	 * @param Node|null $node
+	 * @return DB\QueryBuilder\IQueryBuilder $qb
+	 */
+	private function getSharedWithGroupQuery($groups, $node) {
+		$qb = $this->dbConn->getQueryBuilder();
+		$qb->select('s.*', 'f.fileid', 'f.path')
+			->selectAlias('st.id', 'storage_string_id')
+			->from('share', 's')
+			->leftJoin('s', 'filecache', 'f', $qb->expr()->eq('s.file_source', 'f.fileid'))
+			->leftJoin('f', 'storages', 'st', $qb->expr()->eq('f.storage', 'st.numeric_id'))
+			->orderBy('s.id');
+
+		// Filter by node if provided
+		if ($node !== null) {
+			$qb->andWhere($qb->expr()->eq('file_source', $qb->createNamedParameter($node->getId())));
+		}
+
+		$groups = array_map(function(IGroup $group) { return $group->getGID(); }, $groups);
+
+		$qb->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(\OCP\Share::SHARE_TYPE_GROUP)))
+			->andWhere($qb->expr()->in('share_with', $qb->createNamedParameter(
+				$groups,
+				IQueryBuilder::PARAM_STR_ARRAY
+			)))
+			->andWhere($qb->expr()->orX(
+				$qb->expr()->eq('item_type', $qb->createNamedParameter('file')),
+				$qb->expr()->eq('item_type', $qb->createNamedParameter('folder'))
+			));
+
+		return $qb;
+	}
+
+	/*
+	 * Get shared with group and shared with user shares for the given groups, userId and node
+	 *
+	 * @param IGroup[] $groups
+	 * @param string $userId
+	 * @param Node|null $node
+	 * @return DB\QueryBuilder\IQueryBuilder $qb
+	 */
+	private function getSharedWithUserGroupQuery($groups, $userId, $node) {
+		$qb = $this->dbConn->getQueryBuilder();
+		$qb->select('s.*', 'f.fileid', 'f.path')
+			->selectAlias('st.id', 'storage_string_id')
+			->from('share', 's')
+			->leftJoin('s', 'filecache', 'f', $qb->expr()->eq('s.file_source', 'f.fileid'))
+			->leftJoin('f', 'storages', 'st', $qb->expr()->eq('f.storage', 'st.numeric_id'))
+			->orderBy('s.id');
+
+		// Filter by node if provided
+		if ($node !== null) {
+			$qb->andWhere($qb->expr()->eq('file_source', $qb->createNamedParameter($node->getId())));
+		}
+
+		$groups = array_map(function(IGroup $group) { return $group->getGID(); }, $groups);
+
+		$qb->andWhere($qb->expr()->orX(
+			$qb->expr()->andX(
+				$qb->expr()->eq('share_type', $qb->createNamedParameter(\OCP\Share::SHARE_TYPE_GROUP)),
+				$qb->expr()->in('share_with', $qb->createNamedParameter(
+					$groups,
+					IQueryBuilder::PARAM_STR_ARRAY
+				))
+			),
+			$qb->expr()->andX(
+				$qb->expr()->eq('share_type', $qb->createNamedParameter(\OCP\Share::SHARE_TYPE_USER)),
+				$qb->expr()->eq('share_with', $qb->createNamedParameter($userId))
+			)
+		));
+
+		return $qb;
+	}
+
 	/**
 	 * @inheritdoc
 	 */
@@ -612,16 +793,8 @@ class DefaultShareProvider implements IShareProvider {
 		$shares = [];
 
 		if ($shareType === \OCP\Share::SHARE_TYPE_USER) {
-			//Get shares directly with this user
-			$qb = $this->dbConn->getQueryBuilder();
-			$qb->select('s.*', 'f.fileid', 'f.path')
-				->selectAlias('st.id', 'storage_string_id')
-				->from('share', 's')
-				->leftJoin('s', 'filecache', 'f', $qb->expr()->eq('s.file_source', 'f.fileid'))
-				->leftJoin('f', 'storages', 'st', $qb->expr()->eq('f.storage', 'st.numeric_id'));
-
-			// Order by id
-			$qb->orderBy('s.id');
+			// Create SharedWithUser query
+			$qb = $this->getSharedWithUserQuery($userId, $node);
 
 			// Set limit and offset
 			if ($limit !== -1) {
@@ -629,18 +802,6 @@ class DefaultShareProvider implements IShareProvider {
 			}
 			$qb->setFirstResult($offset);
 
-			$qb->where($qb->expr()->eq('share_type', $qb->createNamedParameter(\OCP\Share::SHARE_TYPE_USER)))
-				->andWhere($qb->expr()->eq('share_with', $qb->createNamedParameter($userId)))
-				->andWhere($qb->expr()->orX(
-					$qb->expr()->eq('item_type', $qb->createNamedParameter('file')),
-					$qb->expr()->eq('item_type', $qb->createNamedParameter('folder'))
-				));
-
-			// Filter by node if provided
-			if ($node !== null) {
-				$qb->andWhere($qb->expr()->eq('file_source', $qb->createNamedParameter($node->getId())));
-			}
-
 			$cursor = $qb->execute();
 
 			while($data = $cursor->fetch()) {
@@ -652,7 +813,7 @@ class DefaultShareProvider implements IShareProvider {
 
 		} else if ($shareType === \OCP\Share::SHARE_TYPE_GROUP) {
 			$user = $this->userManager->get($userId);
-			$allGroups = $this->groupManager->getUserGroups($user);
+			$allGroups = $this->groupManager->getUserGroups($user, 'sharing');
 
 			/** @var Share[] $shares2 */
 			$shares2 = [];
@@ -666,36 +827,14 @@ class DefaultShareProvider implements IShareProvider {
 					break;
 				}
 
-				$qb = $this->dbConn->getQueryBuilder();
-				$qb->select('s.*', 'f.fileid', 'f.path')
-					->selectAlias('st.id', 'storage_string_id')
-					->from('share', 's')
-					->leftJoin('s', 'filecache', 'f', $qb->expr()->eq('s.file_source', 'f.fileid'))
-					->leftJoin('f', 'storages', 'st', $qb->expr()->eq('f.storage', 'st.numeric_id'))
-					->orderBy('s.id')
-					->setFirstResult(0);
+				// Create SharedWithGroups query
+				$qb = $this->getSharedWithGroupQuery($groups, $node);
+				$qb->setFirstResult(0);
 
 				if ($limit !== -1) {
 					$qb->setMaxResults($limit - count($shares));
 				}
 
-				// Filter by node if provided
-				if ($node !== null) {
-					$qb->andWhere($qb->expr()->eq('file_source', $qb->createNamedParameter($node->getId())));
-				}
-
-				$groups = array_map(function(IGroup $group) { return $group->getGID(); }, $groups);
-
-				$qb->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(\OCP\Share::SHARE_TYPE_GROUP)))
-					->andWhere($qb->expr()->in('share_with', $qb->createNamedParameter(
-						$groups,
-						IQueryBuilder::PARAM_STR_ARRAY
-					)))
-					->andWhere($qb->expr()->orX(
-						$qb->expr()->eq('item_type', $qb->createNamedParameter('file')),
-						$qb->expr()->eq('item_type', $qb->createNamedParameter('folder'))
-					));
-
 				$cursor = $qb->execute();
 				while($data = $cursor->fetch()) {
 					if ($offset > 0) {
@@ -710,21 +849,88 @@ class DefaultShareProvider implements IShareProvider {
 				$cursor->closeCursor();
 			}
 
-			/*
- 			 * Resolve all group shares to user specific shares
- 			 * TODO: Optmize this!
- 			 */
-			foreach($shares2 as $share) {
-				$shares[] = $this->resolveGroupShare($share, $userId);
+			//Resolve all group shares to user specific shares
+			if (!empty($shares2)) {
+				$resolvedGroupShares = $this->resolveGroupShares($shares2, $userId);
+				$shares = array_merge($shares, $resolvedGroupShares);
 			}
 		} else {
 			throw new BackendError('Invalid backend');
 		}
 
-
 		return $shares;
 	}
 
+	/**
+	 * @inheritdoc
+	 */
+	public function getAllSharedWith($userId, $node) {
+		// Create array of sharedWith objects (target user -> $userId or group of which user is a member
+		$user = $this->userManager->get($userId);
+
+		// Check if user is member of some groups and chunk them
+		$allGroups = $this->groupManager->getUserGroups($user, 'sharing');
+
+		// Make chunks
+		$sharedWithGroupChunks = array_chunk($allGroups, 100);
+
+		// Check how many group chunks do we need
+		$sharedWithGroupChunksNo = count($sharedWithGroupChunks);
+
+		// If there are not groups, query only user, if there are groups, query both
+		$chunkedResults = [];
+		if ($sharedWithGroupChunksNo === 0) {
+			// There are no groups, query only for user
+			$qb = $this->getSharedWithUserQuery($userId, $node);
+			$cursor = $qb->execute();
+			$chunkedResults[] = $cursor->fetchAll();
+			$cursor->closeCursor();
+		} else {
+			// There are groups, query both for user and for groups
+			$userSharesRetrieved = false;
+			for ($chunkNo = 0; $chunkNo < $sharedWithGroupChunksNo; $chunkNo++) {
+				// Get respective group chunk
+				$groups = $sharedWithGroupChunks[$chunkNo];
+
+				// Check if user shares were already retrieved
+				// One cannot retrieve user shares multiple times, since it will result in duplicated
+				// user shares with each query
+				if ($userSharesRetrieved === false) {
+					$qb = $this->getSharedWithUserGroupQuery($groups, $userId, $node);
+					$userSharesRetrieved = true;
+				} else {
+					$qb = $this->getSharedWithGroupQuery($groups, $node);
+				}
+				$cursor = $qb->execute();
+				$chunkedResults[] = $cursor->fetchAll();
+				$cursor->closeCursor();
+			}
+		}
+
+		$resolvedShares = [];
+		$groupShares = [];
+		foreach($chunkedResults as $resultBatch) {
+			foreach($resultBatch as $data) {
+				if ($this->isAccessibleResult($data)) {
+					$share = $this->createShare($data);
+					if ($share->getShareType() === \OCP\Share::SHARE_TYPE_GROUP){
+						$groupShares[] = $share;
+					} else {
+						$resolvedShares[] = $share;
+					}
+				}
+			}
+		}
+
+		//Resolve all group shares to user specific shares
+		if (!empty($groupShares)) {
+			$resolvedGroupShares = $this->resolveGroupShares($groupShares, $userId);
+			$resolvedShares = array_merge($resolvedShares, $resolvedGroupShares);
+		}
+
+		return $resolvedShares;
+	}
+
 	/**
 	 * Get a share by token
 	 *
@@ -793,6 +999,7 @@ class DefaultShareProvider implements IShareProvider {
 
 		$share->setNodeId((int)$data['file_source']);
 		$share->setNodeType($data['item_type']);
+		$share->setName($data['share_name']);
 
 		if ($data['expiration'] !== null) {
 			$expiration = \DateTime::createFromFormat('Y-m-d H:i:s', $data['expiration']);
@@ -805,37 +1012,100 @@ class DefaultShareProvider implements IShareProvider {
 	}
 
 	/**
-	 * Resolve a group share to a user specific share
-	 * Thus if the user moved their group share make sure this is properly reflected here.
+	 * Will return two maps:
+	 * - $chunkedShareIds responsible to split shareIds into chunks containing 100 elements
+	 * 	 e.g. $chunkedShareIds { { "4", "52", "54",... }[100], { .. }[2] }[2]
 	 *
-	 * @param \OCP\Share\IShare $share
-	 * @param string $userId
-	 * @return Share Returns the updated share if one was found else return the original share.
+	 * - $shareIdToShareMap responsible to split shareIds into chunks containing 100 elements
+	 * 	 e.g. $shareIdToShareMap { "4" => IShare, "52" => IShare, "54" => IShare, ... }[102]
+	 *
+	 * @param \OCP\Share\IShare[] $shares
+	 * @return array $chunkedSharesToMaps e.g { $chunkedShareIds, $shareIdToShareMap }[2]
 	 */
-	private function resolveGroupShare(\OCP\Share\IShare $share, $userId) {
-		$qb = $this->dbConn->getQueryBuilder();
+	private function chunkSharesToMaps($shares) {
+		$chunkedShareIds = [];
+		$shareIdToShareMap = [];
+		$chunkId = 0;
+		$shareNo = 0;
+		foreach($shares as $share) {
+			// Map unique shareIds to IShare
+			$shareId = $share->getId();
+			$shareIdToShareMap[$shareId] = $share;
 
-		$stmt = $qb->select('*')
-			->from('share')
-			->where($qb->expr()->eq('parent', $qb->createNamedParameter($share->getId())))
-			->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(self::SHARE_TYPE_USERGROUP)))
-			->andWhere($qb->expr()->eq('share_with', $qb->createNamedParameter($userId)))
-			->andWhere($qb->expr()->orX(
-				$qb->expr()->eq('item_type', $qb->createNamedParameter('file')),
-				$qb->expr()->eq('item_type', $qb->createNamedParameter('folder'))
-			))
-			->setMaxResults(1)
-			->execute();
-
-		$data = $stmt->fetch();
-		$stmt->closeCursor();
-
-		if ($data !== false) {
-			$share->setPermissions((int)$data['permissions']);
-			$share->setTarget($data['file_target']);
+			// Chunk shareId array
+			if ($shareNo >= 100) {
+				// If we have over 100 shares in the array, start next chunk
+				$shareNo = 0;
+				$chunkId++;
+			} else {
+				// Increase number of shares in current array
+				$shareNo++;
+			}
+			$chunkedShareIds[$chunkId][] = $shareId;
 		}
 
-		return $share;
+		$chunkedSharesToMaps = array($chunkedShareIds, $shareIdToShareMap);
+		return $chunkedSharesToMaps;
+	}
+
+	/**
+	 * Resolve a group shares to a user specific share.
+	 * Thus if the user moved their group share make sure this is properly reflected here,
+	 * If $shares array contains exactly 2 elements, where
+	 * only 1 will be changed(resolved), it returns exactly 2 elements, containing the resolved one.
+	 *
+	 * @param \OCP\Share\IShare[] $shares e.g. { IShare, IShare }[2]
+	 * @param string $userId
+	 * @return \OCP\Share\IShare[] $resolvedShares
+	 * @throws ProviderException
+	 */
+	private function resolveGroupShares($shares, $userId) {
+		$qb = $this->dbConn->getQueryBuilder();
+
+		list($chunkedShareIds, $shareIdToShareMap) = $this->chunkSharesToMaps($shares);
+		foreach($chunkedShareIds as $shareIdsChunk) {
+			$qb->select('*')
+				->from('share')
+				->where($qb->expr()->in('parent', $qb->createNamedParameter(
+					$shareIdsChunk,
+					IQueryBuilder::PARAM_STR_ARRAY
+				)))
+				->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(self::SHARE_TYPE_USERGROUP)))
+				->andWhere($qb->expr()->eq('share_with', $qb->createNamedParameter($userId)))
+				->andWhere($qb->expr()->orX(
+					$qb->expr()->eq('item_type', $qb->createNamedParameter('file')),
+					$qb->expr()->eq('item_type', $qb->createNamedParameter('folder'))
+				));
+
+			$stmt = $qb->execute();
+
+			// Resolve $shareIdToShareMap array containing group shares
+			$shareParents = [];
+			while($data = $stmt->fetch()) {
+				// Get share parent
+				$shareParent = $data['parent'];
+
+				// Ensure uniquenes of parents
+				if (!isset($shareParents[$shareParent])) {
+					$shareParents[$shareParent] = true;
+				} else {
+					throw new ProviderException('Parent of share should be unique');
+				}
+
+				// Resolve only shares contained in the map.
+				// This will ensure that we return the same amount of shares in the input as in the output
+				// If $shareParent is contained in $shareIdToShareMap, it means that needs resolving
+				if (isset($shareIdToShareMap[$shareParent])) {
+					$share = $shareIdToShareMap[$shareParent];
+					$share->setPermissions(intval($data['permissions']));
+					$share->setTarget($data['file_target']);
+				}
+			}
+			$stmt->closeCursor();
+		}
+		
+		$resolvedShares = array_values($shareIdToShareMap);
+		return $resolvedShares;
 	}
 
 	/**
@@ -983,4 +1253,19 @@ class DefaultShareProvider implements IShareProvider {
 			}
 		}
 	}
+
+	/**
+	 * Check whether the share object fits the expectations of this provider
+	 *
+	 * @param IShare $share share
+	 *
+	 * @throws InvalidArgumentException if the share validation failed
+	 */
+	private function validate($share) {
+		if (!is_null($share->getName()) && strlen($share->getName()) > 64) {
+			throw new \InvalidArgumentException('Share name cannot be more than 64 characters');
+		}
+
+		// TODO: add more early validation for fields instead of relying on the DB
+	}
 }
