@@ -421,7 +421,7 @@ class Manager implements IManager {
 		}
 
 		// Verify if the user can share with this group
-		if ($this->shareWithGroupMembersOnly()) {
+		if ($this->shareWithMembershipGroupOnly()) {
 			$sharedBy = $this->userManager->get($share->getSharedBy());
 			$sharedWith = $this->groupManager->get($share->getSharedWith());
 			if (is_null($sharedWith) || !$sharedWith->inGroup($sharedBy)) {
@@ -872,6 +872,13 @@ class Manager implements IManager {
 		$hookParams['itemTarget'] = $hookParams['fileTarget'];
 		$hookParams['unsharedItems'] = [$hookParams];
 		\OC_Hook::emit('OCP\Share', 'post_unshareFromSelf', $hookParams);
+		$event = new GenericEvent(null, [
+			'shareRecipient' => $recipientId,
+			'shareOwner' => $share->getSharedBy(),
+			'recipientPath' => $share->getTarget(),
+			'ownerPath' => $share->getNode()->getPath(),
+			'nodeType' => $share->getNodeType()]);
+		\OC::$server->getEventDispatcher()->dispatch('fromself.unshare',$event);
 	}
 
 	/**
@@ -1297,6 +1304,14 @@ class Manager implements IManager {
 		return $this->config->getAppValue('core', 'shareapi_only_share_with_group_members', 'no') === 'yes';
 	}
 
+	/**
+	 * check if user can only share with groups he's member of
+	 * @return bool
+	 */
+	public function shareWithMembershipGroupOnly() {
+		return $this->config->getAppValue('core', 'shareapi_only_share_with_membership_groups', 'no') === 'yes';
+	}
+
 	/**
 	 * Check if users can share with groups
 	 * @return bool
