@@ -40,14 +40,14 @@ use OC\Authentication\Exceptions\PasswordLoginForbiddenException;
 use OC\Authentication\Token\IProvider;
 use OC\Authentication\Token\IToken;
 use OC\Hooks\Emitter;
-use OC_App;
+use OC\Hooks\PublicEmitter;
 use OC_User;
 use OC_Util;
 use OCA\DAV\Connector\Sabre\Auth;
-use OCP\App\IAppManager;
-use OCP\AppFramework\QueryException;
+use OCP\App\IServiceLoader;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Authentication\IAuthModule;
+use OCP\Events\EventEmitterTrait;
 use OCP\Files\NotPermittedException;
 use OCP\IConfig;
 use OCP\IRequest;
@@ -81,7 +81,8 @@ use Symfony\Component\EventDispatcher\GenericEvent;
  */
 class Session implements IUserSession, Emitter {
 
-	/** @var IUserManager $manager */
+	use EventEmitterTrait;
+	/** @var IUserManager | PublicEmitter $manager */
 	private $manager;
 
 	/** @var ISession $session */
@@ -99,19 +100,26 @@ class Session implements IUserSession, Emitter {
 	/** @var User $activeUser */
 	protected $activeUser;
 
+	/** @var IServiceLoader */
+	private $serviceLoader;
+
 	/**
 	 * @param IUserManager $manager
 	 * @param ISession $session
 	 * @param ITimeFactory $timeFactory
 	 * @param IProvider $tokenProvider
 	 * @param IConfig $config
+	 * @param IServiceLoader $serviceLoader
 	 */
-	public function __construct(IUserManager $manager, ISession $session, ITimeFactory $timeFactory, $tokenProvider, IConfig $config) {
+	public function __construct(IUserManager $manager, ISession $session,
+								ITimeFactory $timeFactory, $tokenProvider,
+								IConfig $config, IServiceLoader $serviceLoader) {
 		$this->manager = $manager;
 		$this->session = $session;
 		$this->timeFactory = $timeFactory;
 		$this->tokenProvider = $tokenProvider;
 		$this->config = $config;
+		$this->serviceLoader = $serviceLoader;
 	}
 
 	/**
@@ -139,15 +147,6 @@ class Session implements IUserSession, Emitter {
 		$this->manager->removeListener($scope, $method, $callback);
 	}
 
-	/**
-	 * get the manager object
-	 *
-	 * @return Manager
-	 */
-	public function getManager() {
-		return $this->manager;
-	}
-
 	/**
 	 * get the session object
 	 *
@@ -273,15 +272,15 @@ class Session implements IUserSession, Emitter {
 	public function getLoginName() {
 		if ($this->activeUser) {
 			return $this->session->get('loginname');
-		} else {
-			$uid = $this->session->get('user_id');
-			if ($uid) {
-				$this->activeUser = $this->manager->get($uid);
-				return $this->session->get('loginname');
-			} else {
-				return null;
-			}
 		}
+
+		$uid = $this->session->get('user_id');
+		if ($uid) {
+			$this->activeUser = $this->manager->get($uid);
+			return $this->session->get('loginname');
+		}
+
+		return null;
 	}
 
 	/**
@@ -310,6 +309,7 @@ class Session implements IUserSession, Emitter {
 	 * @param string $user
 	 * @param string $password
 	 * @param IRequest $request
+	 * @throws \InvalidArgumentException
 	 * @throws LoginException
 	 * @throws PasswordLoginForbiddenException
 	 * @return boolean
@@ -417,6 +417,9 @@ class Session implements IUserSession, Emitter {
 				\OC::$server->getLogger()->warning(
 					'Skeleton not created due to missing write permission'
 				);
+			} catch(\OC\HintException $hintEx) {
+				// only if Skeleton no existing Dir
+				\OC::$server->getLogger()->error($hintEx->getMessage());
 			}
 
 			// trigger any other initialization
@@ -463,31 +466,33 @@ class Session implements IUserSession, Emitter {
 	 * @throws LoginException if an app canceld the login process or the user is not enabled
 	 */
 	private function loginWithPassword($uid, $password) {
-		$this->manager->emit('\OC\User', 'preLogin', [$uid, $password]);
-		$user = $this->manager->checkPassword($uid, $password);
-		if ($user === false) {
-			$this->manager->emit('\OC\User', 'failedLogin', [$uid]);
-			return false;
-		}
+		return $this->emittingCall(function () use (&$uid, &$password) {
+			$this->manager->emit('\OC\User', 'preLogin', [$uid, $password]);
+			$user = $this->manager->checkPassword($uid, $password);
+			if ($user === false) {
+				$this->manager->emit('\OC\User', 'failedLogin', [$uid]);
+				return false;
+			}
 
-		if ($user->isEnabled()) {
-			$this->setUser($user);
-			$this->setLoginName($uid);
-			$firstTimeLogin = $user->updateLastLoginTimestamp();
-			$this->manager->emit('\OC\User', 'postLogin', [$user, $password]);
-			if ($this->isLoggedIn()) {
-				$this->prepareUserLogin($firstTimeLogin);
-				return true;
+			if ($user->isEnabled()) {
+				$this->setUser($user);
+				$this->setLoginName($uid);
+				$firstTimeLogin = $user->updateLastLoginTimestamp();
+				$this->manager->emit('\OC\User', 'postLogin', [$user, $password]);
+				if ($this->isLoggedIn()) {
+					$this->prepareUserLogin($firstTimeLogin);
+					return true;
+				} else {
+					// injecting l10n does not work - there is a circular dependency between session and \OCP\L10N\IFactory
+					$message = \OC::$server->getL10N('lib')->t('Login canceled by app');
+					throw new LoginException($message);
+				}
 			} else {
 				// injecting l10n does not work - there is a circular dependency between session and \OCP\L10N\IFactory
-				$message = \OC::$server->getL10N('lib')->t('Login canceled by app');
+				$message = \OC::$server->getL10N('lib')->t('User disabled');
 				throw new LoginException($message);
 			}
-		} else {
-			// injecting l10n does not work - there is a circular dependency between session and \OCP\L10N\IFactory
-			$message = \OC::$server->getL10N('lib')->t('User disabled');
-			throw new LoginException($message);
-		}
+		}, ['before' => ['uid' => $uid, 'password' => $password], 'after' => ['uid' => $uid, 'password' => $password]], 'user', 'login');
 	}
 
 	/**
@@ -687,7 +692,7 @@ class Session implements IUserSession, Emitter {
 	 */
 	public function tryTokenLogin(IRequest $request) {
 		$authHeader = $request->getHeader('Authorization');
-		if (strpos($authHeader, 'token ') === false) {
+		if ($authHeader === null || strpos($authHeader, 'token ') === false) {
 			// No auth header, let's try session id
 			try {
 				$token = $this->session->getId();
@@ -715,34 +720,10 @@ class Session implements IUserSession, Emitter {
 	 * @throws Exception If the auth module could not be loaded
 	 */
 	public function tryAuthModuleLogin(IRequest $request) {
-		/** @var IAppManager $appManager */
-		$appManager = OC::$server->query('AppManager');
-		$allApps = $appManager->getInstalledApps();
-
-		foreach ($allApps as $appId) {
-			$info = $appManager->getAppInfo($appId);
-
-			if (isset($info['auth-modules'])) {
-				$authModules = $info['auth-modules'];
-
-				foreach ($authModules as $class) {
-					try {
-						if (!OC_App::isAppLoaded($appId)) {
-							OC_App::loadApp($appId);
-						}
-
-						/** @var IAuthModule $authModule */
-						$authModule = OC::$server->query($class);
-
-						if ($authModule instanceof IAuthModule) {
-							return $this->loginUser($authModule->auth($request), $authModule->getUserPassword($request));
-						} else {
-							throw new Exception("Could not load the auth module $class");
-						}
-					} catch (QueryException $exc) {
-						throw new Exception("Could not load the auth module $class");
-					}
-				}
+		foreach ($this->getAuthModules(false) as $authModule) {
+			$user = $authModule->auth($request);
+			if ($user !== null) {
+				return $this->loginUser($authModule->auth($request), $authModule->getUserPassword($request));
 			}
 		}
 
@@ -758,30 +739,32 @@ class Session implements IUserSession, Emitter {
 	 * @throws LoginException if an app canceld the login process or the user is not enabled
 	 */
 	private function loginUser($user, $password) {
-		if (is_null($user)) {
-			return false;
-		}
+		return $this->emittingCall(function () use (&$user, &$password) {
+			if (is_null($user)) {
+				return false;
+			}
 
-		$this->manager->emit('\OC\User', 'preLogin', [$user, $password]);
+			$this->manager->emit('\OC\User', 'preLogin', [$user, $password]);
 
-		if (!$user->isEnabled()) {
-			$message = \OC::$server->getL10N('lib')->t('User disabled');
-			throw new LoginException($message);
-		}
+			if (!$user->isEnabled()) {
+				$message = \OC::$server->getL10N('lib')->t('User disabled');
+				throw new LoginException($message);
+			}
 
-		$this->setUser($user);
-		$this->setLoginName($user->getDisplayName());
+			$this->setUser($user);
+			$this->setLoginName($user->getDisplayName());
 
-		$this->manager->emit('\OC\User', 'postLogin', [$user, $password]);
+			$this->manager->emit('\OC\User', 'postLogin', [$user, $password]);
 
-		if ($this->isLoggedIn()) {
-			$this->prepareUserLogin(false);
-		} else {
-			$message = \OC::$server->getL10N('lib')->t('Login canceled by app');
-			throw new LoginException($message);
-		}
+			if ($this->isLoggedIn()) {
+				$this->prepareUserLogin(false);
+			} else {
+				$message = \OC::$server->getL10N('lib')->t('Login canceled by app');
+				throw new LoginException($message);
+			}
 
-		return true;
+			return true;
+		}, ['before' => ['uid' => $user, 'password' => $password], 'after' => ['uid' => $user, 'password' => $password]], 'user', 'login');
 	}
 
 	/**
@@ -821,22 +804,36 @@ class Session implements IUserSession, Emitter {
 
 	/**
 	 * logout the user from the session
+	 *
+	 * @return bool
 	 */
 	public function logout() {
-		$this->manager->emit('\OC\User', 'logout');
-		$user = $this->getUser();
-		if (!is_null($user)) {
-			try {
-				$this->tokenProvider->invalidateToken($this->session->getId());
-			} catch (SessionNotAvailableException $ex) {
-				
+		return $this->emittingCall(function () {
+			$event = new GenericEvent(null, ['cancel' => false]);
+			$eventDispatcher = \OC::$server->getEventDispatcher();
+			$eventDispatcher->dispatch('\OC\User\Session::pre_logout', $event);
+
+			$this->manager->emit('\OC\User', 'preLogout');
+
+			if ($event['cancel'] === true) {
+				return true;
 			}
-		}
-		$this->setUser(null);
-		$this->setLoginName(null);
-		$this->unsetMagicInCookie();
-		$this->session->clear();
-		$this->manager->emit('\OC\User', 'postLogout');
+
+			$this->manager->emit('\OC\User', 'logout');
+			$user = $this->getUser();
+			if (!is_null($user)) {
+				try {
+					$this->tokenProvider->invalidateToken($this->session->getId());
+				} catch (SessionNotAvailableException $ex) {
+
+				}
+			}
+			$this->setUser(null);
+			$this->setLoginName(null);
+			$this->unsetMagicInCookie();
+			$this->session->clear();
+			$this->manager->emit('\OC\User', 'postLogout');
+		}, ['before' => ['uid' => ''], 'after' => []], 'user', 'logout');
 	}
 
 	/**
@@ -890,4 +887,54 @@ class Session implements IUserSession, Emitter {
 		}
 	}
 
+	public function verifyAuthHeaders($request) {
+		$shallLogout = false;
+		try {
+			$lastUser = null;
+			foreach ($this->getAuthModules(true) as $module) {
+				$user = $module->auth($request);
+				if ($user !== null) {
+					if ($this->isLoggedIn() && $this->getUser()->getUID() !== $user->getUID()) {
+						$shallLogout = true;
+						break;
+					}
+					if ($lastUser !== null && $user->getUID() !== $lastUser->getUID()) {
+						$shallLogout = true;
+						break;
+					}
+					$lastUser = $user;
+				}
+			}
+
+		} catch (Exception $ex) {
+			$shallLogout = true;
+		}
+		if ($shallLogout) {
+			// the session is bad -> kill it
+			$this->logout();
+			return false;
+		}
+		return true;
+	}
+
+	/**
+	 * @param $includeBuiltIn
+	 * @return \Generator | IAuthModule[]
+	 * @throws Exception
+	 */
+	protected function getAuthModules($includeBuiltIn) {
+		if ($includeBuiltIn) {
+			yield new TokenAuthModule($this->session, $this->tokenProvider, $this->manager);
+			yield new BasicAuthModule($this->manager);
+		}
+
+		$modules = $this->serviceLoader->load(['auth-modules']);
+		foreach ($modules as $module) {
+			if ($module instanceof IAuthModule) {
+				yield $module;
+			} else {
+				continue;
+			}
+		}
+	}
 }
