@@ -1,30 +1,14 @@
 OC.L10N.register(
     "settings",
     {
-    "Security & setup warnings" : "Предупреждения за сигурност и настройки",
-    "Sharing" : "Споделяне",
-    "External Storage" : "Външно Дисково Пространство",
-    "Cron" : "Крон",
-    "Log" : "Лог",
-    "Updates" : "Обновления",
-    "Authentication error" : "Възникна проблем с идентификацията",
-    "Your full name has been changed." : "Вашето пълно име е променено.",
-    "Unable to change full name" : "Неуспешна промяна на пълното име.",
-    "Couldn't remove app." : "Неуспешно премахване на приложението.",
-    "Language changed" : "Езикът е променен",
-    "Invalid request" : "Невалидна заявка",
-    "Admins can't remove themself from the admin group" : "Администраторите не могат да премахват себе си от групата \"admin\".",
-    "Unable to add user to group %s" : "Неуспешно добавяне на потребител към групата %s.",
-    "Unable to remove user from group %s" : "Неуспешно премахване на потребител от групата %s.",
-    "Couldn't update app." : "Обновяването на приложението е неуспешно..",
     "Wrong password" : "Грешна парола",
     "No user supplied" : "Липсва потребителско име",
-    "Please provide an admin recovery password, otherwise all user data will be lost" : "Моля, посочете администраторската парола за възстановяване. В противен случай, всичката информация на потребителите ще бъде загубена.",
+    "Authentication error" : "Възникна проблем с идентификацията",
     "Wrong admin recovery password. Please check the password and try again." : "Грешна администраторска парола за възстановяване. Моля, проверете паролата и опитайте отново.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Сървърът не позволява смяна на паролата, но потребителския ключ за криптиране беше успешно обновен.",
     "Unable to change password" : "Неуспешна смяна на паролата.",
-    "Enabled" : "Включено",
-    "Not enabled" : "Изключено",
+    "Couldn't send reset email. Please contact your administrator." : "Изпращането на електронна поща е неуспешно. Моля, свържете се с вашия администратор.",
+    "Federated Cloud Sharing" : "Федеративно споделяне през облака",
     "Group already exists." : "Групата вече съществува.",
     "Unable to add group." : "Неуспешно добавяне на група.",
     "Unable to delete group." : "Неуспешно изтриване на група",
@@ -42,12 +26,18 @@ OC.L10N.register(
     "Forbidden" : "Забранено",
     "Invalid user" : "Невалиден протребител",
     "Unable to change mail address" : "Неуспешна промяна на адрес на електронна поща",
-    "Email saved" : "Имейлът е запазен",
-    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Сигурен/на ли сте, че искате \"{domain}\"  да бъде добавен като сигурен домейн?",
-    "Add trusted domain" : "Добавяне на сигурен домейн",
-    "Sending..." : "Изпращане...",
+    "Your full name has been changed." : "Вашето пълно име е променено.",
+    "Unable to change full name" : "Неуспешна промяна на пълното име.",
+    "__language_name__" : "Български",
+    "Language changed" : "Езикът е променен",
+    "Invalid request" : "Невалидна заявка",
+    "Admins can't remove themself from the admin group" : "Администраторите не могат да премахват себе си от групата \"admin\".",
+    "Unknown user" : "Непознат потребител",
+    "Couldn't remove app." : "Неуспешно премахване на приложението.",
     "All" : "Всички",
-    "Update to %s" : "Обнови до %s",
+    "Enabled" : "Включено",
+    "Not enabled" : "Изключено",
+    "No apps found for your version" : "Няма намерени приложения за вашата версия",
     "Please wait...." : "Моля, изчакайте....",
     "Error while disabling app" : "Грешка при изключването на приложението",
     "Disable" : "Изключване",
@@ -59,59 +49,65 @@ OC.L10N.register(
     "Uninstalling ...." : "Премахване ...",
     "Error while uninstalling app" : "Грешка при премахването на приложението",
     "Uninstall" : "Премахване",
+    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Сигурен/на ли сте, че искате \"{domain}\"  да бъде добавен като сигурен домейн?",
+    "Add trusted domain" : "Добавяне на сигурен домейн",
+    "Valid until {date}" : "Далидна до {date}",
+    "Delete" : "Изтриване",
+    "Sending..." : "Изпращане...",
     "Select a profile picture" : "Избиране на профилна снимка",
     "Very weak password" : "Много слаба парола",
     "Weak password" : "Слаба парола",
     "So-so password" : "Не особено добра парола",
     "Good password" : "Добра парола",
     "Strong password" : "Сигурна парола",
-    "Valid until {date}" : "Далидна до {date}",
-    "Delete" : "Изтриване",
     "Groups" : "Групи",
     "Unable to delete {objName}" : "Неуспешно изтриване на {objName}.",
-    "Error creating group" : "Грешка при създаване на група",
     "A valid group name must be provided" : "Очаква се валидно име на група",
     "deleted {groupName}" : "{groupName} е изтрита",
     "undo" : "възстановяване",
-    "no group" : "няма група",
     "never" : "никога",
     "deleted {userName}" : "{userName}  е изтрит",
     "add group" : "добавяне на група",
+    "enabled" : "включен",
+    "disabled" : "изключен",
+    "no group" : "няма група",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "Промяна на паролата ще доведе до загуба на данни, защото не е налично възстановяване за този потребител.",
     "A valid username must be provided" : "Трябва да бъде зададено валидно потребителско име",
-    "Error creating user" : "Грешка при създаване на потребител",
     "A valid password must be provided" : "Трябва да бъде зададена валидна парола",
     "A valid email must be provided" : "Трябва да бъде зададена валидна електронна поща",
-    "__language_name__" : "Български",
-    "Sync clients" : "Синхронизиращи клиенти",
-    "Personal info" : "Лична информация",
-    "SSL root certificates" : "SSL root сертификати",
-    "Everything (fatal issues, errors, warnings, info, debug)" : "Всичко (фатални проблеми, грешки, предупреждения, информация, дебъгване)",
-    "Info, warnings, errors and fatal issues" : "информация, предупреждения, грешки и фатални проблеми",
-    "Warnings, errors and fatal issues" : "Предупреждения, грешки и фатални проблеми",
-    "Errors and fatal issues" : "Грешки и фатални проблеми",
-    "Fatal issues only" : "Само фатални проблеми",
-    "None" : "Няма",
-    "Login" : "Вход",
-    "Plain" : "Обикновен",
-    "NT LAN Manager" : "NT LAN Manager",
-    "SSL" : "SSL",
-    "TLS" : "TLS",
-    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP е настроен да премахва inline doc блокове. Това ще направи няколко основни приложения недостъпни.",
-    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Това може да се дължи на кеш/акселератор като Zend OPache или eAccelerator.",
-    "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Вашия сървър работи на Microsoft Windows. Ние горещо препоръчваме Linux за оптимално потребителско изживяване.",
-    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP модулът 'fileinfo' липсва. Силно препоръчваме този модъл да бъде добавен, за да бъдат постигнати най-добри резултати при mime-type откриването.",
-    "System locale can not be set to a one which supports UTF-8." : "Системните настройки за местоположение не могат да бъдат промени на такива, подържащи UTF-8.",
-    "This means that there might be problems with certain characters in file names." : "Това означва, че може да има проблеми с определини символи в имената на файловете.",
-    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Силно препоръчваме инсталиране на необходимите паките на системата, за поддръжка на следните местоположения: %s.",
-    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Ако инсталацията не е в основата на вашия домейн и използва системния cron, могат да възникнат проблеми с генерирането на URLи. За избягване на тези проблеми, моля настройте <code>overwrite.cli.url</code> опцията в config.php файла с мрежовия път към вашята инсталация (Вероятно : \\\"%s\\\")",
-    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Не бе възможно да изпълним cron задачата през команден интерфейс. Следните технически грешки се появиха:",
+    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Здрасти,<br><br>Само да ти кажа, че имаш %s профил<br><br> Потребителя ти е: %s<br>Достъпи го: <a href=\"%s\">%s</a><br><br>",
+    "Cheers!" : "Поздрави!",
+    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Здрасти,\n\nСамо да ти кажа, че имаш %s профил.\n\nПотребителя ти е: %s\nДостъпи го: %s\n",
+    "Forum" : "Форум",
+    "Developer documentation" : "Документация за разработчици",
+    "Documentation:" : "Документация:",
+    "Report a bug" : "Докладване на бъг",
+    "Show description …" : "Покажи описание ...",
+    "Hide description …" : "Скрии описание ...",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "Това приложение не може да бъде инсталирано, защото следните зависимости не са удовлетворени:",
+    "Enable only for specific groups" : "Включи само за определени групи",
+    "Uninstall App" : "Премахни Приложението",
+    "Cron" : "Крон",
+    "Last cron job execution: %s." : "Последно изпълнение на cron задача: %s.",
+    "Last cron job execution: %s. Something seems wrong." : "Последно изпълнение на cron задача: %s. Нещо не е както трябва",
+    "Cron was not executed yet!" : "Cron oще не е изпълнен!",
+    "Open documentation" : "Отвори документацията",
+    "Execute one task with each page loaded" : "Изпълни по едно задание с всяка заредена страница.",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php е регистриран към webcron да се свързва с cron.php всеки 15 минути по http.",
+    "Use system's cron service to call the cron.php file every 15 minutes." : "Изполвай системната cron service, за връзка с cron.php файла всеки 15 минути.",
+    "Common Name" : "Познато Име",
+    "Valid until" : "Валиден до",
+    "Issued By" : "Издаден От",
+    "Valid until %s" : "Валиден до %s",
+    "Import root certificate" : "Импортиране на основен сертификат",
+    "Enable encryption" : "Активиране на криптиране",
+    "Sharing" : "Споделяне",
     "Allow apps to use the Share API" : "Разреши приложенията да използват Share API.",
     "Allow users to share via link" : "Разреши потребителите да споделят с връзка",
-    "Enforce password protection" : "Изискай защита с парола.",
     "Allow public uploads" : "Разреши общодостъпно качване",
-    "Allow users to send mail notification for shared files" : "Разреши потребителите да изпращат имейл уведомления за споделени файлове.",
+    "Enforce password protection" : "Изискай защита с парола.",
     "Set default expiration date" : "Заложи дата на изтичане по подразбиране",
+    "Allow users to send mail notification for shared files" : "Разреши потребителите да изпращат имейл уведомления за споделени файлове.",
     "Expire after " : "Изтечи след",
     "days" : "дена",
     "Enforce expiration date" : "Изисквай дата на изтичане",
@@ -120,12 +116,17 @@ OC.L10N.register(
     "Allow users to send mail notification for shared files to other users" : "Разреши потребителите да изпращат уведомителни писма за споделени файлове към други потребители.",
     "Exclude groups from sharing" : "Забрани групи да споделят",
     "These groups will still be able to receive shares, but not to initiate them." : "Тези групи ще могат да получават споделения, но няма да могат самите те да споделят.",
-    "Last cron job execution: %s." : "Последно изпълнение на cron задача: %s.",
-    "Last cron job execution: %s. Something seems wrong." : "Последно изпълнение на cron задача: %s. Нещо не е както трябва",
-    "Cron was not executed yet!" : "Cron oще не е изпълнен!",
-    "Execute one task with each page loaded" : "Изпълни по едно задание с всяка заредена страница.",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php е регистриран към webcron да се свързва с cron.php всеки 15 минути по http.",
-    "Use system's cron service to call the cron.php file every 15 minutes." : "Изполвай системната cron service, за връзка с cron.php файла всеки 15 минути.",
+    "Everything (fatal issues, errors, warnings, info, debug)" : "Всичко (фатални проблеми, грешки, предупреждения, информация, дебъгване)",
+    "Info, warnings, errors and fatal issues" : "информация, предупреждения, грешки и фатални проблеми",
+    "Warnings, errors and fatal issues" : "Предупреждения, грешки и фатални проблеми",
+    "Errors and fatal issues" : "Грешки и фатални проблеми",
+    "Fatal issues only" : "Само фатални проблеми",
+    "Log" : "Лог",
+    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Log файла е по-голям от 100 MB. Изтеглянето му може да отнеме време!",
+    "None" : "Няма",
+    "Login" : "Вход",
+    "Plain" : "Обикновен",
+    "NT LAN Manager" : "NT LAN Manager",
     "This is used for sending out notifications." : "Това се използва за изпращане на уведомления.",
     "Send mode" : "Режим на изпращане",
     "Encryption" : "Криптиране",
@@ -141,72 +142,57 @@ OC.L10N.register(
     "Store credentials" : "Запазвай креденциите",
     "Test email settings" : "Настройки на проверяващия имейл",
     "Send email" : "Изпрати имейл",
-    "Log level" : "Детайли на доклада",
-    "Download logfile" : "Изтегли log файла",
-    "More" : "Още",
-    "Less" : "По-малко",
-    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Log файла е по-голям от 100 MB. Изтеглянето му може да отнеме време!",
+    "Security & setup warnings" : "Предупреждения за сигурност и настройки",
+    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP е настроен да премахва inline doc блокове. Това ще направи няколко основни приложения недостъпни.",
+    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Това може да се дължи на кеш/акселератор като Zend OPache или eAccelerator.",
+    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP модулът 'fileinfo' липсва. Силно препоръчваме този модъл да бъде добавен, за да бъдат постигнати най-добри резултати при mime-type откриването.",
+    "System locale can not be set to a one which supports UTF-8." : "Системните настройки за местоположение не могат да бъдат промени на такива, подържащи UTF-8.",
+    "This means that there might be problems with certain characters in file names." : "Това означва, че може да има проблеми с определини символи в имената на файловете.",
+    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Силно препоръчваме инсталиране на необходимите паките на системата, за поддръжка на следните местоположения: %s.",
+    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Ако инсталацията не е в основата на вашия домейн и използва системния cron, могат да възникнат проблеми с генерирането на URLи. За избягване на тези проблеми, моля настройте <code>overwrite.cli.url</code> опцията в config.php файла с мрежовия път към вашята инсталация (Вероятно : \\\"%s\\\")",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite е използваната база данни. За по-големи инсталации Ви препоръчваме да изберете друг сървър за бази данни.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Особено, когато използвате клиент за работен плот за синхронизация, използването на SQLite e непрепоръчително.",
+    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Не бе възможно да изпълним cron задачата през команден интерфейс. Следните технически грешки се появиха:",
     "How to do backups" : "Как се правят резервни копия",
     "Advanced monitoring" : "Разширено наблюдение",
     "Performance tuning" : "Настройване на производителност",
     "Improving the config.php" : "Подобряване на config.php",
     "Theming" : "Промяна на облика",
-    "Version" : "Версия",
-    "Developer documentation" : "Документация за разработчици",
-    "by" : "от",
-    "licensed" : "лицензирано",
-    "Documentation:" : "Документация:",
-    "Show description …" : "Покажи описание ...",
-    "Hide description …" : "Скрии описание ...",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "Това приложение не може да бъде инсталирано, защото следните зависимости не са удовлетворени:",
-    "Enable only for specific groups" : "Включи само за определени групи",
-    "Uninstall App" : "Премахни Приложението",
-    "No apps found for your version" : "Няма намерени приложения за вашата версия",
-    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Здрасти,<br><br>Само да ти кажа, че имаш %s профил<br><br> Потребителя ти е: %s<br>Достъпи го: <a href=\"%s\">%s</a><br><br>",
-    "Cheers!" : "Поздрави!",
-    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Здрасти,\n\nСамо да ти кажа, че имаш %s профил.\n\nПотребителя ти е: %s\nДостъпи го: %s\n",
-    "Forum" : "Форум",
     "Get the apps to sync your files" : "Изтегли програми за синхронизиране на файловете ти",
     "Desktop client" : "Клиент за настолен компютър",
     "Android app" : "Андроид приложение",
     "iOS app" : "iOS приложение",
-    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Ако искаш да помогнеш на проекта:\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\"  rel=\"noreferrer\">присъедини се и пиши код</a>\n\t\tили\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">разпространи мълвата</a>!",
     "Show First Run Wizard again" : "Покажи Настройките за Първоначално Зареждане отново",
-    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Използвал си <strong>%s</strong> от наличните <strong>%s</strong>.",
+    "Profile picture" : "Аватар",
+    "Upload new" : "Качи нов",
+    "Remove image" : "Премахни изображението",
+    "Cancel" : "Отказ",
+    "Full name" : "Пълно име",
+    "No display name set" : "Няма настроено екранно име",
+    "Email" : "Имейл",
+    "Your email address" : "Твоят имейл адрес",
+    "No email address set" : "Няма настроен адрес на електронна поща",
+    "You are member of the following groups:" : "Ти си член на следните групи:",
     "Password" : "Парола",
     "Unable to change your password" : "Неуспешна промяна на паролата.",
     "Current password" : "Текуща парола",
     "New password" : "Нова парола",
     "Change password" : "Промяна на паролата",
-    "Full name" : "Пълно име",
-    "No display name set" : "Няма настроено екранно име",
-    "Email" : "Имейл",
-    "Your email address" : "Твоят имейл адрес",
-    "Fill in an email address to enable password recovery and receive notifications" : "Въведи имейл, за да включиш функцията за възстановяване на паролата и уведомления.",
-    "No email address set" : "Няма настроен адрес на електронна поща",
-    "You are member of the following groups:" : "Ти си член на следните групи:",
-    "Profile picture" : "Аватар",
-    "Upload new" : "Качи нов",
-    "Select new from Files" : "Избери нов от Файловете",
-    "Remove image" : "Премахни изображението",
-    "Your avatar is provided by your original account." : "Твоят аватар е взет от оригиналния ти профил.",
-    "Cancel" : "Отказ",
-    "Choose as profile image" : "Избери като аватар",
     "Language" : "Език",
     "Help translate" : "Помогни с превода",
-    "Common Name" : "Познато Име",
-    "Valid until" : "Валиден до",
-    "Issued By" : "Издаден От",
-    "Valid until %s" : "Валиден до %s",
-    "Import root certificate" : "Импортиране на основен сертификат",
+    "Unlimited" : "Неограничено",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Разработен от {communityopen}ownCloud общността {linkclose}, {githubopen}изходящия код{linkclose} е лицензиран под {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
+    "Name" : "Име",
+    "Username" : "Потребителско Име",
+    "Done" : "Завършен",
+    "Version" : "Версия",
+    "Personal" : "Лично",
+    "Admin" : "Админ",
+    "Error" : "Грешка",
     "Show storage location" : "Покажи място за запис",
     "Show last log in" : "Покажи последно вписване",
     "Send email to new user" : "Изпращай писмо към нов потребител",
     "Show email address" : "Покажи адреса на електронната поща",
-    "Username" : "Потребителско Име",
     "E-Mail" : "Електронна поща",
     "Create" : "Създаване",
     "Admin Recovery Password" : "Възстановяване на Администраторска Парола",
@@ -217,7 +203,6 @@ OC.L10N.register(
     "Admins" : "Администратори",
     "Default Quota" : "Квота по подразбиране",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Моля, въведи квота за заделено място (пр. \"512 MB\" или \"12 GB\")",
-    "Unlimited" : "Неограничено",
     "Other" : "Друга...",
     "Full Name" : "Пълно Име",
     "Group Admin for" : "Групов администратор за",
