@@ -5,28 +5,19 @@ OC.L10N.register(
     "Authentication error" : "Aŭtentiga eraro",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Motoro ne subtenas ŝanĝi pasvorton, sed la ĉifroŝlosilo de la uzanto sukcese ĝisdatiĝis.",
     "Unable to change password" : "Ne eblis ŝanĝi la pasvorton",
-    "Enabled" : "Kapabligita",
     "Federated Cloud Sharing" : "Federnuba kunhavado",
     "Group already exists." : "Grupo jam ekzistas",
     "Saved" : "Konservita",
     "Email sent" : "La retpoŝtaĵo sendiĝis",
-    "Email saved" : "La retpoŝtadreso konserviĝis",
     "Your full name has been changed." : "Via plena nomo ŝanĝitas.",
     "Unable to change full name" : "Ne eblis ŝanĝi la plenan nomon",
-    "Sharing" : "Kunhavigo",
-    "External Storage" : "Malena memorilo",
-    "Cron" : "Cron",
-    "Email server" : "Retpoŝtoservilo",
-    "Log" : "Protokolo",
-    "Updates" : "Ĝisdatigoj",
+    "__language_name__" : "Esperanto",
     "Language changed" : "La lingvo estas ŝanĝita",
     "Invalid request" : "Nevalida peto",
     "Admins can't remove themself from the admin group" : "Administrantoj ne povas forigi sin mem el la administra grupo.",
-    "Unable to add user to group %s" : "Ne eblis aldoni la uzanton al la grupo %s",
-    "Unable to remove user from group %s" : "Ne eblis forigi la uzantan el la grupo %s",
-    "Couldn't update app." : "Ne eblis ĝisdatigi la aplikaĵon.",
-    "Sending..." : "Sendante...",
+    "Unknown user" : "Nekonata uzanto",
     "All" : "Ĉio",
+    "Enabled" : "Kapabligita",
     "Please wait...." : "Bonvolu atendi...",
     "Error while disabling app" : "Eraris malkapabligo de aplikaĵo",
     "Disable" : "Malkapabligi",
@@ -39,6 +30,7 @@ OC.L10N.register(
     "Error while uninstalling app" : "Eraris malinstalo de aplikaĵo",
     "Uninstall" : "Malinstali",
     "Delete" : "Forigi",
+    "Sending..." : "Sendante...",
     "Select a profile picture" : "Elekti profilan bildon",
     "Very weak password" : "Tre malforta pasvorto",
     "Weak password" : "Malforta pasvorto",
@@ -51,30 +43,46 @@ OC.L10N.register(
     "never" : "neniam",
     "deleted {userName}" : "{userName} foriĝis",
     "add group" : "aldoni grupon",
+    "enabled" : "kapabligita",
+    "disabled" : "malkapabligita",
     "A valid username must be provided" : "Valida uzantonomo devas proviziĝi",
     "A valid password must be provided" : "Valida pasvorto devas proviziĝi",
-    "__language_name__" : "Esperanto",
-    "Unlimited" : "Senlima",
-    "Personal info" : "Persona informo",
-    "Sync clients" : "Sinkronigi klientojn",
-    "Everything (fatal issues, errors, warnings, info, debug)" : "Ĉio (fatalaĵoj, eraroj, avertoj, informoj, sencimigaj mesaĝoj)",
-    "Info, warnings, errors and fatal issues" : "Informoj, avertoj, eraroj kaj fatalaĵoj",
-    "Warnings, errors and fatal issues" : "Avertoj, eraroj kaj fatalaĵoj",
-    "Errors and fatal issues" : "Eraroj kaj fatalaĵoj",
-    "Fatal issues only" : "Fatalaĵoj nur",
-    "None" : "Nenio",
-    "Login" : "Ensaluti",
-    "SSL" : "SSL",
-    "TLS" : "TLS",
+    "User documentation" : "Uzodokumentaro",
+    "Administrator documentation" : "Administrodokumentaro",
+    "Forum" : "Forumo",
+    "Commercial support" : "Komerca subteno",
+    "by %s" : "de %s",
+    "%s-licensed" : "%s-permesila",
+    "Documentation:" : "Dokumentaro:",
+    "Admin documentation" : "Administrodokumentaro",
+    "Show description …" : "Montri priskribon...",
+    "Hide description …" : "Malmontri priskribon...",
+    "Enable only for specific groups" : "Kapabligi nur por specifajn grupojn",
+    "Uninstall App" : "Malinstali aplikaĵon",
+    "Cron" : "Cron",
     "Open documentation" : "Malfermi la dokumentaron",
+    "Common Name" : "Komuna nomo",
+    "Valid until" : "Valida ĝis",
+    "Valid until %s" : "Valida ĝis %s",
+    "This is the final warning: Do you really want to enable encryption?" : "Jen la fina averto: ĉu vi certe volas kapabligi ĉifradon?",
+    "Enable encryption" : "Kapabligi ĉifradon",
+    "Sharing" : "Kunhavigo",
     "Allow apps to use the Share API" : "Kapabligi aplikaĵojn uzi la API-on pri Kunhavigo",
     "Allow users to share via link" : "Permesi uzantojn kunhavigi ligile",
     "Allow public uploads" : "Permesi publikajn alŝutojn",
     "Expire after " : "Eksvalidigi post",
     "days" : "tagoj",
     "Allow resharing" : "Kapabligi rekunhavigon",
-    "This is the final warning: Do you really want to enable encryption?" : "Jen la fina averto: ĉu vi certe volas kapabligi ĉifradon?",
-    "Enable encryption" : "Kapabligi ĉifradon",
+    "Everything (fatal issues, errors, warnings, info, debug)" : "Ĉio (fatalaĵoj, eraroj, avertoj, informoj, sencimigaj mesaĝoj)",
+    "Info, warnings, errors and fatal issues" : "Informoj, avertoj, eraroj kaj fatalaĵoj",
+    "Warnings, errors and fatal issues" : "Avertoj, eraroj kaj fatalaĵoj",
+    "Errors and fatal issues" : "Eraroj kaj fatalaĵoj",
+    "Fatal issues only" : "Fatalaĵoj nur",
+    "Log" : "Protokolo",
+    "What to log" : "Kion protokoli",
+    "None" : "Nenio",
+    "Login" : "Ensaluti",
+    "Email server" : "Retpoŝtoservilo",
     "Send mode" : "Sendi pli",
     "Encryption" : "Ĉifrado",
     "From address" : "El adreso",
@@ -88,27 +96,11 @@ OC.L10N.register(
     "SMTP Password" : "SMTP-pasvorto",
     "Test email settings" : "Provi retpoŝtagordon",
     "Send email" : "Sendi retpoŝton",
-    "Download logfile" : "Elŝuti protokoldosiero",
-    "More" : "Pli",
-    "Less" : "Malpli",
-    "What to log" : "Kion protokoli",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite uziĝas kiel datumbazo. Por pli grandaj instaloj ni rekomendas ŝanĝi ĝin per malsama datumbazomotoro.",
-    "Version" : "Eldono",
-    "by %s" : "de %s",
-    "%s-licensed" : "%s-permesila",
-    "Documentation:" : "Dokumentaro:",
-    "User documentation" : "Uzodokumentaro",
-    "Admin documentation" : "Administrodokumentaro",
-    "Show description …" : "Montri priskribon...",
-    "Hide description …" : "Malmontri priskribon...",
-    "Enable only for specific groups" : "Kapabligi nur por specifajn grupojn",
-    "Uninstall App" : "Malinstali aplikaĵon",
-    "Common Name" : "Komuna nomo",
-    "Valid until" : "Valida ĝis",
-    "Valid until %s" : "Valida ĝis %s",
-    "Administrator documentation" : "Administrodokumentaro",
-    "Forum" : "Forumo",
-    "Commercial support" : "Komerca subteno",
+    "Get the apps to sync your files" : "Ekhavu la aplikaĵojn por sinkronigi viajn dosierojn",
+    "Desktop client" : "Labortabla kliento",
+    "Android app" : "Android-aplikaĵo",
+    "iOS app" : "iOS-aplikaĵo",
     "Profile picture" : "Profila bildo",
     "Upload new" : "Alŝuti novan",
     "Select from Files" : "Elekti el Dosieroj",
@@ -124,13 +116,14 @@ OC.L10N.register(
     "Change password" : "Ŝanĝi la pasvorton",
     "Language" : "Lingvo",
     "Help translate" : "Helpu traduki",
+    "Unlimited" : "Senlima",
     "Name" : "Nomo",
     "Username" : "Uzantonomo",
     "Done" : "Farita",
-    "Get the apps to sync your files" : "Ekhavu la aplikaĵojn por sinkronigi viajn dosierojn",
-    "Desktop client" : "Labortabla kliento",
-    "Android app" : "Android-aplikaĵo",
-    "iOS app" : "iOS-aplikaĵo",
+    "Version" : "Eldono",
+    "Personal" : "Persona",
+    "Admin" : "Administranto",
+    "Error" : "Eraro",
     "Show last log in" : "Montri lastan ensaluton",
     "Show user backend" : "Montri uzantomotoron",
     "E-Mail" : "Retpoŝtadreso",
