@@ -1,33 +1,24 @@
 OC.L10N.register(
     "settings",
     {
-    "Sharing" : "Compartiendo",
-    "External Storage" : "Almacenamiento externo",
-    "Cron" : "Cron",
-    "Log" : "Log",
-    "Updates" : "Actualizaciones",
-    "Authentication error" : "Error al autenticar",
-    "Your full name has been changed." : "Su nombre completo ha sido cambiado.",
-    "Unable to change full name" : "Imposible cambiar el nombre completo",
-    "Language changed" : "Idioma cambiado",
-    "Invalid request" : "Pedido inválido",
-    "Admins can't remove themself from the admin group" : "Los administradores no se pueden quitar a si mismos del grupo administrador. ",
-    "Unable to add user to group %s" : "No fue posible agregar el usuario al grupo %s",
-    "Unable to remove user from group %s" : "No es posible borrar al usuario del grupo %s",
-    "Couldn't update app." : "No se pudo actualizar la App.",
     "Wrong password" : "Clave incorrecta",
     "No user supplied" : "No se ha indicado el usuario",
-    "Please provide an admin recovery password, otherwise all user data will be lost" : "Por favor provea de una contraseña de recuperación administrativa, sino se perderá todos los datos del usuario",
+    "Authentication error" : "Error al autenticar",
     "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación administrativa incorrecta. Por favor, chequee la clave e intente de nuevo",
     "Unable to change password" : "Imposible cambiar la contraseña",
-    "Enabled" : "Habilitado",
     "Saved" : "Guardado",
     "test email settings" : "Configuración de correo de prueba.",
     "Email sent" : "e-mail mandado",
     "You need to set your user email before being able to send test emails." : "Necesita especificar el usuario de correo electrónico antes de poder enviar correos electrónicos de prueba.",
-    "Email saved" : "e-mail guardado",
-    "Sending..." : "Enviando...",
+    "Your full name has been changed." : "Su nombre completo ha sido cambiado.",
+    "Unable to change full name" : "Imposible cambiar el nombre completo",
+    "APCu" : "APCu",
+    "__language_name__" : "Castellano (Argentina)",
+    "Language changed" : "Idioma cambiado",
+    "Invalid request" : "Pedido inválido",
+    "Admins can't remove themself from the admin group" : "Los administradores no se pueden quitar a si mismos del grupo administrador. ",
     "All" : "Todos",
+    "Enabled" : "Habilitado",
     "Please wait...." : "Por favor, esperá....",
     "Error while disabling app" : "Se ha producido un error mientras se deshabilitaba la aplicación",
     "Disable" : "Desactivar",
@@ -36,42 +27,43 @@ OC.L10N.register(
     "Updating...." : "Actualizando....",
     "Error while updating app" : "Error al actualizar App",
     "Updated" : "Actualizado",
+    "Delete" : "Borrar",
+    "Sending..." : "Enviando...",
     "Select a profile picture" : "Seleccionar una imágen de perfil",
     "Very weak password" : "Contraseña muy débil.",
     "Weak password" : "Contraseña débil.",
     "So-so password" : "Contraseña de nivel medio. ",
     "Good password" : "Buena contraseña. ",
     "Strong password" : "Contraseña fuerte.",
-    "Delete" : "Borrar",
     "Groups" : "Grupos",
     "undo" : "deshacer",
     "never" : "nunca",
     "add group" : "agregar grupo",
+    "enabled" : "activado",
+    "disabled" : "desactivado",
     "A valid username must be provided" : "Debe ingresar un nombre de usuario válido",
-    "Error creating user" : "Error creando usuario",
     "A valid password must be provided" : "Debe ingresar una contraseña válida",
-    "__language_name__" : "Castellano (Argentina)",
-    "SSL root certificates" : "certificados SSL raíz",
+    "Cheers!" : "¡Saludos!",
+    "Forum" : "Foro",
+    "Documentation:" : "Documentación:",
+    "Cron" : "Cron",
+    "Execute one task with each page loaded" : "Ejecutá una tarea con cada pagina cargada.",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php está registrado en el servicio webcron para llamarlo cada 15 minutos usando http.",
+    "Sharing" : "Compartiendo",
+    "Allow apps to use the Share API" : "Permitir a las aplicaciones usar la Share API",
+    "Allow public uploads" : "Permitir subidas públicas",
+    "Allow users to send mail notification for shared files" : "Habilitar a los usuarios para enviar notificaciones por correo para archivos compartidos",
+    "Allow resharing" : "Permitir Re-Compartir",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Todo (notificaciones fatales, errores, advertencias, info, debug)",
     "Info, warnings, errors and fatal issues" : "Info, advertencias, errores y notificaciones fatales",
     "Warnings, errors and fatal issues" : "Advertencias, errores y notificaciones fatales",
     "Errors and fatal issues" : "Errores y notificaciones fatales",
     "Fatal issues only" : "Notificaciones fatales solamente",
+    "Log" : "Log",
     "None" : "Ninguno",
     "Login" : "Ingresar",
     "Plain" : "Plano",
     "NT LAN Manager" : "Administrador NT LAN",
-    "SSL" : "SSL",
-    "TLS" : "TLS",
-    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "El módulo PHP 'fileinfo' no existe. Es recomendable que actives este módulo para obtener mejores resultados con la detección mime-type",
-    "System locale can not be set to a one which supports UTF-8." : "La localización del sistema no puede cambiarse a una que soporta UTF-8",
-    "This means that there might be problems with certain characters in file names." : "Esto significa que puede haber problemas con ciertos caracteres en los nombres de archivos.",
-    "Allow apps to use the Share API" : "Permitir a las aplicaciones usar la Share API",
-    "Allow public uploads" : "Permitir subidas públicas",
-    "Allow users to send mail notification for shared files" : "Habilitar a los usuarios para enviar notificaciones por correo para archivos compartidos",
-    "Allow resharing" : "Permitir Re-Compartir",
-    "Execute one task with each page loaded" : "Ejecutá una tarea con cada pagina cargada.",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php está registrado en el servicio webcron para llamarlo cada 15 minutos usando http.",
     "This is used for sending out notifications." : "Esto es usado para enviar notificaciones.",
     "Send mode" : "Modo de envio",
     "Encryption" : "Encriptación",
@@ -85,45 +77,40 @@ OC.L10N.register(
     "SMTP Password" : "Contraseña SMTP",
     "Test email settings" : "Configuracion de correo de prueba.",
     "Send email" : "Enviar correo",
-    "Log level" : "Nivel de Log",
-    "More" : "Más",
-    "Less" : "Menos",
-    "Version" : "Versión",
-    "by" : "por",
-    "Documentation:" : "Documentación:",
-    "Cheers!" : "¡Saludos!",
-    "Forum" : "Foro",
+    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "El módulo PHP 'fileinfo' no existe. Es recomendable que actives este módulo para obtener mejores resultados con la detección mime-type",
+    "System locale can not be set to a one which supports UTF-8." : "La localización del sistema no puede cambiarse a una que soporta UTF-8",
+    "This means that there might be problems with certain characters in file names." : "Esto significa que puede haber problemas con ciertos caracteres en los nombres de archivos.",
     "Get the apps to sync your files" : "Obtené Apps para sincronizar tus archivos",
     "Desktop client" : "Cliente de escritorio",
     "Android app" : "App para Android",
     "iOS app" : "App para iOS",
     "Show First Run Wizard again" : "Mostrar de nuevo el asistente de primera ejecución",
-    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Usás <strong>%s</strong>  de los <strong>%s</strong> disponibles",
+    "Profile picture" : "Imágen de perfil",
+    "Upload new" : "Subir nuevo",
+    "Remove image" : "Remover imagen",
+    "Cancel" : "Cancelar",
+    "Email" : "e-mail",
+    "Your email address" : "Tu dirección de e-mail",
     "Password" : "Contraseña",
     "Unable to change your password" : "No fue posible cambiar tu contraseña",
     "Current password" : "Contraseña actual",
     "New password" : "Nueva contraseña:",
     "Change password" : "Cambiar contraseña",
-    "Email" : "e-mail",
-    "Your email address" : "Tu dirección de e-mail",
-    "Fill in an email address to enable password recovery and receive notifications" : "Rellene una direccion de correo para habilitar la recuperacion de contraseña y recibir notificaciones. ",
-    "Profile picture" : "Imágen de perfil",
-    "Upload new" : "Subir nuevo",
-    "Select new from Files" : "Seleccionar nuevo desde archivos",
-    "Remove image" : "Remover imagen",
-    "Your avatar is provided by your original account." : "Su avatar es proveído por su cuenta original.",
-    "Cancel" : "Cancelar",
-    "Choose as profile image" : "Elegir como imagen de perfil",
     "Language" : "Idioma",
     "Help translate" : "Ayudanos a traducir",
+    "Unlimited" : "Ilimitado",
+    "Name" : "Nombre",
     "Username" : "Nombre de usuario",
+    "Version" : "Versión",
+    "Personal" : "Personal",
+    "Admin" : "Administración",
+    "Error" : "Error",
     "Create" : "Crear",
     "Admin Recovery Password" : "Recuperación de contraseña de administrador",
     "Enter the recovery password in order to recover the users files during password change" : "Ingresá la contraseña de recuperación para recuperar los archivos de usuario al cambiar contraseña",
     "Group" : "Grupo",
     "Default Quota" : "Cuota predeterminada",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Por favor ingrese la cuota de almacenamiento (ej.: \"512 MB\" o \"12 GB\")",
-    "Unlimited" : "Ilimitado",
     "Other" : "Otros",
     "Full Name" : "Nombre completo",
     "Quota" : "Cuota",
