@@ -1,33 +1,16 @@
 OC.L10N.register(
     "settings",
     {
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Security & setup warnings" : "הזהרות אבטחה והתקנה",
-    "Sharing" : "שיתוף",
-    "Server-side encryption" : "הצפנת צד שרת",
-    "External Storage" : "אחסון חיצוני",
-    "Cron" : "Cron",
-    "Email server" : "שרת דואר אלקטרוני",
-    "Log" : "יומן",
-    "Tips & tricks" : "עצות ותחבולות",
-    "Updates" : "עדכונים",
-    "Couldn't remove app." : "לא ניתן להסיר את היישום.",
-    "Language changed" : "שפה השתנתה",
-    "Invalid request" : "בקשה לא חוקית",
-    "Authentication error" : "שגיאת הזדהות",
-    "Admins can't remove themself from the admin group" : "מנהלים לא יכולים להסיר את עצמם מקבוצת המנהלים",
-    "Unable to add user to group %s" : "לא ניתן להוסיף משתמש לקבוצה %s",
-    "Unable to remove user from group %s" : "לא ניתן להסיר משתמש מהקבוצה %s",
-    "Couldn't update app." : "לא ניתן לעדכן את היישום.",
     "Wrong password" : "סיסמא שגוייה",
+    "The new password can not be the same as the previous one" : "הסיסמא החדשה אינה יכולה להיות זהה לסיסמא הקודמת",
     "No user supplied" : "לא סופק שם משתמש",
-    "Please provide an admin recovery password, otherwise all user data will be lost" : "יש לספק את סיסמת המנהל לשחזור, אחרת כל מידע המשתמש יאבד",
+    "Authentication error" : "שגיאת הזדהות",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "יש לספק סיסמת מנהל לשחזור, אחרת כל מידע המשתמש יאבד.",
     "Wrong admin recovery password. Please check the password and try again." : "סיסמת המנהל לשחזור שגוייה. יש לבדוק את הסיסמא ולנסות שוב.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "צד אחורי לא תומך בשינוי סיסמא, אך מפתח הצפנה של המשתמש עודכנה בהצלחה.",
     "Unable to change password" : "לא ניתן לשנות את הסיסמא",
-    "Enabled" : "מופעל",
-    "Not enabled" : "לא מופעל",
+    "%s password changed successfully" : "סיסמא %s שונתה בהצלחה",
+    "Couldn't send reset email. Please contact your administrator." : "לא ניתן היה לשלוח דואר אלקטרוני לאיפוס. יש לפנות למנהל שלך.",
     "installing and updating apps via the app store or Federated Cloud Sharing" : "התקנה ועדכון היישום דרך חנות היישומים או ענן שיתוף מאוגד",
     "Federated Cloud Sharing" : "ענן שיתוף מאוגד",
     "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL משתמש בגרסה %s ישנה (%s). יש לעדכן את מערכת ההפעלה או  שתכונות כדוגמת %s לא יעבדו באופן מהימן.",
@@ -42,6 +25,8 @@ OC.L10N.register(
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "בעיה אירעה בשליחת הדואר האלקטרוני. יש לשנות את ההגדרות שלך. (שגיאה: %s)",
     "Email sent" : "הודעת הדואר האלקטרוני נשלחה",
     "You need to set your user email before being able to send test emails." : "יש להגדיר כתובת דואר אלקטרוני לפני שניתן יהיה לשלוח דואר אלקטרוני לבדיקה.",
+    "Couldn't change the email address because the user does not exist" : "לא ניתן היה לשנות את כתובת הדואר האלקטרוני כיוון שהמשתמש אינו קיים",
+    "Couldn't change the email address because the token is invalid" : "לא ניתן היה לשנות את כתובת הדואר האלקטרוני כיוון שחתימת הייצוג אינה חוקית",
     "Invalid mail address" : "כתובת דואר אלקטרוני לא חוקית",
     "A user with that name already exists." : "משתמש בשם זה כבר קיים.",
     "Unable to create user." : "לא ניתן ליצור משתמש.",
@@ -50,29 +35,42 @@ OC.L10N.register(
     "Forbidden" : "חסום",
     "Invalid user" : "שם משתמש לא חוקי",
     "Unable to change mail address" : "לא ניתן לשנות כתובת דואר אלקטרוני",
-    "Email saved" : "הדואר האלקטרוני נשמר",
+    "Email has been changed successfully." : "כתובת הדואר האלקטרוני שונתה בהצלחה.",
+    "An email has been sent to this address for confirmation" : "דואר אלקטרוני נשלח לכתובת זו לאימות",
+    "No email was sent because you already sent one recently. Please try again later." : "לא נשלח דואר אלקטרוני כיוון שכבר שלחת דואר אלקטרוני לא מכבר. יש לנסות שוב מאוחר יותר",
     "Your full name has been changed." : "השם המלא שלך הוחלף",
     "Unable to change full name" : "לא ניתן לשנות שם מלא",
-    "Are you really sure you want add \"{domain}\" as trusted domain?" : "האם באמת להוסיף \"{domain}\" כשם מתחם מהימן?",
-    "Add trusted domain" : "הוספת שם מתחם מהימן",
-    "Migration in progress. Please wait until the migration is finished" : "המרה בביצוע. יש להמתין עד סיום ההמרה",
-    "Migration started …" : "המרה החלה...",
-    "Sending..." : "שולח...",
+    "%s email address confirm" : "כתובת דואר אלקטרוני %s אומתה",
+    "Couldn't send email address change confirmation mail. Please contact your administrator." : "לא ניתן היה לשלוח הודעת אימות לכתובת הדואר האלקטרוני החדשה. יש ליצור קשר עם מנהל המערכת שלך.",
+    "%s email address changed successfully" : "כתובת הדואר האלקטרוני %s הוחלפה בהצלחה",
+    "Couldn't send email address change notification mail. Please contact your administrator." : "לא ניתן היה לשלוח הודעת אימות לכתובת הדואר האלקטרוני החדשה. יש ליצור קשר עם מנהל המערכת שלך.",
+    "Unable to enable/disable user." : "לא ניתן היה לנטרל / לבטל ניטרול משתמש.",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "__language_name__" : "עברית",
+    "Language changed" : "שפה השתנתה",
+    "Invalid request" : "בקשה לא חוקית",
+    "Admins can't remove themself from the admin group" : "מנהלים לא יכולים להסיר את עצמם מקבוצת המנהלים",
+    "Unknown user" : "משתמש לא ידוע",
+    "Couldn't remove app." : "לא ניתן להסיר את היישום.",
     "Official" : "רישמי",
     "Approved" : "מאושר",
-    "Experimental" : "ניסיוני",
     "All" : "הכל",
+    "Enabled" : "מופעל",
+    "Not enabled" : "לא מופעל",
     "No apps found for your version" : "לא נמצאו יישומים לגרסה שלך",
+    "The app will be downloaded from the app store" : "היישום ירד מחנות היישומים",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "יישומים רישמיים מפותחים על ידי קהילת ownCloud. הם מציעים פונקיונאליות, התאמה ל- ownCloud ומוכנים לשימוש כבד.",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "יישומים מאושרים מפותחים על ידי מפתחים מהימנים ועברו בדיקת הבטחה ראשונית. הם נשמרים באופן פעיל במאגר קוד פתוח והמתזקים שלהם מייעדים אותם לשימוש מזדמן ורגיל.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "יישום זה לא נבדק לבעיות אבטחה והוא חדש או ידוע כלא יציב. התקנת יישום זה הנה על אחריותך בלבד.",
-    "Update to %s" : "עדכון ל- %s",
-    "_You have %n app update pending_::_You have %n app updates pending_" : ["ממתין עבורך %n עדכון יישום","ממתינים עבורך %n עדכוני יישום"],
     "Please wait...." : "נא להמתין…",
     "Error while disabling app" : "אירעה שגיאה בעת נטרול היישום",
     "Disable" : "ניטרול",
     "Enable" : "הפעלה",
     "Error while enabling app" : "שגיאה בעת הפעלת יישום",
+    "Error: this app cannot be enabled because it makes the server unstable" : "שגיאה: לא ניתן להפעיל יישום זה כיוון שהוא גורם לשרת להיות לא יציב. ",
+    "Error: could not disable broken app" : "שגיאה: לא ניתן לנטרל יישום פגום",
+    "Error while disabling broken app" : "שגיאה בזמן נטרול יישום פגום",
     "Updating...." : "מתבצע עדכון…",
     "Error while updating app" : "אירעה שגיאה בעת עדכון היישום",
     "Updated" : "מעודכן",
@@ -81,10 +79,22 @@ OC.L10N.register(
     "Uninstall" : "הסרת התקנה",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "היישום הופעל אך יש לעדכן אותו. בעוד 5 שניות הדף ינותב לעמוד העדכון.",
     "App update" : "עדכון יישום",
-    "No apps found for \"{query}\"" : "לא נמצא יישום עבור \"{query}\"",
+    "Experimental" : "ניסיוני",
+    "No apps found for {query}" : "לא נמצא יישום עבור {query}",
+    "Are you really sure you want add \"{domain}\" as trusted domain?" : "האם באמת להוסיף \"{domain}\" כשם מתחם מהימן?",
+    "Add trusted domain" : "הוספת שם מתחם מהימן",
+    "Migration in progress. Please wait until the migration is finished" : "המרה בביצוע. יש להמתין עד סיום ההמרה",
+    "Migration started …" : "המרה החלה...",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "אירעה שגיאה. יש להעלות תעודת ASCII-encoded PEM.",
     "Valid until {date}" : "בתוקף עד ל- {date}",
     "Delete" : "מחיקה",
+    "Disconnect" : "ניתוק",
+    "Error while loading browser sessions and device tokens" : "שגיאה בזמן טעינת שיחת דפדפן ומחרוזת התקן",
+    "Error while creating device token" : "שגיאה בזמן יצירת מחרוזת התקן",
+    "Error while deleting the token" : "שגיאה בזמן מחיקת המחרוזת",
+    "Sending..." : "שולח...",
+    "Failed to change the email address." : "נכשל בשינוי כתובת הדואר האלקטרוני.",
+    "Email changed successfully." : "כתובת הדואר האלקטרוני הוחלפה בהצלחה.",
     "An error occurred: {message}" : "אירעה שגיאה: {message}",
     "Select a profile picture" : "יש לבחור תמונת פרופיל",
     "Very weak password" : "סיסמא מאוד חלשה",
@@ -98,67 +108,63 @@ OC.L10N.register(
     "A valid group name must be provided" : "יש לספק שם קבוצה תקני",
     "deleted {groupName}" : "נמחק {groupName}",
     "undo" : "ביטול",
-    "no group" : "אין קבוצה",
     "never" : "לעולם לא",
     "deleted {userName}" : "נמחק {userName}",
     "add group" : "הוספת קבוצה",
+    "Invalid quota value \"{val}\"" : "ערך מכסה לא חוקי \"{val}\"",
+    "enabled" : "מופעל",
+    "disabled" : "מנוטרל",
+    "User {uid} has been {state}!" : "במשתמש {uid} התבצעה פעולת {state}!",
+    "no group" : "אין קבוצה",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "שינוי הסיסמא יגרום איבוד מידע, וזאת בגלל ששחזור מידע אינו זמין למשתמש זה",
+    "Password successfully changed" : "סיסמא שונתה בהצלחה",
     "A valid username must be provided" : "יש לספק שם משתמש תקני",
     "Error creating user: {message}" : "שגיאה ביצירת משתמש: {message}",
     "A valid password must be provided" : "יש לספק סיסמא תקנית",
     "A valid email must be provided" : "יש לספק כתובת דואר אלקטרוני תקנית",
-    "__language_name__" : "עברית",
-    "Personal info" : "מידע אישי",
-    "Sync clients" : "סנכרון לקוחות",
-    "Everything (fatal issues, errors, warnings, info, debug)" : "הכול (נושאים חמורים, שגיאות, אזהרות, מידע, ניפוי שגיאות)",
-    "Info, warnings, errors and fatal issues" : "מידע, אזהרות, שגיאות ונושאים חמורים",
-    "Warnings, errors and fatal issues" : "אזהרות, שגיאות ונושאים חמורים",
-    "Errors and fatal issues" : "שגיאות ונושאים חמורים",
-    "Fatal issues only" : "נושאים חמורים בלבד",
-    "None" : "כלום",
-    "Login" : "התחברות",
-    "Plain" : "רגיל",
-    "NT LAN Manager" : "מנהל רשת NT",
-    "SSL" : "SSL",
-    "TLS" : "TLS",
-    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response.",
-    "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "יש לבדוק את <a target=\"_blank\" href=\"%s\">מסמכי ההתקנה ↗</a> בהערות הגדרת php ובהגדרות php של התקנת השרת שלך, בעיקר כאשר משתמשים ב- php-fpm.",
-    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "תצורת קריאה בלבד הופעלה. תצורה זו מונעת קביעת מספר הגדרות באמצעות ממשק האינטרנט. יתר על כן, יש צורך להגדיר ההרשאות כתיבה באופן ידני לכל עדכון.",
-    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP מוגדר ככל הנראה להפשיט בלוקי קוד. מצב זה יגרום למספר יישומי ליבה להיות לא נגישים.",
-    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "זה ככל הנראה נגרם על ידי מאיץ/מטמון כמו Zend OPcache או eAccelerator.",
-    "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "השרת רץ על גבי חלונות של מיקוסופט. אנו ממליצים בחום על לינוקס לחווית משתמש מיטבית.",
-    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s מתחת לגרסה %2$s מותקנת, מסיבות יציבות וביצועים אנו ממליצים לעדכן לגרסה חדשה יותר גרסה %1$s.",
-    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "מודול ה- PHP מסוג 'fileinfo' חסר. אנו ממליצים בחום לאפשר מודול זה כדי לקבל תוצאות מיטביות עם גילוי mime-type.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "נעילת קובץ Transactional מנוטרלת, זה עלול להוביל לבעיות עם race conditions. יש לאפשר 'filelocking.enabled' בקובץ config.php כדי למנוע בעיות אלו. ראו <a target=\"_blank\" href=\"%s\">מסמכים אלו ↗</a> למידע נוסף.",
-    "System locale can not be set to a one which supports UTF-8." : "הגדרות שפה לא יכולות להקבע ככאלה שתומכות ב- UTF-8.",
-    "This means that there might be problems with certain characters in file names." : "משמעות הדבר היא כי ייתכן שיש בעיות עם תוים מסוימים בשמות קבצים.",
-    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : " אנו ממליצים בחום להתקין את החבילות הנדרשות במערכת שלך כדי לתמוך באחת מהגדרות השפה הבאות: %s.",
-    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "אם המערכת שלך לא מותקנת על נתיב הבסיס של שם התחום ומשתמשת במערכת cron, עלולות להיות בעיות עם יצירת כתובות האינטרנט. למניעת בעיות אלו, יש לקבוע את האופציה \"overwrite.cli.url\" בקובץ ה- config.php לנתיב הבסיסי של ההתקנה שלך (הציעו: \"%s \")",
-    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "לא ניתן היה להפעיל את cronjob דרך CLI. השגיאות הבאות נצפתו:",
-    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "יש לבדוק בשבע עיניים את ה- <a target=\"_blank\" href=\"%s\">מדריכי ההתקנה ↗</a>, ולחפש אחר כל שגיאה או הזהרה ב- <a href=\"#log-section\">לוג</a>.",
-    "All checks passed." : "כל הבדיקות עברו",
-    "Open documentation" : "תיעוד פתוח",
-    "Allow apps to use the Share API" : "לאפשר ליישום להשתמש ב־API השיתוף",
-    "Allow users to share via link" : "אפשר למשתמשים לשתף באמצעות קישור",
-    "Enforce password protection" : "חייב הגנת סיסמא",
-    "Allow public uploads" : "אפשר העלאות ציבוריות",
-    "Allow users to send mail notification for shared files" : "אפשר למשתמשים לשלוח הודעות דואר אלקטרוני לשיתוף קבצים",
-    "Set default expiration date" : "הגדרת תאריך תפוגה ברירת מחדל",
-    "Expire after " : "פג אחרי",
-    "days" : "ימים",
-    "Enforce expiration date" : "חייב תאריך תפוגה",
-    "Allow resharing" : "לאפשר שיתוף מחדש",
-    "Restrict users to only share with users in their groups" : "הגבלת משתמשים לשתף רק עם משתמשים בקבוצה שלהם",
-    "Allow users to send mail notification for shared files to other users" : "אפשר למשתמשים לשלוח הודעות דואר אלקטרוני לשיתוף קבצים למשתמשים אחרים",
-    "Exclude groups from sharing" : "מניעת קבוצות משיתוף",
-    "These groups will still be able to receive shares, but not to initiate them." : "קבוצות אלו עדיין יוכלו לקבל שיתופים, אך לא לשתף בעצמם.",
-    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "אפשר השלמה אוטומטית של שמות משתמש בתפריט שיתוף. אם תכונה זו מנוטרלת יש להכניס שם משתמש מלא.",
+    "Use the following link to confirm your changes to the email address: {link}" : "יש להשתמש בקישור זה בכדי לאמת השינוי לכתובת הדואר האלקטרוני: {link}",
+    "Email address changed to {mailAddress} successfully." : "כתובת הדואר האלקטרוני הוחלפה ל- {mailAddress} בהצלחה.",
+    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "שלום,<br><br>רק רצינו להודיע שעכשיו יש לך %s חשבון.<br><br>Your שם משתמש: %s<br>כניסה: <a href=\"%s\">%s</a><br><br>",
+    "Cheers!" : "לחיים!",
+    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "שלום,\n\nרק רצינו להודיע שעכשיו יש לך %s חשבון.\n\nשם המשתמש שלך: %s\nכניסה: %s\n\n",
+    "User documentation" : "תיעוד משתמש",
+    "Administrator documentation" : "תיעוד מנהל",
+    "Online documentation" : "תיעוד מקוון",
+    "Forum" : "פורום",
+    "Issue tracker" : "מעקב בעיות",
+    "Commercial support" : "תמיכה מסחרית",
+    "Apps Management" : "ניהול ישומים",
+    "Developer documentation" : "תיעוד מפתח",
+    "by %s" : "על ידי %s",
+    "%s-licensed" : "%s-בעל רישיון",
+    "Documentation:" : "תיעוד",
+    "Admin documentation" : "תיעוד מנהל",
+    "Visit website" : "ביקור באתר האינטרנט",
+    "Report a bug" : "דיווח על באג",
+    "Show description …" : "הצגת תיאור ...",
+    "Hide description …" : "הסתרת תיאור ...",
+    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "ליישום זה לא הוקצתה גרסה מינמלית של ownCloud. מצב זה יהיה שגוי בגרסה 11 או מאוחרת יותר של ownCloud.",
+    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "ליישום זה לא הוקצתה גרסה מקסימלית של ownCloud. מצב זה יהיה שגוי בגרסה 11 או מאוחרת יותר של ownCloud.",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "לא ניתן להתקין את יישום זה כיוון שייחסי התלות הבאים לא התקיימו:",
+    "Enable only for specific groups" : "אפשר רק לקבוצות מסויימות",
+    "Uninstall App" : "הסרת יישום",
+    "Show enabled apps" : "הצגת יישומים מופעלים",
+    "Show disabled apps" : "הצגת יישומים מנוטרלים",
+    "Cron" : "Cron",
     "Last cron job execution: %s." : "פעילות cron job אחרונה: %s.",
     "Last cron job execution: %s. Something seems wrong." : "פעילות cron job אחרונה: %s. משהו נראה שגוי.",
     "Cron was not executed yet!" : "Cron עדיין לא בוצע!",
+    "Open documentation" : "תיעוד פתוח",
     "Execute one task with each page loaded" : "יש להפעיל משימה אחת עם כל עמוד שנטען",
     "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php רשום בשירות webcron לקרוא ל- cron.php בכל 15 דקות באמצעות http.",
     "Use system's cron service to call the cron.php file every 15 minutes." : "ניתן להשתמש בשירות cron לקרוא לקובץ cron.php בכל 15 דקות.",
+    "SSL Root Certificates" : "אישורי אבטחת SSL לנתיב יסוד",
+    "Common Name" : "שם משותף",
+    "Valid until" : "בתוקף עד",
+    "Issued By" : "הוצא על ידי",
+    "Valid until %s" : "בתוקף עד %s",
+    "Import root certificate" : "יבוא אישור אבטחה לנתיב יסוד",
+    "Server-side encryption" : "הצפנת צד שרת",
     "Enable server-side encryption" : "הפעלת הצפנה בצד שרת",
     "Please read carefully before activating server-side encryption: " : "יש לקרוא בתשומת לב רבה לפני שמפעילים הצפנת צד שרת:",
     "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "ברגע שהצפנה מופעלת, כל הקבצים שיועלו לשרת מרגע זה יהיו מוצפנים בשרת. ניתן יהיה לנטרל את ההצפנה בעתיד רק אם מודול ההצפנה תומך בפונקציה זו, וכל התנאים המוקדמים (דהיינו הגדרת מפתח השחזור) מתקיימים.",
@@ -172,6 +178,41 @@ OC.L10N.register(
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "יש להמיר את מפתחות ההצפנה שלך בממערכת ההצפנה הישנה (ownCloud <= 8.0) למערכת החדשה. יש לאפשר את \"מודול הצפנה ברירת מחדש\" ולהריץ 'occ encryption:migrate'",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "יש להמיר את מפתחות ההצפנה שלך בממערכת ההצפנה הישנה (ownCloud <= 8.0) למערכת החדשה.",
     "Start migration" : "התחלת המרה",
+    "Sharing" : "שיתוף",
+    "Allow apps to use the Share API" : "לאפשר ליישום להשתמש ב־API השיתוף",
+    "Allow users to share via link" : "אפשר למשתמשים לשתף באמצעות קישור",
+    "Allow public uploads" : "אפשר העלאות ציבוריות",
+    "Enforce password protection" : "חייב הגנת סיסמא",
+    "Set default expiration date" : "הגדרת תאריך תפוגה ברירת מחדל",
+    "Allow users to send mail notification for shared files" : "אפשר למשתמשים לשלוח הודעות דואר אלקטרוני לשיתוף קבצים",
+    "Allow users to share file via social media" : "מאפשר למשתמשים לשתף קובץ באמצעות מדייה חברתית",
+    "Expire after " : "פג אחרי",
+    "days" : "ימים",
+    "Enforce expiration date" : "חייב תאריך תפוגה",
+    "Allow resharing" : "לאפשר שיתוף מחדש",
+    "Allow sharing with groups" : "מאפשר שיתוף עם קבוצות",
+    "Restrict users to only share with users in their groups" : "הגבלת משתמשים לשתף רק עם משתמשים בקבוצה שלהם",
+    "Allow users to send mail notification for shared files to other users" : "אפשר למשתמשים לשלוח הודעות דואר אלקטרוני לשיתוף קבצים למשתמשים אחרים",
+    "Exclude groups from sharing" : "מניעת קבוצות משיתוף",
+    "These groups will still be able to receive shares, but not to initiate them." : "קבוצות אלו עדיין יוכלו לקבל שיתופים, אך לא לשתף בעצמם.",
+    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "אפשר השלמה אוטומטית של שמות משתמש בתפריט שיתוף. אם תכונה זו מנוטרלת יש להכניס שם משתמש מלא.",
+    "Restrict enumeration to group members" : "הגבלת מספר הנרשמים לחברי קבוצה",
+    "Everything (fatal issues, errors, warnings, info, debug)" : "הכול (נושאים חמורים, שגיאות, אזהרות, מידע, ניפוי שגיאות)",
+    "Info, warnings, errors and fatal issues" : "מידע, אזהרות, שגיאות ונושאים חמורים",
+    "Warnings, errors and fatal issues" : "אזהרות, שגיאות ונושאים חמורים",
+    "Errors and fatal issues" : "שגיאות ונושאים חמורים",
+    "Fatal issues only" : "נושאים חמורים בלבד",
+    "Log" : "רישום אירועים",
+    "What to log" : "מה לנטר בלוג",
+    "Download logfile (%s)" : "הורדת קובץ לוג (%s)",
+    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "קובץ הלוג גדול מ- 100 מגה-בייט. הורדה עלולה לקחת זמן רב!",
+    "None" : "כלום",
+    "Login" : "התחברות",
+    "Plain" : "רגיל",
+    "NT LAN Manager" : "מנהל רשת NT",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "Email server" : "שרת דואר אלקטרוני",
     "This is used for sending out notifications." : "משתמשים בזה כדי לשלוח הודעות.",
     "Send mode" : "מצב שליחה",
     "Encryption" : "הצפנה",
@@ -187,53 +228,42 @@ OC.L10N.register(
     "Store credentials" : "שמירת אישורים",
     "Test email settings" : "בדיקת הגדרות דואר אלקטרוני",
     "Send email" : "שליחת דואר אלקטרוני",
-    "Download logfile" : "הורדת קובץ לוג",
-    "More" : "יותר",
-    "Less" : "פחות",
-    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "קובץ הלוג גדול מ- 100 מגה-בייט. הורדה עלולה לקחת זמן רב!",
-    "What to log" : "מה לנטר בלוג",
+    "Security & setup warnings" : "הזהרות אבטחה והתקנה",
+    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response.",
+    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "יש לבדוק את <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">הגדרות ההתקנה ↗</a> אחר הערות תצורת php ותצורת php של השרת שלך, בעיקר כשמשתמשים ב- php-fpm.",
+    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "תצורת קריאה בלבד הופעלה. תצורה זו מונעת קביעת מספר הגדרות באמצעות ממשק האינטרנט. יתר על כן, יש צורך להגדיר ההרשאות כתיבה באופן ידני לכל עדכון.",
+    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP מוגדר ככל הנראה להפשיט בלוקי קוד. מצב זה יגרום למספר יישומי ליבה להיות לא נגישים.",
+    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "זה ככל הנראה נגרם על ידי מאיץ/מטמון כמו Zend OPcache או eAccelerator.",
+    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "מסד הנתונים שלך אינו רץ עם \"READ COMMITED\" ברמת בידוד פעולה. דבר זה עלול להוות בעייה בזמן הרצת מספר פעולות במקביל.",
+    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s מתחת לגרסה %2$s מותקנת, מסיבות יציבות וביצועים אנו ממליצים לעדכן לגרסה חדשה יותר גרסה %1$s.",
+    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "מודול ה- PHP מסוג 'fileinfo' חסר. אנו ממליצים בחום לאפשר מודול זה כדי לקבל תוצאות מיטביות עם גילוי mime-type.",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "נעילת קבצים בפעולות מושבתת, זה עלול להוביל לבעיות גרסאות תזמון. יש לאפשר 'filelocking.enabled' בקובץ config.php למניעת בעיות אלו. ניתן לראות מידע נוסף ב- <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">תיעוד ↗</a>.",
+    "Transactional file locking should be configured to use memory-based locking, not the default slow database-based locking. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "נעילת קבצים בפעולות צריכה להיות מוגדרת להשתמש בנעילה מבוססת-זכרון, ולא ברירת המחדל האיטית של נעלה מבוססת-מסד נתונים. למידע נוסף ניתן לקרוא ב-  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">תיעוד ↗</a>.",
+    "System locale can not be set to a one which supports UTF-8." : "הגדרות שפה לא יכולות להקבע ככאלה שתומכות ב- UTF-8.",
+    "This means that there might be problems with certain characters in file names." : "משמעות הדבר היא כי ייתכן שיש בעיות עם תוים מסוימים בשמות קבצים.",
+    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : " אנו ממליצים בחום להתקין את החבילות הנדרשות במערכת שלך כדי לתמוך באחת מהגדרות השפה הבאות: %s.",
+    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "אם המערכת שלך לא מותקנת על נתיב הבסיס של שם התחום ומשתמשת במערכת cron, עלולות להיות בעיות עם יצירת כתובות האינטרנט. למניעת בעיות אלו, יש לקבוע את האופציה \"overwrite.cli.url\" בקובץ ה- config.php לנתיב הבסיסי של ההתקנה שלך (הציעו: \"%s \")",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "המערכת משתמשת ב- SQLite כמסד נתונים. להתקנות גדולות אנו ממליצים לעבור למסדי נתונים צד אחורי אחרים.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "במיוחד כאשר משתמשים במחשב שולחני לסנכרון קבצים השימוש ב SQLite אינו מומלץ.",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "לצורך מעבר למסד נתונים אחר ניתן להשתמש בכלי שורת הפעולה: 'occ db:convert-type', או להסתכל ב- <a target=\"_blank\" href=\"%s\">מסמכים הבאים ↗</a>.",
+    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "למעבר למסד נתונים אחר יש להשתמש בכלי שורת פקודה: 'occ db:convert-type', או לעיין ב- <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">תיעוד↗</a>.",
+    "We recommend to enable system cron as any other cron method has possible performance and reliability implications." : "אנו ממליצים להפעיל מערכת cron כיוון שלכל שיטת cron אחרת יש השלכות אפשריות של ביצועים ואמינות.",
+    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "לא ניתן היה להפעיל את cronjob דרך CLI. השגיאות הבאות נצפתו:",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "יש לבדוק בשבע עיניים את <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">מדריכי ההתקנה ↗</a>, ויש לחפש אחר שגיאות או הזהרות ב- <a href=\"#log-section\">לוג</a>.",
+    "All checks passed." : "כל הבדיקות עברו",
+    "System Status" : "מצב מערכת",
+    "Tips & tricks" : "עצות ותחבולות",
     "How to do backups" : "איך לבצע גיבויים",
     "Advanced monitoring" : "ניטור מתקדם",
     "Performance tuning" : "כוונון ביצועים",
     "Improving the config.php" : "שיפור קובץ config.php",
     "Theming" : "ערכת נושא",
     "Hardening and security guidance" : "הדרכת הקשחה ואבטחה",
-    "Version" : "גרסה",
-    "Developer documentation" : "תיעוד מפתח",
-    "Experimental applications ahead" : "ישומים ניסיוניים לפנים",
-    "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "יישומים ניסיוניים לא נבדקו לבעיות אבטחה, חדשים או ידועים כלא יציבים ותחת פיתוח כבד. התקנה שלהם עלולה להוביל לאיבוד מידע או לפרצות אבטחה.",
-    "by %s" : "על ידי %s",
-    "%s-licensed" : "%s-בעל רישיון",
-    "Documentation:" : "תיעוד",
-    "User documentation" : "תיעוד משתמש",
-    "Admin documentation" : "תיעוד מנהל",
-    "Show description …" : "הצגת תיאור ...",
-    "Hide description …" : "הסתרת תיאור ...",
-    "This app has an update available." : "ליישום זה קיים עדכון זמין.",
-    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "ליישום זה לא הוקצתה גרסה מינמלית של ownCloud. מצב זה יהיה שגוי בגרסה 11 או מאוחרת יותר של ownCloud.",
-    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "ליישום זה לא הוקצתה גרסה מקסימלית של ownCloud. מצב זה יהיה שגוי בגרסה 11 או מאוחרת יותר של ownCloud.",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "לא ניתן להתקין את יישום זה כיוון שייחסי התלות הבאים לא התקיימו:",
-    "Enable only for specific groups" : "אפשר רק לקבוצות מסויימות",
-    "Uninstall App" : "הסרת יישום",
-    "Enable experimental apps" : "אפשר יישומים ניסיוניים",
-    "SSL Root Certificates" : "אישורי אבטחת SSL לנתיב יסוד",
-    "Common Name" : "שם משותף",
-    "Valid until" : "בתוקף עד",
-    "Issued By" : "הוצא על ידי",
-    "Valid until %s" : "בתוקף עד %s",
-    "Import root certificate" : "יבוא אישור אבטחה לנתיב יסוד",
-    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "שלום,<br><br>רק רצינו להודיע שעכשיו יש לך %s חשבון.<br><br>Your שם משתמש: %s<br>כניסה: <a href=\"%s\">%s</a><br><br>",
-    "Cheers!" : "לחיים!",
-    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "שלום,\n\nרק רצינו להודיע שעכשיו יש לך %s חשבון.\n\nשם המשתמש שלך: %s\nכניסה: %s\n\n",
-    "Administrator documentation" : "תיעוד מנהל",
-    "Online documentation" : "תיעוד מקוון",
-    "Forum" : "פורום",
-    "Issue tracker" : "מעקב בעיות",
-    "Commercial support" : "תמיכה מסחרית",
-    "You are using <strong>%s</strong> of <strong>%s</strong>" : "הנך משתמש ב- <strong>%s</strong> מתוך <strong>%s</strong>",
+    "Get the apps to sync your files" : "קבלת היישומים לסנכרון הקבצים שלך",
+    "Desktop client" : "מחשב אישי",
+    "Android app" : "יישום אנדרואיד",
+    "iOS app" : "יישום אייפון",
+    "If you want to support the project\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\t\tor\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "אם ברצונך לתמוך בפרויקט\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">ניתן להצטרך לפיתוח</a>\n\t\t\tאו\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">להפיץ את הבשורה</a>!",
+    "Show First Run Wizard again" : "הצגת אשף ההפעלה הראשונית שוב",
     "Profile picture" : "תמונת פרופיל",
     "Upload new" : "העלאת חדש",
     "Select from Files" : "בחירה מתוך קבצים",
@@ -246,6 +276,8 @@ OC.L10N.register(
     "No display name set" : "לא נקבע שם תצוגה",
     "Email" : "דואר אלקטרוני",
     "Your email address" : "כתובת הדואר האלקטרוני שלך",
+    "Change email" : "החלפת כתובת דואר אלקטרוני",
+    "Set email" : "קביעת כתובת דואר אלקטרוני",
     "For password recovery and notifications" : "לשחזור סיסמא והודעות",
     "No email address set" : "לא נקבעה כתובת דואר אלקטרוני",
     "You are member of the following groups:" : "הקבוצות הבאות כוללות אותך:",
@@ -256,19 +288,34 @@ OC.L10N.register(
     "Change password" : "שינוי סיסמא",
     "Language" : "שפה",
     "Help translate" : "עזרה בתרגום",
-    "Get the apps to sync your files" : "קבלת היישומים לסנכרון הקבצים שלך",
-    "Desktop client" : "מחשב אישי",
-    "Android app" : "יישום אנדרואיד",
-    "iOS app" : "יישום אייפון",
-    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "אם ברצונך לתמוך בפרויקט\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">ניתן להצטרך לפיתוח</a>\n\t\tאו\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">להפיץ את הבשורה</a>!",
-    "Show First Run Wizard again" : "הצגת אשף ההפעלה הראשונית שוב",
+    "Unlimited" : "ללא הגבלה",
+    "You are using %s of %s" : "בשימוש %s מתוך %s",
+    "You are using %s of %s (%s %%)" : "בשימוש %s מתוך%s (%s %%)",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "פיתוח על ידי {open}קהילת ownCloud community{linkclose}, {githubopen}קוד המקור{linkclose} ברישיון תחת ה- {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
+    "Sessions" : "שיחות",
+    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "אלו הם לקוחות האינטרנט, המחשב השולחני והטלפון שכרגע מחוברים ל- ownCloud שלך.",
+    "Browser" : "דפדפן",
+    "Most recent activity" : "פעילות אחרונה",
+    "App passwords" : "סיסמת יישום",
+    "You've linked these apps." : "יישומים אלו כבר קושרו על ידך.",
+    "Name" : "שם",
+    "An app password is a passcode that gives an app or device permissions to access your %s account." : "סיסמת יישום הנה קוד סיסמא שמאפשרת ליישום או התקן הרשאות גישה לחשבון %s שלך.",
+    "App name" : "שם יישום",
+    "Create new app password" : "יצירת סיסמת יישום חדשה",
+    "Use the credentials below to configure your app or device." : "יש להשתמש באישורים מטה להגדרת היישום או ההתקן שלך.",
+    "Username" : "שם משתמש",
+    "Done" : "הסתיים",
+    "Version" : "גרסה",
+    "Personal" : "אישי",
+    "Admin" : "ניהול",
+    "Error" : "שגיאה",
+    "No panels for this section." : "אין תפריטים לפעולה זו.",
+    "Show enabled/disabled option" : "הצגת אפשרות הפעלה / ניטרול",
     "Show storage location" : "הצגת מיקום אחסון",
     "Show last log in" : "הצגת כניסה אחרונה",
     "Show user backend" : "הצגת צד אחורי למשתמש",
     "Send email to new user" : "שליחת דואר אלקטרוני למשתמש חדש",
     "Show email address" : "הצגת כתובת דואר אלקטרוני",
-    "Username" : "שם משתמש",
     "E-Mail" : "דואר אלקטרוני",
     "Create" : "יצירה",
     "Admin Recovery Password" : "סיסמת השחזור של המנהל",
@@ -279,7 +326,6 @@ OC.L10N.register(
     "Admins" : "מנהלים",
     "Default Quota" : "מכסת ברירת המחדל",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "יש להכניס מכסת אחסון (לדוגמא: \"512 MB\" or \"12 GB\")",
-    "Unlimited" : "ללא הגבלה",
     "Other" : "אחר",
     "Full Name" : "שם מלא",
     "Group Admin for" : "קבוצת ניהול עבור",
