@@ -1,33 +1,15 @@
 OC.L10N.register(
     "settings",
     {
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Security & setup warnings" : "보안 및 설치 경고",
-    "Sharing" : "공유",
-    "Server-side encryption" : "서버 측 암호화",
-    "External Storage" : "외부 저장소",
-    "Cron" : "Cron",
-    "Email server" : "이메일 서버",
-    "Log" : "로그",
-    "Tips & tricks" : "팁과 추가 정보",
-    "Updates" : "업데이트",
-    "Couldn't remove app." : "앱을 삭제할 수 없습니다.",
-    "Language changed" : "언어가 변경됨",
-    "Invalid request" : "잘못된 요청",
-    "Authentication error" : "인증 오류",
-    "Admins can't remove themself from the admin group" : "관리자 자신을 관리자 그룹에서 삭제할 수 없음",
-    "Unable to add user to group %s" : "그룹 %s에 사용자를 추가할 수 없음",
-    "Unable to remove user from group %s" : "그룹 %s에서 사용자를 삭제할 수 없음",
-    "Couldn't update app." : "앱을 업데이트할 수 없습니다.",
     "Wrong password" : "잘못된 암호",
     "No user supplied" : "사용자가 지정되지 않음",
-    "Please provide an admin recovery password, otherwise all user data will be lost" : "관리자 복구 암호를 입력하지 않으면 모든 사용자 데이터가 삭제됩니다",
+    "Authentication error" : "인증 오류",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "관리자 복구 암호를 입력하십시오. 그렇지 않으면 모든 사용자 데이이터가 초기화됩니다다.",
     "Wrong admin recovery password. Please check the password and try again." : "관리자 복구 암호가 잘못되었습니다. 암호를 다시 확인하십시오.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "백엔드에서 암호 변경을 지원하지 않지만, 암호화 키는 갱신되었습니다.",
     "Unable to change password" : "암호를 변경할 수 없음",
-    "Enabled" : "활성",
-    "Not enabled" : "비활성",
+    "%s password changed successfully" : "%s 암호가 성공적으로 변경됨",
+    "Couldn't send reset email. Please contact your administrator." : "재설정 메일을 보낼수 없습니다. 관리자에게 문의하십시오.",
     "installing and updating apps via the app store or Federated Cloud Sharing" : "앱 스토어 및 연합 클라우드 공유로 앱 설치 및 업데이트",
     "Federated Cloud Sharing" : "클라우드 연합 공유",
     "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL이 오래된 %s 버전을 사용하고 있습니다(%s). 운영 체제나 기능을 업데이트하지 않으면 %s 등을 안정적으로 사용할 수 없습니다.",
@@ -40,7 +22,7 @@ OC.L10N.register(
     "Saved" : "저장됨",
     "test email settings" : "이메일 설정 시험",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "이메일을 보내는 중 오류가 발생했습니다. 설정을 확인하십시오.(오류: %s)",
-    "Email sent" : "이메일 발송됨",
+    "Email sent" : "이메일 보냄",
     "You need to set your user email before being able to send test emails." : "테스트 이메일을 보내기 전 내 주소를 설정해야 합니다.",
     "Invalid mail address" : "잘못된 이메일 주소",
     "A user with that name already exists." : "같은 이름의 사용자가 이미 존재합니다.",
@@ -50,40 +32,50 @@ OC.L10N.register(
     "Forbidden" : "거부됨",
     "Invalid user" : "잘못된 사용자",
     "Unable to change mail address" : "이메일 주소를 변경할 수 없음",
-    "Email saved" : "이메일 저장됨",
     "Your full name has been changed." : "전체 이름이 변경되었습니다.",
     "Unable to change full name" : "전체 이름을 변경할 수 없음",
-    "Are you really sure you want add \"{domain}\" as trusted domain?" : "신뢰할 수 있는 도메인 목록에 \"{domain}\"을(를) 추가하시겠습니까?",
-    "Add trusted domain" : "신뢰할 수 있는 도메인 추가",
-    "Migration in progress. Please wait until the migration is finished" : "이전 작업 중입니다. 작업이 완료될 때까지 기다려 주십시오",
-    "Migration started …" : "이전 시작됨...",
-    "Sending..." : "보내는 중...",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "__language_name__" : "한국어",
+    "Language changed" : "언어가 변경됨",
+    "Invalid request" : "잘못된 요청",
+    "Admins can't remove themself from the admin group" : "관리자 자신을 관리자 그룹에서 삭제할 수 없음",
+    "Unknown user" : "알려지지 않은 사용자",
+    "Couldn't remove app." : "앱을 삭제할 수 없습니다.",
     "Official" : "공식",
     "Approved" : "승인됨",
-    "Experimental" : "실험적",
     "All" : "모두",
+    "Enabled" : "활성",
+    "Not enabled" : "비활성",
     "No apps found for your version" : "설치된 버전에 대한 앱 없음",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "공식 앱은 ownCloud 커뮤니티 내에서 개발됩니다. ownCloud의 주요 기능을 제공하며 상용 환경에서 사용 가능합니다.",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "승인된 앱은 신뢰할 수 있는 개발자가 개발하며 보안 검사를 통과했습니다. 열린 코드 저장소에서 관리되며 일반적인 환경에서 사용할 수 있는 수준으로 관리됩니다.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "이 앱의 보안 문제가 점검되지 않았고, 출시된 지 얼마 지나지 않았거나 아직 불안정합니다. 본인 책임 하에 설치하십시오.",
-    "Update to %s" : "%s(으)로 업데이트",
     "Please wait...." : "기다려 주십시오....",
     "Error while disabling app" : "앱을 비활성화하는 중 오류 발생",
     "Disable" : "사용 안함",
     "Enable" : "사용함",
     "Error while enabling app" : "앱을 활성화하는 중 오류 발생",
+    "Error: this app cannot be enabled because it makes the server unstable" : "오류: 이 앱은 서버를 불안정하게 만들 수 있어서 활성화할 수 없습니다",
+    "Error: could not disable broken app" : "오류: 망가진 앱을 비활성화할 수 없음",
+    "Error while disabling broken app" : "망가진 앱을 비활성화 하는 중 오류 발생",
     "Updating...." : "업데이트 중....",
     "Error while updating app" : "앱을 업데이트하는 중 오류 발생",
     "Updated" : "업데이트됨",
-    "Uninstalling ...." : "제거 하는 중 ....",
+    "Uninstalling ...." : "제거하는 중 ....",
     "Error while uninstalling app" : "앱을 제거하는 중 오류 발생",
     "Uninstall" : "제거",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "앱이 활성화되었지만, 앱을 업데이트해야 합니다. 5초 후 앱 업데이트 페이지로 넘어갑니다.",
     "App update" : "앱 업데이트",
-    "No apps found for \"{query}\"" : "\"{query}\"에 해당하는 앱을 찾을 수 없음",
+    "Experimental" : "실험적",
+    "Are you really sure you want add \"{domain}\" as trusted domain?" : "신뢰할 수 있는 도메인 목록에 \"{domain}\"을(를) 추가하시겠습니까?",
+    "Add trusted domain" : "신뢰할 수 있는 도메인 추가",
+    "Migration in progress. Please wait until the migration is finished" : "이전 작업 중입니다. 작업이 완료될 때까지 기다려 주십시오",
+    "Migration started …" : "이전 시작됨...",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "오류가 발생했습니다. ASCII로 인코딩된 PEM 인증서를 업로드하십시오.",
     "Valid until {date}" : "{date}까지 유효함",
     "Delete" : "삭제",
+    "Sending..." : "보내는 중...",
     "An error occurred: {message}" : "오류 발생: {message}",
     "Select a profile picture" : "프로필 사진 선택",
     "Very weak password" : "매우 약한 암호",
@@ -93,68 +85,57 @@ OC.L10N.register(
     "Strong password" : "강력한 암호",
     "Groups" : "그룹",
     "Unable to delete {objName}" : "{objName}을(를) 삭제할 수 없음",
+    "Error creating group: {message}" : "그룹 생성 오류: {message}",
     "A valid group name must be provided" : "올바른 그룹 이름을 입력해야 함",
     "deleted {groupName}" : "{groupName} 삭제됨",
     "undo" : "실행 취소",
-    "no group" : "그룹 없음",
     "never" : "없음",
     "deleted {userName}" : "{userName} 삭제됨",
     "add group" : "그룹 추가",
-    "Changing the password will result in data loss, because data recovery is not available for this user" : "이 사용자에 대해 데이터 복구를 사용할 수 없기 때문에, 암호를 변경하면 데이터를 잃게 됩니다.",
+    "enabled" : "활성화됨",
+    "disabled" : "비활성화됨",
+    "no group" : "그룹 없음",
+    "Changing the password will result in data loss, because data recovery is not available for this user" : "이 사용자의 데이터를 복구할 수 없기 때문에, 암호를 변경하면 데이터가 손실됨",
     "A valid username must be provided" : "올바른 사용자 이름을 입력해야 함",
+    "Error creating user: {message}" : "사용자 생성 오류: {message}",
     "A valid password must be provided" : "올바른 암호를 입력해야 함",
     "A valid email must be provided" : "올바른 이메일 주소를 입력해야 함",
-    "__language_name__" : "한국어",
-    "Personal info" : "개인 정보",
-    "Sync clients" : "동기화 클라이언트",
-    "Everything (fatal issues, errors, warnings, info, debug)" : "모두 (치명적 문제, 오류, 경고, 정보, 디버그)",
-    "Info, warnings, errors and fatal issues" : "정보, 경고, 오류, 치명적 문제",
-    "Warnings, errors and fatal issues" : "경고, 오류, 치명적 문제",
-    "Errors and fatal issues" : "오류, 치명적 문제",
-    "Fatal issues only" : "치명적 문제만",
-    "None" : "없음",
-    "Login" : "로그인",
-    "Plain" : "일반",
-    "NT LAN Manager" : "NT LAN 관리자",
-    "SSL" : "SSL",
-    "TLS" : "TLS",
-    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php가 시스템 환경 변수를 올바르게 조회할 수 있도록 설정되지 않았습니다. getenv(\"PATH\")의 값이 비어 있습니다.",
-    "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "<a target=\"_blank\" href=\"%s\">설치 문서↗</a>를 참조하여 php 설정 방법 및 php 설정을 변경하십시오. php-fpm을 사용한다면 더 주의하십시오.",
-    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "읽기 전용 설정이 활성화되었습니다. 이 상태에서는 웹 인터페이스를 통하여 일부 설정을 변경할 수 없습니다. 또한 매 업데이트마다 파일을 쓸 수 있는 상태로 변경해야 합니다.",
-    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP에서 인라인 doc 블록을 삭제하도록 설정되어 있습니다. 일부 코어 앱에 접근할 수 없을 수도 있습니다.",
-    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Zend OPcache, eAccelerator 같은 캐시/가속기 문제일 수도 있습니다.",
-    "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "서버가 Microsoft Windows 환경에서 동작하고 있습니다. 최적의 사용자 경험을 위해서는 리눅스를 사용할 것을 권장합니다.",
-    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP 모듈 'fileinfo'가 존재하지 않습니다. MIME 형식 감지 결과를 향상시키기 위하여 이 모듈을 활성화하는 것을 추천합니다.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "트랜잭션 기반 파일 잠금이 비활성화되어 있으며, 경쟁 상태 문제가 발생할 수 있습니다. config.php에서 'filelocking.enabled'를 활성화하면 본 문제를 해결할 수 있습니다. 더 많은 정보를 보려면 <a target=\"_blank\" href=\"%s\">문서 ↗</a>를 참고하십시오.",
-    "System locale can not be set to a one which supports UTF-8." : "UTF-8을 지원하는 시스템 로캘을 사용할 수 없습니다.",
-    "This means that there might be problems with certain characters in file names." : "파일 이름의 일부 문자에 문제가 생길 수도 있습니다.",
-    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "다음 중 하나 이상의 로캘을 지원하기 위하여 필요한 패키지를 시스템에 설치하는 것을 추천합니다: %s.",
-    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "도메인의 루트 디렉터리 아래에 설치되어 있지 않고 시스템 cron을 사용한다면 URL 생성에 문제가 발생할 수도 있습니다. 이 문제를 해결하려면 설치본의 웹 루트 경로에 있는 config.php 파일의 \"overwrite.cli.url\" 옵션을 변경하십시오(제안: \"%s\")",
-    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "CLI로 cronjob을 실행할 수 없었습니다. 다음 기술적 오류가 발생했습니다:",
-    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "<a target=\"_blank\" href=\"%s\">설치 가이드 ↗</a>를 다시 확인하시고 <a href=\"#log-section\">로그</a>의 오류 및 경고를 확인하십시오.",
-    "All checks passed." : "모든 검사를 통과했습니다.",
-    "Open documentation" : "문서 열기",
-    "Allow apps to use the Share API" : "앱에서 공유 API를 사용할 수 있도록 허용",
-    "Allow users to share via link" : "사용자별 링크 공유 허용",
-    "Enforce password protection" : "암호 보호 강제",
-    "Allow public uploads" : "공개 업로드 허용",
-    "Allow users to send mail notification for shared files" : "공유 파일 이메일 알림 전송 허용",
-    "Set default expiration date" : "기본 만료 날짜 설정",
-    "Expire after " : "다음 날짜 후 만료",
-    "days" : "일",
-    "Enforce expiration date" : "만료 날짜 강제",
-    "Allow resharing" : "재공유 허용",
-    "Restrict users to only share with users in their groups" : "그룹 내 사용자끼리만 공유할 수 있도록 허용",
-    "Allow users to send mail notification for shared files to other users" : "다른 사용자에게 공유 파일 이메일 알림 전송 허용",
-    "Exclude groups from sharing" : "공유에서 그룹 제외",
-    "These groups will still be able to receive shares, but not to initiate them." : "이 그룹의 사용자들은 다른 사용자가 공유한 파일을 받을 수는 있지만, 자기 파일을 공유할 수는 없습니다.",
-    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "공유 대화 상자에서 사용자 이름 자동 완성을 사용합니다. 이 설정을 사용하지 않으면 전체 사용자 이름을 입력해야 합니다.",
+    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "안녕하세요.<br><br>%s 계정을 사용할 수 있음을 알려 드립니다.<br><br>사용자 이름: %s<br>접근 링크: <a href=\"%s\">%s</a><br><br>",
+    "Cheers!" : "감사합니다!",
+    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "안녕하세요.\n\n%s 계정을 사용할 수 있음을 알려 드립니다.\n\n사용자 이름: %s\n접근 링크: %s\n\n",
+    "User documentation" : "사용자 문서",
+    "Administrator documentation" : "관리자 문서",
+    "Online documentation" : "온라인 문서",
+    "Forum" : "포럼",
+    "Issue tracker" : "이슈 트래커",
+    "Commercial support" : "상용 지원",
+    "Developer documentation" : "개발자 문서",
+    "by %s" : "%s 개발",
+    "Documentation:" : "문서:",
+    "Admin documentation" : "관리 문서",
+    "Report a bug" : "버그 보고",
+    "Show description …" : "설명 보기 …",
+    "Hide description …" : "설명 숨기기 …",
+    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "이 앱 개발자가 최대 ownCloud 버전을 지정하지 않았습니다. ownCloud 11 이후 버전에서 오류가 발생할 것입니다.",
+    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "이 앱 개발자가 최소 ownCloud 버전을 지정하지 않았습니다. ownCloud 11 이후 버전에서 오류가 발생할 것입니다.",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "다음 의존성을 만족할 수 없기 때문에 이 앱을 설치할 수 없습니다:",
+    "Enable only for specific groups" : "특정 그룹에만 허용",
+    "Uninstall App" : "앱 제거",
+    "Cron" : "Cron",
     "Last cron job execution: %s." : "마지막 cron 작업 실행: %s.",
     "Last cron job execution: %s. Something seems wrong." : "마지막 cron 작업 실행: %s. 문제가 발생한 것 같습니다.",
     "Cron was not executed yet!" : "Cron이 실행되지 않았습니다!",
+    "Open documentation" : "문서 열기",
     "Execute one task with each page loaded" : "개별 페이지를 불러올 때마다 실행",
     "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php는 webcron 서비스에 등록되어 HTTP로 15분마다 cron.php에 접근합니다.",
     "Use system's cron service to call the cron.php file every 15 minutes." : "시스템의 cron 서비스를 통하여 15분마다 cron.php 파일을 실행합니다.",
+    "SSL Root Certificates" : "SSL 루트 인증서",
+    "Common Name" : "공통 이름",
+    "Valid until" : "만료 기간:",
+    "Issued By" : "발급자:",
+    "Valid until %s" : "%s까지 유효함",
+    "Import root certificate" : "루트 인증서 가져오기",
+    "Server-side encryption" : "서버 측 암호화",
     "Enable server-side encryption" : "서버 측 암호화 사용",
     "Please read carefully before activating server-side encryption: " : "서버 측 암호화를 활성화하기 전에 읽어 보십시오:",
     "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "암호화를 사용하면, 사용하기 시작한 시간 이후에 서버에 업로드된 모든 파일이 암호화됩니다. 나중에 암호화를 사용하지 않으려면 사용하고 있는 암호화 모듈에서 비활성화를 지원해야 하고 모든 사전 조건(예: 복구 키 설정)을 만족해야 합니다.",
@@ -168,7 +149,38 @@ OC.L10N.register(
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "과거에 사용하였던(ownCloud <= 8.0) 암호화된 데이터에서 키를 이전해야 합니다. \"기본 암호화 모듈\"을 활성화한 다음 'occ encryption:migrate'를 실행하십시오",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "ownCloud 8.0 이하에서 사용한 이전 암호화 키를 새 키로 이전해야 합니다.",
     "Start migration" : "이전 시작",
-    "This is used for sending out notifications." : "알림을 보낼 때 사용됩니다.",
+    "Sharing" : "공유",
+    "Allow apps to use the Share API" : "앱에서 공유 API를 사용할 수 있도록 허용",
+    "Allow users to share via link" : "사용자별 링크 공유 허용",
+    "Allow public uploads" : "공개 업로드 허용",
+    "Enforce password protection" : "암호 보호 강제",
+    "Set default expiration date" : "기본 만료 날짜 설정",
+    "Allow users to send mail notification for shared files" : "공유 파일 이메일 알림 전송 허용",
+    "Expire after " : "다음 날짜 후 만료",
+    "days" : "일",
+    "Enforce expiration date" : "만료 날짜 강제",
+    "Allow resharing" : "재공유 허용",
+    "Restrict users to only share with users in their groups" : "그룹 내 사용자끼리만 공유할 수 있도록 허용",
+    "Allow users to send mail notification for shared files to other users" : "다른 사용자에게 공유 파일 이메일 알림 전송 허용",
+    "Exclude groups from sharing" : "공유에서 그룹 제외",
+    "These groups will still be able to receive shares, but not to initiate them." : "이 그룹의 사용자들은 다른 사용자가 공유한 파일을 받을 수는 있지만, 자기 파일을 공유할 수는 없습니다.",
+    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "공유 대화 상자에서 사용자 이름 자동 완성을 사용합니다. 이 설정을 사용하지 않으면 전체 사용자 이름을 입력해야 합니다.",
+    "Everything (fatal issues, errors, warnings, info, debug)" : "모두 (치명적 문제, 오류, 경고, 정보, 디버그)",
+    "Info, warnings, errors and fatal issues" : "정보, 경고, 오류, 치명적 문제",
+    "Warnings, errors and fatal issues" : "경고, 오류, 치명적 문제",
+    "Errors and fatal issues" : "오류, 치명적 문제",
+    "Fatal issues only" : "치명적 문제만",
+    "Log" : "로그",
+    "What to log" : "남길 로그",
+    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "로그 파일이 100MB보다 큽니다. 다운로드하는 데 시간이 걸릴 수 있습니다!",
+    "None" : "없음",
+    "Login" : "로그인",
+    "Plain" : "일반",
+    "NT LAN Manager" : "NT LAN 관리자",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "Email server" : "이메일 서버",
+    "This is used for sending out notifications." : "알림을 보낼 때 사용합니다.",
     "Send mode" : "보내기 모드",
     "Encryption" : "암호화",
     "From address" : "보낸 사람 주소",
@@ -183,55 +195,45 @@ OC.L10N.register(
     "Store credentials" : "인증 정보 저장",
     "Test email settings" : "이메일 설정 시험",
     "Send email" : "이메일 보내기",
-    "Download logfile" : "로그 파일 다운로드",
-    "More" : "더 중요함",
-    "Less" : "덜 중요함",
-    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "로그 파일이 100MB보다 큽니다. 다운로드하는 데 시간이 걸릴 수 있습니다!",
-    "What to log" : "남길 로그",
+    "Security & setup warnings" : "보안 및 설치 경고",
+    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php가 시스템 환경 변수를 올바르게 조회할 수 있도록 설정되지 않았습니다. getenv(\"PATH\")의 값이 비어 있습니다.",
+    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "읽기 전용 설정이 활성화되었습니다. 이 상태에서는 웹 인터페이스를 통하여 일부 설정을 변경할 수 없습니다. 또한 매 업데이트마다 파일을 쓸 수 있는 상태로 변경해야 합니다.",
+    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP에서 인라인 doc 블록을 삭제하도록 설정되어 있습니다. 일부 코어 앱에 접근할 수 없을 수도 있습니다.",
+    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Zend OPcache, eAccelerator 같은 캐시/가속기 문제일 수도 있습니다.",
+    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP의 'fileinfo' 모듈이 없습니다. 올바른 MIME 형식 감지를 위해서 이 모듈을 활성화하는 것을 추천합니다.",
+    "System locale can not be set to a one which supports UTF-8." : "UTF-8을 지원하는 시스템 로캘을 사용할 수 없습니다.",
+    "This means that there might be problems with certain characters in file names." : "파일 이름의 일부 문자에 문제가 생길 수도 있습니다.",
+    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "다음 중 하나 이상의 로캘을 지원하기 위하여 필요한 패키지를 시스템에 설치하는 것을 추천합니다: %s.",
+    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "도메인의 루트 디렉터리 아래에 설치되어 있지 않고 시스템 cron을 사용한다면 URL 생성에 문제가 발생할 수도 있습니다. 이 문제를 해결하려면 설치본의 웹 루트 경로에 있는 config.php 파일의 \"overwrite.cli.url\" 옵션을 변경하십시오(제안: \"%s\")",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "데이터베이스로 SQLite를 사용하고 있습니다. 대규모의 파일을 관리하려고 한다면 다른 데이터베이스 백엔드로 전환할 것을 권장합니다.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "특히 파일 동기화를 위해 데스크톱 클라이언트를 사용할 예정이면, SQLite를 사용하지 않는 것이 좋습니다.",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "다른 데이터베이스로 이전하려면 다음 명령을 사용하십시오: 'occ db:convert-type' 다른 명령을 알아보려면 <a target=\"_blank\" href=\"%s\">문서 ↗</a>를 참고하십시오.",
+    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "CLI로 cronjob을 실행할 수 없었습니다. 다음 기술적 오류가 발생했습니다:",
+    "All checks passed." : "모든 검사를 통과했습니다.",
+    "Tips & tricks" : "팁과 추가 정보",
     "How to do backups" : "백업 방법",
     "Advanced monitoring" : "고급 모니터링",
     "Performance tuning" : "성능 튜닝",
     "Improving the config.php" : "config.php 개선",
     "Theming" : "테마 꾸미기",
     "Hardening and security guidance" : "보안 강화 지침",
-    "Version" : "버전",
-    "Developer documentation" : "개발자 문서",
-    "Experimental applications ahead" : "실험적인 앱 사용 예정",
-    "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "실험적인 앱은 보안 문제 검사를 통과하지 않았으며, 아직 새롭거나, 불안정하거나, 개발 중일 수도 있습니다. 이러한 앱을 설치하면 데이터 손실 및 보안 문제가 발생할 수도 있습니다.",
-    "Documentation:" : "문서:",
-    "User documentation" : "사용자 문서",
-    "Admin documentation" : "관리 문서",
-    "Show description …" : "설명 보기...",
-    "Hide description …" : "설명 숨기기...",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "다음 의존성을 만족할 수 없기 때문에 이 앱을 설치할 수 없습니다:",
-    "Enable only for specific groups" : "특정 그룹에만 허용",
-    "Uninstall App" : "앱 제거",
-    "Enable experimental apps" : "실험적인 앱 사용",
-    "Common Name" : "공통 이름",
-    "Valid until" : "만료 기간:",
-    "Issued By" : "발급자:",
-    "Valid until %s" : "%s까지 유효함",
-    "Import root certificate" : "루트 인증서 가져오기",
-    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "안녕하세요.<br><br>%s 계정을 사용할 수 있음을 알려 드립니다.<br><br>사용자 이름: %s<br>접근 링크: <a href=\"%s\">%s</a><br><br>",
-    "Cheers!" : "감사합니다!",
-    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "안녕하세요.\n\n%s 계정을 사용할 수 있음을 알려 드립니다.\n\n사용자 이름: %s\n접근 링크: %s\n\n",
-    "Administrator documentation" : "관리자 문서",
-    "Online documentation" : "온라인 문서",
-    "Forum" : "포럼",
-    "Issue tracker" : "이슈 트래커",
-    "Commercial support" : "상용 지원",
-    "You are using <strong>%s</strong> of <strong>%s</strong>" : "현재 <strong>%s</strong> / <strong>%s</strong>을(를) 사용중입니다.",
+    "Get the apps to sync your files" : "파일 동기화 앱 가져오기",
+    "Desktop client" : "데스크톱 클라이언트",
+    "Android app" : "Android 앱",
+    "iOS app" : "iOS 앱",
+    "Show First Run Wizard again" : "첫 실행 마법사 다시 보이기",
     "Profile picture" : "프로필 사진",
     "Upload new" : "새로 업로드",
+    "Select from Files" : "파일에서 선택",
     "Remove image" : "그림 삭제",
+    "png or jpg, max. 20 MB" : "PNG, JPG, 최대 20MB",
+    "Picture provided by original account" : "원래 계정에서 제공하는 사진",
     "Cancel" : "취소",
+    "Choose as profile picture" : "프로필 사진으로 선택",
     "Full name" : "전체 이름",
     "No display name set" : "표시 이름이 설정되지 않음",
     "Email" : "이메일",
     "Your email address" : "이메일 주소",
+    "For password recovery and notifications" : "암호 복구와 알림에 사용",
     "No email address set" : "이메일 주소가 설정되지 않음",
     "You are member of the following groups:" : "다음 그룹의 구성원입니다:",
     "Password" : "암호",
@@ -241,19 +243,20 @@ OC.L10N.register(
     "Change password" : "암호 변경",
     "Language" : "언어",
     "Help translate" : "번역 돕기",
-    "Get the apps to sync your files" : "파일 동기화 앱 가져오기",
-    "Desktop client" : "데스크톱 클라이언트",
-    "Android app" : "Android 앱",
-    "iOS app" : "iOS 앱",
-    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "프로젝트를 지원하려면\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">개발에 참여하거나</a>\n\t\t\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">널리 알려 주십시오</a>!",
-    "Show First Run Wizard again" : "첫 실행 마법사 다시 보이기",
+    "Unlimited" : "무제한",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "{communityopen}ownCloud 커뮤니티{linkclose}에서 개발함. {githubopen}원본 코드{linkclose}는 {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose} 라이선스로 배포됩니다.",
+    "Name" : "이름",
+    "Username" : "사용자 이름",
+    "Done" : "완료",
+    "Version" : "버전",
+    "Personal" : "개인",
+    "Admin" : "관리자",
+    "Error" : "오류",
     "Show storage location" : "저장소 위치 보이기",
     "Show last log in" : "마지막 로그인 시간 보이기",
     "Show user backend" : "사용자 백엔드 보이기",
     "Send email to new user" : "새 사용자에게 이메일 보내기",
     "Show email address" : "이메일 주소 보이기",
-    "Username" : "사용자 이름",
     "E-Mail" : "이메일",
     "Create" : "만들기",
     "Admin Recovery Password" : "관리자 복구 암호",
@@ -264,7 +267,6 @@ OC.L10N.register(
     "Admins" : "관리자",
     "Default Quota" : "기본 할당량",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "저장소 할당량을 입력하십시오 (예: \"512 MB\", \"12 GB\")",
-    "Unlimited" : "무제한",
     "Other" : "기타",
     "Full Name" : "전체 이름",
     "Group Admin for" : "다음 그룹의 관리자:",
