@@ -4,12 +4,10 @@ OC.L10N.register(
     "Wrong password" : "Nesprávne heslo",
     "No user supplied" : "Nebol uvedený používateľ",
     "Authentication error" : "Chyba autentifikácie",
-    "Please provide an admin recovery password, otherwise all user data will be lost" : "Zadajte administrátorské heslo pre obnovu, inak budú všetky dáta stratené",
     "Wrong admin recovery password. Please check the password and try again." : "Chybné administrátorské heslo pre obnovu. Skontrolujte správnosť hesla a skúste to znovu.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Backend nepodporuje zmenu hesla, ale šifrovací kľúč používateľa bol úspešne zmenený.",
     "Unable to change password" : "Zmena hesla sa nepodarila",
-    "Enabled" : "Povolené",
-    "Not enabled" : "Zakázané",
+    "Couldn't send reset email. Please contact your administrator." : "Nemožno poslať email pre obnovu. Kontaktujte prosím vášho administrátora.",
     "Federated Cloud Sharing" : "Združené cloudové zdieľanie",
     "A problem occurred, please check your log files (Error: %s)" : "Nastala chyba, skontrolujte prosím váš log súbor (Chyba: %s)",
     "Migration Completed" : "Migrácia ukončená",
@@ -30,38 +28,22 @@ OC.L10N.register(
     "Forbidden" : "Zakázané",
     "Invalid user" : "Neplatný používateľ",
     "Unable to change mail address" : "Nemožno zmeniť emailovú adresu",
-    "Email saved" : "Email uložený",
     "Your full name has been changed." : "Vaše meno a priezvisko bolo zmenené.",
     "Unable to change full name" : "Nemožno zmeniť meno a priezvisko",
     "APCu" : "APCu",
     "Redis" : "Redis",
-    "Security & setup warnings" : "Bezpečnosť a nastavenia upozornení",
-    "Sharing" : "Zdieľanie",
-    "Server-side encryption" : "Šifrovanie na serveri",
-    "External Storage" : "Externé úložisko",
-    "Cron" : "Cron",
-    "Email server" : "Email server",
-    "Log" : "Záznam",
-    "Tips & tricks" : "Tipy a triky",
-    "Updates" : "Aktualizácie",
-    "Couldn't remove app." : "Nemožno odstrániť aplikáciu.",
+    "__language_name__" : "Slovensky",
     "Language changed" : "Jazyk zmenený",
     "Invalid request" : "Neplatná požiadavka",
     "Admins can't remove themself from the admin group" : "Administrátori nesmú odstrániť sami seba zo skupiny admin",
-    "Unable to add user to group %s" : "Nie je možné pridať používateľa do skupiny %s",
-    "Unable to remove user from group %s" : "Nie je možné odstrániť používateľa zo skupiny %s",
-    "Couldn't update app." : "Nemožno aktualizovať aplikáciu.",
-    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Ste si istí, že chcete pridať \"{domain}\" medzi dôveryhodné domény?",
-    "Add trusted domain" : "Pridať dôveryhodnú doménu",
-    "Migration in progress. Please wait until the migration is finished" : "Prebieha migrácia. Počkajte prosím, kým sa skončí",
-    "Migration started …" : "Migrácia spustená ...",
-    "Sending..." : "Odosielam...",
+    "Unknown user" : "Neznámy používateľ",
+    "Couldn't remove app." : "Nemožno odstrániť aplikáciu.",
     "Official" : "Oficiálny",
     "Approved" : "Schválené",
-    "Experimental" : "Experimentálny",
     "All" : "Všetky",
+    "Enabled" : "Povolené",
+    "Not enabled" : "Zakázané",
     "No apps found for your version" : "Aplikácie pre vašu verziu sa nenašli",
-    "Update to %s" : "Aktualizovať na %s",
     "Please wait...." : "Čakajte prosím...",
     "Error while disabling app" : "Chyba pri zakázaní aplikácie",
     "Disable" : "Zakázať",
@@ -73,8 +55,14 @@ OC.L10N.register(
     "Uninstalling ...." : "Prebieha odinštalovanie...",
     "Error while uninstalling app" : "Chyba pri odinštalovaní aplikácie",
     "Uninstall" : "Odinštalácia",
+    "Experimental" : "Experimentálny",
+    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Ste si istí, že chcete pridať \"{domain}\" medzi dôveryhodné domény?",
+    "Add trusted domain" : "Pridať dôveryhodnú doménu",
+    "Migration in progress. Please wait until the migration is finished" : "Prebieha migrácia. Počkajte prosím, kým sa skončí",
+    "Migration started …" : "Migrácia spustená ...",
     "Valid until {date}" : "Platný do {date}",
     "Delete" : "Zmazať",
+    "Sending..." : "Odosielam...",
     "Select a profile picture" : "Vybrať avatara",
     "Very weak password" : "Veľmi slabé heslo",
     "Weak password" : "Slabé heslo",
@@ -86,39 +74,52 @@ OC.L10N.register(
     "A valid group name must be provided" : "Musíte zadať platný názov skupiny",
     "deleted {groupName}" : "vymazaná {groupName}",
     "undo" : "vrátiť",
-    "no group" : "nie je v skupine",
     "never" : "nikdy",
     "deleted {userName}" : "vymazané {userName}",
     "add group" : "pridať skupinu",
+    "enabled" : "zapnuté",
+    "disabled" : "vypnuté",
+    "no group" : "nie je v skupine",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "Zmena hesla bude mať za následok stratu dát, pretože obnova dát nie je k dispozícii pre tohto používateľa",
     "A valid username must be provided" : "Musíte zadať platné používateľské meno",
     "A valid password must be provided" : "Musíte zadať platné heslo",
     "A valid email must be provided" : "Musíte zadať platnú emailovú adresu",
-    "__language_name__" : "Slovensky",
-    "Unlimited" : "Nelimitované",
-    "Personal info" : "Osobné informácie",
-    "Sync clients" : "Klienti synchronizácie",
-    "Everything (fatal issues, errors, warnings, info, debug)" : "Všetko (fatálne problémy, chyby, upozornenia, info, debug)",
-    "Info, warnings, errors and fatal issues" : "Info, upozornenia, chyby a fatálne problémy",
-    "Warnings, errors and fatal issues" : "Upozornenia, chyby a fatálne problémy",
-    "Errors and fatal issues" : "Chyby a fatálne problémy",
-    "Fatal issues only" : "Len fatálne problémy",
-    "None" : "Žiadny",
-    "Login" : "Prihlásenie",
-    "Plain" : "Neformátovaný",
-    "NT LAN Manager" : "NT LAN Manager",
-    "SSL" : "SSL",
-    "TLS" : "TLS",
-    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Konfigurácia je nastavená len na čítanie. Toto znemožňuje urobiť niektoré nastavenia prostredníctvom webového rozhrania. Okrem toho, súbor musí byť zapisovanie ručne povolené pre každú aktualizáciu.",
-    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP je zjavne nastavené, aby odstraňovalo bloky vloženej dokumentácie. To zneprístupní niekoľko základných aplikácií.",
-    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "To je pravdepodobne spôsobené cache/akcelerátorom ako napr. Zend OPcache alebo eAccelerator.",
-    "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Server je spustený s Microsoft Windows. Pre optimálne používanie odporúčame Linux.",
-    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Chýba modul 'fileinfo'. Dôrazne doporučujeme ho povoliť pre dosiahnutie najlepších výsledkov zisťovania mime-typu.",
-    "System locale can not be set to a one which supports UTF-8." : "Nie je možné nastaviť znakovú sadu, ktorá podporuje UTF-8.",
-    "This means that there might be problems with certain characters in file names." : "To znamená, že sa môžu vyskytnúť problémy s niektorými znakmi v názvoch súborov.",
-    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Dôrazne doporučujeme nainštalovať na váš systém požadované balíčky podporujúce jednu z nasledovných znakových sád: %s.",
-    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Inštalácia mimo koreňový priečinok domény a používanie systémového príkazu cron môže spôsobiť problém s generovaním správnej URL. Pre zabránenie týmto chybám nastavte prosím správnu cestu v svojom config.php súbore pre hodnotu \"overwrite.cli.url\" (Doporučujeme: \"%s\")",
+    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Dobrý deň,<br><br>toto je oznámenie o novo vytvorenom účte %s.<br><br>Vaše používateľské meno: %s<br>Prihlásiť sa môžete tu: <a href=\"%s\">%s</a><br><br>",
+    "Cheers!" : "Pekný deň!",
+    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Ahoj,\n\ntoto je oznámenie o novo vytvorenom účte %s.\n\nVaše používateľské meno: %s\nPrihlásiť sa môžete tu: %s\n\n",
+    "User documentation" : "Príručka používateľa",
+    "Administrator documentation" : "Príručka administrátora",
+    "Online documentation" : "Online príručka",
+    "Forum" : "Fórum",
+    "Issue tracker" : "Zoznam chýb",
+    "Commercial support" : "Komerčná podpora",
+    "Developer documentation" : "Dokumentácia vývojára",
+    "Documentation:" : "Dokumentácia:",
+    "Admin documentation" : "Príručka administrátora",
+    "Show description …" : "Zobraziť popis …",
+    "Hide description …" : "Skryť popis …",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "Túto aplikáciu nemožno nainštalovať, pretože nie sú splnené nasledovné závislosti:",
+    "Enable only for specific groups" : "Povoliť len pre vybrané skupiny",
+    "Uninstall App" : "Odinštalovanie aplikácie",
+    "Cron" : "Cron",
+    "Last cron job execution: %s." : "Posledný cron prebehol: %s.",
+    "Last cron job execution: %s. Something seems wrong." : "Posledný cron prebehol: %s. Zdá sa, že niečo nie je vporiadku.",
+    "Cron was not executed yet!" : "Cron sa ešte nespustil!",
     "Open documentation" : "Otvoriť dokumentáciu",
+    "Execute one task with each page loaded" : "Vykonať jednu úlohu s každým načítaní stránky",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php je zaregistrovaná v službe WebCron a zavolá cron.php každých 15 minút cez http.",
+    "Use system's cron service to call the cron.php file every 15 minutes." : "Použiť systémovú službu cron na spúšťanie súboru cron.php každých 15 minút.",
+    "Common Name" : "Bežný názov",
+    "Valid until" : "Platný do",
+    "Issued By" : "Vydal",
+    "Valid until %s" : "Platný do %s",
+    "Import root certificate" : "Importovať koreňový certifikát",
+    "Server-side encryption" : "Šifrovanie na serveri",
+    "Enable server-side encryption" : "Povoliť šifrovanie na serveri",
+    "Enable encryption" : "Povoliť šifrovanie",
+    "Select default encryption module:" : "Vybrať predvolený šifrovací modul:",
+    "Start migration" : "Začať migráciu",
+    "Sharing" : "Zdieľanie",
     "Allow apps to use the Share API" : "Povoliť aplikáciám používať API na zdieľanie",
     "Allow users to share via link" : "Povoliť používateľom zdieľanie pomocou odkazov",
     "Allow public uploads" : "Povoliť verejné nahrávanie súborov",
@@ -133,16 +134,20 @@ OC.L10N.register(
     "Allow users to send mail notification for shared files to other users" : "Povoliť používateľom zasielať emailom oznámenie o zdieľaní súborov ostatným používateľom",
     "Exclude groups from sharing" : "Vybrať skupiny zo zdieľania",
     "These groups will still be able to receive shares, but not to initiate them." : "Tieto skupiny budú môcť stále zdieľať, ale sami nemôžu zdieľať ostatným.",
-    "Last cron job execution: %s." : "Posledný cron prebehol: %s.",
-    "Last cron job execution: %s. Something seems wrong." : "Posledný cron prebehol: %s. Zdá sa, že niečo nie je vporiadku.",
-    "Cron was not executed yet!" : "Cron sa ešte nespustil!",
-    "Execute one task with each page loaded" : "Vykonať jednu úlohu s každým načítaní stránky",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php je zaregistrovaná v službe WebCron a zavolá cron.php každých 15 minút cez http.",
-    "Use system's cron service to call the cron.php file every 15 minutes." : "Použiť systémovú službu cron na spúšťanie súboru cron.php každých 15 minút.",
-    "Enable server-side encryption" : "Povoliť šifrovanie na serveri",
-    "Enable encryption" : "Povoliť šifrovanie",
-    "Select default encryption module:" : "Vybrať predvolený šifrovací modul:",
-    "Start migration" : "Začať migráciu",
+    "Everything (fatal issues, errors, warnings, info, debug)" : "Všetko (fatálne problémy, chyby, upozornenia, info, debug)",
+    "Info, warnings, errors and fatal issues" : "Info, upozornenia, chyby a fatálne problémy",
+    "Warnings, errors and fatal issues" : "Upozornenia, chyby a fatálne problémy",
+    "Errors and fatal issues" : "Chyby a fatálne problémy",
+    "Fatal issues only" : "Len fatálne problémy",
+    "Log" : "Záznam",
+    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Súbor protokolu je väčší ako 100 MB. Jeho sťahovanie môže chvíľu trvať!",
+    "None" : "Žiadny",
+    "Login" : "Prihlásenie",
+    "Plain" : "Neformátovaný",
+    "NT LAN Manager" : "NT LAN Manager",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "Email server" : "Email server",
     "This is used for sending out notifications." : "Používa sa na odosielanie upozornení.",
     "Send mode" : "Mód odosielania",
     "Encryption" : "Šifrovanie",
@@ -158,44 +163,29 @@ OC.L10N.register(
     "Store credentials" : "Ukladať prihlasovacie údaje",
     "Test email settings" : "Nastavenia testovacieho emailu",
     "Send email" : "Odoslať email",
-    "Download logfile" : "Stiahnuť súbor logu",
-    "More" : "Viac",
-    "Less" : "Menej",
-    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Súbor protokolu je väčší ako 100 MB. Jeho sťahovanie môže chvíľu trvať!",
+    "Security & setup warnings" : "Bezpečnosť a nastavenia upozornení",
+    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Konfigurácia je nastavená len na čítanie. Toto znemožňuje urobiť niektoré nastavenia prostredníctvom webového rozhrania. Okrem toho, súbor musí byť zapisovanie ručne povolené pre každú aktualizáciu.",
+    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP je zjavne nastavené, aby odstraňovalo bloky vloženej dokumentácie. To zneprístupní niekoľko základných aplikácií.",
+    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "To je pravdepodobne spôsobené cache/akcelerátorom ako napr. Zend OPcache alebo eAccelerator.",
+    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Chýba modul 'fileinfo'. Dôrazne doporučujeme ho povoliť pre dosiahnutie najlepších výsledkov zisťovania mime-typu.",
+    "System locale can not be set to a one which supports UTF-8." : "Nie je možné nastaviť znakovú sadu, ktorá podporuje UTF-8.",
+    "This means that there might be problems with certain characters in file names." : "To znamená, že sa môžu vyskytnúť problémy s niektorými znakmi v názvoch súborov.",
+    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Dôrazne doporučujeme nainštalovať na váš systém požadované balíčky podporujúce jednu z nasledovných znakových sád: %s.",
+    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Inštalácia mimo koreňový priečinok domény a používanie systémového príkazu cron môže spôsobiť problém s generovaním správnej URL. Pre zabránenie týmto chybám nastavte prosím správnu cestu v svojom config.php súbore pre hodnotu \"overwrite.cli.url\" (Doporučujeme: \"%s\")",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "Ako databáza je použitá SQLite. Pre veľké inštalácie odporúčame prejsť na inú databázu.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Najmä pri používaní aplikácie na synchronizáciu s desktopom nie je databáza SQLite doporučená.",
+    "Tips & tricks" : "Tipy a triky",
     "How to do backups" : "Ako vytvárať zálohy",
     "Advanced monitoring" : "Pokročilé sledovanie",
     "Performance tuning" : "Ladenie výkonu",
     "Improving the config.php" : "Zlepšenie config.php",
     "Theming" : "Vzhľady tém",
     "Hardening and security guidance" : "Sprievodca vylepšením bezpečnosti",
-    "Version" : "Verzia",
-    "Developer documentation" : "Dokumentácia vývojára",
-    "Experimental applications ahead" : "Experimentálna aplikácia v poradí",
-    "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Experimentálne aplikácie nie sú preverované na bezpečnostné chyby, môžu byť nestabilné a veľmi sa meniť. Ich inštaláciou môžete spôsobiť stratu dát alebo bezpečnostné problémy.",
-    "Documentation:" : "Dokumentácia:",
-    "User documentation" : "Príručka používateľa",
-    "Admin documentation" : "Príručka administrátora",
-    "Show description …" : "Zobraziť popis …",
-    "Hide description …" : "Skryť popis …",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "Túto aplikáciu nemožno nainštalovať, pretože nie sú splnené nasledovné závislosti:",
-    "Enable only for specific groups" : "Povoliť len pre vybrané skupiny",
-    "Uninstall App" : "Odinštalovanie aplikácie",
-    "Enable experimental apps" : "Povoliť experimentálne aplikácie",
-    "Common Name" : "Bežný názov",
-    "Valid until" : "Platný do",
-    "Issued By" : "Vydal",
-    "Valid until %s" : "Platný do %s",
-    "Import root certificate" : "Importovať koreňový certifikát",
-    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Dobrý deň,<br><br>toto je oznámenie o novo vytvorenom účte %s.<br><br>Vaše používateľské meno: %s<br>Prihlásiť sa môžete tu: <a href=\"%s\">%s</a><br><br>",
-    "Cheers!" : "Pekný deň!",
-    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Ahoj,\n\ntoto je oznámenie o novo vytvorenom účte %s.\n\nVaše používateľské meno: %s\nPrihlásiť sa môžete tu: %s\n\n",
-    "Administrator documentation" : "Príručka administrátora",
-    "Online documentation" : "Online príručka",
-    "Forum" : "Fórum",
-    "Issue tracker" : "Zoznam chýb",
-    "Commercial support" : "Komerčná podpora",
+    "Get the apps to sync your files" : "Získať aplikácie na synchronizáciu vašich súborov",
+    "Desktop client" : "Desktopový klient",
+    "Android app" : "Android aplikácia",
+    "iOS app" : "iOS aplikácia",
+    "Show First Run Wizard again" : "Znovu zobraziť sprievodcu prvým spustením",
     "Profile picture" : "Avatar",
     "Upload new" : "Nahrať nový",
     "Remove image" : "Zmazať obrázok",
@@ -213,16 +203,15 @@ OC.L10N.register(
     "Change password" : "Zmeniť heslo",
     "Language" : "Jazyk",
     "Help translate" : "Pomôcť s prekladom",
+    "Unlimited" : "Nelimitované",
+    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Vyvinula {communityopen}komunita ownCloud{linkclose}. {githubopen}Zdrojový kód{linkclose} je dostupný za podmienok licencie {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
     "Name" : "Názov",
     "Username" : "Používateľské meno",
     "Done" : "Hotovo",
-    "Get the apps to sync your files" : "Získať aplikácie na synchronizáciu vašich súborov",
-    "Desktop client" : "Desktopový klient",
-    "Android app" : "Android aplikácia",
-    "iOS app" : "iOS aplikácia",
-    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Ak chcete projekt podporiť,\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">zapojte sa do vývoja</a>\n\t\talebo\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">ho propagujte</a>!",
-    "Show First Run Wizard again" : "Znovu zobraziť sprievodcu prvým spustením",
-    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Vyvinula {communityopen}komunita ownCloud{linkclose}. {githubopen}Zdrojový kód{linkclose} je dostupný za podmienok licencie {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
+    "Version" : "Verzia",
+    "Personal" : "Osobné",
+    "Admin" : "Administrácia",
+    "Error" : "Chyba",
     "Show storage location" : "Zobraziť umiestnenie úložiska",
     "Show last log in" : "Zobraziť posledné prihlásenie",
     "Show user backend" : "Zobraziť backend používateľa",
