@@ -1,33 +1,13 @@
 OC.L10N.register(
     "settings",
     {
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Security & setup warnings" : "Безбедносна и упозорења поставе",
-    "Sharing" : "Дељење",
-    "Server-side encryption" : "Шифровање на страни сервера",
-    "External Storage" : "Спољашње складиште",
-    "Cron" : "Крон",
-    "Email server" : "Сервер е-поште",
-    "Log" : "Бележење",
-    "Tips & tricks" : "Савети и трикови",
-    "Updates" : "Ажурирања",
-    "Couldn't remove app." : "Не могу да уклоним апликацију.",
-    "Language changed" : "Језик је промењен",
-    "Invalid request" : "Неисправан захтев",
-    "Authentication error" : "Грешка при провери идентитета",
-    "Admins can't remove themself from the admin group" : "Администратор не може себе да уклони из admin групе",
-    "Unable to add user to group %s" : "Не могу да додам корисника у групу %s",
-    "Unable to remove user from group %s" : "Не могу да уклоним корисника из групе %s",
-    "Couldn't update app." : "Не могу да ажурирам апликацију.",
     "Wrong password" : "Погрешна лозинка",
     "No user supplied" : "Није наведен корисник",
-    "Please provide an admin recovery password, otherwise all user data will be lost" : "Наведите администраторску лозинку опоравка. У супротном, сви кориснички подаци биће изгубљени.",
+    "Authentication error" : "Грешка при провери идентитета",
     "Wrong admin recovery password. Please check the password and try again." : "Погрешна администраторска лозинка опоравка. Проверите лозинку и покушајте поново.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Позадина не подржава измеу лозинке али кориснички шифрарски кључеви су успешно ажурирани.",
     "Unable to change password" : "Не могу да променим лозинку",
-    "Enabled" : "Укључено",
-    "Not enabled" : "Искључено",
+    "Couldn't send reset email. Please contact your administrator." : "Не могу да пошаљем е-пошту за ресетовање лозинке. Контактирајте администратора.",
     "Federated Cloud Sharing" : "Здружено дељење у облаку",
     "A problem occurred, please check your log files (Error: %s)" : "Појавио се проблем. Проверите записнике (грешка: %s)",
     "Migration Completed" : "Пресељење завршено",
@@ -48,23 +28,25 @@ OC.L10N.register(
     "Forbidden" : "Забрањено",
     "Invalid user" : "Неисправан корисник",
     "Unable to change mail address" : "Не могу да изменим е-адресу",
-    "Email saved" : "Е-порука сачувана",
     "Your full name has been changed." : "Ваше пуно име је промењено.",
     "Unable to change full name" : "Не могу да променим пуно име",
-    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Да ли заиста желите да додате „{domain}“ као поуздан домен?",
-    "Add trusted domain" : "Додај поуздан домен",
-    "Migration in progress. Please wait until the migration is finished" : "Пресељење је у току. Сачекајте док се не заврши",
-    "Migration started …" : "Пресељење покренуто...",
-    "Sending..." : "Шаљем...",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "__language_name__" : "Српски",
+    "Language changed" : "Језик је промењен",
+    "Invalid request" : "Неисправан захтев",
+    "Admins can't remove themself from the admin group" : "Администратор не може себе да уклони из admin групе",
+    "Unknown user" : "Непознат корисник",
+    "Couldn't remove app." : "Не могу да уклоним апликацију.",
     "Official" : "Званичне",
     "Approved" : "Одобрене",
-    "Experimental" : "Експерименталне",
     "All" : "Све",
+    "Enabled" : "Укључено",
+    "Not enabled" : "Искључено",
     "No apps found for your version" : "Нема апликација за вашу верзију",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Званичнe апликације су развиjене од стране и унутар оунКлауд заједнице. Оне пружају главне функционалности и спремне су и стабилне за свакодневну употребу.",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Одобрене апликације су развили проверени програмери и апликације су прошле основне безбедносне провере. Оне се активно одржавају у репозиторијуму за апликације отвореног кода и њихови одржаватељи сматрају да су стабилне за уобичајену употребу.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Ова апликација није проверена по питању безбедности и нова је или зна да буде нестабилна. Инсталирате је на сопствену одговорност.",
-    "Update to %s" : "Ажурирај на %s",
     "Please wait...." : "Сачекајте…",
     "Error while disabling app" : "Грешка при искључивању апликације",
     "Disable" : "Искључи",
@@ -76,9 +58,15 @@ OC.L10N.register(
     "Uninstalling ...." : "Деинсталирам ...",
     "Error while uninstalling app" : "Грешка при деинсталацији апликације",
     "Uninstall" : "Деинсталирај",
+    "Experimental" : "Експерименталне",
+    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Да ли заиста желите да додате „{domain}“ као поуздан домен?",
+    "Add trusted domain" : "Додај поуздан домен",
+    "Migration in progress. Please wait until the migration is finished" : "Пресељење је у току. Сачекајте док се не заврши",
+    "Migration started …" : "Пресељење покренуто...",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Дошло је до грешке. Отпремите АСКИ кодирани ПЕМ сертификат.",
     "Valid until {date}" : "Важи до {date}",
     "Delete" : "Обриши",
+    "Sending..." : "Шаљем...",
     "Select a profile picture" : "Изаберите слику профила",
     "Very weak password" : "Веома слаба лозинка",
     "Weak password" : "Слаба лозинка",
@@ -90,47 +78,61 @@ OC.L10N.register(
     "A valid group name must be provided" : "Мора бити наведено исправно име групе",
     "deleted {groupName}" : "обрисана {groupName}",
     "undo" : "опозови",
-    "no group" : "нема групе",
     "never" : "никада",
     "deleted {userName}" : "обрисан {userName}",
     "add group" : "додај групу",
+    "enabled" : "укључено",
+    "disabled" : "искључено",
+    "no group" : "нема групе",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "Измена лозинке ће резултирати губитком података јер опорављање података није доступно за овог корисника",
     "A valid username must be provided" : "Морате унети исправно корисничко име",
     "A valid password must be provided" : "Морате унети исправну лозинку",
     "A valid email must be provided" : "Мора бити наведена исправна е-адреса",
-    "__language_name__" : "Српски",
-    "Personal info" : "Лични подаци",
-    "Sync clients" : "Синхронизовање клијената",
-    "Everything (fatal issues, errors, warnings, info, debug)" : "Све (фаталне проблеме, грешке, упозорења, информације, отклањање грешака)",
-    "Info, warnings, errors and fatal issues" : "Информације, упозорења, грешке и фатални проблеми",
-    "Warnings, errors and fatal issues" : "Упозорења, грешке и фатални проблеми",
-    "Errors and fatal issues" : "Грешке и фатални проблеми",
-    "Fatal issues only" : "Само фатални проблеми",
-    "None" : "Ништа",
-    "Login" : "Пријава",
-    "Plain" : "Обичан",
-    "NT LAN Manager" : "НТ ЛАН менаџер",
-    "SSL" : "ССЛ",
-    "TLS" : "ТЛС",
-    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "ПХП није подешен да може да провери системске променљиве. Проба са getenv(\"PATH\") враћа празан одговор.",
-    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Омогућена је Само-читај конфигурација. То спречава постављање неке конфигурације преко веб-интерфејса. Осим тога, фајлу мора бити ручно омогућено уписивање код сваког освежавања.",
-    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "ПХП је очигледно подешен да се скида уметнуте док блокова. То ће учинити неколико кључних апликација недоступним.",
-    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ово је вероватно изазвано кешом или акцелератором као што су ЗендОПкеш или еАкцелератор.",
-    "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Ваш сервер ради под оперативним системом Microsoft Windows. Препоручујемо оперативни систем Linux за оптималaн кориснички доживљај.",
-    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Недостаје ПХП модул „fileinfo“. Препоручујемо вам да га укључите да бисте добили најбоље резултате с откривањем МИМЕ врста.",
-    "System locale can not be set to a one which supports UTF-8." : "Системски локалитет се не може поставити на неки који подржава УТФ-8",
-    "This means that there might be problems with certain characters in file names." : "То значи да може доћи до проблема са неким знаковима у називима фајлова.",
-    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Препоручујемо да инсталирате потребне пакете да бисте подржали следеће локалитете: %s",
-    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Ако инсталација није инсталирана у основи домена и користи системски крон, може бити проблема са генерисањем веб адреса. Да бисте избегли ове проблеме, молимо вас да подесите \"overwrite.cli.url\" опцију у вашем  config.php фајлу у путању веб-основе ваше инсталације (Предложено: \"%s\")",
-    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Није било могуће да се изврши крон задатак путем интерфејса командне линије. Појавила су се следеће техничке грешке:",
-    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Молимо вас да добро проверите <a target=\"_blank\" href=\"%s\">упутства за инсталацију ↗</a>, и да проверите ли постоје било какве грешке или упозорења у <a href=\"#log-section\">дневнику записа</a>.",
+    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Поздрав,<br><br>само вас обавештавам да сад имате %s налог.<br><br>Ваше корисничко име: %s<br>Приступите му на: <a href=\"%s\">%s</a><br><br>",
+    "Cheers!" : "Здраво!",
+    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Поздрав.\n\nСамо да знате да сада имате %s налог.\n\nВаше корисничко име: %s\nПриступите му на: %s\n",
+    "User documentation" : "Корисничка документација",
+    "Administrator documentation" : "Администраторска документација",
+    "Online documentation" : "Документација на мрежи",
+    "Forum" : "Форум",
+    "Issue tracker" : "Пратилац проблема",
+    "Commercial support" : "Комерцијална подршка",
+    "Developer documentation" : "Програмерска документација",
+    "Documentation:" : "Документација:",
+    "Admin documentation" : "Администраторска документација",
+    "Show description …" : "Прикажи опис…",
+    "Hide description …" : "Сакриј опис…",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "Апликација се не може инсталирати јер следеће зависности нису испуњене:",
+    "Enable only for specific groups" : "Укључи само за одређене групе",
+    "Uninstall App" : "Деинсталирај апликацију",
+    "Cron" : "Крон",
+    "Last cron job execution: %s." : "Последњи извршени крон задатак: %s.",
+    "Last cron job execution: %s. Something seems wrong." : "Последњи извршени крон задатак: %s. Нешто изгледа није у реду.",
+    "Cron was not executed yet!" : "Крон задатак још увек није извршен!",
     "Open documentation" : "Отвори документацију",
+    "Execute one task with each page loaded" : "Изврши један задатак са сваком учитаном страницом",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php је регистрован код  вебкрон сервиса за позивање cron.php сваких 15 минута преко протокола http.",
+    "Use system's cron service to call the cron.php file every 15 minutes." : "Користите системски крон сервис за позивање cron.php фајла сваких 15 минута.",
+    "Common Name" : "Уобичајено име",
+    "Valid until" : "Важи до",
+    "Issued By" : "Издавач",
+    "Valid until %s" : "Важи до %s",
+    "Import root certificate" : "Увоз кореног сертификата",
+    "Server-side encryption" : "Шифровање на страни сервера",
+    "Enable server-side encryption" : "Укључи шифровање на страни сервера",
+    "Enable encryption" : "Укључи шифровање",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "Шифрарски модул није учитан. Укључите га у менију апликација",
+    "Select default encryption module:" : "Изаберите подразумевани шифрарски модул:",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Морате да пребаците старе шифрарске кључеве (оунКлауд <= 8.0) на нови. Укључите „оунКлауд подразумевани шифрарски модул“ и покрените 'occ encryption:migrate'",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Морате да преселите шифрарске кључеве старог шифровања (оунКлауд <= 8.0) на нове.",
+    "Start migration" : "Покрени пресељење",
+    "Sharing" : "Дељење",
     "Allow apps to use the Share API" : "Дозвољава апликацијама да користе АПИ дељења",
     "Allow users to share via link" : "Дозволи корисницима да деле путем везе",
-    "Enforce password protection" : "Захтевај заштиту лозинком",
     "Allow public uploads" : "Дозволи јавна отпремања",
-    "Allow users to send mail notification for shared files" : "Дозволи корисницима да шаљу обавештења за дељене фајлове",
+    "Enforce password protection" : "Захтевај заштиту лозинком",
     "Set default expiration date" : "Постави подразумевано време истека",
+    "Allow users to send mail notification for shared files" : "Дозволи корисницима да шаљу обавештења за дељене фајлове",
     "Expire after " : "Истиче након",
     "days" : "дана",
     "Enforce expiration date" : "Захтевај датум истека",
@@ -139,19 +141,20 @@ OC.L10N.register(
     "Allow users to send mail notification for shared files to other users" : "Дозволи корисницима да шаљу обавештења е-поштом за дељене фајлове",
     "Exclude groups from sharing" : "Изузми групе из дељења",
     "These groups will still be able to receive shares, but not to initiate them." : "Ове групе ће моћи да примају дељења али не и да их праве.",
-    "Last cron job execution: %s." : "Последњи извршени крон задатак: %s.",
-    "Last cron job execution: %s. Something seems wrong." : "Последњи извршени крон задатак: %s. Нешто изгледа није у реду.",
-    "Cron was not executed yet!" : "Крон задатак још увек није извршен!",
-    "Execute one task with each page loaded" : "Изврши један задатак са сваком учитаном страницом",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php је регистрован код  вебкрон сервиса за позивање cron.php сваких 15 минута преко протокола http.",
-    "Use system's cron service to call the cron.php file every 15 minutes." : "Користите системски крон сервис за позивање cron.php фајла сваких 15 минута.",
-    "Enable server-side encryption" : "Укључи шифровање на страни сервера",
-    "Enable encryption" : "Укључи шифровање",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "Шифрарски модул није учитан. Укључите га у менију апликација",
-    "Select default encryption module:" : "Изаберите подразумевани шифрарски модул:",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Морате да пребаците старе шифрарске кључеве (оунКлауд <= 8.0) на нови. Укључите „оунКлауд подразумевани шифрарски модул“ и покрените 'occ encryption:migrate'",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Морате да преселите шифрарске кључеве старог шифровања (оунКлауд <= 8.0) на нове.",
-    "Start migration" : "Покрени пресељење",
+    "Everything (fatal issues, errors, warnings, info, debug)" : "Све (фаталне проблеме, грешке, упозорења, информације, отклањање грешака)",
+    "Info, warnings, errors and fatal issues" : "Информације, упозорења, грешке и фатални проблеми",
+    "Warnings, errors and fatal issues" : "Упозорења, грешке и фатални проблеми",
+    "Errors and fatal issues" : "Грешке и фатални проблеми",
+    "Fatal issues only" : "Само фатални проблеми",
+    "Log" : "Бележење",
+    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Фајл записника је већи од 100МБ. Преузимање може потрајати!",
+    "None" : "Ништа",
+    "Login" : "Пријава",
+    "Plain" : "Обичан",
+    "NT LAN Manager" : "НТ ЛАН менаџер",
+    "SSL/TLS" : "ССЛ/ТЛС",
+    "STARTTLS" : "СТАРТТЛС",
+    "Email server" : "Сервер е-поште",
     "This is used for sending out notifications." : "Ово се користи за слање обавештења.",
     "Send mode" : "Режим слања",
     "Encryption" : "Шифровање",
@@ -167,45 +170,31 @@ OC.L10N.register(
     "Store credentials" : "Сачувај акредитиве",
     "Test email settings" : "Тестирај поставке е-поште",
     "Send email" : "Пошаљи е-пошту",
-    "Download logfile" : "Преузми записник",
-    "More" : "Више",
-    "Less" : "Мање",
-    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Фајл записника је већи од 100МБ. Преузимање може потрајати!",
+    "Security & setup warnings" : "Безбедносна и упозорења поставе",
+    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "ПХП није подешен да може да провери системске променљиве. Проба са getenv(\"PATH\") враћа празан одговор.",
+    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Омогућена је Само-читај конфигурација. То спречава постављање неке конфигурације преко веб-интерфејса. Осим тога, фајлу мора бити ручно омогућено уписивање код сваког освежавања.",
+    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "ПХП је очигледно подешен да се скида уметнуте док блокова. То ће учинити неколико кључних апликација недоступним.",
+    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ово је вероватно изазвано кешом или акцелератором као што су ЗендОПкеш или еАкцелератор.",
+    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Недостаје ПХП модул „fileinfo“. Препоручујемо вам да га укључите да бисте добили најбоље резултате с откривањем МИМЕ врста.",
+    "System locale can not be set to a one which supports UTF-8." : "Системски локалитет се не може поставити на неки који подржава УТФ-8",
+    "This means that there might be problems with certain characters in file names." : "То значи да може доћи до проблема са неким знаковима у називима фајлова.",
+    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Препоручујемо да инсталирате потребне пакете да бисте подржали следеће локалитете: %s",
+    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Ако инсталација није инсталирана у основи домена и користи системски крон, може бити проблема са генерисањем веб адреса. Да бисте избегли ове проблеме, молимо вас да подесите \"overwrite.cli.url\" опцију у вашем  config.php фајлу у путању веб-основе ваше инсталације (Предложено: \"%s\")",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite се користи као базе података. За веће инсталације препоручујемо да се пребаците на други модел базе података.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Нарочито ако се користи клијент програм у графичком окружењу, коришћење СКуЛајта није препоручљиво.",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "За миграцију на другу базу користите командну линију: 'occ db:convert-type', или погледајте <a target=\"_blank\" href=\"%s\">документацију ↗</a>.",
+    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Није било могуће да се изврши крон задатак путем интерфејса командне линије. Појавила су се следеће техничке грешке:",
+    "Tips & tricks" : "Савети и трикови",
     "How to do backups" : "Како правити резерве",
     "Advanced monitoring" : "Напредно праћење",
     "Performance tuning" : "Побољшање перформанси",
     "Improving the config.php" : "Побољшање фајла поставки",
     "Theming" : "Теме",
     "Hardening and security guidance" : "Ојачавање система и безбедносне препоруке",
-    "Version" : "Верзија",
-    "Developer documentation" : "Програмерска документација",
-    "Experimental applications ahead" : "Експериментална апликација",
-    "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Експерименталне апликације се непроверене што се тиче безбедности и могу бити нестабилне и недовршене. Инсталирање може довести до губитка података или нарушавања безбедности.",
-    "Documentation:" : "Документација:",
-    "User documentation" : "Корисничка документација",
-    "Admin documentation" : "Администраторска документација",
-    "Show description …" : "Прикажи опис…",
-    "Hide description …" : "Сакриј опис…",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "Апликација се не може инсталирати јер следеће зависности нису испуњене:",
-    "Enable only for specific groups" : "Укључи само за одређене групе",
-    "Uninstall App" : "Деинсталирај апликацију",
-    "Enable experimental apps" : "Укључи експерименталне апликације",
-    "Common Name" : "Уобичајено име",
-    "Valid until" : "Важи до",
-    "Issued By" : "Издавач",
-    "Valid until %s" : "Важи до %s",
-    "Import root certificate" : "Увоз кореног сертификата",
-    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Поздрав,<br><br>само вас обавештавам да сад имате %s налог.<br><br>Ваше корисничко име: %s<br>Приступите му на: <a href=\"%s\">%s</a><br><br>",
-    "Cheers!" : "Здраво!",
-    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Поздрав.\n\nСамо да знате да сада имате %s налог.\n\nВаше корисничко име: %s\nПриступите му на: %s\n",
-    "Administrator documentation" : "Администраторска документација",
-    "Online documentation" : "Документација на мрежи",
-    "Forum" : "Форум",
-    "Issue tracker" : "Пратилац проблема",
-    "Commercial support" : "Комерцијална подршка",
+    "Get the apps to sync your files" : "Преузмите апликације ради синхронизовања ваших фајлова",
+    "Desktop client" : "Клијент за рачунар",
+    "Android app" : "Андроид апликација",
+    "iOS app" : "иОС апликација",
+    "Show First Run Wizard again" : "Поново прикажи чаробњака за прво покретање",
     "Profile picture" : "Слика профила",
     "Upload new" : "Отпреми нову",
     "Remove image" : "Уклони слику",
@@ -223,19 +212,20 @@ OC.L10N.register(
     "Change password" : "Измени лозинку",
     "Language" : "Језик",
     "Help translate" : " Помозите у превођењу",
-    "Get the apps to sync your files" : "Преузмите апликације ради синхронизовања ваших фајлова",
-    "Desktop client" : "Клијент за рачунар",
-    "Android app" : "Андроид апликација",
-    "iOS app" : "иОС апликација",
-    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Ако желите да подржите пројект\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">придружите се развоју</a>\n\t\tили\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">разгласите свима</a>!",
-    "Show First Run Wizard again" : "Поново прикажи чаробњака за прво покретање",
+    "Unlimited" : "Неограничено",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Развијено од стране {communityopen}оунКлауд заједнице{linkclose}, {githubopen}изворни код{linkclose} је лиценциран под {licenseopen}<abbr title=\"Аферо општа јавна лиценца\">АОЈЛ (AGPL)</abbr>{linkclose}.",
+    "Name" : "назив",
+    "Username" : "Корисничко име",
+    "Done" : "Завршено",
+    "Version" : "Верзија",
+    "Personal" : "Лично",
+    "Admin" : "Администрација",
+    "Error" : "Грешка",
     "Show storage location" : "Прикажи локацију складишта",
     "Show last log in" : "Прикажи последњу пријаву",
     "Show user backend" : "Прикажи позадину за кориснике",
     "Send email to new user" : "Пошаљи е-пошту новом кориснику",
     "Show email address" : "Прикажи е-адресу",
-    "Username" : "Корисничко име",
     "E-Mail" : "Е-пошта",
     "Create" : "Направи",
     "Admin Recovery Password" : "Администраторска лозинка за опоравак",
@@ -246,7 +236,6 @@ OC.L10N.register(
     "Admins" : "Администратори",
     "Default Quota" : "Подразумевана квота",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Унесите квоту складиштења (нпр. 512 MB или 12 GB)",
-    "Unlimited" : "Неограничено",
     "Other" : "Друго",
     "Full Name" : "Пуно име",
     "Group Admin for" : "Администратор група",
